
module Make

# 42 "asllib/Parser.mly"
          (Config : ParserConfig.CONFIG)
# 7 "asllib/Parser.ml"

= struct
  
  module MenhirBasics = struct
    
    exception Error
    
    let _eRR =
      fun _s ->
        raise Error
    
    type token = Tokens.token
    
  end
  
  include MenhirBasics
  
# 50 "asllib/Parser.mly"
  

open AST
open ASTUtils
open Desugar

let version = V1

let t_bit =
  T_Bits (E_Literal (L_Int Z.one) |> add_dummy_annotation ~version, [])

let zero = E_Literal (L_Int Z.zero) |> add_dummy_annotation ~version

let make_ldi_vars (xs, ty) =
  let make_one x =
    S_Decl (LDK_Var, LDI_Typed (LDI_Var x, ty), None)
    |> add_dummy_annotation ~version
  in
  List.map make_one xs |> stmt_from_list |> desc

let make_ty_decl_subtype (x, s) =
  let name, _fields = s.desc in
  let ty = ASTUtils.add_pos_from s (T_Named name) in
  D_TypeDecl (x, ty, Some s.desc)

let prec =
  let open AST in
  function
  | BOR | BAND | IMPL | BEQ -> 1
  | EQ_OP | NEQ -> 2
  | PLUS | MINUS | OR | EOR | AND -> 3
  | MUL | DIV | DIVRM | RDIV | MOD | SHL | SHR -> 4
  | POW -> 5
  | _ -> 0 (* Non assoc *)

let check_not_same_prec loc op op' =
  if prec op = prec op' then Error.(fatal_from loc CannotParse)

let check_not_binop_same_prec op e =
  match e.desc with
  | E_Binop (op', _, _) when op != op' -> check_not_same_prec e op op'
  | _ -> ()

let e_binop (e1, op, e2) =
  let () = check_not_binop_same_prec op e1
  and () = check_not_binop_same_prec op e2
  in
  E_Binop (op, e1, e2)

let e_call call = E_Call { call with call_type = ST_Function }
let s_call call = S_Call { call with call_type = ST_Procedure }


# 79 "asllib/Parser.ml"
  
  type ('s, 'r) _menhir_state = 
    | MenhirState0000 : ('s, _menhir_box_opn) _menhir_state
      (** State 0000.
        Stack shape : .
        Start symbol: opn. *)

    | MenhirState0001 : (('s, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_state
      (** State 0001.
        Stack shape : WHILE.
        Start symbol: opn. *)

    | MenhirState0003 : (('s, 'r) _menhir_cell1_UNKNOWN, 'r) _menhir_state
      (** State 0003.
        Stack shape : UNKNOWN.
        Start symbol: <undetermined>. *)

    | MenhirState0006 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 0006.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0009 : (('s, 'r) _menhir_cell1_INTEGER _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0009.
        Stack shape : INTEGER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0013 : (('s, 'r) _menhir_cell1_NOT, 'r) _menhir_state
      (** State 0013.
        Stack shape : NOT.
        Start symbol: <undetermined>. *)

    | MenhirState0014 : (('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 0014.
        Stack shape : MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState0015 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 0015.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0017 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 0017.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState0019 : (('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 0019.
        Stack shape : IDENTIFIER LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0022 : (('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_state
      (** State 0022.
        Stack shape : BNOT.
        Start symbol: <undetermined>. *)

    | MenhirState0024 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0024.
        Stack shape : BNOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0025 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_state
      (** State 0025.
        Stack shape : expr LLBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState0026 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LLBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0026.
        Stack shape : expr LLBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState0027 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHR, 'r) _menhir_state
      (** State 0027.
        Stack shape : expr SHR.
        Start symbol: <undetermined>. *)

    | MenhirState0028 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0028.
        Stack shape : expr SHR expr.
        Start symbol: <undetermined>. *)

    | MenhirState0029 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_POW, 'r) _menhir_state
      (** State 0029.
        Stack shape : expr POW.
        Start symbol: <undetermined>. *)

    | MenhirState0030 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_POW, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0030.
        Stack shape : expr POW expr.
        Start symbol: <undetermined>. *)

    | MenhirState0031 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_state
      (** State 0031.
        Stack shape : expr LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState0032 : (('s, 'r) _menhir_cell1_COLON, 'r) _menhir_state
      (** State 0032.
        Stack shape : COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0033 : ((('s, 'r) _menhir_cell1_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0033.
        Stack shape : COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState0034 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHL, 'r) _menhir_state
      (** State 0034.
        Stack shape : expr SHL.
        Start symbol: <undetermined>. *)

    | MenhirState0035 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SHL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0035.
        Stack shape : expr SHL expr.
        Start symbol: <undetermined>. *)

    | MenhirState0037 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IN _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0037.
        Stack shape : expr IN LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0039 : (('s, 'r) _menhir_cell1_UNKNOWN, 'r) _menhir_state
      (** State 0039.
        Stack shape : UNKNOWN.
        Start symbol: <undetermined>. *)

    | MenhirState0043 : (('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 0043.
        Stack shape : BITS LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0044 : ((('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0044.
        Stack shape : BITS LPAR expr.
        Start symbol: <undetermined>. *)

    | MenhirState0046 : (((('s, 'r) _menhir_cell1_BITS _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0046.
        Stack shape : BITS LPAR expr RPAR LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0047 : (('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_state
      (** State 0047.
        Stack shape : LBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState0051 : ((('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0051.
        Stack shape : LBRACKET separated_nonempty_list(COMMA,slice) RBRACKET IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0055 : (((('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_loption_non_empty_trailing_list_COMMA_bitfield__ _menhir_cell0_RBRACE, 'r) _menhir_state
      (** State 0055.
        Stack shape : LBRACKET separated_nonempty_list(COMMA,slice) RBRACKET IDENTIFIER LBRACE loption(non_empty_trailing_list(COMMA,bitfield)) RBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0057 : ((('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 0057.
        Stack shape : LBRACKET separated_nonempty_list(COMMA,slice) RBRACKET IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0059 : ((('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 0059.
        Stack shape : LBRACKET separated_nonempty_list(COMMA,slice) RBRACKET IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0062 : (('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_state
      (** State 0062.
        Stack shape : ARRAY.
        Start symbol: <undetermined>. *)

    | MenhirState0063 : ((('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0063.
        Stack shape : ARRAY expr.
        Start symbol: <undetermined>. *)

    | MenhirState0064 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RDIV, 'r) _menhir_state
      (** State 0064.
        Stack shape : expr RDIV.
        Start symbol: <undetermined>. *)

    | MenhirState0065 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RDIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0065.
        Stack shape : expr RDIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState0067 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOT, 'r) _menhir_state
      (** State 0067.
        Stack shape : expr DOT.
        Start symbol: <undetermined>. *)

    | MenhirState0069 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 0069.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0074 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_CONCAT, 'r) _menhir_state
      (** State 0074.
        Stack shape : expr CONCAT.
        Start symbol: <undetermined>. *)

    | MenhirState0075 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_CONCAT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0075.
        Stack shape : expr CONCAT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0077 : (((('s, 'r) _menhir_cell1_ARRAY, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RBRACKET, 'r) _menhir_state
      (** State 0077.
        Stack shape : ARRAY expr RBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState0079 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS, 'r) _menhir_state
      (** State 0079.
        Stack shape : expr PLUS.
        Start symbol: <undetermined>. *)

    | MenhirState0080 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0080.
        Stack shape : expr PLUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState0081 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MUL, 'r) _menhir_state
      (** State 0081.
        Stack shape : expr MUL.
        Start symbol: <undetermined>. *)

    | MenhirState0082 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MUL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0082.
        Stack shape : expr MUL expr.
        Start symbol: <undetermined>. *)

    | MenhirState0083 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MOD, 'r) _menhir_state
      (** State 0083.
        Stack shape : expr MOD.
        Start symbol: <undetermined>. *)

    | MenhirState0084 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MOD, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0084.
        Stack shape : expr MOD expr.
        Start symbol: <undetermined>. *)

    | MenhirState0085 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIVRM, 'r) _menhir_state
      (** State 0085.
        Stack shape : expr DIVRM.
        Start symbol: <undetermined>. *)

    | MenhirState0086 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIVRM, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0086.
        Stack shape : expr DIVRM expr.
        Start symbol: <undetermined>. *)

    | MenhirState0087 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIV, 'r) _menhir_state
      (** State 0087.
        Stack shape : expr DIV.
        Start symbol: <undetermined>. *)

    | MenhirState0088 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DIV, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0088.
        Stack shape : expr DIV expr.
        Start symbol: <undetermined>. *)

    | MenhirState0089 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OR, 'r) _menhir_state
      (** State 0089.
        Stack shape : expr OR.
        Start symbol: <undetermined>. *)

    | MenhirState0090 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0090.
        Stack shape : expr OR expr.
        Start symbol: <undetermined>. *)

    | MenhirState0091 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_NEQ, 'r) _menhir_state
      (** State 0091.
        Stack shape : expr NEQ.
        Start symbol: <undetermined>. *)

    | MenhirState0093 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_NEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0093.
        Stack shape : expr NEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState0094 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 0094.
        Stack shape : expr MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState0095 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0095.
        Stack shape : expr MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState0096 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LT, 'r) _menhir_state
      (** State 0096.
        Stack shape : expr LT.
        Start symbol: <undetermined>. *)

    | MenhirState0097 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0097.
        Stack shape : expr LT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0098 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_EOR, 'r) _menhir_state
      (** State 0098.
        Stack shape : expr EOR.
        Start symbol: <undetermined>. *)

    | MenhirState0099 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_EOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0099.
        Stack shape : expr EOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState0100 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_state
      (** State 0100.
        Stack shape : expr COLON_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0101 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0101.
        Stack shape : expr COLON_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState0102 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AND, 'r) _menhir_state
      (** State 0102.
        Stack shape : expr AND.
        Start symbol: <undetermined>. *)

    | MenhirState0103 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0103.
        Stack shape : expr AND expr.
        Start symbol: <undetermined>. *)

    | MenhirState0104 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LEQ, 'r) _menhir_state
      (** State 0104.
        Stack shape : expr LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState0105 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0105.
        Stack shape : expr LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState0106 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GT, 'r) _menhir_state
      (** State 0106.
        Stack shape : expr GT.
        Start symbol: <undetermined>. *)

    | MenhirState0107 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0107.
        Stack shape : expr GT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0108 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GEQ, 'r) _menhir_state
      (** State 0108.
        Stack shape : expr GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState0109 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0109.
        Stack shape : expr GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState0110 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IMPL, 'r) _menhir_state
      (** State 0110.
        Stack shape : expr IMPL.
        Start symbol: <undetermined>. *)

    | MenhirState0111 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IMPL, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0111.
        Stack shape : expr IMPL expr.
        Start symbol: <undetermined>. *)

    | MenhirState0112 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_state
      (** State 0112.
        Stack shape : expr EQ_OP.
        Start symbol: <undetermined>. *)

    | MenhirState0114 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_EQ_OP, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0114.
        Stack shape : expr EQ_OP expr.
        Start symbol: <undetermined>. *)

    | MenhirState0115 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BOR, 'r) _menhir_state
      (** State 0115.
        Stack shape : expr BOR.
        Start symbol: <undetermined>. *)

    | MenhirState0116 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BOR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0116.
        Stack shape : expr BOR expr.
        Start symbol: <undetermined>. *)

    | MenhirState0117 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BEQ, 'r) _menhir_state
      (** State 0117.
        Stack shape : expr BEQ.
        Start symbol: <undetermined>. *)

    | MenhirState0118 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0118.
        Stack shape : expr BEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState0119 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BAND, 'r) _menhir_state
      (** State 0119.
        Stack shape : expr BAND.
        Start symbol: <undetermined>. *)

    | MenhirState0120 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_BAND, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0120.
        Stack shape : expr BAND expr.
        Start symbol: <undetermined>. *)

    | MenhirState0121 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AS, 'r) _menhir_state
      (** State 0121.
        Stack shape : expr AS.
        Start symbol: <undetermined>. *)

    | MenhirState0122 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_AS, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 0122.
        Stack shape : expr AS LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0126 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0126.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState0127 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SLICING, 'r) _menhir_state
      (** State 0127.
        Stack shape : expr SLICING.
        Start symbol: <undetermined>. *)

    | MenhirState0128 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SLICING, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0128.
        Stack shape : expr SLICING expr.
        Start symbol: <undetermined>. *)

    | MenhirState0129 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SLICING, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0129.
        Stack shape : expr SLICING expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0131 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0131.
        Stack shape : expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0135 : (((('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 0135.
        Stack shape : LBRACKET separated_nonempty_list(COMMA,slice) RBRACKET IDENTIFIER ty.
        Start symbol: <undetermined>. *)

    | MenhirState0137 : ((('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 0137.
        Stack shape : LBRACKET separated_nonempty_list(COMMA,slice) RBRACKET IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0139 : (((('s, 'r) _menhir_cell1_LBRACKET, 'r) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 0139.
        Stack shape : LBRACKET separated_nonempty_list(COMMA,slice) RBRACKET IDENTIFIER ty.
        Start symbol: <undetermined>. *)

    | MenhirState0141 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0141.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState0142 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_STAR_COLON, 'r) _menhir_state
      (** State 0142.
        Stack shape : expr STAR_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0143 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_STAR_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0143.
        Stack shape : expr STAR_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState0144 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_STAR_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0144.
        Stack shape : expr STAR_COLON expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0146 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS_COLON, 'r) _menhir_state
      (** State 0146.
        Stack shape : expr PLUS_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0147 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0147.
        Stack shape : expr PLUS_COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState0148 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_PLUS_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0148.
        Stack shape : expr PLUS_COLON expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0150 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0150.
        Stack shape : expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0152 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON, 'r) _menhir_state
      (** State 0152.
        Stack shape : expr COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0153 : (((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0153.
        Stack shape : expr COLON expr.
        Start symbol: <undetermined>. *)

    | MenhirState0154 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0154.
        Stack shape : expr COLON expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0160 : (('s, 'r) _menhir_cell1_UNKNOWN, 'r) _menhir_state
      (** State 0160.
        Stack shape : UNKNOWN.
        Start symbol: <undetermined>. *)

    | MenhirState0164 : (('s, 'r) _menhir_cell1_NOT, 'r) _menhir_state
      (** State 0164.
        Stack shape : NOT.
        Start symbol: <undetermined>. *)

    | MenhirState0165 : ((('s, 'r) _menhir_cell1_NOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0165.
        Stack shape : NOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0166 : (('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 0166.
        Stack shape : MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState0167 : ((('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0167.
        Stack shape : MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState0169 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 0169.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0170 : (('s, 'r) _menhir_cell1_LEQ, 'r) _menhir_state
      (** State 0170.
        Stack shape : LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState0171 : ((('s, 'r) _menhir_cell1_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0171.
        Stack shape : LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState0172 : (('s, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 0172.
        Stack shape : LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0174 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 0174.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState0175 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0175.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState0176 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 0176.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState0177 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0177.
        Stack shape : IF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState0178 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_state
      (** State 0178.
        Stack shape : expr THEN expr ELSIF.
        Start symbol: <undetermined>. *)

    | MenhirState0179 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0179.
        Stack shape : expr THEN expr ELSIF expr.
        Start symbol: <undetermined>. *)

    | MenhirState0180 : ((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 0180.
        Stack shape : expr THEN expr ELSIF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState0181 : (((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0181.
        Stack shape : expr THEN expr ELSIF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState0182 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSE, 'r) _menhir_state
      (** State 0182.
        Stack shape : expr THEN expr ELSE.
        Start symbol: <undetermined>. *)

    | MenhirState0183 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ELSE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0183.
        Stack shape : expr THEN expr ELSE expr.
        Start symbol: <undetermined>. *)

    | MenhirState0187 : (('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 0187.
        Stack shape : IDENTIFIER LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0191 : (('s, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0191.
        Stack shape : expr.
        Start symbol: <undetermined>. *)

    | MenhirState0192 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0192.
        Stack shape : expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0194 : (('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0194.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0197 : (('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0197.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0202 : ((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_state
      (** State 0202.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0203 : ((('s, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 0203.
        Stack shape : separated_nonempty_list(COMMA,expr) RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0208 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 0208.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0209 : ((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0209.
        Stack shape : IDENTIFIER expr.
        Start symbol: <undetermined>. *)

    | MenhirState0210 : (((('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0210.
        Stack shape : IDENTIFIER expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0216 : ((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_state
      (** State 0216.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0218 : (('s, 'r) _menhir_cell1_GEQ, 'r) _menhir_state
      (** State 0218.
        Stack shape : GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState0219 : ((('s, 'r) _menhir_cell1_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0219.
        Stack shape : GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState0221 : (('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_state
      (** State 0221.
        Stack shape : BNOT.
        Start symbol: <undetermined>. *)

    | MenhirState0222 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 0222.
        Stack shape : BNOT LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0227 : (('s, 'r) _menhir_cell1_pattern, 'r) _menhir_state
      (** State 0227.
        Stack shape : pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0230 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0230.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0231 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0231.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0232 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0232.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0233 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0233.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0234 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0234.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0235 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0235.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0236 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0236.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0237 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0237.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0238 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0238.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0239 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0239.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0240 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0240.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0241 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0241.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0242 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0242.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0243 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0243.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0244 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0244.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0246 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0246.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0247 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0247.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0248 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0248.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0249 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0249.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0250 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0250.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0251 : (('s, 'r) _menhir_cell1_expr_pattern _menhir_cell0_MINUS, 'r) _menhir_state
      (** State 0251.
        Stack shape : expr_pattern MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState0252 : ((('s, 'r) _menhir_cell1_expr_pattern _menhir_cell0_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0252.
        Stack shape : expr_pattern MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState0253 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0253.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0254 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0254.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0255 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0255.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0256 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0256.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0258 : (('s, 'r) _menhir_cell1_expr_pattern _menhir_cell0_LEQ, 'r) _menhir_state
      (** State 0258.
        Stack shape : expr_pattern LEQ.
        Start symbol: <undetermined>. *)

    | MenhirState0259 : ((('s, 'r) _menhir_cell1_expr_pattern _menhir_cell0_LEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0259.
        Stack shape : expr_pattern LEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState0260 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0260.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0264 : (('s, 'r) _menhir_cell1_expr_pattern _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0264.
        Stack shape : expr_pattern LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0268 : (('s, 'r) _menhir_cell1_expr_pattern _menhir_cell0_BNOT _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0268.
        Stack shape : expr_pattern BNOT LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0271 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0271.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0272 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0272.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0273 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0273.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0274 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0274.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0275 : (('s, 'r) _menhir_cell1_expr_pattern _menhir_cell0_GEQ, 'r) _menhir_state
      (** State 0275.
        Stack shape : expr_pattern GEQ.
        Start symbol: <undetermined>. *)

    | MenhirState0276 : ((('s, 'r) _menhir_cell1_expr_pattern _menhir_cell0_GEQ, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0276.
        Stack shape : expr_pattern GEQ expr.
        Start symbol: <undetermined>. *)

    | MenhirState0277 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0277.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0279 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0279.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0280 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0280.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0281 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0281.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0283 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0283.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0287 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0287.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0288 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0288.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0289 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0289.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0290 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0290.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0291 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0291.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0292 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0292.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0293 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0293.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0294 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0294.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0295 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0295.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0296 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0296.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0297 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0297.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0298 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0298.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0299 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0299.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0300 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0300.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0301 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0301.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0302 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_LBRACE, 'r) _menhir_state
      (** State 0302.
        Stack shape : expr_pattern LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0307 : (('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_state
      (** State 0307.
        Stack shape : expr_pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0308 : ((('s, 'r) _menhir_cell1_expr_pattern, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0308.
        Stack shape : expr_pattern expr.
        Start symbol: <undetermined>. *)

    | MenhirState0309 : ((('s, 'r) _menhir_cell1_BNOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0309.
        Stack shape : BNOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0313 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_pattern, 'r) _menhir_state
      (** State 0313.
        Stack shape : LPAR pattern.
        Start symbol: <undetermined>. *)

    | MenhirState0321 : ((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_IN _menhir_cell0_BNOT _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0321.
        Stack shape : expr IN BNOT LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0324 : (((('s, 'r) _menhir_cell1_COLON, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0324.
        Stack shape : COLON expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0331 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0331.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState0332 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 0332.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState0333 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0333.
        Stack shape : IF expr THEN expr.
        Start symbol: <undetermined>. *)

    | MenhirState0335 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0335.
        Stack shape : LPAR expr.
        Start symbol: <undetermined>. *)

    | MenhirState0337 : (((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0337.
        Stack shape : LPAR expr COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0340 : ((('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0340.
        Stack shape : MINUS expr.
        Start symbol: <undetermined>. *)

    | MenhirState0341 : ((('s, 'r) _menhir_cell1_NOT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0341.
        Stack shape : NOT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0345 : (('s, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 0345.
        Stack shape : ty.
        Start symbol: <undetermined>. *)

    | MenhirState0350 : (('s, 'r) _menhir_cell1_UNKNOWN, 'r) _menhir_state
      (** State 0350.
        Stack shape : UNKNOWN.
        Start symbol: <undetermined>. *)

    | MenhirState0352 : ((('s, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0352.
        Stack shape : WHILE expr.
        Start symbol: opn. *)

    | MenhirState0353 : (((('s, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_state
      (** State 0353.
        Stack shape : WHILE expr LOOPLIMIT.
        Start symbol: opn. *)

    | MenhirState0354 : ((((('s, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0354.
        Stack shape : WHILE expr LOOPLIMIT expr.
        Start symbol: opn. *)

    | MenhirState0355 : (((((('s, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_state
      (** State 0355.
        Stack shape : WHILE expr LOOPLIMIT expr DO.
        Start symbol: opn. *)

    | MenhirState0356 : (('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_state
      (** State 0356.
        Stack shape : WHILE.
        Start symbol: <undetermined>. *)

    | MenhirState0357 : ((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0357.
        Stack shape : WHILE expr.
        Start symbol: <undetermined>. *)

    | MenhirState0358 : (((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_state
      (** State 0358.
        Stack shape : WHILE expr LOOPLIMIT.
        Start symbol: <undetermined>. *)

    | MenhirState0359 : ((((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0359.
        Stack shape : WHILE expr LOOPLIMIT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0360 : (((((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_state
      (** State 0360.
        Stack shape : WHILE expr LOOPLIMIT expr DO.
        Start symbol: <undetermined>. *)

    | MenhirState0361 : (('s, 'r) _menhir_cell1_VAR, 'r) _menhir_state
      (** State 0361.
        Stack shape : VAR.
        Start symbol: <undetermined>. *)

    | MenhirState0363 : (('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 0363.
        Stack shape : MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState0365 : (('s, 'r) _menhir_cell1_MINUS, 'r) _menhir_state
      (** State 0365.
        Stack shape : MINUS.
        Start symbol: <undetermined>. *)

    | MenhirState0367 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 0367.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0369 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 0369.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0371 : (('s, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 0371.
        Stack shape : IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0374 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 0374.
        Stack shape : LPAR decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState0377 : (((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_separated_nonempty_list_COMMA_decl_item_ _menhir_cell0_RPAR, 'r) _menhir_state
      (** State 0377.
        Stack shape : LPAR decl_item separated_nonempty_list(COMMA,decl_item) RPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0379 : (((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_separated_nonempty_list_COMMA_decl_item_ _menhir_cell0_RPAR, 'r) _menhir_state
      (** State 0379.
        Stack shape : LPAR decl_item separated_nonempty_list(COMMA,decl_item) RPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0382 : ((('s, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 0382.
        Stack shape : decl_item decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState0385 : ((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 0385.
        Stack shape : VAR IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0387 : (((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_, 'r) _menhir_state
      (** State 0387.
        Stack shape : VAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER).
        Start symbol: <undetermined>. *)

    | MenhirState0389 : ((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_, 'r) _menhir_cell1_ty _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0389.
        Stack shape : VAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) ty SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0393 : (('s, 'r) _menhir_cell1_UNREACHABLE _menhir_cell0_LPAR _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0393.
        Stack shape : UNREACHABLE LPAR RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0394 : (('s, 'r) _menhir_cell1_TRY, 'r) _menhir_state
      (** State 0394.
        Stack shape : TRY.
        Start symbol: <undetermined>. *)

    | MenhirState0395 : (('s, 'r) _menhir_cell1_THROW, 'r) _menhir_state
      (** State 0395.
        Stack shape : THROW.
        Start symbol: <undetermined>. *)

    | MenhirState0396 : ((('s, 'r) _menhir_cell1_THROW, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0396.
        Stack shape : THROW SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0397 : (('s, 'r) _menhir_cell1_RETURN, 'r) _menhir_state
      (** State 0397.
        Stack shape : RETURN.
        Start symbol: <undetermined>. *)

    | MenhirState0398 : ((('s, 'r) _menhir_cell1_RETURN, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0398.
        Stack shape : RETURN SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0399 : (('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_state
      (** State 0399.
        Stack shape : REPEAT.
        Start symbol: <undetermined>. *)

    | MenhirState0401 : (('s, 'r) _menhir_cell1_PRINT _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 0401.
        Stack shape : PRINT LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0403 : ((('s, 'r) _menhir_cell1_PRINT _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0403.
        Stack shape : PRINT LPAR RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0405 : (('s, 'r) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 0405.
        Stack shape : PRAGMA IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0406 : ((('s, 'r) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0406.
        Stack shape : PRAGMA IDENTIFIER SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0408 : (('s, 'r) _menhir_cell1_PASS _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0408.
        Stack shape : PASS SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0410 : (('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_state
      (** State 0410.
        Stack shape : LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0413 : (('s, 'r) _menhir_cell1_lexpr_atom_desc, 'r) _menhir_state
      (** State 0413.
        Stack shape : lexpr_atom_desc.
        Start symbol: <undetermined>. *)

    | MenhirState0414 : ((('s, 'r) _menhir_cell1_lexpr_atom_desc, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0414.
        Stack shape : lexpr_atom_desc expr.
        Start symbol: <undetermined>. *)

    | MenhirState0416 : (('s, 'r) _menhir_cell1_lexpr_atom_desc, 'r) _menhir_state
      (** State 0416.
        Stack shape : lexpr_atom_desc.
        Start symbol: <undetermined>. *)

    | MenhirState0420 : (('s, 'r) _menhir_cell1_lexpr_atom_desc, 'r) _menhir_state
      (** State 0420.
        Stack shape : lexpr_atom_desc.
        Start symbol: <undetermined>. *)

    | MenhirState0426 : ((('s, 'r) _menhir_cell1_LPAR, 'r) _menhir_cell1_lexpr, 'r) _menhir_state
      (** State 0426.
        Stack shape : LPAR lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState0430 : ((('s, 'r) _menhir_cell1_lexpr, 'r) _menhir_cell1_lexpr, 'r) _menhir_state
      (** State 0430.
        Stack shape : lexpr lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState0432 : (('s, 'r) _menhir_cell1_LET, 'r) _menhir_state
      (** State 0432.
        Stack shape : LET.
        Start symbol: <undetermined>. *)

    | MenhirState0434 : ((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 0434.
        Stack shape : LET decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState0436 : (((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0436.
        Stack shape : LET decl_item IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0438 : ((((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 0438.
        Stack shape : LET decl_item IDENTIFIER LBRACE RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0440 : (((((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0440.
        Stack shape : LET decl_item IDENTIFIER LBRACE RBRACE LPAR RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0441 : (('s, 'r) _menhir_cell1_IF, 'r) _menhir_state
      (** State 0441.
        Stack shape : IF.
        Start symbol: <undetermined>. *)

    | MenhirState0442 : ((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0442.
        Stack shape : IF expr.
        Start symbol: <undetermined>. *)

    | MenhirState0443 : (((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 0443.
        Stack shape : IF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState0445 : (('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 0445.
        Stack shape : IDENTIFIER LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0447 : ((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0447.
        Stack shape : IDENTIFIER LPAR RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0450 : (('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 0450.
        Stack shape : FOR IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0451 : ((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0451.
        Stack shape : FOR IDENTIFIER expr.
        Start symbol: <undetermined>. *)

    | MenhirState0452 : (((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_TO, 'r) _menhir_state
      (** State 0452.
        Stack shape : FOR IDENTIFIER expr TO.
        Start symbol: <undetermined>. *)

    | MenhirState0453 : ((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_TO, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0453.
        Stack shape : FOR IDENTIFIER expr TO expr.
        Start symbol: <undetermined>. *)

    | MenhirState0454 : (((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_TO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_state
      (** State 0454.
        Stack shape : FOR IDENTIFIER expr TO expr LOOPLIMIT.
        Start symbol: <undetermined>. *)

    | MenhirState0455 : ((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_TO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0455.
        Stack shape : FOR IDENTIFIER expr TO expr LOOPLIMIT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0456 : (((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_TO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_state
      (** State 0456.
        Stack shape : FOR IDENTIFIER expr TO expr LOOPLIMIT expr DO.
        Start symbol: <undetermined>. *)

    | MenhirState0458 : (('s, 'r) _menhir_cell1_DEBUG _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 0458.
        Stack shape : DEBUG LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0460 : ((('s, 'r) _menhir_cell1_DEBUG _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0460.
        Stack shape : DEBUG LPAR RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0461 : (('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_state
      (** State 0461.
        Stack shape : CONSTANT.
        Start symbol: <undetermined>. *)

    | MenhirState0463 : ((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 0463.
        Stack shape : CONSTANT decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState0465 : (((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0465.
        Stack shape : CONSTANT decl_item IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0467 : ((((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 0467.
        Stack shape : CONSTANT decl_item IDENTIFIER LBRACE RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0469 : (((((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0469.
        Stack shape : CONSTANT decl_item IDENTIFIER LBRACE RBRACE LPAR RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0470 : (('s, 'r) _menhir_cell1_CASE, 'r) _menhir_state
      (** State 0470.
        Stack shape : CASE.
        Start symbol: <undetermined>. *)

    | MenhirState0471 : ((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0471.
        Stack shape : CASE expr.
        Start symbol: <undetermined>. *)

    | MenhirState0472 : (((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OF, 'r) _menhir_state
      (** State 0472.
        Stack shape : CASE expr OF.
        Start symbol: <undetermined>. *)

    | MenhirState0473 : (('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_state
      (** State 0473.
        Stack shape : WHEN.
        Start symbol: <undetermined>. *)

    | MenhirState0475 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, 'r) _menhir_state
      (** State 0475.
        Stack shape : WHEN separated_nonempty_list(COMMA,pattern).
        Start symbol: <undetermined>. *)

    | MenhirState0476 : (((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0476.
        Stack shape : WHEN separated_nonempty_list(COMMA,pattern) expr.
        Start symbol: <undetermined>. *)

    | MenhirState0477 : ((((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ARROW, 'r) _menhir_state
      (** State 0477.
        Stack shape : WHEN separated_nonempty_list(COMMA,pattern) expr ARROW.
        Start symbol: <undetermined>. *)

    | MenhirState0478 : (('s, 'r) _menhir_cell1_ASSERT, 'r) _menhir_state
      (** State 0478.
        Stack shape : ASSERT.
        Start symbol: <undetermined>. *)

    | MenhirState0479 : ((('s, 'r) _menhir_cell1_ASSERT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0479.
        Stack shape : ASSERT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0480 : (((('s, 'r) _menhir_cell1_ASSERT, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0480.
        Stack shape : ASSERT expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0482 : (('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 0482.
        Stack shape : ARROBASE_LOOPLIMIT LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0483 : ((('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0483.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr.
        Start symbol: <undetermined>. *)

    | MenhirState0485 : (((('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR _menhir_cell0_WHILE, 'r) _menhir_state
      (** State 0485.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR WHILE.
        Start symbol: <undetermined>. *)

    | MenhirState0486 : ((((('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR _menhir_cell0_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0486.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR WHILE expr.
        Start symbol: <undetermined>. *)

    | MenhirState0487 : (((((('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR _menhir_cell0_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_state
      (** State 0487.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR WHILE expr DO.
        Start symbol: <undetermined>. *)

    | MenhirState0488 : ((((((('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR _menhir_cell0_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0488.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR WHILE expr DO nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0492 : (((((((('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR _menhir_cell0_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_end_semicolon, 'r) _menhir_state
      (** State 0492.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR WHILE expr DO nonempty_list(stmt) end_semicolon.
        Start symbol: <undetermined>. *)

    | MenhirState0495 : (('s, 'r) _menhir_cell1_lexpr, 'r) _menhir_state
      (** State 0495.
        Stack shape : lexpr.
        Start symbol: <undetermined>. *)

    | MenhirState0496 : ((('s, 'r) _menhir_cell1_lexpr, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0496.
        Stack shape : lexpr expr.
        Start symbol: <undetermined>. *)

    | MenhirState0497 : (((('s, 'r) _menhir_cell1_lexpr, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0497.
        Stack shape : lexpr expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0499 : (((('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR _menhir_cell0_REPEAT, 'r) _menhir_state
      (** State 0499.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR REPEAT.
        Start symbol: <undetermined>. *)

    | MenhirState0501 : ((((('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR _menhir_cell0_REPEAT, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0501.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR REPEAT nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0502 : (((((('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR _menhir_cell0_REPEAT, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0502.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR REPEAT nonempty_list(stmt) expr.
        Start symbol: <undetermined>. *)

    | MenhirState0503 : ((((((('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_RPAR _menhir_cell0_REPEAT, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0503.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR REPEAT nonempty_list(stmt) expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0506 : (((((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ARROW, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0506.
        Stack shape : WHEN separated_nonempty_list(COMMA,pattern) expr ARROW nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0508 : ((((((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_ARROW, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_OTHERWISE, 'r) _menhir_state
      (** State 0508.
        Stack shape : WHEN separated_nonempty_list(COMMA,pattern) expr ARROW nonempty_list(stmt) OTHERWISE.
        Start symbol: <undetermined>. *)

    | MenhirState0511 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, 'r) _menhir_state
      (** State 0511.
        Stack shape : WHEN separated_nonempty_list(COMMA,pattern).
        Start symbol: <undetermined>. *)

    | MenhirState0512 : (((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0512.
        Stack shape : WHEN separated_nonempty_list(COMMA,pattern) nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0514 : ((((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_OTHERWISE, 'r) _menhir_state
      (** State 0514.
        Stack shape : WHEN separated_nonempty_list(COMMA,pattern) nonempty_list(stmt) OTHERWISE.
        Start symbol: <undetermined>. *)

    | MenhirState0517 : ((((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OF, 'r) _menhir_cell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__, 'r) _menhir_state
      (** State 0517.
        Stack shape : CASE expr OF nlist_opt_terminated(annotated(case_alt),annotated(case_otherwise)).
        Start symbol: <undetermined>. *)

    | MenhirState0518 : (((((('s, 'r) _menhir_cell1_CASE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_OF, 'r) _menhir_cell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__, 'r) _menhir_cell1_end_semicolon, 'r) _menhir_state
      (** State 0518.
        Stack shape : CASE expr OF nlist_opt_terminated(annotated(case_alt),annotated(case_otherwise)) end_semicolon.
        Start symbol: <undetermined>. *)

    | MenhirState0523 : (((((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0523.
        Stack shape : CONSTANT decl_item IDENTIFIER LBRACE RBRACE LPAR separated_nonempty_list(COMMA,expr) RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0525 : ((((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0525.
        Stack shape : CONSTANT decl_item IDENTIFIER LBRACE COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0527 : (((((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_state
      (** State 0527.
        Stack shape : CONSTANT decl_item IDENTIFIER LBRACE COMMA separated_nonempty_list(COMMA,expr) RBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0529 : ((((((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__ _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0529.
        Stack shape : CONSTANT decl_item IDENTIFIER LBRACE COMMA separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0531 : (((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0531.
        Stack shape : CONSTANT decl_item expr.
        Start symbol: <undetermined>. *)

    | MenhirState0532 : ((((('s, 'r) _menhir_cell1_CONSTANT, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0532.
        Stack shape : CONSTANT decl_item expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0537 : ((('s, 'r) _menhir_cell1_DEBUG _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0537.
        Stack shape : DEBUG LPAR separated_nonempty_list(COMMA,expr) RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0539 : ((((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_TO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0539.
        Stack shape : FOR IDENTIFIER expr TO expr LOOPLIMIT expr DO nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0540 : (((((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_TO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_end_semicolon, 'r) _menhir_state
      (** State 0540.
        Stack shape : FOR IDENTIFIER expr TO expr LOOPLIMIT expr DO nonempty_list(stmt) end_semicolon.
        Start symbol: <undetermined>. *)

    | MenhirState0542 : (((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_TO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_state
      (** State 0542.
        Stack shape : FOR IDENTIFIER expr TO expr DO.
        Start symbol: <undetermined>. *)

    | MenhirState0543 : ((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_TO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0543.
        Stack shape : FOR IDENTIFIER expr TO expr DO nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0544 : (((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_TO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_end_semicolon, 'r) _menhir_state
      (** State 0544.
        Stack shape : FOR IDENTIFIER expr TO expr DO nonempty_list(stmt) end_semicolon.
        Start symbol: <undetermined>. *)

    | MenhirState0546 : (((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOWNTO, 'r) _menhir_state
      (** State 0546.
        Stack shape : FOR IDENTIFIER expr DOWNTO.
        Start symbol: <undetermined>. *)

    | MenhirState0547 : ((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOWNTO, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0547.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr.
        Start symbol: <undetermined>. *)

    | MenhirState0548 : (((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOWNTO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_state
      (** State 0548.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr LOOPLIMIT.
        Start symbol: <undetermined>. *)

    | MenhirState0549 : ((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOWNTO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0549.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr LOOPLIMIT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0550 : (((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOWNTO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_state
      (** State 0550.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr LOOPLIMIT expr DO.
        Start symbol: <undetermined>. *)

    | MenhirState0551 : ((((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOWNTO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0551.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr LOOPLIMIT expr DO nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0552 : (((((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOWNTO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_end_semicolon, 'r) _menhir_state
      (** State 0552.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr LOOPLIMIT expr DO nonempty_list(stmt) end_semicolon.
        Start symbol: <undetermined>. *)

    | MenhirState0554 : (((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOWNTO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_state
      (** State 0554.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr DO.
        Start symbol: <undetermined>. *)

    | MenhirState0555 : ((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOWNTO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0555.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr DO nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0556 : (((((((('s, 'r) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DOWNTO, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_end_semicolon, 'r) _menhir_state
      (** State 0556.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr DO nonempty_list(stmt) end_semicolon.
        Start symbol: <undetermined>. *)

    | MenhirState0559 : ((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR, 'r) _menhir_state
      (** State 0559.
        Stack shape : IDENTIFIER LPAR RPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0560 : (((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0560.
        Stack shape : IDENTIFIER LPAR RPAR expr.
        Start symbol: <undetermined>. *)

    | MenhirState0561 : ((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0561.
        Stack shape : IDENTIFIER LPAR RPAR expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0566 : ((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 0566.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0569 : (((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_state
      (** State 0569.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState0570 : ((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0570.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState0571 : (((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0571.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0574 : ((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 0574.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0575 : (((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0575.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER expr.
        Start symbol: <undetermined>. *)

    | MenhirState0576 : ((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0576.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0580 : ((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0580.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0582 : ((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR, 'r) _menhir_state
      (** State 0582.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0583 : (((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0583.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR expr.
        Start symbol: <undetermined>. *)

    | MenhirState0584 : ((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0584.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0589 : ((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 0589.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0592 : (((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_state
      (** State 0592.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState0593 : ((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0593.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState0594 : (((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0594.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0597 : ((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 0597.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0598 : (((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0598.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER expr.
        Start symbol: <undetermined>. *)

    | MenhirState0599 : ((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0599.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0601 : (('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0601.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0603 : ((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_state
      (** State 0603.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0605 : (((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__ _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0605.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0607 : (((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__, 'r) _menhir_state
      (** State 0607.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)).
        Start symbol: <undetermined>. *)

    | MenhirState0608 : ((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0608.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) expr.
        Start symbol: <undetermined>. *)

    | MenhirState0609 : (((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0609.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0614 : (((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 0614.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0617 : ((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_state
      (** State 0617.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET.
        Start symbol: <undetermined>. *)

    | MenhirState0618 : (((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0618.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET expr.
        Start symbol: <undetermined>. *)

    | MenhirState0619 : ((((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0619.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0622 : (((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, 'r) _menhir_state
      (** State 0622.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0623 : ((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0623.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER expr.
        Start symbol: <undetermined>. *)

    | MenhirState0624 : (((((('s, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0624.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0626 : ((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0626.
        Stack shape : IF expr THEN nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0627 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_ELSIF, 'r) _menhir_state
      (** State 0627.
        Stack shape : expr THEN nonempty_list(stmt) ELSIF.
        Start symbol: <undetermined>. *)

    | MenhirState0628 : (((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0628.
        Stack shape : expr THEN nonempty_list(stmt) ELSIF expr.
        Start symbol: <undetermined>. *)

    | MenhirState0629 : ((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_state
      (** State 0629.
        Stack shape : expr THEN nonempty_list(stmt) ELSIF expr THEN.
        Start symbol: <undetermined>. *)

    | MenhirState0630 : (((((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_ELSIF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0630.
        Stack shape : expr THEN nonempty_list(stmt) ELSIF expr THEN nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0631 : ((((('s, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_ELSE, 'r) _menhir_state
      (** State 0631.
        Stack shape : expr THEN nonempty_list(stmt) ELSE.
        Start symbol: <undetermined>. *)

    | MenhirState0634 : (((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_s_else, 'r) _menhir_state
      (** State 0634.
        Stack shape : IF expr THEN nonempty_list(stmt) s_else.
        Start symbol: <undetermined>. *)

    | MenhirState0635 : ((((((('s, 'r) _menhir_cell1_IF, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_THEN, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_s_else, 'r) _menhir_cell1_end_semicolon, 'r) _menhir_state
      (** State 0635.
        Stack shape : IF expr THEN nonempty_list(stmt) s_else end_semicolon.
        Start symbol: <undetermined>. *)

    | MenhirState0640 : (((((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0640.
        Stack shape : LET decl_item IDENTIFIER LBRACE RBRACE LPAR separated_nonempty_list(COMMA,expr) RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0642 : ((((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0642.
        Stack shape : LET decl_item IDENTIFIER LBRACE COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0644 : (((((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_state
      (** State 0644.
        Stack shape : LET decl_item IDENTIFIER LBRACE COMMA separated_nonempty_list(COMMA,expr) RBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0646 : ((((((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__ _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0646.
        Stack shape : LET decl_item IDENTIFIER LBRACE COMMA separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0648 : (((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0648.
        Stack shape : LET decl_item expr.
        Start symbol: <undetermined>. *)

    | MenhirState0649 : ((((('s, 'r) _menhir_cell1_LET, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0649.
        Stack shape : LET decl_item expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0654 : ((('s, 'r) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0654.
        Stack shape : PRAGMA IDENTIFIER separated_nonempty_list(COMMA,expr) SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0659 : ((('s, 'r) _menhir_cell1_PRINT _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0659.
        Stack shape : PRINT LPAR separated_nonempty_list(COMMA,expr) RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0662 : ((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0662.
        Stack shape : REPEAT nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0663 : (((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0663.
        Stack shape : REPEAT nonempty_list(stmt) expr.
        Start symbol: <undetermined>. *)

    | MenhirState0664 : ((((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0664.
        Stack shape : REPEAT nonempty_list(stmt) expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0666 : ((((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_state
      (** State 0666.
        Stack shape : REPEAT nonempty_list(stmt) expr LOOPLIMIT.
        Start symbol: <undetermined>. *)

    | MenhirState0667 : (((((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0667.
        Stack shape : REPEAT nonempty_list(stmt) expr LOOPLIMIT expr.
        Start symbol: <undetermined>. *)

    | MenhirState0668 : ((((((('s, 'r) _menhir_cell1_REPEAT, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0668.
        Stack shape : REPEAT nonempty_list(stmt) expr LOOPLIMIT expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0671 : ((('s, 'r) _menhir_cell1_RETURN, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0671.
        Stack shape : RETURN expr.
        Start symbol: <undetermined>. *)

    | MenhirState0672 : (((('s, 'r) _menhir_cell1_RETURN, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0672.
        Stack shape : RETURN expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0675 : ((('s, 'r) _menhir_cell1_THROW, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0675.
        Stack shape : THROW expr.
        Start symbol: <undetermined>. *)

    | MenhirState0676 : (((('s, 'r) _menhir_cell1_THROW, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0676.
        Stack shape : THROW expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0679 : ((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0679.
        Stack shape : TRY nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0680 : (('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_state
      (** State 0680.
        Stack shape : WHEN.
        Start symbol: <undetermined>. *)

    | MenhirState0682 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_state
      (** State 0682.
        Stack shape : WHEN IDENTIFIER.
        Start symbol: <undetermined>. *)

    | MenhirState0684 : (((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 0684.
        Stack shape : WHEN IDENTIFIER ty.
        Start symbol: <undetermined>. *)

    | MenhirState0685 : ((((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_ty, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0685.
        Stack shape : WHEN IDENTIFIER ty nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0688 : ((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_ty, 'r) _menhir_state
      (** State 0688.
        Stack shape : WHEN ty.
        Start symbol: <undetermined>. *)

    | MenhirState0689 : (((('s, 'r) _menhir_cell1_WHEN, 'r) _menhir_cell1_ty, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0689.
        Stack shape : WHEN ty nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0691 : (((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_nonempty_list_catcher_, 'r) _menhir_state
      (** State 0691.
        Stack shape : TRY nonempty_list(stmt) nonempty_list(catcher).
        Start symbol: <undetermined>. *)

    | MenhirState0693 : ((((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_nonempty_list_catcher_, 'r) _menhir_cell1_OTHERWISE, 'r) _menhir_state
      (** State 0693.
        Stack shape : TRY nonempty_list(stmt) nonempty_list(catcher) OTHERWISE.
        Start symbol: <undetermined>. *)

    | MenhirState0694 : (((((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_nonempty_list_catcher_, 'r) _menhir_cell1_OTHERWISE, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0694.
        Stack shape : TRY nonempty_list(stmt) nonempty_list(catcher) OTHERWISE nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0695 : ((((((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_nonempty_list_catcher_, 'r) _menhir_cell1_OTHERWISE, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_end_semicolon, 'r) _menhir_state
      (** State 0695.
        Stack shape : TRY nonempty_list(stmt) nonempty_list(catcher) OTHERWISE nonempty_list(stmt) end_semicolon.
        Start symbol: <undetermined>. *)

    | MenhirState0697 : ((((('s, 'r) _menhir_cell1_TRY, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_nonempty_list_catcher_, 'r) _menhir_cell1_end_semicolon, 'r) _menhir_state
      (** State 0697.
        Stack shape : TRY nonempty_list(stmt) nonempty_list(catcher) end_semicolon.
        Start symbol: <undetermined>. *)

    | MenhirState0701 : (((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_, 'r) _menhir_state
      (** State 0701.
        Stack shape : VAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER).
        Start symbol: <undetermined>. *)

    | MenhirState0703 : ((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_IDENTIFIER, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_, 'r) _menhir_cell1_ty _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0703.
        Stack shape : VAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) ty SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0706 : ((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0706.
        Stack shape : VAR decl_item SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0708 : ((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_state
      (** State 0708.
        Stack shape : VAR decl_item.
        Start symbol: <undetermined>. *)

    | MenhirState0710 : (((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_state
      (** State 0710.
        Stack shape : VAR decl_item IDENTIFIER LBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0712 : ((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_state
      (** State 0712.
        Stack shape : VAR decl_item IDENTIFIER LBRACE RBRACE LPAR.
        Start symbol: <undetermined>. *)

    | MenhirState0714 : (((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0714.
        Stack shape : VAR decl_item IDENTIFIER LBRACE RBRACE LPAR RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0718 : (((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_RBRACE _menhir_cell0_LPAR, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0718.
        Stack shape : VAR decl_item IDENTIFIER LBRACE RBRACE LPAR separated_nonempty_list(COMMA,expr) RPAR SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0720 : ((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_state
      (** State 0720.
        Stack shape : VAR decl_item IDENTIFIER LBRACE COMMA.
        Start symbol: <undetermined>. *)

    | MenhirState0722 : (((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_state
      (** State 0722.
        Stack shape : VAR decl_item IDENTIFIER LBRACE COMMA separated_nonempty_list(COMMA,expr) RBRACE.
        Start symbol: <undetermined>. *)

    | MenhirState0724 : ((((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, 'r) _menhir_cell1_COMMA, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, 'r) _menhir_cell1_loption_plist_expr__ _menhir_cell0_SEMI_COLON, 'r) _menhir_state
      (** State 0724.
        Stack shape : VAR decl_item IDENTIFIER LBRACE COMMA separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0726 : (((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_expr, 'r) _menhir_state
      (** State 0726.
        Stack shape : VAR decl_item expr.
        Start symbol: <undetermined>. *)

    | MenhirState0727 : ((((('s, 'r) _menhir_cell1_VAR, 'r) _menhir_cell1_decl_item, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_SEMI_COLON, 'r) _menhir_state
      (** State 0727.
        Stack shape : VAR decl_item expr SEMI_COLON.
        Start symbol: <undetermined>. *)

    | MenhirState0729 : ((((((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0729.
        Stack shape : WHILE expr LOOPLIMIT expr DO nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0730 : (((((((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_LOOPLIMIT, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_end_semicolon, 'r) _menhir_state
      (** State 0730.
        Stack shape : WHILE expr LOOPLIMIT expr DO nonempty_list(stmt) end_semicolon.
        Start symbol: <undetermined>. *)

    | MenhirState0732 : (((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_state
      (** State 0732.
        Stack shape : WHILE expr DO.
        Start symbol: <undetermined>. *)

    | MenhirState0733 : ((((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_state
      (** State 0733.
        Stack shape : WHILE expr DO nonempty_list(stmt).
        Start symbol: <undetermined>. *)

    | MenhirState0734 : (((((('s, 'r) _menhir_cell1_WHILE, 'r) _menhir_cell1_expr, 'r) _menhir_cell1_DO, 'r) _menhir_cell1_nonempty_list_stmt_, 'r) _menhir_cell1_end_semicolon, 'r) _menhir_state
      (** State 0734.
        Stack shape : WHILE expr DO nonempty_list(stmt) end_semicolon.
        Start symbol: <undetermined>. *)

    | MenhirState0736 : ((((((('s, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 0736.
        Stack shape : WHILE expr LOOPLIMIT expr DO nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState0739 : (((('s, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_state
      (** State 0739.
        Stack shape : WHILE expr DO.
        Start symbol: opn. *)

    | MenhirState0740 : ((((('s, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 0740.
        Stack shape : WHILE expr DO nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState0743 : (('s, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_state
      (** State 0743.
        Stack shape : VAR.
        Start symbol: opn. *)

    | MenhirState0745 : ((('s, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_IDENTIFIER, _menhir_box_opn) _menhir_state
      (** State 0745.
        Stack shape : VAR IDENTIFIER.
        Start symbol: opn. *)

    | MenhirState0747 : (((('s, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_, _menhir_box_opn) _menhir_state
      (** State 0747.
        Stack shape : VAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER).
        Start symbol: opn. *)

    | MenhirState0751 : (((('s, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_, _menhir_box_opn) _menhir_state
      (** State 0751.
        Stack shape : VAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER).
        Start symbol: opn. *)

    | MenhirState0758 : ((('s, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_state
      (** State 0758.
        Stack shape : VAR decl_item.
        Start symbol: opn. *)

    | MenhirState0760 : (((('s, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_state
      (** State 0760.
        Stack shape : VAR decl_item IDENTIFIER LBRACE.
        Start symbol: opn. *)

    | MenhirState0762 : ((((('s, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_RBRACE _menhir_cell0_LPAR, _menhir_box_opn) _menhir_state
      (** State 0762.
        Stack shape : VAR decl_item IDENTIFIER LBRACE RBRACE LPAR.
        Start symbol: opn. *)

    | MenhirState0770 : ((((('s, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA, _menhir_box_opn) _menhir_state
      (** State 0770.
        Stack shape : VAR decl_item IDENTIFIER LBRACE COMMA.
        Start symbol: opn. *)

    | MenhirState0772 : (((((('s, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_state
      (** State 0772.
        Stack shape : VAR decl_item IDENTIFIER LBRACE COMMA separated_nonempty_list(COMMA,expr) RBRACE.
        Start symbol: opn. *)

    | MenhirState0776 : (((('s, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0776.
        Stack shape : VAR decl_item expr.
        Start symbol: opn. *)

    | MenhirState0784 : (('s, _menhir_box_opn) _menhir_cell1_TRY, _menhir_box_opn) _menhir_state
      (** State 0784.
        Stack shape : TRY.
        Start symbol: opn. *)

    | MenhirState0786 : ((('s, _menhir_box_opn) _menhir_cell1_TRY, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 0786.
        Stack shape : TRY nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState0787 : (((('s, _menhir_box_opn) _menhir_cell1_TRY, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_nonempty_list_catcher_, _menhir_box_opn) _menhir_state
      (** State 0787.
        Stack shape : TRY nonempty_list(stmt) nonempty_list(catcher).
        Start symbol: opn. *)

    | MenhirState0789 : ((((('s, _menhir_box_opn) _menhir_cell1_TRY, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_nonempty_list_catcher_, _menhir_box_opn) _menhir_cell1_OTHERWISE, _menhir_box_opn) _menhir_state
      (** State 0789.
        Stack shape : TRY nonempty_list(stmt) nonempty_list(catcher) OTHERWISE.
        Start symbol: opn. *)

    | MenhirState0790 : (((((('s, _menhir_box_opn) _menhir_cell1_TRY, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_nonempty_list_catcher_, _menhir_box_opn) _menhir_cell1_OTHERWISE, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 0790.
        Stack shape : TRY nonempty_list(stmt) nonempty_list(catcher) OTHERWISE nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState0795 : (('s, _menhir_box_opn) _menhir_cell1_THROW, _menhir_box_opn) _menhir_state
      (** State 0795.
        Stack shape : THROW.
        Start symbol: opn. *)

    | MenhirState0798 : ((('s, _menhir_box_opn) _menhir_cell1_THROW, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0798.
        Stack shape : THROW expr.
        Start symbol: opn. *)

    | MenhirState0801 : (('s, _menhir_box_opn) _menhir_cell1_RETURN, _menhir_box_opn) _menhir_state
      (** State 0801.
        Stack shape : RETURN.
        Start symbol: opn. *)

    | MenhirState0804 : ((('s, _menhir_box_opn) _menhir_cell1_RETURN, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0804.
        Stack shape : RETURN expr.
        Start symbol: opn. *)

    | MenhirState0807 : (('s, _menhir_box_opn) _menhir_cell1_REPEAT, _menhir_box_opn) _menhir_state
      (** State 0807.
        Stack shape : REPEAT.
        Start symbol: opn. *)

    | MenhirState0809 : ((('s, _menhir_box_opn) _menhir_cell1_REPEAT, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 0809.
        Stack shape : REPEAT nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState0810 : (((('s, _menhir_box_opn) _menhir_cell1_REPEAT, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0810.
        Stack shape : REPEAT nonempty_list(stmt) expr.
        Start symbol: opn. *)

    | MenhirState0813 : ((((('s, _menhir_box_opn) _menhir_cell1_REPEAT, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_state
      (** State 0813.
        Stack shape : REPEAT nonempty_list(stmt) expr LOOPLIMIT.
        Start symbol: opn. *)

    | MenhirState0814 : (((((('s, _menhir_box_opn) _menhir_cell1_REPEAT, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0814.
        Stack shape : REPEAT nonempty_list(stmt) expr LOOPLIMIT expr.
        Start symbol: opn. *)

    | MenhirState0818 : (('s, _menhir_box_opn) _menhir_cell1_PRINT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_state
      (** State 0818.
        Stack shape : PRINT LPAR.
        Start symbol: opn. *)

    | MenhirState0827 : (('s, _menhir_box_opn) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_state
      (** State 0827.
        Stack shape : PRAGMA IDENTIFIER.
        Start symbol: opn. *)

    | MenhirState0836 : (('s, _menhir_box_opn) _menhir_cell1_LET, _menhir_box_opn) _menhir_state
      (** State 0836.
        Stack shape : LET.
        Start symbol: opn. *)

    | MenhirState0838 : ((('s, _menhir_box_opn) _menhir_cell1_LET, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_state
      (** State 0838.
        Stack shape : LET decl_item.
        Start symbol: opn. *)

    | MenhirState0840 : (((('s, _menhir_box_opn) _menhir_cell1_LET, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_state
      (** State 0840.
        Stack shape : LET decl_item IDENTIFIER LBRACE.
        Start symbol: opn. *)

    | MenhirState0842 : ((((('s, _menhir_box_opn) _menhir_cell1_LET, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_RBRACE _menhir_cell0_LPAR, _menhir_box_opn) _menhir_state
      (** State 0842.
        Stack shape : LET decl_item IDENTIFIER LBRACE RBRACE LPAR.
        Start symbol: opn. *)

    | MenhirState0850 : ((((('s, _menhir_box_opn) _menhir_cell1_LET, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA, _menhir_box_opn) _menhir_state
      (** State 0850.
        Stack shape : LET decl_item IDENTIFIER LBRACE COMMA.
        Start symbol: opn. *)

    | MenhirState0852 : (((((('s, _menhir_box_opn) _menhir_cell1_LET, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_state
      (** State 0852.
        Stack shape : LET decl_item IDENTIFIER LBRACE COMMA separated_nonempty_list(COMMA,expr) RBRACE.
        Start symbol: opn. *)

    | MenhirState0856 : (((('s, _menhir_box_opn) _menhir_cell1_LET, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0856.
        Stack shape : LET decl_item expr.
        Start symbol: opn. *)

    | MenhirState0859 : (('s, _menhir_box_opn) _menhir_cell1_IF, _menhir_box_opn) _menhir_state
      (** State 0859.
        Stack shape : IF.
        Start symbol: opn. *)

    | MenhirState0860 : ((('s, _menhir_box_opn) _menhir_cell1_IF, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0860.
        Stack shape : IF expr.
        Start symbol: opn. *)

    | MenhirState0861 : (((('s, _menhir_box_opn) _menhir_cell1_IF, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_THEN, _menhir_box_opn) _menhir_state
      (** State 0861.
        Stack shape : IF expr THEN.
        Start symbol: opn. *)

    | MenhirState0862 : ((((('s, _menhir_box_opn) _menhir_cell1_IF, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_THEN, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 0862.
        Stack shape : IF expr THEN nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState0863 : (((((('s, _menhir_box_opn) _menhir_cell1_IF, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_THEN, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_s_else, _menhir_box_opn) _menhir_state
      (** State 0863.
        Stack shape : IF expr THEN nonempty_list(stmt) s_else.
        Start symbol: opn. *)

    | MenhirState0867 : (('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_state
      (** State 0867.
        Stack shape : IDENTIFIER LPAR.
        Start symbol: opn. *)

    | MenhirState0871 : ((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_RPAR, _menhir_box_opn) _menhir_state
      (** State 0871.
        Stack shape : IDENTIFIER LPAR RPAR.
        Start symbol: opn. *)

    | MenhirState0872 : (((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_RPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0872.
        Stack shape : IDENTIFIER LPAR RPAR expr.
        Start symbol: opn. *)

    | MenhirState0878 : ((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_state
      (** State 0878.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER.
        Start symbol: opn. *)

    | MenhirState0881 : (((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, _menhir_box_opn) _menhir_state
      (** State 0881.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET.
        Start symbol: opn. *)

    | MenhirState0882 : ((((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0882.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET expr.
        Start symbol: opn. *)

    | MenhirState0886 : ((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_state
      (** State 0886.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER.
        Start symbol: opn. *)

    | MenhirState0887 : (((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0887.
        Stack shape : IDENTIFIER LPAR RPAR IDENTIFIER expr.
        Start symbol: opn. *)

    | MenhirState0894 : ((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR, _menhir_box_opn) _menhir_state
      (** State 0894.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR.
        Start symbol: opn. *)

    | MenhirState0895 : (((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0895.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR expr.
        Start symbol: opn. *)

    | MenhirState0901 : ((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_state
      (** State 0901.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER.
        Start symbol: opn. *)

    | MenhirState0904 : (((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, _menhir_box_opn) _menhir_state
      (** State 0904.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET.
        Start symbol: opn. *)

    | MenhirState0905 : ((((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0905.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET expr.
        Start symbol: opn. *)

    | MenhirState0909 : ((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_state
      (** State 0909.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER.
        Start symbol: opn. *)

    | MenhirState0910 : (((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0910.
        Stack shape : IDENTIFIER LPAR separated_nonempty_list(COMMA,expr) RPAR IDENTIFIER expr.
        Start symbol: opn. *)

    | MenhirState0913 : (('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_state
      (** State 0913.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: opn. *)

    | MenhirState0915 : ((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_state
      (** State 0915.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE.
        Start symbol: opn. *)

    | MenhirState0919 : (((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_cell1_loption_plist_expr__, _menhir_box_opn) _menhir_state
      (** State 0919.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)).
        Start symbol: opn. *)

    | MenhirState0920 : ((((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_cell1_loption_plist_expr__, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0920.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) expr.
        Start symbol: opn. *)

    | MenhirState0926 : (((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_state
      (** State 0926.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER.
        Start symbol: opn. *)

    | MenhirState0929 : ((((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, _menhir_box_opn) _menhir_state
      (** State 0929.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET.
        Start symbol: opn. *)

    | MenhirState0930 : (((((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0930.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER separated_nonempty_list(COMMA,IDENTIFIER) RBRACKET expr.
        Start symbol: opn. *)

    | MenhirState0934 : (((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_state
      (** State 0934.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER.
        Start symbol: opn. *)

    | MenhirState0935 : ((((('s, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0935.
        Stack shape : IDENTIFIER LBRACE separated_nonempty_list(COMMA,expr) RBRACE loption(plist(expr)) IDENTIFIER expr.
        Start symbol: opn. *)

    | MenhirState0940 : (('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_state
      (** State 0940.
        Stack shape : FOR IDENTIFIER.
        Start symbol: opn. *)

    | MenhirState0941 : ((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0941.
        Stack shape : FOR IDENTIFIER expr.
        Start symbol: opn. *)

    | MenhirState0942 : (((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_state
      (** State 0942.
        Stack shape : FOR IDENTIFIER expr TO.
        Start symbol: opn. *)

    | MenhirState0943 : ((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0943.
        Stack shape : FOR IDENTIFIER expr TO expr.
        Start symbol: opn. *)

    | MenhirState0944 : (((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_state
      (** State 0944.
        Stack shape : FOR IDENTIFIER expr TO expr LOOPLIMIT.
        Start symbol: opn. *)

    | MenhirState0945 : ((((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0945.
        Stack shape : FOR IDENTIFIER expr TO expr LOOPLIMIT expr.
        Start symbol: opn. *)

    | MenhirState0946 : (((((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_state
      (** State 0946.
        Stack shape : FOR IDENTIFIER expr TO expr LOOPLIMIT expr DO.
        Start symbol: opn. *)

    | MenhirState0947 : ((((((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 0947.
        Stack shape : FOR IDENTIFIER expr TO expr LOOPLIMIT expr DO nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState0950 : (((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_state
      (** State 0950.
        Stack shape : FOR IDENTIFIER expr TO expr DO.
        Start symbol: opn. *)

    | MenhirState0951 : ((((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 0951.
        Stack shape : FOR IDENTIFIER expr TO expr DO nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState0954 : (((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_state
      (** State 0954.
        Stack shape : FOR IDENTIFIER expr DOWNTO.
        Start symbol: opn. *)

    | MenhirState0955 : ((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0955.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr.
        Start symbol: opn. *)

    | MenhirState0956 : (((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_state
      (** State 0956.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr LOOPLIMIT.
        Start symbol: opn. *)

    | MenhirState0957 : ((((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0957.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr LOOPLIMIT expr.
        Start symbol: opn. *)

    | MenhirState0958 : (((((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_state
      (** State 0958.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr LOOPLIMIT expr DO.
        Start symbol: opn. *)

    | MenhirState0959 : ((((((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 0959.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr LOOPLIMIT expr DO nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState0962 : (((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_state
      (** State 0962.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr DO.
        Start symbol: opn. *)

    | MenhirState0963 : ((((((('s, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 0963.
        Stack shape : FOR IDENTIFIER expr DOWNTO expr DO nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState0967 : (('s, _menhir_box_opn) _menhir_cell1_DEBUG _menhir_cell0_LPAR, _menhir_box_opn) _menhir_state
      (** State 0967.
        Stack shape : DEBUG LPAR.
        Start symbol: opn. *)

    | MenhirState0975 : (('s, _menhir_box_opn) _menhir_cell1_CONSTANT, _menhir_box_opn) _menhir_state
      (** State 0975.
        Stack shape : CONSTANT.
        Start symbol: opn. *)

    | MenhirState0977 : ((('s, _menhir_box_opn) _menhir_cell1_CONSTANT, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_state
      (** State 0977.
        Stack shape : CONSTANT decl_item.
        Start symbol: opn. *)

    | MenhirState0979 : (((('s, _menhir_box_opn) _menhir_cell1_CONSTANT, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_state
      (** State 0979.
        Stack shape : CONSTANT decl_item IDENTIFIER LBRACE.
        Start symbol: opn. *)

    | MenhirState0981 : ((((('s, _menhir_box_opn) _menhir_cell1_CONSTANT, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_RBRACE _menhir_cell0_LPAR, _menhir_box_opn) _menhir_state
      (** State 0981.
        Stack shape : CONSTANT decl_item IDENTIFIER LBRACE RBRACE LPAR.
        Start symbol: opn. *)

    | MenhirState0989 : ((((('s, _menhir_box_opn) _menhir_cell1_CONSTANT, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA, _menhir_box_opn) _menhir_state
      (** State 0989.
        Stack shape : CONSTANT decl_item IDENTIFIER LBRACE COMMA.
        Start symbol: opn. *)

    | MenhirState0991 : (((((('s, _menhir_box_opn) _menhir_cell1_CONSTANT, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_state
      (** State 0991.
        Stack shape : CONSTANT decl_item IDENTIFIER LBRACE COMMA separated_nonempty_list(COMMA,expr) RBRACE.
        Start symbol: opn. *)

    | MenhirState0995 : (((('s, _menhir_box_opn) _menhir_cell1_CONSTANT, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0995.
        Stack shape : CONSTANT decl_item expr.
        Start symbol: opn. *)

    | MenhirState0998 : (('s, _menhir_box_opn) _menhir_cell1_CASE, _menhir_box_opn) _menhir_state
      (** State 0998.
        Stack shape : CASE.
        Start symbol: opn. *)

    | MenhirState0999 : ((('s, _menhir_box_opn) _menhir_cell1_CASE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 0999.
        Stack shape : CASE expr.
        Start symbol: opn. *)

    | MenhirState1000 : (((('s, _menhir_box_opn) _menhir_cell1_CASE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_OF, _menhir_box_opn) _menhir_state
      (** State 1000.
        Stack shape : CASE expr OF.
        Start symbol: opn. *)

    | MenhirState1001 : ((((('s, _menhir_box_opn) _menhir_cell1_CASE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_OF, _menhir_box_opn) _menhir_cell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__, _menhir_box_opn) _menhir_state
      (** State 1001.
        Stack shape : CASE expr OF nlist_opt_terminated(annotated(case_alt),annotated(case_otherwise)).
        Start symbol: opn. *)

    | MenhirState1004 : (('s, _menhir_box_opn) _menhir_cell1_ASSERT, _menhir_box_opn) _menhir_state
      (** State 1004.
        Stack shape : ASSERT.
        Start symbol: opn. *)

    | MenhirState1005 : ((('s, _menhir_box_opn) _menhir_cell1_ASSERT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 1005.
        Stack shape : ASSERT expr.
        Start symbol: opn. *)

    | MenhirState1009 : (('s, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_state
      (** State 1009.
        Stack shape : ARROBASE_LOOPLIMIT LPAR.
        Start symbol: opn. *)

    | MenhirState1010 : ((('s, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 1010.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr.
        Start symbol: opn. *)

    | MenhirState1012 : (((('s, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_WHILE, _menhir_box_opn) _menhir_state
      (** State 1012.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR WHILE.
        Start symbol: opn. *)

    | MenhirState1013 : ((((('s, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 1013.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR WHILE expr.
        Start symbol: opn. *)

    | MenhirState1014 : (((((('s, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_state
      (** State 1014.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR WHILE expr DO.
        Start symbol: opn. *)

    | MenhirState1015 : ((((((('s, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 1015.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR WHILE expr DO nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState1018 : (((('s, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_REPEAT, _menhir_box_opn) _menhir_state
      (** State 1018.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR REPEAT.
        Start symbol: opn. *)

    | MenhirState1020 : ((((('s, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_REPEAT, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_state
      (** State 1020.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR REPEAT nonempty_list(stmt).
        Start symbol: opn. *)

    | MenhirState1021 : (((((('s, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_REPEAT, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 1021.
        Stack shape : ARROBASE_LOOPLIMIT LPAR expr RPAR REPEAT nonempty_list(stmt) expr.
        Start symbol: opn. *)

    | MenhirState1026 : (('s, _menhir_box_opn) _menhir_cell1_lexpr, _menhir_box_opn) _menhir_state
      (** State 1026.
        Stack shape : lexpr.
        Start symbol: opn. *)

    | MenhirState1027 : ((('s, _menhir_box_opn) _menhir_cell1_lexpr, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_state
      (** State 1027.
        Stack shape : lexpr expr.
        Start symbol: opn. *)

    | MenhirState1030 : ('s, _menhir_box_spec) _menhir_state
      (** State 1030.
        Stack shape : .
        Start symbol: spec. *)

    | MenhirState1033 : (('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1033.
        Stack shape : VAR MINUS.
        Start symbol: spec. *)

    | MenhirState1034 : ((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1034.
        Stack shape : VAR MINUS expr.
        Start symbol: spec. *)

    | MenhirState1035 : (((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1035.
        Stack shape : VAR MINUS expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1039 : (('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER _menhir_cell0_SUBTYPES _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1039.
        Stack shape : TYPE IDENTIFIER SUBTYPES IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1041 : (('s _menhir_cell0_SUBTYPES _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_WITH _menhir_cell0_LBRACE, _menhir_box_spec) _menhir_state
      (** State 1041.
        Stack shape : SUBTYPES IDENTIFIER WITH LBRACE.
        Start symbol: spec. *)

    | MenhirState1043 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1043.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1045 : ((('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1045.
        Stack shape : IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1047 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1047.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1049 : ((('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1049.
        Stack shape : IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1055 : ((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER _menhir_cell0_SUBTYPES _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption___anonymous_22_ _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1055.
        Stack shape : TYPE IDENTIFIER SUBTYPES IDENTIFIER loption(__anonymous_22) SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1057 : (('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1057.
        Stack shape : SETTER IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1058 : (('s _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_LBRACE, _menhir_box_spec) _menhir_state
      (** State 1058.
        Stack shape : IDENTIFIER LBRACE.
        Start symbol: spec. *)

    | MenhirState1060 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1060.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1062 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1062.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1064 : ((('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1064.
        Stack shape : IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1066 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1066.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1068 : ((('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1068.
        Stack shape : IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1073 : ((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_state
      (** State 1073.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR.
        Start symbol: spec. *)

    | MenhirState1077 : (((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1077.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1079 : ((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1079.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR IDENTIFIER ty BEGIN.
        Start symbol: spec. *)

    | MenhirState1080 : (((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1080.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR IDENTIFIER ty BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1081 : ((((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1081.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR IDENTIFIER ty BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1083 : (('s, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1083.
        Stack shape : PRAGMA IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1084 : ((('s, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1084.
        Stack shape : PRAGMA IDENTIFIER SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1087 : (('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1087.
        Stack shape : LET MINUS.
        Start symbol: spec. *)

    | MenhirState1088 : ((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1088.
        Stack shape : LET MINUS expr.
        Start symbol: spec. *)

    | MenhirState1089 : (((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1089.
        Stack shape : LET MINUS expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1091 : (('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1091.
        Stack shape : GETTER IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1093 : ((('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_state
      (** State 1093.
        Stack shape : GETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR.
        Start symbol: spec. *)

    | MenhirState1095 : (((('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_state
      (** State 1095.
        Stack shape : GETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR.
        Start symbol: spec. *)

    | MenhirState1097 : ((((('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1097.
        Stack shape : GETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty BEGIN.
        Start symbol: spec. *)

    | MenhirState1098 : (((((('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1098.
        Stack shape : GETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1099 : ((((((('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1099.
        Stack shape : GETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1101 : (('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1101.
        Stack shape : FUNC IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1103 : ((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_state
      (** State 1103.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR.
        Start symbol: spec. *)

    | MenhirState1105 : (((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1105.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR BEGIN.
        Start symbol: spec. *)

    | MenhirState1106 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1106.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1107 : (((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1107.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1110 : (('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1110.
        Stack shape : CONSTANT MINUS.
        Start symbol: spec. *)

    | MenhirState1111 : ((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1111.
        Stack shape : CONSTANT MINUS expr.
        Start symbol: spec. *)

    | MenhirState1112 : (((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1112.
        Stack shape : CONSTANT MINUS expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1115 : (('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1115.
        Stack shape : CONFIG MINUS.
        Start symbol: spec. *)

    | MenhirState1116 : ((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1116.
        Stack shape : CONFIG MINUS expr.
        Start symbol: spec. *)

    | MenhirState1117 : (((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1117.
        Stack shape : CONFIG MINUS expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1119 : (('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1119.
        Stack shape : CONFIG MINUS.
        Start symbol: spec. *)

    | MenhirState1121 : ((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1121.
        Stack shape : CONFIG MINUS ty.
        Start symbol: spec. *)

    | MenhirState1122 : (((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1122.
        Stack shape : CONFIG MINUS ty expr.
        Start symbol: spec. *)

    | MenhirState1123 : ((((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1123.
        Stack shape : CONFIG MINUS ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1125 : (('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1125.
        Stack shape : CONFIG MINUS.
        Start symbol: spec. *)

    | MenhirState1127 : ((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1127.
        Stack shape : CONFIG MINUS ty.
        Start symbol: spec. *)

    | MenhirState1128 : (((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1128.
        Stack shape : CONFIG MINUS ty expr.
        Start symbol: spec. *)

    | MenhirState1129 : ((((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1129.
        Stack shape : CONFIG MINUS ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1132 : (('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1132.
        Stack shape : CONFIG IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1133 : ((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1133.
        Stack shape : CONFIG IDENTIFIER expr.
        Start symbol: spec. *)

    | MenhirState1134 : (((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1134.
        Stack shape : CONFIG IDENTIFIER expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1136 : (('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1136.
        Stack shape : CONFIG IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1138 : ((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1138.
        Stack shape : CONFIG IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1139 : (((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1139.
        Stack shape : CONFIG IDENTIFIER ty expr.
        Start symbol: spec. *)

    | MenhirState1140 : ((((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1140.
        Stack shape : CONFIG IDENTIFIER ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1142 : (('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1142.
        Stack shape : CONFIG IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1144 : ((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1144.
        Stack shape : CONFIG IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1145 : (((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1145.
        Stack shape : CONFIG IDENTIFIER ty expr.
        Start symbol: spec. *)

    | MenhirState1146 : ((((('s, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1146.
        Stack shape : CONFIG IDENTIFIER ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1149 : (('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1149.
        Stack shape : CONSTANT MINUS.
        Start symbol: spec. *)

    | MenhirState1151 : ((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1151.
        Stack shape : CONSTANT MINUS ty.
        Start symbol: spec. *)

    | MenhirState1152 : (((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1152.
        Stack shape : CONSTANT MINUS ty expr.
        Start symbol: spec. *)

    | MenhirState1153 : ((((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1153.
        Stack shape : CONSTANT MINUS ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1155 : (('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1155.
        Stack shape : CONSTANT MINUS.
        Start symbol: spec. *)

    | MenhirState1157 : ((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1157.
        Stack shape : CONSTANT MINUS ty.
        Start symbol: spec. *)

    | MenhirState1158 : (((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1158.
        Stack shape : CONSTANT MINUS ty expr.
        Start symbol: spec. *)

    | MenhirState1159 : ((((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1159.
        Stack shape : CONSTANT MINUS ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1162 : (('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1162.
        Stack shape : CONSTANT IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1163 : ((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1163.
        Stack shape : CONSTANT IDENTIFIER expr.
        Start symbol: spec. *)

    | MenhirState1164 : (((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1164.
        Stack shape : CONSTANT IDENTIFIER expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1166 : (('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1166.
        Stack shape : CONSTANT IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1168 : ((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1168.
        Stack shape : CONSTANT IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1169 : (((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1169.
        Stack shape : CONSTANT IDENTIFIER ty expr.
        Start symbol: spec. *)

    | MenhirState1170 : ((((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1170.
        Stack shape : CONSTANT IDENTIFIER ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1172 : (('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1172.
        Stack shape : CONSTANT IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1174 : ((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1174.
        Stack shape : CONSTANT IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1175 : (((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1175.
        Stack shape : CONSTANT IDENTIFIER ty expr.
        Start symbol: spec. *)

    | MenhirState1176 : ((((('s, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1176.
        Stack shape : CONSTANT IDENTIFIER ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1179 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1179.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1181 : (((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_state
      (** State 1181.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR.
        Start symbol: spec. *)

    | MenhirState1183 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1183.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty.
        Start symbol: spec. *)

    | MenhirState1184 : (((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1184.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty expr.
        Start symbol: spec. *)

    | MenhirState1185 : ((((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1185.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty expr BEGIN.
        Start symbol: spec. *)

    | MenhirState1186 : (((((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1186.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty expr BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1187 : ((((((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1187.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty expr BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1189 : (((((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1189.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty expr BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1191 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1191.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty BEGIN.
        Start symbol: spec. *)

    | MenhirState1192 : (((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1192.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1193 : ((((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1193.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1195 : (((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1195.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1198 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1198.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1200 : ((('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1200.
        Stack shape : IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1202 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1202.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1204 : ((('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1204.
        Stack shape : IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1208 : (((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1208.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR BEGIN.
        Start symbol: spec. *)

    | MenhirState1209 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1209.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1210 : (((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1210.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1212 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1212.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1214 : (((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_state
      (** State 1214.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR.
        Start symbol: spec. *)

    | MenhirState1216 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1216.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty.
        Start symbol: spec. *)

    | MenhirState1217 : (((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1217.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty expr.
        Start symbol: spec. *)

    | MenhirState1218 : ((((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1218.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty expr BEGIN.
        Start symbol: spec. *)

    | MenhirState1219 : (((((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1219.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty expr BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1220 : ((((((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1220.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty expr BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1222 : (((((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1222.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty expr BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1224 : ((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1224.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty BEGIN.
        Start symbol: spec. *)

    | MenhirState1225 : (((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1225.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1226 : ((((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1226.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1228 : (((((('s, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1228.
        Stack shape : FUNC IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1231 : (((((('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1231.
        Stack shape : GETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR ty BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1235 : (((('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_state
      (** State 1235.
        Stack shape : GETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR.
        Start symbol: spec. *)

    | MenhirState1237 : ((((('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1237.
        Stack shape : GETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty BEGIN.
        Start symbol: spec. *)

    | MenhirState1238 : (((((('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1238.
        Stack shape : GETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1239 : ((((((('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1239.
        Stack shape : GETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1241 : (((((('s, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1241.
        Stack shape : GETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR ty BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1244 : (('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1244.
        Stack shape : LET MINUS.
        Start symbol: spec. *)

    | MenhirState1246 : ((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1246.
        Stack shape : LET MINUS ty.
        Start symbol: spec. *)

    | MenhirState1247 : (((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1247.
        Stack shape : LET MINUS ty expr.
        Start symbol: spec. *)

    | MenhirState1248 : ((((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1248.
        Stack shape : LET MINUS ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1250 : (('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1250.
        Stack shape : LET MINUS.
        Start symbol: spec. *)

    | MenhirState1252 : ((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1252.
        Stack shape : LET MINUS ty.
        Start symbol: spec. *)

    | MenhirState1253 : (((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1253.
        Stack shape : LET MINUS ty expr.
        Start symbol: spec. *)

    | MenhirState1254 : ((((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1254.
        Stack shape : LET MINUS ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1257 : (('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1257.
        Stack shape : LET IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1258 : ((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1258.
        Stack shape : LET IDENTIFIER expr.
        Start symbol: spec. *)

    | MenhirState1259 : (((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1259.
        Stack shape : LET IDENTIFIER expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1261 : (('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1261.
        Stack shape : LET IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1263 : ((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1263.
        Stack shape : LET IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1264 : (((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1264.
        Stack shape : LET IDENTIFIER ty expr.
        Start symbol: spec. *)

    | MenhirState1265 : ((((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1265.
        Stack shape : LET IDENTIFIER ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1267 : (('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1267.
        Stack shape : LET IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1269 : ((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1269.
        Stack shape : LET IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1270 : (((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1270.
        Stack shape : LET IDENTIFIER ty expr.
        Start symbol: spec. *)

    | MenhirState1271 : ((((('s, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1271.
        Stack shape : LET IDENTIFIER ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1275 : ((('s, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1275.
        Stack shape : PRAGMA IDENTIFIER separated_nonempty_list(COMMA,expr) SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1278 : (((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1278.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR IDENTIFIER ty BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1280 : (((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1280.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1282 : ((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1282.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR IDENTIFIER ty BEGIN.
        Start symbol: spec. *)

    | MenhirState1283 : (((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1283.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR IDENTIFIER ty BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1284 : ((((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1284.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR IDENTIFIER ty BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1286 : (((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1286.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR RPAR IDENTIFIER ty BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1292 : (((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1292.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1294 : ((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1294.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR IDENTIFIER ty BEGIN.
        Start symbol: spec. *)

    | MenhirState1295 : (((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1295.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR IDENTIFIER ty BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1296 : ((((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1296.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR IDENTIFIER ty BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1298 : (((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1298.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR IDENTIFIER ty BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1300 : (((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1300.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1302 : ((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_state
      (** State 1302.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR IDENTIFIER ty BEGIN.
        Start symbol: spec. *)

    | MenhirState1303 : (((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_state
      (** State 1303.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR IDENTIFIER ty BEGIN nonempty_list(stmt).
        Start symbol: spec. *)

    | MenhirState1304 : ((((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1304.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR IDENTIFIER ty BEGIN nonempty_list(stmt) end_semicolon.
        Start symbol: spec. *)

    | MenhirState1306 : (((((('s, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon, _menhir_box_spec) _menhir_state
      (** State 1306.
        Stack shape : SETTER IDENTIFIER loption(braced(nclist(opt_typed_identifier))) LPAR separated_nonempty_list(COMMA,typed_identifier) RPAR IDENTIFIER ty BEGIN end_semicolon.
        Start symbol: spec. *)

    | MenhirState1309 : (('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1309.
        Stack shape : TYPE IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1311 : ((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_RECORD _menhir_cell0_LBRACE, _menhir_box_spec) _menhir_state
      (** State 1311.
        Stack shape : TYPE IDENTIFIER RECORD LBRACE.
        Start symbol: spec. *)

    | MenhirState1315 : ((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_EXCEPTION _menhir_cell0_LBRACE, _menhir_box_spec) _menhir_state
      (** State 1315.
        Stack shape : TYPE IDENTIFIER EXCEPTION LBRACE.
        Start symbol: spec. *)

    | MenhirState1319 : ((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ENUMERATION _menhir_cell0_LBRACE, _menhir_box_spec) _menhir_state
      (** State 1319.
        Stack shape : TYPE IDENTIFIER ENUMERATION LBRACE.
        Start symbol: spec. *)

    | MenhirState1321 : (('s, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1321.
        Stack shape : IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1327 : ((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty_decl _menhir_cell0_SUBTYPES _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1327.
        Stack shape : TYPE IDENTIFIER ty_decl SUBTYPES IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1330 : ((('s, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty_decl _menhir_cell0_option_subtype_ _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1330.
        Stack shape : TYPE IDENTIFIER ty_decl option(subtype) SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1334 : (('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1334.
        Stack shape : VAR MINUS.
        Start symbol: spec. *)

    | MenhirState1336 : ((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1336.
        Stack shape : VAR MINUS ty SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1338 : ((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1338.
        Stack shape : VAR MINUS ty.
        Start symbol: spec. *)

    | MenhirState1339 : (((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1339.
        Stack shape : VAR MINUS ty expr.
        Start symbol: spec. *)

    | MenhirState1340 : ((((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1340.
        Stack shape : VAR MINUS ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1342 : (('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_state
      (** State 1342.
        Stack shape : VAR MINUS.
        Start symbol: spec. *)

    | MenhirState1344 : ((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1344.
        Stack shape : VAR MINUS ty SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1346 : ((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1346.
        Stack shape : VAR MINUS ty.
        Start symbol: spec. *)

    | MenhirState1347 : (((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1347.
        Stack shape : VAR MINUS ty expr.
        Start symbol: spec. *)

    | MenhirState1348 : ((((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1348.
        Stack shape : VAR MINUS ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1351 : (('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1351.
        Stack shape : VAR IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1352 : ((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1352.
        Stack shape : VAR IDENTIFIER expr.
        Start symbol: spec. *)

    | MenhirState1353 : (((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1353.
        Stack shape : VAR IDENTIFIER expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1355 : (('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1355.
        Stack shape : VAR IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1357 : ((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1357.
        Stack shape : VAR IDENTIFIER ty SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1359 : ((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1359.
        Stack shape : VAR IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1360 : (((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1360.
        Stack shape : VAR IDENTIFIER ty expr.
        Start symbol: spec. *)

    | MenhirState1361 : ((((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1361.
        Stack shape : VAR IDENTIFIER ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1363 : (('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_state
      (** State 1363.
        Stack shape : VAR IDENTIFIER.
        Start symbol: spec. *)

    | MenhirState1365 : ((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1365.
        Stack shape : VAR IDENTIFIER ty SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1367 : ((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_state
      (** State 1367.
        Stack shape : VAR IDENTIFIER ty.
        Start symbol: spec. *)

    | MenhirState1368 : (((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_state
      (** State 1368.
        Stack shape : VAR IDENTIFIER ty expr.
        Start symbol: spec. *)

    | MenhirState1369 : ((((('s, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON, _menhir_box_spec) _menhir_state
      (** State 1369.
        Stack shape : VAR IDENTIFIER ty expr SEMI_COLON.
        Start symbol: spec. *)

    | MenhirState1374 : ('s, _menhir_box_stmts) _menhir_state
      (** State 1374.
        Stack shape : .
        Start symbol: stmts. *)

  
  and ('s, 'r) _menhir_cell1_decl_item = 
    | MenhirCell1_decl_item of 's * ('s, 'r) _menhir_state * (AST.local_decl_item)
  
  and ('s, 'r) _menhir_cell1_end_semicolon = 
    | MenhirCell1_end_semicolon of 's * ('s, 'r) _menhir_state * (unit) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_expr = 
    | MenhirCell1_expr of 's * ('s, 'r) _menhir_state * (AST.expr) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_expr_pattern = 
    | MenhirCell1_expr_pattern of 's * ('s, 'r) _menhir_state * (AST.expr) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_lexpr = 
    | MenhirCell1_lexpr of 's * ('s, 'r) _menhir_state * (AST.lexpr) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_lexpr_atom_desc = 
    | MenhirCell1_lexpr_atom_desc of 's * ('s, 'r) _menhir_state * (AST.lexpr_desc) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_loption___anonymous_22_ = 
    | MenhirCell1_loption___anonymous_22_ of 's * ('s, 'r) _menhir_state * (AST.field list) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ = 
    | MenhirCell1_loption_braced_nclist_opt_typed_identifier___ of 's * ('s, 'r) _menhir_state * ((string * AST.ty option) list)
  
  and ('s, 'r) _menhir_cell1_loption_non_empty_trailing_list_COMMA_bitfield__ = 
    | MenhirCell1_loption_non_empty_trailing_list_COMMA_bitfield__ of 's * ('s, 'r) _menhir_state * (AST.bitfield list)
  
  and ('s, 'r) _menhir_cell1_loption_plist_expr__ = 
    | MenhirCell1_loption_plist_expr__ of 's * ('s, 'r) _menhir_state * (AST.expr list) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ = 
    | MenhirCell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ of 's * ('s, 'r) _menhir_state * (AST.case_alt list)
  
  and ('s, 'r) _menhir_cell1_nonempty_list_catcher_ = 
    | MenhirCell1_nonempty_list_catcher_ of 's * ('s, 'r) _menhir_state * (AST.catcher list)
  
  and ('s, 'r) _menhir_cell1_nonempty_list_stmt_ = 
    | MenhirCell1_nonempty_list_stmt_ of 's * ('s, 'r) _menhir_state * (AST.stmt list) * Lexing.position
  
  and 's _menhir_cell0_option_subtype_ = 
    | MenhirCell0_option_subtype_ of 's * ((string * AST.field list) option)
  
  and ('s, 'r) _menhir_cell1_pattern = 
    | MenhirCell1_pattern of 's * ('s, 'r) _menhir_state * (AST.pattern) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_s_else = 
    | MenhirCell1_s_else of 's * ('s, 'r) _menhir_state * (AST.stmt) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ = 
    | MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ of 's * ('s, 'r) _menhir_state * (string list)
  
  and ('s, 'r) _menhir_cell1_separated_nonempty_list_COMMA_decl_item_ = 
    | MenhirCell1_separated_nonempty_list_COMMA_decl_item_ of 's * ('s, 'r) _menhir_state * (AST.local_decl_item list)
  
  and ('s, 'r) _menhir_cell1_separated_nonempty_list_COMMA_expr_ = 
    | MenhirCell1_separated_nonempty_list_COMMA_expr_ of 's * ('s, 'r) _menhir_state * (AST.expr list) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_separated_nonempty_list_COMMA_pattern_ = 
    | MenhirCell1_separated_nonempty_list_COMMA_pattern_ of 's * ('s, 'r) _menhir_state * (AST.pattern list) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_separated_nonempty_list_COMMA_slice_ = 
    | MenhirCell1_separated_nonempty_list_COMMA_slice_ of 's * ('s, 'r) _menhir_state * (AST.slice list)
  
  and ('s, 'r) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ = 
    | MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ of 's * ('s, 'r) _menhir_state * (AST.typed_identifier list)
  
  and ('s, 'r) _menhir_cell1_ty = 
    | MenhirCell1_ty of 's * ('s, 'r) _menhir_state * (AST.ty) * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ty_decl = 
    | MenhirCell1_ty_decl of 's * ('s, 'r) _menhir_state * (AST.ty)
  
  and ('s, 'r) _menhir_cell1_AND = 
    | MenhirCell1_AND of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ARRAY = 
    | MenhirCell1_ARRAY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ARROBASE_LOOPLIMIT = 
    | MenhirCell1_ARROBASE_LOOPLIMIT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ARROW = 
    | MenhirCell1_ARROW of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_AS = 
    | MenhirCell1_AS of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ASSERT = 
    | MenhirCell1_ASSERT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BAND = 
    | MenhirCell1_BAND of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_BEGIN = 
    | MenhirCell1_BEGIN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_BEGIN = 
    | MenhirCell0_BEGIN of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BEQ = 
    | MenhirCell1_BEQ of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_BITS = 
    | MenhirCell1_BITS of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BNOT = 
    | MenhirCell1_BNOT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_BNOT = 
    | MenhirCell0_BNOT of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_BOR = 
    | MenhirCell1_BOR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_CASE = 
    | MenhirCell1_CASE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_COLON = 
    | MenhirCell1_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_COLON_COLON = 
    | MenhirCell1_COLON_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_COMMA = 
    | MenhirCell1_COMMA of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_CONCAT = 
    | MenhirCell1_CONCAT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_CONFIG = 
    | MenhirCell1_CONFIG of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_CONSTANT = 
    | MenhirCell1_CONSTANT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_DEBUG = 
    | MenhirCell1_DEBUG of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_DIV = 
    | MenhirCell1_DIV of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_DIVRM = 
    | MenhirCell1_DIVRM of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_DO = 
    | MenhirCell1_DO of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_DOT = 
    | MenhirCell1_DOT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_DOWNTO = 
    | MenhirCell1_DOWNTO of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ELSE = 
    | MenhirCell1_ELSE of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_ELSIF = 
    | MenhirCell1_ELSIF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_END = 
    | MenhirCell1_END of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_ENUMERATION = 
    | MenhirCell1_ENUMERATION of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_EOR = 
    | MenhirCell1_EOR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_EQ_OP = 
    | MenhirCell1_EQ_OP of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_EXCEPTION = 
    | MenhirCell1_EXCEPTION of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FOR = 
    | MenhirCell1_FOR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_FUNC = 
    | MenhirCell1_FUNC of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_GEQ = 
    | MenhirCell1_GEQ of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_GEQ = 
    | MenhirCell0_GEQ of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_GETTER = 
    | MenhirCell1_GETTER of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_GT = 
    | MenhirCell1_GT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_IDENTIFIER = 
    | MenhirCell1_IDENTIFIER of 's * ('s, 'r) _menhir_state * (
# 40 "asllib/Tokens.mly"
       (string)
# 3849 "asllib/Parser.ml"
  ) * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_IDENTIFIER = 
    | MenhirCell0_IDENTIFIER of 's * (
# 40 "asllib/Tokens.mly"
       (string)
# 3856 "asllib/Parser.ml"
  ) * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IF = 
    | MenhirCell1_IF of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_IMPL = 
    | MenhirCell1_IMPL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_IN = 
    | MenhirCell1_IN of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_INTEGER = 
    | MenhirCell1_INTEGER of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LBRACE = 
    | MenhirCell1_LBRACE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LBRACE = 
    | MenhirCell0_LBRACE of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LBRACKET = 
    | MenhirCell1_LBRACKET of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LEQ = 
    | MenhirCell1_LEQ of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LEQ = 
    | MenhirCell0_LEQ of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LET = 
    | MenhirCell1_LET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LLBRACKET = 
    | MenhirCell1_LLBRACKET of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LOOPLIMIT = 
    | MenhirCell1_LOOPLIMIT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_LPAR = 
    | MenhirCell1_LPAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_LPAR = 
    | MenhirCell0_LPAR of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_LT = 
    | MenhirCell1_LT of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_MINUS = 
    | MenhirCell1_MINUS of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and 's _menhir_cell0_MINUS = 
    | MenhirCell0_MINUS of 's * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_MOD = 
    | MenhirCell1_MOD of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_MUL = 
    | MenhirCell1_MUL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_NEQ = 
    | MenhirCell1_NEQ of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_NOT = 
    | MenhirCell1_NOT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_OF = 
    | MenhirCell1_OF of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_OR = 
    | MenhirCell1_OR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_OTHERWISE = 
    | MenhirCell1_OTHERWISE of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PASS = 
    | MenhirCell1_PASS of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PLUS = 
    | MenhirCell1_PLUS of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PLUS_COLON = 
    | MenhirCell1_PLUS_COLON of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_POW = 
    | MenhirCell1_POW of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_PRAGMA = 
    | MenhirCell1_PRAGMA of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_PRINT = 
    | MenhirCell1_PRINT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RBRACE = 
    | MenhirCell1_RBRACE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_RBRACE = 
    | MenhirCell0_RBRACE of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RBRACKET = 
    | MenhirCell1_RBRACKET of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_RBRACKET = 
    | MenhirCell0_RBRACKET of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RDIV = 
    | MenhirCell1_RDIV of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_RECORD = 
    | MenhirCell1_RECORD of 's * ('s, 'r) _menhir_state * Lexing.position * Lexing.position
  
  and ('s, 'r) _menhir_cell1_REPEAT = 
    | MenhirCell1_REPEAT of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_REPEAT = 
    | MenhirCell0_REPEAT of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RETURN = 
    | MenhirCell1_RETURN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_RPAR = 
    | MenhirCell1_RPAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_RPAR = 
    | MenhirCell0_RPAR of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SEMI_COLON = 
    | MenhirCell1_SEMI_COLON of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_SEMI_COLON = 
    | MenhirCell0_SEMI_COLON of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SETTER = 
    | MenhirCell1_SETTER of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_SHL = 
    | MenhirCell1_SHL of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SHR = 
    | MenhirCell1_SHR of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_SLICING = 
    | MenhirCell1_SLICING of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_STAR_COLON = 
    | MenhirCell1_STAR_COLON of 's * ('s, 'r) _menhir_state
  
  and 's _menhir_cell0_SUBTYPES = 
    | MenhirCell0_SUBTYPES of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_THEN = 
    | MenhirCell1_THEN of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_THROW = 
    | MenhirCell1_THROW of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TO = 
    | MenhirCell1_TO of 's * ('s, 'r) _menhir_state
  
  and ('s, 'r) _menhir_cell1_TRY = 
    | MenhirCell1_TRY of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_TYPE = 
    | MenhirCell1_TYPE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_UNKNOWN = 
    | MenhirCell1_UNKNOWN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_UNREACHABLE = 
    | MenhirCell1_UNREACHABLE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_VAR = 
    | MenhirCell1_VAR of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_WHEN = 
    | MenhirCell1_WHEN of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and ('s, 'r) _menhir_cell1_WHILE = 
    | MenhirCell1_WHILE of 's * ('s, 'r) _menhir_state * Lexing.position
  
  and 's _menhir_cell0_WHILE = 
    | MenhirCell0_WHILE of 's * Lexing.position
  
  and ('s, 'r) _menhir_cell1_WITH = 
    | MenhirCell1_WITH of 's * ('s, 'r) _menhir_state
  
  and _menhir_box_stmts = 
    | MenhirBox_stmts of (AST.stmt) [@@unboxed]
  
  and _menhir_box_spec = 
    | MenhirBox_spec of (AST.t) [@@unboxed]
  
  and _menhir_box_opn = 
    | MenhirBox_opn of (AST.t) [@@unboxed]
  
  let _menhir_action_003 =
    fun _1 _1_inlined1 _2 ->
      let as_ty =
        let _1 = _1_inlined1 in
        _2
      in
      let untyped_decl_item =
        let _1_1 = _1 in
        
# 415 "asllib/Parser.mly"
                              LDI_Var      
# 4062 "asllib/Parser.ml"
         _1_1
      in
      (
# 411 "asllib/Parser.mly"
                                      LDI_Typed    
# 4068 "asllib/Parser.ml"
       (untyped_decl_item, as_ty) : (AST.local_decl_item))
  
  let _menhir_action_004 =
    fun _1 _1_inlined1 _2 ->
      let as_ty =
        let _1 = _1_inlined1 in
        _2
      in
      let untyped_decl_item =
        let _1_1 = _1 in
        
# 415 "asllib/Parser.mly"
                              LDI_Var      
# 4082 "asllib/Parser.ml"
         _1_1
      in
      (
# 411 "asllib/Parser.mly"
                                      LDI_Typed    
# 4088 "asllib/Parser.ml"
       (untyped_decl_item, as_ty) : (AST.local_decl_item))
  
  let _menhir_action_005 =
    fun _1 _1_inlined1 _2 ->
      let as_ty =
        let _1 = _1_inlined1 in
        _2
      in
      let untyped_decl_item = 
# 416 "asllib/Parser.mly"
                            ( LDI_Discard )
# 4100 "asllib/Parser.ml"
       in
      (
# 411 "asllib/Parser.mly"
                                      LDI_Typed    
# 4105 "asllib/Parser.ml"
       (untyped_decl_item, as_ty) : (AST.local_decl_item))
  
  let _menhir_action_006 =
    fun _1 _1_inlined1 _2 ->
      let as_ty =
        let _1 = _1_inlined1 in
        _2
      in
      let untyped_decl_item = 
# 416 "asllib/Parser.mly"
                            ( LDI_Discard )
# 4117 "asllib/Parser.ml"
       in
      (
# 411 "asllib/Parser.mly"
                                      LDI_Typed    
# 4122 "asllib/Parser.ml"
       (untyped_decl_item, as_ty) : (AST.local_decl_item))
  
  let _menhir_action_007 =
    fun _1_inlined1 _2 _2_inlined1 li x ->
      let as_ty =
        let (_2, _1) = (_2_inlined1, _1_inlined1) in
        _2
      in
      let untyped_decl_item =
        let _1 =
          let x = 
# 177 "asllib/Parser.mly"
                                                    ( x :: li )
# 4136 "asllib/Parser.ml"
           in
          
# 205 "<standard.mly>"
    ( x )
# 4141 "asllib/Parser.ml"
          
        in
        let _1_1 = _1 in
        
# 417 "asllib/Parser.mly"
                              LDI_Tuple    
# 4148 "asllib/Parser.ml"
         _1_1
      in
      (
# 411 "asllib/Parser.mly"
                                      LDI_Typed    
# 4154 "asllib/Parser.ml"
       (untyped_decl_item, as_ty) : (AST.local_decl_item))
  
  let _menhir_action_008 =
    fun _1_inlined1 _2 _2_inlined1 li x ->
      let as_ty =
        let (_2, _1) = (_2_inlined1, _1_inlined1) in
        _2
      in
      let untyped_decl_item =
        let _1 =
          let x = 
# 177 "asllib/Parser.mly"
                                                    ( x :: li )
# 4168 "asllib/Parser.ml"
           in
          
# 205 "<standard.mly>"
    ( x )
# 4173 "asllib/Parser.ml"
          
        in
        let _1_1 = _1 in
        
# 417 "asllib/Parser.mly"
                              LDI_Tuple    
# 4180 "asllib/Parser.ml"
         _1_1
      in
      (
# 411 "asllib/Parser.mly"
                                      LDI_Typed    
# 4186 "asllib/Parser.ml"
       (untyped_decl_item, as_ty) : (AST.local_decl_item))
  
  let _menhir_action_009 =
    fun _1 ->
      let _1_1 = _1 in
      (
# 415 "asllib/Parser.mly"
                              LDI_Var      
# 4195 "asllib/Parser.ml"
       _1_1 : (AST.local_decl_item))
  
  let _menhir_action_010 =
    fun _1 ->
      (
# 416 "asllib/Parser.mly"
                            ( LDI_Discard )
# 4203 "asllib/Parser.ml"
       : (AST.local_decl_item))
  
  let _menhir_action_011 =
    fun _2 li x ->
      let _1 =
        let x = 
# 177 "asllib/Parser.mly"
                                                    ( x :: li )
# 4212 "asllib/Parser.ml"
         in
        
# 205 "<standard.mly>"
    ( x )
# 4217 "asllib/Parser.ml"
        
      in
      let _1_1 = _1 in
      (
# 417 "asllib/Parser.mly"
                              LDI_Tuple    
# 4224 "asllib/Parser.ml"
       _1_1 : (AST.local_decl_item))
  
  let _menhir_action_012 =
    fun _1 _2 ->
      (_2 : (AST.expr))
  
  let _menhir_action_013 =
    fun _1 _3 _endpos_e_else_ _startpos__1_ c e e_else ->
      let desc = 
# 252 "asllib/Parser.mly"
                                                        E_Cond 
# 4236 "asllib/Parser.ml"
       (c, e, e_else) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_else_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4244 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_014 =
    fun _1 _endpos_opt_ _startpos__1_ opt ->
      let _endpos = _endpos_opt_ in
      let _startpos = _startpos__1_ in
      (
# 187 "asllib/Parser.mly"
                                                  (
      if Option.is_none opt && not Config.allow_no_end_semicolon then
          Error.fatal_here _startpos _endpos @@ Error.ObsoleteSyntax "Missing ';' after 'end' keyword.";
  )
# 4257 "asllib/Parser.ml"
       : (unit))
  
  let _menhir_action_015 =
    fun _endpos_i_ _startpos_i_ i ->
      let desc =
        let value = 
# 200 "asllib/Parser.mly"
                        L_Int          
# 4266 "asllib/Parser.ml"
         i in
        
# 264 "asllib/Parser.mly"
                                                                    E_Literal             
# 4271 "asllib/Parser.ml"
         value
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_i_, _startpos_i_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4280 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_016 =
    fun _endpos_b_ _startpos_b_ b ->
      let desc =
        let value = 
# 201 "asllib/Parser.mly"
                        L_Bool         
# 4289 "asllib/Parser.ml"
         b in
        
# 264 "asllib/Parser.mly"
                                                                    E_Literal             
# 4294 "asllib/Parser.ml"
         value
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_b_, _startpos_b_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4303 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_017 =
    fun _endpos_r_ _startpos_r_ r ->
      let desc =
        let value = 
# 202 "asllib/Parser.mly"
                        L_Real         
# 4312 "asllib/Parser.ml"
         r in
        
# 264 "asllib/Parser.mly"
                                                                    E_Literal             
# 4317 "asllib/Parser.ml"
         value
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_r_, _startpos_r_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4326 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_018 =
    fun _endpos_b_ _startpos_b_ b ->
      let desc =
        let value = 
# 203 "asllib/Parser.mly"
                        L_BitVector    
# 4335 "asllib/Parser.ml"
         b in
        
# 264 "asllib/Parser.mly"
                                                                    E_Literal             
# 4340 "asllib/Parser.ml"
         value
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_b_, _startpos_b_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4349 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_019 =
    fun _endpos_s_ _startpos_s_ s ->
      let desc =
        let value = 
# 204 "asllib/Parser.mly"
                        L_String       
# 4358 "asllib/Parser.ml"
         s in
        
# 264 "asllib/Parser.mly"
                                                                    E_Literal             
# 4363 "asllib/Parser.ml"
         value
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_s_, _startpos_s_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4372 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_020 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 265 "asllib/Parser.mly"
                                                                    E_Var                 
# 4382 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4391 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_021 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 214 "asllib/Parser.mly"
                  ( AND    )
# 4400 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4405 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4414 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_022 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 215 "asllib/Parser.mly"
                  ( BAND   )
# 4423 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4428 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4437 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_023 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 216 "asllib/Parser.mly"
                  ( BOR    )
# 4446 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4451 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4460 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_024 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 217 "asllib/Parser.mly"
                  ( EQ_OP  )
# 4469 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4474 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4483 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_025 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 218 "asllib/Parser.mly"
                  ( DIV    )
# 4492 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4497 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4506 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_026 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 219 "asllib/Parser.mly"
                  ( DIVRM  )
# 4515 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4520 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4529 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_027 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 220 "asllib/Parser.mly"
                  ( EOR    )
# 4538 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4543 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4552 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_028 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 221 "asllib/Parser.mly"
                  ( EQ_OP  )
# 4561 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4566 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4575 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_029 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 222 "asllib/Parser.mly"
                  ( NEQ    )
# 4584 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4589 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4598 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_030 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 223 "asllib/Parser.mly"
                  ( GT     )
# 4607 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4612 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4621 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_031 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 224 "asllib/Parser.mly"
                  ( GEQ    )
# 4630 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4635 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4644 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_032 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 225 "asllib/Parser.mly"
                  ( IMPL   )
# 4653 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4658 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4667 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_033 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 226 "asllib/Parser.mly"
                  ( LT     )
# 4676 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4681 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4690 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_034 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 227 "asllib/Parser.mly"
                  ( LEQ    )
# 4699 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4704 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4713 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_035 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 228 "asllib/Parser.mly"
                  ( PLUS   )
# 4722 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4727 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4736 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_036 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 229 "asllib/Parser.mly"
                  ( MINUS  )
# 4745 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4750 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4759 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_037 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 230 "asllib/Parser.mly"
                  ( MOD    )
# 4768 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4773 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4782 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_038 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 231 "asllib/Parser.mly"
                  ( MUL    )
# 4791 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4796 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4805 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_039 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 232 "asllib/Parser.mly"
                  ( OR     )
# 4814 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4819 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4828 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_040 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 233 "asllib/Parser.mly"
                  ( RDIV   )
# 4837 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4842 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4851 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_041 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 234 "asllib/Parser.mly"
                  ( SHL    )
# 4860 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4865 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4874 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_042 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 235 "asllib/Parser.mly"
                  ( SHR    )
# 4883 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4888 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4897 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_043 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 236 "asllib/Parser.mly"
                  ( POW    )
# 4906 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4911 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4920 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_044 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 237 "asllib/Parser.mly"
                  ( BV_CONCAT )
# 4929 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4934 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4943 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_045 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op =
          let _1 = () in
          
# 211 "asllib/Parser.mly"
                                  ( PLUS )
# 4954 "asllib/Parser.ml"
          
        in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 4960 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4969 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_046 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 207 "asllib/Parser.mly"
            ( BNOT )
# 4978 "asllib/Parser.ml"
         in
        
# 267 "asllib/Parser.mly"
                                                                    E_Unop                
# 4983 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 4992 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_047 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 208 "asllib/Parser.mly"
            ( NEG )
# 5001 "asllib/Parser.ml"
         in
        
# 267 "asllib/Parser.mly"
                                                                    E_Unop                
# 5006 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5015 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_048 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 209 "asllib/Parser.mly"
            ( NOT )
# 5024 "asllib/Parser.ml"
         in
        
# 267 "asllib/Parser.mly"
                                                                    E_Unop                
# 5029 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5038 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_049 =
    fun _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else ->
      let desc = 
# 268 "asllib/Parser.mly"
                                                                    E_Cond                
# 5046 "asllib/Parser.ml"
       (e1, e2, e_else) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_else_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5054 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_050 =
    fun _endpos__3_ _startpos_name_ name ->
      let desc =
        let call =
          let args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 5065 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 5070 "asllib/Parser.ml"
            
          in
          
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 5076 "asllib/Parser.ml"
          
        in
        
# 269 "asllib/Parser.mly"
                                                                    e_call                
# 5082 "asllib/Parser.ml"
         call
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5091 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_051 =
    fun _1_inlined1 _endpos__3_ _startpos_name_ name ->
      let desc =
        let call =
          let args =
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 5103 "asllib/Parser.ml"
            
          in
          
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 5109 "asllib/Parser.ml"
          
        in
        
# 269 "asllib/Parser.mly"
                                                                    e_call                
# 5115 "asllib/Parser.ml"
         call
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5124 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_052 =
    fun _1_inlined1 _endpos_args_ _startpos_name_ args name ->
      let desc =
        let call =
          let params =
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 5136 "asllib/Parser.ml"
            
          in
          
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 5142 "asllib/Parser.ml"
          
        in
        
# 269 "asllib/Parser.mly"
                                                                    e_call                
# 5148 "asllib/Parser.ml"
         call
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5157 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_053 =
    fun _1_inlined1 _endpos__3_ _startpos_e_ e ->
      let desc =
        let slices =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 5168 "asllib/Parser.ml"
          
        in
        
# 270 "asllib/Parser.mly"
                                                                    E_Slice               
# 5174 "asllib/Parser.ml"
         (e, slices)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5183 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_054 =
    fun _2 _4 _endpos__4_ _startpos_e1_ e1 e2 ->
      let desc = 
# 271 "asllib/Parser.mly"
                                                                    E_GetArray            
# 5191 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__4_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5199 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_055 =
    fun _2 _endpos_x_ _startpos_e_ e x ->
      let desc = 
# 272 "asllib/Parser.mly"
                                                                    E_GetField            
# 5207 "asllib/Parser.ml"
       (e, x) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_x_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5215 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_056 =
    fun _1_inlined1 _2 _endpos__3_ _startpos_e_ e ->
      let desc =
        let fs =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 5226 "asllib/Parser.ml"
          
        in
        
# 273 "asllib/Parser.mly"
                                                                    E_GetFields           
# 5232 "asllib/Parser.ml"
         (e, fs)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5241 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_057 =
    fun _2 _endpos_ty_ _startpos_sub_expr_ sub_expr ty ->
      let desc = 
# 275 "asllib/Parser.mly"
                                                                    E_ATC                 
# 5249 "asllib/Parser.ml"
       (sub_expr, ty) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5257 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_058 =
    fun _2 _endpos__3_ _startpos__1_ _startpos_sub_expr_ sub_expr ->
      let desc =
        let implicit_t_int =
          let desc =
            let constraint_kind =
              let _1 =
                let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 5270 "asllib/Parser.ml"
                 in
                
# 205 "<standard.mly>"
    ( x )
# 5275 "asllib/Parser.ml"
                
              in
              let _1_1 = _1 in
              
# 300 "asllib/Parser.mly"
                                                          WellConstrained  
# 5282 "asllib/Parser.ml"
               _1_1
            in
            
# 380 "asllib/Parser.mly"
                                                       T_Int 
# 5288 "asllib/Parser.ml"
             constraint_kind
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5297 "asllib/Parser.ml"
          
        in
        
# 276 "asllib/Parser.mly"
                                                                    E_ATC                 
# 5303 "asllib/Parser.ml"
         (sub_expr, implicit_t_int)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5312 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_059 =
    fun _1_inlined1 _2 _endpos__3_ _startpos__1_ _startpos_sub_expr_ sub_expr ->
      let desc =
        let implicit_t_int =
          let desc =
            let constraint_kind =
              let _1 =
                let x = _1_inlined1 in
                
# 205 "<standard.mly>"
    ( x )
# 5326 "asllib/Parser.ml"
                
              in
              let _1_1 = _1 in
              
# 300 "asllib/Parser.mly"
                                                          WellConstrained  
# 5333 "asllib/Parser.ml"
               _1_1
            in
            
# 380 "asllib/Parser.mly"
                                                       T_Int 
# 5339 "asllib/Parser.ml"
             constraint_kind
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5348 "asllib/Parser.ml"
          
        in
        
# 276 "asllib/Parser.mly"
                                                                    E_ATC                 
# 5354 "asllib/Parser.ml"
         (sub_expr, implicit_t_int)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5363 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_060 =
    fun _1_inlined1 _2 _endpos__1_inlined1_ _endpos__3_ _startpos__1_inlined1_ _startpos_sub_expr_ sub_expr ->
      let desc =
        let pattern_set =
          let x =
            let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
            let desc =
              let _1_1 = _1 in
              
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 5377 "asllib/Parser.ml"
               _1_1
            in
            let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5386 "asllib/Parser.ml"
            
          in
          
# 205 "<standard.mly>"
    ( x )
# 5392 "asllib/Parser.ml"
          
        in
        
# 278 "asllib/Parser.mly"
                                                                    E_Pattern             
# 5398 "asllib/Parser.ml"
         (sub_expr, pattern_set)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5407 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_061 =
    fun _1 _1_inlined2 _2 _endpos__1_inlined2_ _endpos__3_ _startpos__1_ _startpos__1_inlined2_ _startpos_sub_expr_ sub_expr ->
      let desc =
        let pattern_set =
          let desc =
            let _2 =
              let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
              let x =
                let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
                let desc =
                  let _1_1 = _1 in
                  
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 5424 "asllib/Parser.ml"
                   _1_1
                in
                let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
                let _endpos = _endpos_desc_ in
                let _symbolstartpos = _startpos_desc_ in
                
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5433 "asllib/Parser.ml"
                
              in
              
# 205 "<standard.mly>"
    ( x )
# 5439 "asllib/Parser.ml"
              
            in
            let _2_1 = _2 in
            
# 326 "asllib/Parser.mly"
                                      Pattern_Not  
# 5446 "asllib/Parser.ml"
             _2_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5455 "asllib/Parser.ml"
          
        in
        
# 278 "asllib/Parser.mly"
                                                                    E_Pattern             
# 5461 "asllib/Parser.ml"
         (sub_expr, pattern_set)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5470 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_062 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_sub_expr_ sub_expr ->
      let desc =
        let pattern_mask =
          let desc =
            let _1_1 = _1 in
            
# 308 "asllib/Parser.mly"
                                            Pattern_Mask  
# 5482 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5491 "asllib/Parser.ml"
          
        in
        
# 279 "asllib/Parser.mly"
                                                                    E_Pattern             
# 5497 "asllib/Parser.ml"
         (sub_expr, pattern_mask)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5506 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_063 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e ->
      let desc =
        let p =
          let desc =
            let _1_1 = _1 in
            
# 308 "asllib/Parser.mly"
                                            Pattern_Mask  
# 5518 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5527 "asllib/Parser.ml"
          
        in
        
# 280 "asllib/Parser.mly"
                                                                  ( E_Pattern (e, Pattern_Not (p) |> add_pos_from p) )
# 5533 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5542 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_064 =
    fun _1 _1_inlined1 _endpos_ty_ _startpos__1_ ty ->
      let desc =
        let _2 = _1_inlined1 in
        
# 282 "asllib/Parser.mly"
                                                                    E_Unknown             
# 5552 "asllib/Parser.ml"
         ty
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5561 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_065 =
    fun _1 _1_inlined1 _endpos_ty_ _startpos__1_ ty ->
      let desc =
        let _2 = _1_inlined1 in
        
# 282 "asllib/Parser.mly"
                                                                    E_Unknown             
# 5571 "asllib/Parser.ml"
         ty
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5580 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_066 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let e = 
# 205 "<standard.mly>"
    ( x )
# 5589 "asllib/Parser.ml"
         in
        
# 283 "asllib/Parser.mly"
                                                                  ( E_Tuple [ e ]        )
# 5594 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5603 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_067 =
    fun _endpos__3_ _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let fields =
          let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 5613 "asllib/Parser.ml"
           in
          
# 205 "<standard.mly>"
    ( x )
# 5618 "asllib/Parser.ml"
          
        in
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5627 "asllib/Parser.ml"
          
        in
        
# 286 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), fields) )
# 5633 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5642 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_068 =
    fun _1_inlined1 _endpos__3_ _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let fields =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 5653 "asllib/Parser.ml"
          
        in
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5662 "asllib/Parser.ml"
          
        in
        
# 286 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), fields) )
# 5668 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5677 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_069 =
    fun _2 _endpos__3_ _startpos__1_ li x ->
      let desc =
        let _1 =
          let x = 
# 177 "asllib/Parser.mly"
                                                    ( x :: li )
# 5687 "asllib/Parser.ml"
           in
          
# 205 "<standard.mly>"
    ( x )
# 5692 "asllib/Parser.ml"
          
        in
        let _1_1 = _1 in
        
# 257 "asllib/Parser.mly"
                                                                    E_Tuple               
# 5699 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5708 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_070 =
    fun _endpos_i_ _startpos_i_ i ->
      let desc =
        let value = 
# 200 "asllib/Parser.mly"
                        L_Int          
# 5717 "asllib/Parser.ml"
         i in
        
# 264 "asllib/Parser.mly"
                                                                    E_Literal             
# 5722 "asllib/Parser.ml"
         value
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_i_, _startpos_i_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5731 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_071 =
    fun _endpos_b_ _startpos_b_ b ->
      let desc =
        let value = 
# 201 "asllib/Parser.mly"
                        L_Bool         
# 5740 "asllib/Parser.ml"
         b in
        
# 264 "asllib/Parser.mly"
                                                                    E_Literal             
# 5745 "asllib/Parser.ml"
         value
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_b_, _startpos_b_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5754 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_072 =
    fun _endpos_r_ _startpos_r_ r ->
      let desc =
        let value = 
# 202 "asllib/Parser.mly"
                        L_Real         
# 5763 "asllib/Parser.ml"
         r in
        
# 264 "asllib/Parser.mly"
                                                                    E_Literal             
# 5768 "asllib/Parser.ml"
         value
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_r_, _startpos_r_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5777 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_073 =
    fun _endpos_b_ _startpos_b_ b ->
      let desc =
        let value = 
# 203 "asllib/Parser.mly"
                        L_BitVector    
# 5786 "asllib/Parser.ml"
         b in
        
# 264 "asllib/Parser.mly"
                                                                    E_Literal             
# 5791 "asllib/Parser.ml"
         value
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_b_, _startpos_b_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5800 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_074 =
    fun _endpos_s_ _startpos_s_ s ->
      let desc =
        let value = 
# 204 "asllib/Parser.mly"
                        L_String       
# 5809 "asllib/Parser.ml"
         s in
        
# 264 "asllib/Parser.mly"
                                                                    E_Literal             
# 5814 "asllib/Parser.ml"
         value
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_s_, _startpos_s_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5823 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_075 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 265 "asllib/Parser.mly"
                                                                    E_Var                 
# 5833 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5842 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_076 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 214 "asllib/Parser.mly"
                  ( AND    )
# 5851 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 5856 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5865 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_077 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 215 "asllib/Parser.mly"
                  ( BAND   )
# 5874 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 5879 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5888 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_078 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 216 "asllib/Parser.mly"
                  ( BOR    )
# 5897 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 5902 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5911 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_079 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 217 "asllib/Parser.mly"
                  ( EQ_OP  )
# 5920 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 5925 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5934 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_080 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 218 "asllib/Parser.mly"
                  ( DIV    )
# 5943 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 5948 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5957 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_081 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 219 "asllib/Parser.mly"
                  ( DIVRM  )
# 5966 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 5971 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 5980 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_082 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 220 "asllib/Parser.mly"
                  ( EOR    )
# 5989 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 5994 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6003 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_083 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 221 "asllib/Parser.mly"
                  ( EQ_OP  )
# 6012 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6017 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6026 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_084 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 222 "asllib/Parser.mly"
                  ( NEQ    )
# 6035 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6040 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6049 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_085 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 223 "asllib/Parser.mly"
                  ( GT     )
# 6058 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6063 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6072 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_086 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 224 "asllib/Parser.mly"
                  ( GEQ    )
# 6081 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6086 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6095 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_087 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 225 "asllib/Parser.mly"
                  ( IMPL   )
# 6104 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6109 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6118 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_088 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 226 "asllib/Parser.mly"
                  ( LT     )
# 6127 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6132 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6141 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_089 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 227 "asllib/Parser.mly"
                  ( LEQ    )
# 6150 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6155 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6164 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_090 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 228 "asllib/Parser.mly"
                  ( PLUS   )
# 6173 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6178 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6187 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_091 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 229 "asllib/Parser.mly"
                  ( MINUS  )
# 6196 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6201 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6210 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_092 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 230 "asllib/Parser.mly"
                  ( MOD    )
# 6219 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6224 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6233 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_093 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 231 "asllib/Parser.mly"
                  ( MUL    )
# 6242 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6247 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6256 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_094 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 232 "asllib/Parser.mly"
                  ( OR     )
# 6265 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6270 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6279 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_095 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 233 "asllib/Parser.mly"
                  ( RDIV   )
# 6288 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6293 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6302 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_096 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 234 "asllib/Parser.mly"
                  ( SHL    )
# 6311 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6316 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6325 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_097 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 235 "asllib/Parser.mly"
                  ( SHR    )
# 6334 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6339 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6348 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_098 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 236 "asllib/Parser.mly"
                  ( POW    )
# 6357 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6362 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6371 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_099 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op = 
# 237 "asllib/Parser.mly"
                  ( BV_CONCAT )
# 6380 "asllib/Parser.ml"
         in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6385 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6394 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_100 =
    fun _1 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc =
        let op =
          let _1 = () in
          
# 211 "asllib/Parser.mly"
                                  ( PLUS )
# 6405 "asllib/Parser.ml"
          
        in
        
# 266 "asllib/Parser.mly"
                                                                    e_binop               
# 6411 "asllib/Parser.ml"
         (e1, op, e2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6420 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_101 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 207 "asllib/Parser.mly"
            ( BNOT )
# 6429 "asllib/Parser.ml"
         in
        
# 267 "asllib/Parser.mly"
                                                                    E_Unop                
# 6434 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6443 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_102 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 208 "asllib/Parser.mly"
            ( NEG )
# 6452 "asllib/Parser.ml"
         in
        
# 267 "asllib/Parser.mly"
                                                                    E_Unop                
# 6457 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6466 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_103 =
    fun _1 _endpos_e_ _startpos__1_ e ->
      let desc =
        let op = 
# 209 "asllib/Parser.mly"
            ( NOT )
# 6475 "asllib/Parser.ml"
         in
        
# 267 "asllib/Parser.mly"
                                                                    E_Unop                
# 6480 "asllib/Parser.ml"
         (op, e)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6489 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_104 =
    fun _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else ->
      let desc = 
# 268 "asllib/Parser.mly"
                                                                    E_Cond                
# 6497 "asllib/Parser.ml"
       (e1, e2, e_else) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e_else_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6505 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_105 =
    fun _endpos__3_ _startpos_name_ name ->
      let desc =
        let call =
          let args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 6516 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 6521 "asllib/Parser.ml"
            
          in
          
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 6527 "asllib/Parser.ml"
          
        in
        
# 269 "asllib/Parser.mly"
                                                                    e_call                
# 6533 "asllib/Parser.ml"
         call
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6542 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_106 =
    fun _1_inlined1 _endpos__3_ _startpos_name_ name ->
      let desc =
        let call =
          let args =
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 6554 "asllib/Parser.ml"
            
          in
          
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 6560 "asllib/Parser.ml"
          
        in
        
# 269 "asllib/Parser.mly"
                                                                    e_call                
# 6566 "asllib/Parser.ml"
         call
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6575 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_107 =
    fun _1_inlined1 _endpos_args_ _startpos_name_ args name ->
      let desc =
        let call =
          let params =
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 6587 "asllib/Parser.ml"
            
          in
          
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 6593 "asllib/Parser.ml"
          
        in
        
# 269 "asllib/Parser.mly"
                                                                    e_call                
# 6599 "asllib/Parser.ml"
         call
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6608 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_108 =
    fun _1_inlined1 _endpos__3_ _startpos_e_ e ->
      let desc =
        let slices =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 6619 "asllib/Parser.ml"
          
        in
        
# 270 "asllib/Parser.mly"
                                                                    E_Slice               
# 6625 "asllib/Parser.ml"
         (e, slices)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6634 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_109 =
    fun _2 _4 _endpos__4_ _startpos_e1_ e1 e2 ->
      let desc = 
# 271 "asllib/Parser.mly"
                                                                    E_GetArray            
# 6642 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__4_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6650 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_110 =
    fun _2 _endpos_x_ _startpos_e_ e x ->
      let desc = 
# 272 "asllib/Parser.mly"
                                                                    E_GetField            
# 6658 "asllib/Parser.ml"
       (e, x) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_x_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6666 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_111 =
    fun _1_inlined1 _2 _endpos__3_ _startpos_e_ e ->
      let desc =
        let fs =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 6677 "asllib/Parser.ml"
          
        in
        
# 273 "asllib/Parser.mly"
                                                                    E_GetFields           
# 6683 "asllib/Parser.ml"
         (e, fs)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6692 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_112 =
    fun _2 _endpos_ty_ _startpos_sub_expr_ sub_expr ty ->
      let desc = 
# 275 "asllib/Parser.mly"
                                                                    E_ATC                 
# 6700 "asllib/Parser.ml"
       (sub_expr, ty) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6708 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_113 =
    fun _2 _endpos__3_ _startpos__1_ _startpos_sub_expr_ sub_expr ->
      let desc =
        let implicit_t_int =
          let desc =
            let constraint_kind =
              let _1 =
                let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 6721 "asllib/Parser.ml"
                 in
                
# 205 "<standard.mly>"
    ( x )
# 6726 "asllib/Parser.ml"
                
              in
              let _1_1 = _1 in
              
# 300 "asllib/Parser.mly"
                                                          WellConstrained  
# 6733 "asllib/Parser.ml"
               _1_1
            in
            
# 380 "asllib/Parser.mly"
                                                       T_Int 
# 6739 "asllib/Parser.ml"
             constraint_kind
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6748 "asllib/Parser.ml"
          
        in
        
# 276 "asllib/Parser.mly"
                                                                    E_ATC                 
# 6754 "asllib/Parser.ml"
         (sub_expr, implicit_t_int)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6763 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_114 =
    fun _1_inlined1 _2 _endpos__3_ _startpos__1_ _startpos_sub_expr_ sub_expr ->
      let desc =
        let implicit_t_int =
          let desc =
            let constraint_kind =
              let _1 =
                let x = _1_inlined1 in
                
# 205 "<standard.mly>"
    ( x )
# 6777 "asllib/Parser.ml"
                
              in
              let _1_1 = _1 in
              
# 300 "asllib/Parser.mly"
                                                          WellConstrained  
# 6784 "asllib/Parser.ml"
               _1_1
            in
            
# 380 "asllib/Parser.mly"
                                                       T_Int 
# 6790 "asllib/Parser.ml"
             constraint_kind
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6799 "asllib/Parser.ml"
          
        in
        
# 276 "asllib/Parser.mly"
                                                                    E_ATC                 
# 6805 "asllib/Parser.ml"
         (sub_expr, implicit_t_int)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6814 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_115 =
    fun _1_inlined1 _2 _endpos__1_inlined1_ _endpos__3_ _startpos__1_inlined1_ _startpos_sub_expr_ sub_expr ->
      let desc =
        let pattern_set =
          let x =
            let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
            let desc =
              let _1_1 = _1 in
              
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 6828 "asllib/Parser.ml"
               _1_1
            in
            let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6837 "asllib/Parser.ml"
            
          in
          
# 205 "<standard.mly>"
    ( x )
# 6843 "asllib/Parser.ml"
          
        in
        
# 278 "asllib/Parser.mly"
                                                                    E_Pattern             
# 6849 "asllib/Parser.ml"
         (sub_expr, pattern_set)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6858 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_116 =
    fun _1 _1_inlined2 _2 _endpos__1_inlined2_ _endpos__3_ _startpos__1_ _startpos__1_inlined2_ _startpos_sub_expr_ sub_expr ->
      let desc =
        let pattern_set =
          let desc =
            let _2 =
              let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
              let x =
                let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
                let desc =
                  let _1_1 = _1 in
                  
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 6875 "asllib/Parser.ml"
                   _1_1
                in
                let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
                let _endpos = _endpos_desc_ in
                let _symbolstartpos = _startpos_desc_ in
                
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6884 "asllib/Parser.ml"
                
              in
              
# 205 "<standard.mly>"
    ( x )
# 6890 "asllib/Parser.ml"
              
            in
            let _2_1 = _2 in
            
# 326 "asllib/Parser.mly"
                                      Pattern_Not  
# 6897 "asllib/Parser.ml"
             _2_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6906 "asllib/Parser.ml"
          
        in
        
# 278 "asllib/Parser.mly"
                                                                    E_Pattern             
# 6912 "asllib/Parser.ml"
         (sub_expr, pattern_set)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6921 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_117 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_sub_expr_ sub_expr ->
      let desc =
        let pattern_mask =
          let desc =
            let _1_1 = _1 in
            
# 308 "asllib/Parser.mly"
                                            Pattern_Mask  
# 6933 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6942 "asllib/Parser.ml"
          
        in
        
# 279 "asllib/Parser.mly"
                                                                    E_Pattern             
# 6948 "asllib/Parser.ml"
         (sub_expr, pattern_mask)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_sub_expr_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6957 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_118 =
    fun _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e ->
      let desc =
        let p =
          let desc =
            let _1_1 = _1 in
            
# 308 "asllib/Parser.mly"
                                            Pattern_Mask  
# 6969 "asllib/Parser.ml"
             _1_1
          in
          let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6978 "asllib/Parser.ml"
          
        in
        
# 280 "asllib/Parser.mly"
                                                                  ( E_Pattern (e, Pattern_Not (p) |> add_pos_from p) )
# 6984 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos_e_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 6993 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_119 =
    fun _1 _1_inlined1 _endpos_ty_ _startpos__1_ ty ->
      let desc =
        let _2 = _1_inlined1 in
        
# 282 "asllib/Parser.mly"
                                                                    E_Unknown             
# 7003 "asllib/Parser.ml"
         ty
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7012 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_120 =
    fun _1 _1_inlined1 _endpos_ty_ _startpos__1_ ty ->
      let desc =
        let _2 = _1_inlined1 in
        
# 282 "asllib/Parser.mly"
                                                                    E_Unknown             
# 7022 "asllib/Parser.ml"
         ty
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_ty_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7031 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_121 =
    fun _endpos__3_ _startpos__1_ x ->
      let desc =
        let e = 
# 205 "<standard.mly>"
    ( x )
# 7040 "asllib/Parser.ml"
         in
        
# 283 "asllib/Parser.mly"
                                                                  ( E_Tuple [ e ]        )
# 7045 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7054 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_122 =
    fun _endpos__3_ _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let fields =
          let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 7064 "asllib/Parser.ml"
           in
          
# 205 "<standard.mly>"
    ( x )
# 7069 "asllib/Parser.ml"
          
        in
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7078 "asllib/Parser.ml"
          
        in
        
# 286 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), fields) )
# 7084 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7093 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_123 =
    fun _1_inlined1 _endpos__3_ _endpos_desc_ _startpos_desc_ desc ->
      let desc =
        let fields =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 7104 "asllib/Parser.ml"
          
        in
        let t =
          let _endpos = _endpos_desc_ in
          let _symbolstartpos = _startpos_desc_ in
          
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7113 "asllib/Parser.ml"
          
        in
        
# 286 "asllib/Parser.mly"
        ( E_Record (add_pos_from t (T_Named t.desc), fields) )
# 7119 "asllib/Parser.ml"
        
      in
      let _endpos_desc_ = _endpos__3_ in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7128 "asllib/Parser.ml"
       : (AST.expr))
  
  let _menhir_action_124 =
    fun _endpos_desc_ _startpos_desc_ desc ->
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7138 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_125 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 392 "asllib/Parser.mly"
                      ( LE_Discard )
# 7146 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7154 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_126 =
    fun _1_inlined1 _2 _endpos__3_ _startpos__1_ x ->
      let desc =
        let _1 =
          let x =
            let _1 = _1_inlined1 in
            let li = _1 in
            
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 7167 "asllib/Parser.ml"
            
          in
          
# 205 "<standard.mly>"
    ( x )
# 7173 "asllib/Parser.ml"
          
        in
        let _1_1 = _1 in
        
# 394 "asllib/Parser.mly"
                               LE_Destructuring 
# 7180 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7189 "asllib/Parser.ml"
       : (AST.lexpr))
  
  let _menhir_action_127 =
    fun _1 ->
      let _1_1 = _1 in
      (
# 398 "asllib/Parser.mly"
                    LE_Var 
# 7198 "asllib/Parser.ml"
       _1_1 : (AST.lexpr_desc))
  
  let _menhir_action_128 =
    fun _1_inlined1 _endpos_desc_ _startpos_desc_ desc ->
      let slices =
        let x = _1_inlined1 in
        
# 205 "<standard.mly>"
    ( x )
# 7208 "asllib/Parser.ml"
        
      in
      let le =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7217 "asllib/Parser.ml"
        
      in
      (
# 399 "asllib/Parser.mly"
                              LE_Slice 
# 7223 "asllib/Parser.ml"
       (le, slices) : (AST.lexpr_desc))
  
  let _menhir_action_129 =
    fun _2 _4 _endpos_desc_ _startpos_desc_ desc expr ->
      let le =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7234 "asllib/Parser.ml"
        
      in
      (
# 400 "asllib/Parser.mly"
                                                  LE_SetArray 
# 7240 "asllib/Parser.ml"
       (le, expr) : (AST.lexpr_desc))
  
  let _menhir_action_130 =
    fun _2 _endpos_desc_ _startpos_desc_ desc field ->
      let le =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7251 "asllib/Parser.ml"
        
      in
      (
# 401 "asllib/Parser.mly"
                                           LE_SetField 
# 7257 "asllib/Parser.ml"
       (le, field) : (AST.lexpr_desc))
  
  let _menhir_action_131 =
    fun _2 _endpos_desc_ _startpos_desc_ desc ->
      let li =
        let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 7266 "asllib/Parser.ml"
         in
        
# 205 "<standard.mly>"
    ( x )
# 7271 "asllib/Parser.ml"
        
      in
      let le =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7280 "asllib/Parser.ml"
        
      in
      (
# 402 "asllib/Parser.mly"
                                                         ( LE_SetFields (le, li, []) )
# 7286 "asllib/Parser.ml"
       : (AST.lexpr_desc))
  
  let _menhir_action_132 =
    fun _1_inlined1 _2 _endpos_desc_ _startpos_desc_ desc ->
      let li =
        let x = _1_inlined1 in
        
# 205 "<standard.mly>"
    ( x )
# 7296 "asllib/Parser.ml"
        
      in
      let le =
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7305 "asllib/Parser.ml"
        
      in
      (
# 402 "asllib/Parser.mly"
                                                         ( LE_SetFields (le, li, []) )
# 7311 "asllib/Parser.ml"
       : (AST.lexpr_desc))
  
  let _menhir_action_133 =
    fun () ->
      (
# 216 "<standard.mly>"
    ( [] )
# 7319 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_134 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined5 _2 _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined5 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 7334 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 7340 "asllib/Parser.ml"
            
          in
          let recurse_limit = 
# 123 "<standard.mly>"
    ( None )
# 7346 "asllib/Parser.ml"
           in
          let return_type =
            let _1 = _1_inlined3 in
            _2
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 7356 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 7361 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 544 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            builtin = false;
          }
        )
# 7379 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7388 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 7394 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_135 =
    fun _1 _1_inlined1 _1_inlined3 _2 _endpos__1_inlined4_ _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _endpos__1_ = _endpos__1_inlined4_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 7408 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7416 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 7422 "asllib/Parser.ml"
            
          in
          let recurse_limit = 
# 123 "<standard.mly>"
    ( None )
# 7428 "asllib/Parser.ml"
           in
          let return_type =
            let _1 = _1_inlined3 in
            _2
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 7438 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 7443 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 544 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            builtin = false;
          }
        )
# 7461 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7470 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 7476 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_136 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined6 _2 _2_inlined1 _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined6 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 7491 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 7497 "asllib/Parser.ml"
            
          in
          let recurse_limit =
            let (_2, _1) = (_2_inlined1, _1_inlined4) in
            let x = _2 in
            
# 126 "<standard.mly>"
    ( Some x )
# 7506 "asllib/Parser.ml"
            
          in
          let return_type =
            let _1 = _1_inlined3 in
            _2
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 7517 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 7522 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 544 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            builtin = false;
          }
        )
# 7540 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7549 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 7555 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_137 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _2 _2_inlined1 _endpos__1_inlined5_ _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _endpos__1_ = _endpos__1_inlined5_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 7569 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7577 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 7583 "asllib/Parser.ml"
            
          in
          let recurse_limit =
            let (_2, _1) = (_2_inlined1, _1_inlined4) in
            let x = _2 in
            
# 126 "<standard.mly>"
    ( Some x )
# 7592 "asllib/Parser.ml"
            
          in
          let return_type =
            let _1 = _1_inlined3 in
            _2
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 7603 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 7608 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 544 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            builtin = false;
          }
        )
# 7626 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7635 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 7641 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_138 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined6 _2 _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined6 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 7656 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 7662 "asllib/Parser.ml"
            
          in
          let recurse_limit = 
# 123 "<standard.mly>"
    ( None )
# 7668 "asllib/Parser.ml"
           in
          let return_type =
            let _1 = _1_inlined4 in
            _2
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 7680 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 544 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            builtin = false;
          }
        )
# 7698 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7707 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 7713 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_139 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _2 _endpos__1_inlined5_ _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _endpos__1_ = _endpos__1_inlined5_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 7727 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7735 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 7741 "asllib/Parser.ml"
            
          in
          let recurse_limit = 
# 123 "<standard.mly>"
    ( None )
# 7747 "asllib/Parser.ml"
           in
          let return_type =
            let _1 = _1_inlined4 in
            _2
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 7759 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 544 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            builtin = false;
          }
        )
# 7777 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7786 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 7792 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_140 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined5 _1_inlined7 _2 _2_inlined1 _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined7 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 7807 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 7813 "asllib/Parser.ml"
            
          in
          let recurse_limit =
            let (_2, _1) = (_2_inlined1, _1_inlined5) in
            let x = _2 in
            
# 126 "<standard.mly>"
    ( Some x )
# 7822 "asllib/Parser.ml"
            
          in
          let return_type =
            let _1 = _1_inlined4 in
            _2
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 7835 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 544 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            builtin = false;
          }
        )
# 7853 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7862 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 7868 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_141 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined5 _2 _2_inlined1 _endpos__1_inlined6_ _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _endpos__1_ = _endpos__1_inlined6_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 7882 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7890 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 7896 "asllib/Parser.ml"
            
          in
          let recurse_limit =
            let (_2, _1) = (_2_inlined1, _1_inlined5) in
            let x = _2 in
            
# 126 "<standard.mly>"
    ( Some x )
# 7905 "asllib/Parser.ml"
            
          in
          let return_type =
            let _1 = _1_inlined4 in
            _2
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 7918 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 544 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = Some return_type;
            subprogram_type = ST_Function;
            recurse_limit;
            builtin = false;
          }
        )
# 7936 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 7945 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 7951 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_142 =
    fun _1 _1_inlined1 _1_inlined4 _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined4 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 7966 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 7972 "asllib/Parser.ml"
            
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 7979 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 7984 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 559 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        )
# 8002 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8011 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8017 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_143 =
    fun _1 _1_inlined1 _endpos__1_inlined3_ _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _endpos__1_ = _endpos__1_inlined3_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 8031 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8039 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 8045 "asllib/Parser.ml"
            
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 8052 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 8057 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 559 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        )
# 8075 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8084 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8090 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_144 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined5 _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _1_inlined1 = _1_inlined5 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 8105 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 8111 "asllib/Parser.ml"
            
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 8120 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 559 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        )
# 8138 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8147 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8153 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_145 =
    fun _1 _1_inlined1 _1_inlined3 _endpos__1_inlined4_ _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let body =
            let _endpos__1_ = _endpos__1_inlined4_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 8167 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8175 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 8181 "asllib/Parser.ml"
            
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 8190 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 559 "asllib/Parser.mly"
        (
          D_Func {
            name;
            parameters = params_opt;
            args = func_args;
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        )
# 8208 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8217 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8223 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_146 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined5 _2 _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let func_body =
            let _1_inlined1 = _1_inlined5 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 8238 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 8244 "asllib/Parser.ml"
            
          in
          let return_type =
            let _1 = _1_inlined3 in
            _2
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 8255 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 8260 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 575 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = func_args;
              return_type = Some return_type;
              body = SB_ASL func_body;
              subprogram_type = ST_Getter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 8279 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8288 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8294 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_147 =
    fun _1 _1_inlined1 _1_inlined3 _2 _endpos__1_inlined4_ _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let func_body =
            let _endpos__1_ = _endpos__1_inlined4_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 8308 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8316 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 8322 "asllib/Parser.ml"
            
          in
          let return_type =
            let _1 = _1_inlined3 in
            _2
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 8333 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 8338 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 575 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = func_args;
              return_type = Some return_type;
              body = SB_ASL func_body;
              subprogram_type = ST_Getter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 8357 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8366 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8372 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_148 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined6 _2 _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let func_body =
            let _1_inlined1 = _1_inlined6 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 8387 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 8393 "asllib/Parser.ml"
            
          in
          let return_type =
            let _1 = _1_inlined4 in
            _2
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 8406 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 575 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = func_args;
              return_type = Some return_type;
              body = SB_ASL func_body;
              subprogram_type = ST_Getter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 8425 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8434 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8440 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_149 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _2 _endpos__1_inlined5_ _endpos__3_inlined1_ _startpos__1_ name xs ->
      let x =
        let desc =
          let func_body =
            let _endpos__1_ = _endpos__1_inlined5_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 8454 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8462 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 8468 "asllib/Parser.ml"
            
          in
          let return_type =
            let _1 = _1_inlined4 in
            _2
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 8481 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 575 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = func_args;
              return_type = Some return_type;
              body = SB_ASL func_body;
              subprogram_type = ST_Getter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 8500 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8509 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8515 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_150 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined5 _2 _5 _endpos__3_inlined1_ _startpos__1_ name x xs ->
      let x =
        let desc =
          let func_body =
            let _1_inlined1 = _1_inlined5 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 8530 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 8536 "asllib/Parser.ml"
            
          in
          let v =
            let _1 = _1_inlined3 in
            let y = _2 in
            
# 172 "<standard.mly>"
    ( (x, y) )
# 8545 "asllib/Parser.ml"
            
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 8552 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 8557 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 592 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = v :: func_args;
              return_type = None;
              body = SB_ASL func_body;
              subprogram_type = ST_Setter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 8576 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8585 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8591 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_151 =
    fun _1 _1_inlined1 _1_inlined3 _2 _5 _endpos__1_inlined4_ _endpos__3_inlined1_ _startpos__1_ name x xs ->
      let x =
        let desc =
          let func_body =
            let _endpos__1_ = _endpos__1_inlined4_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 8605 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8613 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 8619 "asllib/Parser.ml"
            
          in
          let v =
            let _1 = _1_inlined3 in
            let y = _2 in
            
# 172 "<standard.mly>"
    ( (x, y) )
# 8628 "asllib/Parser.ml"
            
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 8635 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 8640 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 592 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = v :: func_args;
              return_type = None;
              body = SB_ASL func_body;
              subprogram_type = ST_Setter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 8659 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8668 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8674 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_152 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined5 _2 _5 _endpos__3_inlined1_ _startpos__1_ name x xs ->
      let x =
        let desc =
          let func_body =
            let _1_inlined1 = _1_inlined5 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 8689 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 8695 "asllib/Parser.ml"
            
          in
          let v =
            let _1 = _1_inlined3 in
            let y = _2 in
            
# 172 "<standard.mly>"
    ( (x, y) )
# 8704 "asllib/Parser.ml"
            
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 8711 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 8716 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 592 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = v :: func_args;
              return_type = None;
              body = SB_ASL func_body;
              subprogram_type = ST_Setter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 8735 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8744 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8750 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_153 =
    fun _1 _1_inlined1 _1_inlined3 _2 _5 _endpos__1_inlined4_ _endpos__3_inlined1_ _startpos__1_ name x xs ->
      let x =
        let desc =
          let func_body =
            let _endpos__1_ = _endpos__1_inlined4_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 8764 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8772 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 8778 "asllib/Parser.ml"
            
          in
          let v =
            let _1 = _1_inlined3 in
            let y = _2 in
            
# 172 "<standard.mly>"
    ( (x, y) )
# 8787 "asllib/Parser.ml"
            
          in
          let func_args =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 8794 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 8799 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 592 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = v :: func_args;
              return_type = None;
              body = SB_ASL func_body;
              subprogram_type = ST_Setter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 8818 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8827 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8833 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_154 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined6 _2 _5 _endpos__3_inlined1_ _startpos__1_ name x xs ->
      let x =
        let desc =
          let func_body =
            let _1_inlined1 = _1_inlined6 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 8848 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 8854 "asllib/Parser.ml"
            
          in
          let v =
            let _1 = _1_inlined4 in
            let y = _2 in
            
# 172 "<standard.mly>"
    ( (x, y) )
# 8863 "asllib/Parser.ml"
            
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 8872 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 592 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = v :: func_args;
              return_type = None;
              body = SB_ASL func_body;
              subprogram_type = ST_Setter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 8891 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8900 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8906 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_155 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _2 _5 _endpos__1_inlined5_ _endpos__3_inlined1_ _startpos__1_ name x xs ->
      let x =
        let desc =
          let func_body =
            let _endpos__1_ = _endpos__1_inlined5_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 8920 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8928 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 8934 "asllib/Parser.ml"
            
          in
          let v =
            let _1 = _1_inlined4 in
            let y = _2 in
            
# 172 "<standard.mly>"
    ( (x, y) )
# 8943 "asllib/Parser.ml"
            
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 8952 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 592 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = v :: func_args;
              return_type = None;
              body = SB_ASL func_body;
              subprogram_type = ST_Setter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 8971 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 8980 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 8986 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_156 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined6 _2 _5 _endpos__3_inlined1_ _startpos__1_ name x xs ->
      let x =
        let desc =
          let func_body =
            let _1_inlined1 = _1_inlined6 in
            let x =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 9001 "asllib/Parser.ml"
               _1_1
            in
            
# 205 "<standard.mly>"
    ( x )
# 9007 "asllib/Parser.ml"
            
          in
          let v =
            let _1 = _1_inlined4 in
            let y = _2 in
            
# 172 "<standard.mly>"
    ( (x, y) )
# 9016 "asllib/Parser.ml"
            
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 9025 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 592 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = v :: func_args;
              return_type = None;
              body = SB_ASL func_body;
              subprogram_type = ST_Setter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 9044 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9053 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9059 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_157 =
    fun _1 _1_inlined1 _1_inlined3 _1_inlined4 _2 _5 _endpos__1_inlined5_ _endpos__3_inlined1_ _startpos__1_ name x xs ->
      let x =
        let desc =
          let func_body =
            let _endpos__1_ = _endpos__1_inlined5_ in
            let x =
              let _endpos__0_ = _endpos__1_ in
              let desc = 
# 533 "asllib/Parser.mly"
                                                   ( S_Pass )
# 9073 "asllib/Parser.ml"
               in
              let _endpos_desc_ = _endpos__0_ in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _endpos in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9081 "asllib/Parser.ml"
              
            in
            
# 205 "<standard.mly>"
    ( x )
# 9087 "asllib/Parser.ml"
            
          in
          let v =
            let _1 = _1_inlined4 in
            let y = _2 in
            
# 172 "<standard.mly>"
    ( (x, y) )
# 9096 "asllib/Parser.ml"
            
          in
          let func_args =
            let _1_inlined1 = _1_inlined3 in
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 9105 "asllib/Parser.ml"
            
          in
          let params_opt = _1_inlined1 in
          
# 592 "asllib/Parser.mly"
        (
          D_Func
            {
              name;
              parameters = params_opt;
              args = v :: func_args;
              return_type = None;
              body = SB_ASL func_body;
              subprogram_type = ST_Setter;
              recurse_limit = None;
              builtin = false;
            }
        )
# 9124 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9133 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9139 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_158 =
    fun _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ t x xs ->
      let x =
        let desc =
          let x =
            let subtype_opt = _1_inlined1 in
            
# 608 "asllib/Parser.mly"
                                                            D_TypeDecl            
# 9151 "asllib/Parser.ml"
             (x, t, subtype_opt)
          in
          
# 196 "<standard.mly>"
    ( x )
# 9157 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9166 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9172 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_159 =
    fun _1 _1_inlined1 _2_inlined1 _3 _endpos__2_ _endpos__3_ _startpos__1_ _startpos__1_inlined1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let s =
              let (_startpos__1_, _1) = (_startpos__1_inlined1_, _1_inlined1) in
              let desc =
                let _2_1 = _2 in
                let _3_1 = _3 in
                (_2_1, _3_1)
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9194 "asllib/Parser.ml"
              
            in
            
# 611 "asllib/Parser.mly"
                                                            make_ty_decl_subtype  
# 9200 "asllib/Parser.ml"
             (x, s)
          in
          
# 196 "<standard.mly>"
    ( x )
# 9206 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9215 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9221 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_160 =
    fun _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9232 "asllib/Parser.ml"
             x in
            let ty = 
# 123 "<standard.mly>"
    ( None )
# 9237 "asllib/Parser.ml"
             in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 9244 "asllib/Parser.ml"
              
            in
            let keyword = 
# 430 "asllib/Parser.mly"
                ( GDK_Let      )
# 9250 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9255 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9261 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9270 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9276 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_161 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9288 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 9296 "asllib/Parser.ml"
              
            in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 9304 "asllib/Parser.ml"
              
            in
            let keyword = 
# 430 "asllib/Parser.mly"
                ( GDK_Let      )
# 9310 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9315 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9321 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9330 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9336 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_162 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9348 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 9356 "asllib/Parser.ml"
              
            in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 9364 "asllib/Parser.ml"
              
            in
            let keyword = 
# 430 "asllib/Parser.mly"
                ( GDK_Let      )
# 9370 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9375 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9381 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9390 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9396 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_163 =
    fun _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9407 "asllib/Parser.ml"
             x in
            let ty = 
# 123 "<standard.mly>"
    ( None )
# 9412 "asllib/Parser.ml"
             in
            let name = _1_inlined1 in
            let keyword = 
# 430 "asllib/Parser.mly"
                ( GDK_Let      )
# 9418 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9423 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9429 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9438 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9444 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_164 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9456 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 9464 "asllib/Parser.ml"
              
            in
            let name = _1_inlined1 in
            let keyword = 
# 430 "asllib/Parser.mly"
                ( GDK_Let      )
# 9471 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9476 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9482 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9491 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9497 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_165 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9509 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 9517 "asllib/Parser.ml"
              
            in
            let name = _1_inlined1 in
            let keyword = 
# 430 "asllib/Parser.mly"
                ( GDK_Let      )
# 9524 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9529 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9535 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9544 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9550 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_166 =
    fun _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9561 "asllib/Parser.ml"
             x in
            let ty = 
# 123 "<standard.mly>"
    ( None )
# 9566 "asllib/Parser.ml"
             in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 9573 "asllib/Parser.ml"
              
            in
            let keyword = 
# 431 "asllib/Parser.mly"
                ( GDK_Constant )
# 9579 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9584 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9590 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9599 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9605 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_167 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9617 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 9625 "asllib/Parser.ml"
              
            in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 9633 "asllib/Parser.ml"
              
            in
            let keyword = 
# 431 "asllib/Parser.mly"
                ( GDK_Constant )
# 9639 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9644 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9650 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9659 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9665 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_168 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9677 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 9685 "asllib/Parser.ml"
              
            in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 9693 "asllib/Parser.ml"
              
            in
            let keyword = 
# 431 "asllib/Parser.mly"
                ( GDK_Constant )
# 9699 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9704 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9710 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9719 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9725 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_169 =
    fun _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9736 "asllib/Parser.ml"
             x in
            let ty = 
# 123 "<standard.mly>"
    ( None )
# 9741 "asllib/Parser.ml"
             in
            let name = _1_inlined1 in
            let keyword = 
# 431 "asllib/Parser.mly"
                ( GDK_Constant )
# 9747 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9752 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9758 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9767 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9773 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_170 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9785 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 9793 "asllib/Parser.ml"
              
            in
            let name = _1_inlined1 in
            let keyword = 
# 431 "asllib/Parser.mly"
                ( GDK_Constant )
# 9800 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9805 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9811 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9820 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9826 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_171 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9838 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 9846 "asllib/Parser.ml"
              
            in
            let name = _1_inlined1 in
            let keyword = 
# 431 "asllib/Parser.mly"
                ( GDK_Constant )
# 9853 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9858 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9864 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9873 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9879 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_172 =
    fun _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9890 "asllib/Parser.ml"
             x in
            let ty = 
# 123 "<standard.mly>"
    ( None )
# 9895 "asllib/Parser.ml"
             in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 9902 "asllib/Parser.ml"
              
            in
            let keyword = 
# 432 "asllib/Parser.mly"
                ( GDK_Var      )
# 9908 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9913 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9919 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9928 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9934 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_173 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 9946 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 9954 "asllib/Parser.ml"
              
            in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 9962 "asllib/Parser.ml"
              
            in
            let keyword = 
# 432 "asllib/Parser.mly"
                ( GDK_Var      )
# 9968 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 9973 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 9979 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 9988 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 9994 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_174 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 10006 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 10014 "asllib/Parser.ml"
              
            in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 10022 "asllib/Parser.ml"
              
            in
            let keyword = 
# 432 "asllib/Parser.mly"
                ( GDK_Var      )
# 10028 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 10033 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10039 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10048 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10054 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_175 =
    fun _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 10065 "asllib/Parser.ml"
             x in
            let ty = 
# 123 "<standard.mly>"
    ( None )
# 10070 "asllib/Parser.ml"
             in
            let name = _1_inlined1 in
            let keyword = 
# 432 "asllib/Parser.mly"
                ( GDK_Var      )
# 10076 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 10081 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10087 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10096 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10102 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_176 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 10114 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 10122 "asllib/Parser.ml"
              
            in
            let name = _1_inlined1 in
            let keyword = 
# 432 "asllib/Parser.mly"
                ( GDK_Var      )
# 10129 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 10134 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10140 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10149 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10155 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_177 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 10167 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 10175 "asllib/Parser.ml"
              
            in
            let name = _1_inlined1 in
            let keyword = 
# 432 "asllib/Parser.mly"
                ( GDK_Var      )
# 10182 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 10187 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10193 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10202 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10208 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_178 =
    fun _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 10219 "asllib/Parser.ml"
             x in
            let ty = 
# 123 "<standard.mly>"
    ( None )
# 10224 "asllib/Parser.ml"
             in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 10231 "asllib/Parser.ml"
              
            in
            let keyword = 
# 433 "asllib/Parser.mly"
                ( GDK_Config   )
# 10237 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 10242 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10248 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10257 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10263 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_179 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 10275 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 10283 "asllib/Parser.ml"
              
            in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 10291 "asllib/Parser.ml"
              
            in
            let keyword = 
# 433 "asllib/Parser.mly"
                ( GDK_Config   )
# 10297 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 10302 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10308 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10317 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10323 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_180 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 10335 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 10343 "asllib/Parser.ml"
              
            in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 10351 "asllib/Parser.ml"
              
            in
            let keyword = 
# 433 "asllib/Parser.mly"
                ( GDK_Config   )
# 10357 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 10362 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10368 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10377 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10383 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_181 =
    fun _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 10394 "asllib/Parser.ml"
             x in
            let ty = 
# 123 "<standard.mly>"
    ( None )
# 10399 "asllib/Parser.ml"
             in
            let name = _1_inlined1 in
            let keyword = 
# 433 "asllib/Parser.mly"
                ( GDK_Config   )
# 10405 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 10410 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10416 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10425 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10431 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_182 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 10443 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 10451 "asllib/Parser.ml"
              
            in
            let name = _1_inlined1 in
            let keyword = 
# 433 "asllib/Parser.mly"
                ( GDK_Config   )
# 10458 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 10463 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10469 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10478 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10484 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_183 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let initial_value = 
# 133 "asllib/Parser.mly"
                        Some 
# 10496 "asllib/Parser.ml"
             x in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 10504 "asllib/Parser.ml"
              
            in
            let name = _1_inlined1 in
            let keyword = 
# 433 "asllib/Parser.mly"
                ( GDK_Config   )
# 10511 "asllib/Parser.ml"
             in
            
# 616 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword; name; ty; initial_value } )
# 10516 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10522 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10531 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10537 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_184 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 133 "asllib/Parser.mly"
                        Some 
# 10552 "asllib/Parser.ml"
               x
            in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 10560 "asllib/Parser.ml"
              
            in
            
# 620 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Var; name; ty; initial_value=None})
# 10566 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10572 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10581 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10587 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_185 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 133 "asllib/Parser.mly"
                        Some 
# 10602 "asllib/Parser.ml"
               x
            in
            let name =
              let _1 = _1_inlined1 in
              
# 537 "asllib/Parser.mly"
           ( global_ignored () )
# 10610 "asllib/Parser.ml"
              
            in
            
# 620 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Var; name; ty; initial_value=None})
# 10616 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10622 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10631 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10637 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_186 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 133 "asllib/Parser.mly"
                        Some 
# 10652 "asllib/Parser.ml"
               x
            in
            let name = _1_inlined1 in
            
# 620 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Var; name; ty; initial_value=None})
# 10659 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10665 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10674 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10680 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_187 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let ty =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 133 "asllib/Parser.mly"
                        Some 
# 10695 "asllib/Parser.ml"
               x
            in
            let name = _1_inlined1 in
            
# 620 "asllib/Parser.mly"
        ( D_GlobalStorage { keyword=GDK_Var; name; ty; initial_value=None})
# 10702 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10708 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10717 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10723 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_188 =
    fun _1 _2_inlined1 _endpos__2_ _endpos__2_inlined1_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let (_endpos__2_, _2) = (_endpos__2_inlined1_, _2_inlined1) in
            let loc =
              let desc =
                let _3 = 
# 161 "asllib/Parser.mly"
                ( [] )
# 10737 "asllib/Parser.ml"
                 in
                ()
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10747 "asllib/Parser.ml"
              
            in
            
# 624 "asllib/Parser.mly"
        ( Error.fatal_from loc @@ Error.NotYetImplemented "Pragma in declarations")
# 10753 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10759 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10768 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10774 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_189 =
    fun _1 _1_inlined1 _2_inlined1 _endpos__1_inlined1_ _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let loc =
              let desc =
                let _3 = _1_inlined1 in
                ()
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10794 "asllib/Parser.ml"
              
            in
            
# 624 "asllib/Parser.mly"
        ( Error.fatal_from loc @@ Error.NotYetImplemented "Pragma in declarations")
# 10800 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 10806 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 10815 "asllib/Parser.ml"
        
      in
      (
# 219 "<standard.mly>"
    ( x :: xs )
# 10821 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_190 =
    fun () ->
      (
# 145 "<standard.mly>"
    ( [] )
# 10829 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_191 =
    fun _1 _1_inlined2 ->
      let x =
        let _1_inlined1 = _1_inlined2 in
        let x = _1_inlined1 in
        
# 205 "<standard.mly>"
    ( x )
# 10840 "asllib/Parser.ml"
        
      in
      (
# 148 "<standard.mly>"
    ( x )
# 10846 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_192 =
    fun () ->
      (
# 145 "<standard.mly>"
    ( [] )
# 10854 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_193 =
    fun _1_inlined1 ->
      let x =
        let x = _1_inlined1 in
        
# 205 "<standard.mly>"
    ( x )
# 10864 "asllib/Parser.ml"
        
      in
      (
# 148 "<standard.mly>"
    ( x )
# 10870 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_194 =
    fun () ->
      (
# 145 "<standard.mly>"
    ( [] )
# 10878 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_195 =
    fun _1_inlined1 ->
      let x =
        let x = _1_inlined1 in
        
# 205 "<standard.mly>"
    ( x )
# 10888 "asllib/Parser.ml"
        
      in
      (
# 148 "<standard.mly>"
    ( x )
# 10894 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_196 =
    fun () ->
      (
# 145 "<standard.mly>"
    ( [] )
# 10902 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_197 =
    fun x ->
      (
# 148 "<standard.mly>"
    ( x )
# 10910 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_198 =
    fun () ->
      (
# 145 "<standard.mly>"
    ( [] )
# 10918 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_199 =
    fun x ->
      (
# 148 "<standard.mly>"
    ( x )
# 10926 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_200 =
    fun () ->
      (
# 145 "<standard.mly>"
    ( [] )
# 10934 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_201 =
    fun () ->
      let x =
        let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 10943 "asllib/Parser.ml"
         in
        
# 205 "<standard.mly>"
    ( x )
# 10948 "asllib/Parser.ml"
        
      in
      (
# 148 "<standard.mly>"
    ( x )
# 10954 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_202 =
    fun _1_inlined1 ->
      let x =
        let x = _1_inlined1 in
        
# 205 "<standard.mly>"
    ( x )
# 10964 "asllib/Parser.ml"
        
      in
      (
# 148 "<standard.mly>"
    ( x )
# 10970 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_203 =
    fun _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined1_ ->
      let x =
        let desc =
          let stmt =
            let _1 = _1_inlined2 in
            let _1_1 = _1 in
            
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 10983 "asllib/Parser.ml"
             _1_1
          in
          let where = 
# 123 "<standard.mly>"
    ( None )
# 10989 "asllib/Parser.ml"
           in
          let pattern =
            let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
            let desc =
              let _1_1 = _1 in
              
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 10998 "asllib/Parser.ml"
               _1_1
            in
            let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11007 "asllib/Parser.ml"
            
          in
          
# 441 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 11013 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11022 "asllib/Parser.ml"
        
      in
      (
# 183 "asllib/Parser.mly"
         ( [ x ] )
# 11028 "asllib/Parser.ml"
       : (AST.case_alt list))
  
  let _menhir_action_204 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _4 _endpos__1_inlined1_ _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined1_ ->
      let x =
        let desc =
          let stmt =
            let _1 = _1_inlined3 in
            let _1_1 = _1 in
            
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 11041 "asllib/Parser.ml"
             _1_1
          in
          let where =
            let _1 = _1_inlined2 in
            let x = _2 in
            
# 126 "<standard.mly>"
    ( Some x )
# 11050 "asllib/Parser.ml"
            
          in
          let pattern =
            let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
            let desc =
              let _1_1 = _1 in
              
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 11060 "asllib/Parser.ml"
               _1_1
            in
            let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11069 "asllib/Parser.ml"
            
          in
          
# 441 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 11075 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11084 "asllib/Parser.ml"
        
      in
      (
# 183 "asllib/Parser.mly"
         ( [ x ] )
# 11090 "asllib/Parser.ml"
       : (AST.case_alt list))
  
  let _menhir_action_205 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _endpos__1_inlined3_ _endpos_desc_ _startpos__1_ _startpos__1_inlined1_ _startpos_desc_ desc ->
      let y =
        let (_endpos__1_, _1) = (_endpos__1_inlined3_, _1_inlined3) in
        let desc =
          let stmt =
            let _1_1 = _1 in
            
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 11103 "asllib/Parser.ml"
             _1_1
          in
          let loc =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11112 "asllib/Parser.ml"
            
          in
          
# 445 "asllib/Parser.mly"
  ( { pattern = add_pos_from loc Pattern_All; where = None; stmt } )
# 11118 "asllib/Parser.ml"
          
        in
        let _endpos_desc_ = _endpos__1_ in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11127 "asllib/Parser.ml"
        
      in
      let x =
        let desc =
          let stmt =
            let _1 = _1_inlined2 in
            let _1_1 = _1 in
            
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 11138 "asllib/Parser.ml"
             _1_1
          in
          let where = 
# 123 "<standard.mly>"
    ( None )
# 11144 "asllib/Parser.ml"
           in
          let pattern =
            let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
            let desc =
              let _1_1 = _1 in
              
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 11153 "asllib/Parser.ml"
               _1_1
            in
            let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11162 "asllib/Parser.ml"
            
          in
          
# 441 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 11168 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11177 "asllib/Parser.ml"
        
      in
      (
# 184 "asllib/Parser.mly"
              ( [ x; y ] )
# 11183 "asllib/Parser.ml"
       : (AST.case_alt list))
  
  let _menhir_action_206 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _1_inlined4 _2 _2_inlined1 _4 _endpos__1_inlined1_ _endpos__1_inlined3_ _endpos__1_inlined4_ _endpos_desc_ _startpos__1_ _startpos__1_inlined1_ _startpos_desc_ desc ->
      let y =
        let (_endpos__1_, _1, _2) = (_endpos__1_inlined4_, _1_inlined4, _2_inlined1) in
        let desc =
          let stmt =
            let _1_1 = _1 in
            
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 11196 "asllib/Parser.ml"
             _1_1
          in
          let loc =
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11205 "asllib/Parser.ml"
            
          in
          
# 445 "asllib/Parser.mly"
  ( { pattern = add_pos_from loc Pattern_All; where = None; stmt } )
# 11211 "asllib/Parser.ml"
          
        in
        let _endpos_desc_ = _endpos__1_ in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11220 "asllib/Parser.ml"
        
      in
      let x =
        let desc =
          let stmt =
            let _1 = _1_inlined3 in
            let _1_1 = _1 in
            
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 11231 "asllib/Parser.ml"
             _1_1
          in
          let where =
            let _1 = _1_inlined2 in
            let x = _2 in
            
# 126 "<standard.mly>"
    ( Some x )
# 11240 "asllib/Parser.ml"
            
          in
          let pattern =
            let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
            let desc =
              let _1_1 = _1 in
              
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 11250 "asllib/Parser.ml"
               _1_1
            in
            let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11259 "asllib/Parser.ml"
            
          in
          
# 441 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 11265 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11274 "asllib/Parser.ml"
        
      in
      (
# 184 "asllib/Parser.mly"
              ( [ x; y ] )
# 11280 "asllib/Parser.ml"
       : (AST.case_alt list))
  
  let _menhir_action_207 =
    fun _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined1_ l ->
      let x =
        let desc =
          let stmt =
            let _1 = _1_inlined2 in
            let _1_1 = _1 in
            
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 11293 "asllib/Parser.ml"
             _1_1
          in
          let where = 
# 123 "<standard.mly>"
    ( None )
# 11299 "asllib/Parser.ml"
           in
          let pattern =
            let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
            let desc =
              let _1_1 = _1 in
              
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 11308 "asllib/Parser.ml"
               _1_1
            in
            let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11317 "asllib/Parser.ml"
            
          in
          
# 441 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 11323 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11332 "asllib/Parser.ml"
        
      in
      (
# 185 "asllib/Parser.mly"
                                       ( x :: l )
# 11338 "asllib/Parser.ml"
       : (AST.case_alt list))
  
  let _menhir_action_208 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _4 _endpos__1_inlined1_ _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined1_ l ->
      let x =
        let desc =
          let stmt =
            let _1 = _1_inlined3 in
            let _1_1 = _1 in
            
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 11351 "asllib/Parser.ml"
             _1_1
          in
          let where =
            let _1 = _1_inlined2 in
            let x = _2 in
            
# 126 "<standard.mly>"
    ( Some x )
# 11360 "asllib/Parser.ml"
            
          in
          let pattern =
            let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
            let desc =
              let _1_1 = _1 in
              
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 11370 "asllib/Parser.ml"
               _1_1
            in
            let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11379 "asllib/Parser.ml"
            
          in
          
# 441 "asllib/Parser.mly"
      ( { pattern; where; stmt } )
# 11385 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined3_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 11394 "asllib/Parser.ml"
        
      in
      (
# 185 "asllib/Parser.mly"
                                       ( x :: l )
# 11400 "asllib/Parser.ml"
       : (AST.case_alt list))
  
  let _menhir_action_209 =
    fun x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 11408 "asllib/Parser.ml"
       in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11413 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_210 =
    fun x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 11423 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11429 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_211 =
    fun _2 h t ->
      (
# 155 "asllib/Parser.mly"
                                                 ( h :: t )
# 11437 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_212 =
    fun _1_inlined1 x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 11445 "asllib/Parser.ml"
       in
      let x =
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11453 "asllib/Parser.ml"
          
        in
        
# 345 "asllib/Parser.mly"
                                              ( BitField_Simple (x, s)     )
# 11459 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11465 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_213 =
    fun _1_inlined1 x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 11475 "asllib/Parser.ml"
        
      in
      let x =
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11484 "asllib/Parser.ml"
          
        in
        
# 345 "asllib/Parser.mly"
                                              ( BitField_Simple (x, s)     )
# 11490 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11496 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_214 =
    fun _1_inlined1 _1_inlined3 x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 11504 "asllib/Parser.ml"
       in
      let x =
        let bf =
          let _1_inlined1 = _1_inlined3 in
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11513 "asllib/Parser.ml"
          
        in
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11521 "asllib/Parser.ml"
          
        in
        
# 346 "asllib/Parser.mly"
                                              ( BitField_Nested (x, s, bf) )
# 11527 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11533 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_215 =
    fun _1_inlined1 _1_inlined3 x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 11543 "asllib/Parser.ml"
        
      in
      let x =
        let bf =
          let _1_inlined1 = _1_inlined3 in
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11553 "asllib/Parser.ml"
          
        in
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11561 "asllib/Parser.ml"
          
        in
        
# 346 "asllib/Parser.mly"
                                              ( BitField_Nested (x, s, bf) )
# 11567 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11573 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_216 =
    fun _1_inlined1 _1_inlined2 _2_inlined1 x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 11581 "asllib/Parser.ml"
       in
      let x =
        let _2 = _2_inlined1 in
        let ty =
          let _1 = _1_inlined2 in
          _2
        in
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11594 "asllib/Parser.ml"
          
        in
        
# 347 "asllib/Parser.mly"
                                              ( BitField_Type   (x, s, ty) )
# 11600 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11606 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_217 =
    fun _1_inlined1 _1_inlined2 _2_inlined1 x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 11616 "asllib/Parser.ml"
        
      in
      let x =
        let _2 = _2_inlined1 in
        let ty =
          let _1 = _1_inlined2 in
          _2
        in
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11630 "asllib/Parser.ml"
          
        in
        
# 347 "asllib/Parser.mly"
                                              ( BitField_Type   (x, s, ty) )
# 11636 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11642 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_218 =
    fun _1_inlined1 _1_inlined2 _2_inlined1 x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 11650 "asllib/Parser.ml"
       in
      let x =
        let _2 = _2_inlined1 in
        let ty =
          let _1 = _1_inlined2 in
          _2
        in
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11663 "asllib/Parser.ml"
          
        in
        
# 347 "asllib/Parser.mly"
                                              ( BitField_Type   (x, s, ty) )
# 11669 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11675 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_219 =
    fun _1_inlined1 _1_inlined2 _2_inlined1 x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 11685 "asllib/Parser.ml"
        
      in
      let x =
        let _2 = _2_inlined1 in
        let ty =
          let _1 = _1_inlined2 in
          _2
        in
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11699 "asllib/Parser.ml"
          
        in
        
# 347 "asllib/Parser.mly"
                                              ( BitField_Type   (x, s, ty) )
# 11705 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11711 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_220 =
    fun _1_inlined1 _2 t x ->
      let h =
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11722 "asllib/Parser.ml"
          
        in
        
# 345 "asllib/Parser.mly"
                                              ( BitField_Simple (x, s)     )
# 11728 "asllib/Parser.ml"
        
      in
      (
# 155 "asllib/Parser.mly"
                                                 ( h :: t )
# 11734 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_221 =
    fun _1_inlined1 _1_inlined3 _2 t x ->
      let h =
        let bf =
          let _1_inlined1 = _1_inlined3 in
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11746 "asllib/Parser.ml"
          
        in
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11754 "asllib/Parser.ml"
          
        in
        
# 346 "asllib/Parser.mly"
                                              ( BitField_Nested (x, s, bf) )
# 11760 "asllib/Parser.ml"
        
      in
      (
# 155 "asllib/Parser.mly"
                                                 ( h :: t )
# 11766 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_222 =
    fun _1_inlined1 _1_inlined2 _2 _2_inlined1 t x ->
      let h =
        let _2 = _2_inlined1 in
        let ty =
          let _1 = _1_inlined2 in
          _2
        in
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11782 "asllib/Parser.ml"
          
        in
        
# 347 "asllib/Parser.mly"
                                              ( BitField_Type   (x, s, ty) )
# 11788 "asllib/Parser.ml"
        
      in
      (
# 155 "asllib/Parser.mly"
                                                 ( h :: t )
# 11794 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_223 =
    fun _1_inlined1 _1_inlined2 _2 _2_inlined1 t x ->
      let h =
        let _2 = _2_inlined1 in
        let ty =
          let _1 = _1_inlined2 in
          _2
        in
        let s =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 11810 "asllib/Parser.ml"
          
        in
        
# 347 "asllib/Parser.mly"
                                              ( BitField_Type   (x, s, ty) )
# 11816 "asllib/Parser.ml"
        
      in
      (
# 155 "asllib/Parser.mly"
                                                 ( h :: t )
# 11822 "asllib/Parser.ml"
       : (AST.bitfield list))
  
  let _menhir_action_224 =
    fun _1 _2_inlined1 x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 11830 "asllib/Parser.ml"
       in
      let x =
        let _2 = _2_inlined1 in
        let y = _2 in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 11838 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11844 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_225 =
    fun _1 _2_inlined1 x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 11854 "asllib/Parser.ml"
        
      in
      let x =
        let _2 = _2_inlined1 in
        let y = _2 in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 11863 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11869 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_226 =
    fun _1 _2_inlined1 x ->
      let _2 = 
# 123 "<standard.mly>"
    ( None )
# 11877 "asllib/Parser.ml"
       in
      let x =
        let _2 = _2_inlined1 in
        let y = _2 in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 11885 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11891 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_227 =
    fun _1 _2_inlined1 x x_inlined1 ->
      let _2 =
        let x = x_inlined1 in
        
# 126 "<standard.mly>"
    ( Some x )
# 11901 "asllib/Parser.ml"
        
      in
      let x =
        let _2 = _2_inlined1 in
        let y = _2 in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 11910 "asllib/Parser.ml"
        
      in
      (
# 154 "asllib/Parser.mly"
                       ( [ x ] )
# 11916 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_228 =
    fun _1 _2 _2_inlined1 t x ->
      let h =
        let _2 = _2_inlined1 in
        let y = _2 in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 11927 "asllib/Parser.ml"
        
      in
      (
# 155 "asllib/Parser.mly"
                                                 ( h :: t )
# 11933 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_229 =
    fun _1 _2 _2_inlined1 t x ->
      let h =
        let _2 = _2_inlined1 in
        let y = _2 in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 11944 "asllib/Parser.ml"
        
      in
      (
# 155 "asllib/Parser.mly"
                                                 ( h :: t )
# 11950 "asllib/Parser.ml"
       : (AST.field list))
  
  let _menhir_action_230 =
    fun _1 _1_inlined1 _4 ty ->
      let x =
        let stmt_list =
          let _1 = _1_inlined1 in
          let _1_1 = _1 in
          
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 11962 "asllib/Parser.ml"
           _1_1
        in
        let _2 = 
# 123 "<standard.mly>"
    ( None )
# 11968 "asllib/Parser.ml"
         in
        let _2_1 = _2 in
        (_2_1, ty, stmt_list)
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 11976 "asllib/Parser.ml"
       : (AST.catcher list))
  
  let _menhir_action_231 =
    fun _1 _1_inlined1 _4 ty x ->
      let x =
        let stmt_list =
          let _1 = _1_inlined1 in
          let _1_1 = _1 in
          
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 11988 "asllib/Parser.ml"
           _1_1
        in
        let _2 =
          let x = 
# 196 "<standard.mly>"
    ( x )
# 11995 "asllib/Parser.ml"
           in
          
# 126 "<standard.mly>"
    ( Some x )
# 12000 "asllib/Parser.ml"
          
        in
        let _2_1 = _2 in
        (_2_1, ty, stmt_list)
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12009 "asllib/Parser.ml"
       : (AST.catcher list))
  
  let _menhir_action_232 =
    fun _1 _1_inlined1 _4 ty xs ->
      let x =
        let stmt_list =
          let _1 = _1_inlined1 in
          let _1_1 = _1 in
          
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12021 "asllib/Parser.ml"
           _1_1
        in
        let _2 = 
# 123 "<standard.mly>"
    ( None )
# 12027 "asllib/Parser.ml"
         in
        let _2_1 = _2 in
        (_2_1, ty, stmt_list)
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 12035 "asllib/Parser.ml"
       : (AST.catcher list))
  
  let _menhir_action_233 =
    fun _1 _1_inlined1 _4 ty x xs ->
      let x =
        let stmt_list =
          let _1 = _1_inlined1 in
          let _1_1 = _1 in
          
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12047 "asllib/Parser.ml"
           _1_1
        in
        let _2 =
          let x = 
# 196 "<standard.mly>"
    ( x )
# 12054 "asllib/Parser.ml"
           in
          
# 126 "<standard.mly>"
    ( Some x )
# 12059 "asllib/Parser.ml"
          
        in
        let _2_1 = _2 in
        (_2_1, ty, stmt_list)
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 12068 "asllib/Parser.ml"
       : (AST.catcher list))
  
  let _menhir_action_234 =
    fun _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ e s2 ->
      let x =
        let desc =
          let x =
            let s1 =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12082 "asllib/Parser.ml"
               _1_1
            in
            
# 458 "asllib/Parser.mly"
                                                       S_Cond 
# 12088 "asllib/Parser.ml"
             (e, s1, s2)
          in
          
# 196 "<standard.mly>"
    ( x )
# 12094 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12103 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12109 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_235 =
    fun _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ expr ->
      let x =
        let desc =
          let x =
            let alt = _1_inlined1 in
            
# 459 "asllib/Parser.mly"
                                                       S_Case 
# 12121 "asllib/Parser.ml"
             (expr, alt)
          in
          
# 196 "<standard.mly>"
    ( x )
# 12127 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12136 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12142 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_236 =
    fun _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ expr ->
      let x =
        let desc =
          let x =
            let stmt_list =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12156 "asllib/Parser.ml"
               _1_1
            in
            let loop_limit = 
# 123 "<standard.mly>"
    ( None )
# 12162 "asllib/Parser.ml"
             in
            
# 460 "asllib/Parser.mly"
                                                       S_While 
# 12167 "asllib/Parser.ml"
             (expr, loop_limit, stmt_list)
          in
          
# 196 "<standard.mly>"
    ( x )
# 12173 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12182 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12188 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_237 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ expr ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let stmt_list =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12203 "asllib/Parser.ml"
               _1_1
            in
            let loop_limit =
              let _1 = _1_inlined1 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 12212 "asllib/Parser.ml"
              
            in
            
# 460 "asllib/Parser.mly"
                                                       S_While 
# 12218 "asllib/Parser.ml"
             (expr, loop_limit, stmt_list)
          in
          
# 196 "<standard.mly>"
    ( x )
# 12224 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12233 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12239 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_238 =
    fun _1 _1_inlined1 _1_inlined2 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e ->
      let x =
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12253 "asllib/Parser.ml"
               _1_1
            in
            let limit = 
# 123 "<standard.mly>"
    ( None )
# 12259 "asllib/Parser.ml"
             in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                       ( AST.Up )
# 12266 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 12272 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 12278 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12287 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12293 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_239 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let body =
              let _1 = _1_inlined3 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12308 "asllib/Parser.ml"
               _1_1
            in
            let limit =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 12317 "asllib/Parser.ml"
              
            in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                       ( AST.Up )
# 12325 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 12331 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 12337 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12346 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12352 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_240 =
    fun _1 _1_inlined1 _1_inlined2 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e ->
      let x =
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12366 "asllib/Parser.ml"
               _1_1
            in
            let limit = 
# 123 "<standard.mly>"
    ( None )
# 12372 "asllib/Parser.ml"
             in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                                            ( AST.Down )
# 12379 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 12385 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 12391 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12400 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12406 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_241 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let body =
              let _1 = _1_inlined3 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12421 "asllib/Parser.ml"
               _1_1
            in
            let limit =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 12430 "asllib/Parser.ml"
              
            in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                                            ( AST.Down )
# 12438 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 12444 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 12450 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12459 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12465 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_242 =
    fun _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ c ->
      let x =
        let desc =
          let x =
            let o = 
# 123 "<standard.mly>"
    ( None )
# 12476 "asllib/Parser.ml"
             in
            let s =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12484 "asllib/Parser.ml"
               _1_1
            in
            
# 464 "asllib/Parser.mly"
                                                                              S_Try  
# 12490 "asllib/Parser.ml"
             (s, c, o)
          in
          
# 196 "<standard.mly>"
    ( x )
# 12496 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12505 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12511 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_243 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _endpos__2_ _startpos__1_ c ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let o =
              let (_1_inlined1, _1) = (_1_inlined3, _1_inlined2) in
              let x =
                let _1 = _1_inlined1 in
                let _1_1 = _1 in
                
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12528 "asllib/Parser.ml"
                 _1_1
              in
              
# 126 "<standard.mly>"
    ( Some x )
# 12534 "asllib/Parser.ml"
              
            in
            let s =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12543 "asllib/Parser.ml"
               _1_1
            in
            
# 464 "asllib/Parser.mly"
                                                                              S_Try  
# 12549 "asllib/Parser.ml"
             (s, c, o)
          in
          
# 196 "<standard.mly>"
    ( x )
# 12555 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12564 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12570 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_244 =
    fun _1 _1_inlined2 _3 _5 _endpos__2_ _startpos__1_ cond x ->
      let x =
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 12584 "asllib/Parser.ml"
               _1_1
            in
            let looplimit = 
# 205 "<standard.mly>"
    ( x )
# 12590 "asllib/Parser.ml"
             in
            
# 466 "asllib/Parser.mly"
          ( S_While (cond, Some looplimit, body) )
# 12595 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 12601 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12610 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12616 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_245 =
    fun _1 _endpos__2_ _startpos__1_ ->
      let x =
        let desc =
          let x = 
# 435 "asllib/Parser.mly"
            ( S_Pass )
# 12626 "asllib/Parser.ml"
           in
          
# 196 "<standard.mly>"
    ( x )
# 12631 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12640 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12646 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_246 =
    fun _1 _endpos__2_ _startpos__1_ ->
      let x =
        let desc =
          let x =
            let _2 = 
# 123 "<standard.mly>"
    ( None )
# 12657 "asllib/Parser.ml"
             in
            let _2_1 = _2 in
            
# 470 "asllib/Parser.mly"
                                                               S_Return  
# 12663 "asllib/Parser.ml"
             _2_1
          in
          
# 196 "<standard.mly>"
    ( x )
# 12669 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12678 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12684 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_247 =
    fun _1 _endpos__2_ _startpos__1_ x ->
      let x =
        let desc =
          let x =
            let _2 = 
# 126 "<standard.mly>"
    ( Some x )
# 12695 "asllib/Parser.ml"
             in
            let _2_1 = _2 in
            
# 470 "asllib/Parser.mly"
                                                               S_Return  
# 12701 "asllib/Parser.ml"
             _2_1
          in
          
# 196 "<standard.mly>"
    ( x )
# 12707 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12716 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12722 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_248 =
    fun _endpos__2_ _startpos_name_ name ->
      let x =
        let desc =
          let x =
            let call =
              let args =
                let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 12735 "asllib/Parser.ml"
                 in
                
# 205 "<standard.mly>"
    ( x )
# 12740 "asllib/Parser.ml"
                
              in
              
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 12746 "asllib/Parser.ml"
              
            in
            
# 471 "asllib/Parser.mly"
                                                               s_call  
# 12752 "asllib/Parser.ml"
             call
          in
          
# 196 "<standard.mly>"
    ( x )
# 12758 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12767 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12773 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_249 =
    fun _1_inlined1 _endpos__2_ _startpos_name_ name ->
      let x =
        let desc =
          let x =
            let call =
              let args =
                let x = _1_inlined1 in
                
# 205 "<standard.mly>"
    ( x )
# 12787 "asllib/Parser.ml"
                
              in
              
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 12793 "asllib/Parser.ml"
              
            in
            
# 471 "asllib/Parser.mly"
                                                               s_call  
# 12799 "asllib/Parser.ml"
             call
          in
          
# 196 "<standard.mly>"
    ( x )
# 12805 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12814 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12820 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_250 =
    fun _1_inlined1 _endpos__2_ _startpos_name_ args name ->
      let x =
        let desc =
          let x =
            let call =
              let params =
                let x = _1_inlined1 in
                
# 205 "<standard.mly>"
    ( x )
# 12834 "asllib/Parser.ml"
                
              in
              
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 12840 "asllib/Parser.ml"
              
            in
            
# 471 "asllib/Parser.mly"
                                                               s_call  
# 12846 "asllib/Parser.ml"
             call
          in
          
# 196 "<standard.mly>"
    ( x )
# 12852 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12861 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12867 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_251 =
    fun _1 _endpos__2_ _startpos__1_ e ->
      let x =
        let desc =
          let x = 
# 472 "asllib/Parser.mly"
                                                               S_Assert  
# 12877 "asllib/Parser.ml"
           e in
          
# 196 "<standard.mly>"
    ( x )
# 12882 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12891 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12897 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_252 =
    fun _1 _3 _endpos__2_ _startpos__1_ decl_item x ->
      let x =
        let desc =
          let x =
            let _4 = 
# 133 "asllib/Parser.mly"
                        Some 
# 12908 "asllib/Parser.ml"
             x in
            let local_decl_keyword = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 12913 "asllib/Parser.ml"
             in
            let _4_1 = _4 in
            
# 473 "asllib/Parser.mly"
                                                               S_Decl    
# 12919 "asllib/Parser.ml"
             (local_decl_keyword, decl_item, _4_1)
          in
          
# 196 "<standard.mly>"
    ( x )
# 12925 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12934 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12940 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_253 =
    fun _1 _3 _endpos__2_ _startpos__1_ decl_item x ->
      let x =
        let desc =
          let x =
            let _4 = 
# 133 "asllib/Parser.mly"
                        Some 
# 12951 "asllib/Parser.ml"
             x in
            let local_decl_keyword = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 12956 "asllib/Parser.ml"
             in
            let _4_1 = _4 in
            
# 473 "asllib/Parser.mly"
                                                               S_Decl    
# 12962 "asllib/Parser.ml"
             (local_decl_keyword, decl_item, _4_1)
          in
          
# 196 "<standard.mly>"
    ( x )
# 12968 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 12977 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 12983 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_254 =
    fun _2_inlined1 _endpos__2_ _startpos_le_ e le ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            
# 474 "asllib/Parser.mly"
                                                               S_Assign  
# 12995 "asllib/Parser.ml"
             (le, e)
          in
          
# 196 "<standard.mly>"
    ( x )
# 13001 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_le_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13010 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13016 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_255 =
    fun _2_inlined1 _endpos__2_ _endpos__3_ _startpos_name_ name rhs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 13031 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 13036 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 13042 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13051 "asllib/Parser.ml"
              
            in
            
# 476 "asllib/Parser.mly"
        ( desugar_setter call [] rhs )
# 13057 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13063 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13072 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13078 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_256 =
    fun _1_inlined1 _2_inlined1 _endpos__2_ _endpos__3_ _startpos_name_ name rhs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 13094 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 13100 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13109 "asllib/Parser.ml"
              
            in
            
# 476 "asllib/Parser.mly"
        ( desugar_setter call [] rhs )
# 13115 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13121 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13130 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13136 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_257 =
    fun _1_inlined1 _2_inlined1 _endpos__2_ _endpos_args_ _startpos_name_ args name rhs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let params =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 13152 "asllib/Parser.ml"
                  
                in
                
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 13158 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13167 "asllib/Parser.ml"
              
            in
            
# 476 "asllib/Parser.mly"
        ( desugar_setter call [] rhs )
# 13173 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13179 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13188 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13194 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_258 =
    fun _2_inlined1 _4 _endpos__2_ _endpos__3_ _startpos_name_ fld name rhs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 13209 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 13214 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 13220 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13229 "asllib/Parser.ml"
              
            in
            
# 478 "asllib/Parser.mly"
        ( desugar_setter call [fld] rhs )
# 13235 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13241 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13250 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13256 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_259 =
    fun _1_inlined1 _2_inlined1 _4 _endpos__2_ _endpos__3_ _startpos_name_ fld name rhs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 13272 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 13278 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13287 "asllib/Parser.ml"
              
            in
            
# 478 "asllib/Parser.mly"
        ( desugar_setter call [fld] rhs )
# 13293 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13299 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13308 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13314 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_260 =
    fun _1_inlined1 _2_inlined1 _4 _endpos__2_ _endpos_args_ _startpos_name_ args fld name rhs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let params =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 13330 "asllib/Parser.ml"
                  
                in
                
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 13336 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13345 "asllib/Parser.ml"
              
            in
            
# 478 "asllib/Parser.mly"
        ( desugar_setter call [fld] rhs )
# 13351 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13357 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13366 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13372 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_261 =
    fun _1_inlined2 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos__3_ _startpos_name_ name rhs x ->
      let x =
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let flds =
              let (_1_inlined1, _2) = (_1_inlined2, _2_inlined1) in
              let x =
                let _1 = _1_inlined1 in
                let li = _1 in
                
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 13389 "asllib/Parser.ml"
                
              in
              
# 205 "<standard.mly>"
    ( x )
# 13395 "asllib/Parser.ml"
              
            in
            let call =
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 13404 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 13409 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 13415 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13424 "asllib/Parser.ml"
              
            in
            
# 480 "asllib/Parser.mly"
        ( desugar_setter call flds rhs )
# 13430 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13436 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13445 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13451 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_262 =
    fun _1_inlined1 _1_inlined3 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos__3_ _startpos_name_ name rhs x ->
      let x =
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let flds =
              let (_1_inlined1, _2) = (_1_inlined3, _2_inlined1) in
              let x =
                let _1 = _1_inlined1 in
                let li = _1 in
                
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 13468 "asllib/Parser.ml"
                
              in
              
# 205 "<standard.mly>"
    ( x )
# 13474 "asllib/Parser.ml"
              
            in
            let call =
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 13484 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 13490 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13499 "asllib/Parser.ml"
              
            in
            
# 480 "asllib/Parser.mly"
        ( desugar_setter call flds rhs )
# 13505 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13511 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13520 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13526 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_263 =
    fun _1_inlined1 _1_inlined3 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos_args_ _startpos_name_ args name rhs x ->
      let x =
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let flds =
              let (_1_inlined1, _2) = (_1_inlined3, _2_inlined1) in
              let x =
                let _1 = _1_inlined1 in
                let li = _1 in
                
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 13543 "asllib/Parser.ml"
                
              in
              
# 205 "<standard.mly>"
    ( x )
# 13549 "asllib/Parser.ml"
              
            in
            let call =
              let desc =
                let params =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 13559 "asllib/Parser.ml"
                  
                in
                
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 13565 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13574 "asllib/Parser.ml"
              
            in
            
# 480 "asllib/Parser.mly"
        ( desugar_setter call flds rhs )
# 13580 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13586 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13595 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13601 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_264 =
    fun _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _3) = (_endpos__3_inlined2_, _3_inlined1) in
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 13617 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 13622 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 13628 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13637 "asllib/Parser.ml"
              
            in
            let ldk = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 13643 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 13648 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13654 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13663 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13669 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_265 =
    fun _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _1_inlined1, _3) = (_endpos__3_inlined2_, _1_inlined2, _3_inlined1) in
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 13686 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 13692 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13701 "asllib/Parser.ml"
              
            in
            let ldk = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 13707 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 13712 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13718 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13727 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13733 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_266 =
    fun _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_1, _3) = (_1_inlined1, _3_inlined1) in
              let desc =
                let params = _1 in
                
# 531 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 13749 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13758 "asllib/Parser.ml"
              
            in
            let ldk = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 13764 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 13769 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13775 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13784 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13790 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_267 =
    fun _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _3) = (_endpos__3_inlined2_, _3_inlined1) in
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 13806 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 13811 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 13817 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13826 "asllib/Parser.ml"
              
            in
            let ldk = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 13832 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 13837 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13843 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13852 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13858 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_268 =
    fun _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _1_inlined1, _3) = (_endpos__3_inlined2_, _1_inlined2, _3_inlined1) in
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 13875 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 13881 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13890 "asllib/Parser.ml"
              
            in
            let ldk = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 13896 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 13901 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13907 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13916 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13922 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_269 =
    fun _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_1, _3) = (_1_inlined1, _3_inlined1) in
              let desc =
                let params = _1 in
                
# 531 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 13938 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13947 "asllib/Parser.ml"
              
            in
            let ldk = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 13953 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 13958 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 13964 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 13973 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 13979 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_270 =
    fun _1 _endpos__2_ _startpos__1_ ldi ->
      let x =
        let desc =
          let x =
            let e = 
# 123 "<standard.mly>"
    ( None )
# 13990 "asllib/Parser.ml"
             in
            
# 483 "asllib/Parser.mly"
                                                             ( S_Decl (LDK_Var, ldi, e) )
# 13995 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14001 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14010 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14016 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_271 =
    fun _1 _1_inlined1 _2_inlined1 _endpos__2_ _startpos__1_ ldi ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let e =
              let _1 = _1_inlined1 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 14031 "asllib/Parser.ml"
              
            in
            
# 483 "asllib/Parser.mly"
                                                             ( S_Decl (LDK_Var, ldi, e) )
# 14037 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14043 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14052 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14058 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_272 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _2_inlined2 _endpos__2_ _startpos__1_ x ->
      let x =
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let as_ty =
              let (_2, _1) = (_2_inlined1, _1_inlined2) in
              _2
            in
            let _2 =
              let _1 = _1_inlined1 in
              let li = _1 in
              
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 14077 "asllib/Parser.ml"
              
            in
            let _2_1 = _2 in
            
# 484 "asllib/Parser.mly"
                                                               make_ldi_vars  
# 14084 "asllib/Parser.ml"
             (_2_1, as_ty)
          in
          
# 196 "<standard.mly>"
    ( x )
# 14090 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14099 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14105 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_273 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _2_inlined2 _endpos__2_ _startpos__1_ x ->
      let x =
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let as_ty =
              let (_2, _1) = (_2_inlined1, _1_inlined2) in
              _2
            in
            let _2 =
              let _1 = _1_inlined1 in
              let li = _1 in
              
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 14124 "asllib/Parser.ml"
              
            in
            let _2_1 = _2 in
            
# 484 "asllib/Parser.mly"
                                                               make_ldi_vars  
# 14131 "asllib/Parser.ml"
             (_2_1, as_ty)
          in
          
# 196 "<standard.mly>"
    ( x )
# 14137 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14146 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14152 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_274 =
    fun _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _3) = (_endpos__3_inlined2_, _3_inlined1) in
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 14168 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 14173 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 14179 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14188 "asllib/Parser.ml"
              
            in
            
# 486 "asllib/Parser.mly"
        ( desugar_elided_parameter LDK_Var lhs call)
# 14194 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14200 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14209 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14215 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_275 =
    fun _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _1_inlined1, _3) = (_endpos__3_inlined2_, _1_inlined2, _3_inlined1) in
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 14232 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 14238 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14247 "asllib/Parser.ml"
              
            in
            
# 486 "asllib/Parser.mly"
        ( desugar_elided_parameter LDK_Var lhs call)
# 14253 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14259 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14268 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14274 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_276 =
    fun _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_1, _3) = (_1_inlined1, _3_inlined1) in
              let desc =
                let params = _1 in
                
# 531 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 14290 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14299 "asllib/Parser.ml"
              
            in
            
# 486 "asllib/Parser.mly"
        ( desugar_elided_parameter LDK_Var lhs call)
# 14305 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14311 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14320 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14326 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_277 =
    fun _1 _endpos__2_ _startpos__1_ ->
      let x =
        let desc =
          let x =
            let args =
              let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 14338 "asllib/Parser.ml"
               in
              
# 205 "<standard.mly>"
    ( x )
# 14343 "asllib/Parser.ml"
              
            in
            
# 487 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = false } )
# 14349 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14355 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14364 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14370 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_278 =
    fun _1 _1_inlined2 _endpos__2_ _startpos__1_ ->
      let x =
        let desc =
          let x =
            let args =
              let _1_inlined1 = _1_inlined2 in
              let x = _1_inlined1 in
              
# 205 "<standard.mly>"
    ( x )
# 14384 "asllib/Parser.ml"
              
            in
            
# 487 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = false } )
# 14390 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14396 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14405 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14411 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_279 =
    fun _1 _endpos__2_ _startpos__1_ ->
      let x =
        let desc =
          let x =
            let args =
              let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 14423 "asllib/Parser.ml"
               in
              
# 205 "<standard.mly>"
    ( x )
# 14428 "asllib/Parser.ml"
              
            in
            
# 488 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = true } )
# 14434 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14440 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14449 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14455 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_280 =
    fun _1 _1_inlined2 _endpos__2_ _startpos__1_ ->
      let x =
        let desc =
          let x =
            let args =
              let _1_inlined1 = _1_inlined2 in
              let x = _1_inlined1 in
              
# 205 "<standard.mly>"
    ( x )
# 14469 "asllib/Parser.ml"
              
            in
            
# 488 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = true } )
# 14475 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14481 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14490 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14496 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_281 =
    fun _1 _2_inlined1 _3 _endpos__2_ _startpos__1_ ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            
# 489 "asllib/Parser.mly"
                                                             ( S_Unreachable )
# 14508 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14514 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14523 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14529 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_282 =
    fun _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ expr ->
      let x =
        let desc =
          let x =
            let loop_limit = 
# 123 "<standard.mly>"
    ( None )
# 14540 "asllib/Parser.ml"
             in
            let stmt_list =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 14548 "asllib/Parser.ml"
               _1_1
            in
            
# 490 "asllib/Parser.mly"
                                                               S_Repeat  
# 14554 "asllib/Parser.ml"
             (stmt_list, expr, loop_limit)
          in
          
# 196 "<standard.mly>"
    ( x )
# 14560 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14569 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14575 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_283 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _3 _endpos__2_ _startpos__1_ expr ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let loop_limit =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 14590 "asllib/Parser.ml"
              
            in
            let stmt_list =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 14599 "asllib/Parser.ml"
               _1_1
            in
            
# 490 "asllib/Parser.mly"
                                                               S_Repeat  
# 14605 "asllib/Parser.ml"
             (stmt_list, expr, loop_limit)
          in
          
# 196 "<standard.mly>"
    ( x )
# 14611 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14620 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14626 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_284 =
    fun _1 _1_inlined2 _3 _5 _endpos__2_ _startpos__1_ cond x ->
      let x =
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 14640 "asllib/Parser.ml"
               _1_1
            in
            let looplimit = 
# 205 "<standard.mly>"
    ( x )
# 14646 "asllib/Parser.ml"
             in
            
# 492 "asllib/Parser.mly"
          ( S_Repeat (body, cond, Some looplimit) )
# 14651 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14657 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14666 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14672 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_285 =
    fun _1 _endpos__2_ _startpos__1_ e ->
      let x =
        let desc =
          let x = 
# 493 "asllib/Parser.mly"
                                                             ( S_Throw (Some (e, None)) )
# 14682 "asllib/Parser.ml"
           in
          
# 196 "<standard.mly>"
    ( x )
# 14687 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14696 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14702 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_286 =
    fun _1 _endpos__2_ _startpos__1_ ->
      let x =
        let desc =
          let x = 
# 494 "asllib/Parser.mly"
                                                             ( S_Throw None             )
# 14712 "asllib/Parser.ml"
           in
          
# 196 "<standard.mly>"
    ( x )
# 14717 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14726 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14732 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_287 =
    fun _1 _2_inlined1 _endpos__2_ _endpos__2_inlined1_ _startpos__1_ ->
      let x =
        let desc =
          let x =
            let (_endpos__2_, _2) = (_endpos__2_inlined1_, _2_inlined1) in
            let loc =
              let desc =
                let _3 = 
# 161 "asllib/Parser.mly"
                ( [] )
# 14746 "asllib/Parser.ml"
                 in
                ()
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14756 "asllib/Parser.ml"
              
            in
            
# 496 "asllib/Parser.mly"
          ( Error.fatal_from loc @@ Error.NotYetImplemented "Pragmas in statements" )
# 14762 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14768 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14777 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14783 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_288 =
    fun _1 _1_inlined1 _2_inlined1 _endpos__1_inlined1_ _endpos__2_ _startpos__1_ ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let loc =
              let desc =
                let _3 = _1_inlined1 in
                ()
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14803 "asllib/Parser.ml"
              
            in
            
# 496 "asllib/Parser.mly"
          ( Error.fatal_from loc @@ Error.NotYetImplemented "Pragmas in statements" )
# 14809 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 14815 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14824 "asllib/Parser.ml"
        
      in
      (
# 228 "<standard.mly>"
    ( [ x ] )
# 14830 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_289 =
    fun _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ e s2 xs ->
      let x =
        let desc =
          let x =
            let s1 =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 14844 "asllib/Parser.ml"
               _1_1
            in
            
# 458 "asllib/Parser.mly"
                                                       S_Cond 
# 14850 "asllib/Parser.ml"
             (e, s1, s2)
          in
          
# 196 "<standard.mly>"
    ( x )
# 14856 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14865 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 14871 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_290 =
    fun _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ expr xs ->
      let x =
        let desc =
          let x =
            let alt = _1_inlined1 in
            
# 459 "asllib/Parser.mly"
                                                       S_Case 
# 14883 "asllib/Parser.ml"
             (expr, alt)
          in
          
# 196 "<standard.mly>"
    ( x )
# 14889 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14898 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 14904 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_291 =
    fun _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ expr xs ->
      let x =
        let desc =
          let x =
            let stmt_list =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 14918 "asllib/Parser.ml"
               _1_1
            in
            let loop_limit = 
# 123 "<standard.mly>"
    ( None )
# 14924 "asllib/Parser.ml"
             in
            
# 460 "asllib/Parser.mly"
                                                       S_While 
# 14929 "asllib/Parser.ml"
             (expr, loop_limit, stmt_list)
          in
          
# 196 "<standard.mly>"
    ( x )
# 14935 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14944 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 14950 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_292 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ expr xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let stmt_list =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 14965 "asllib/Parser.ml"
               _1_1
            in
            let loop_limit =
              let _1 = _1_inlined1 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 14974 "asllib/Parser.ml"
              
            in
            
# 460 "asllib/Parser.mly"
                                                       S_While 
# 14980 "asllib/Parser.ml"
             (expr, loop_limit, stmt_list)
          in
          
# 196 "<standard.mly>"
    ( x )
# 14986 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 14995 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15001 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_293 =
    fun _1 _1_inlined1 _1_inlined2 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e xs ->
      let x =
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 15015 "asllib/Parser.ml"
               _1_1
            in
            let limit = 
# 123 "<standard.mly>"
    ( None )
# 15021 "asllib/Parser.ml"
             in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                       ( AST.Up )
# 15028 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 15034 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 15040 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15049 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15055 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_294 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let body =
              let _1 = _1_inlined3 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 15070 "asllib/Parser.ml"
               _1_1
            in
            let limit =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 15079 "asllib/Parser.ml"
              
            in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                       ( AST.Up )
# 15087 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 15093 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 15099 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15108 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15114 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_295 =
    fun _1 _1_inlined1 _1_inlined2 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e xs ->
      let x =
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 15128 "asllib/Parser.ml"
               _1_1
            in
            let limit = 
# 123 "<standard.mly>"
    ( None )
# 15134 "asllib/Parser.ml"
             in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                                            ( AST.Down )
# 15141 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 15147 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 15153 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15162 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15168 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_296 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let body =
              let _1 = _1_inlined3 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 15183 "asllib/Parser.ml"
               _1_1
            in
            let limit =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 15192 "asllib/Parser.ml"
              
            in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                                            ( AST.Down )
# 15200 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 15206 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 15212 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15221 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15227 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_297 =
    fun _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ c xs ->
      let x =
        let desc =
          let x =
            let o = 
# 123 "<standard.mly>"
    ( None )
# 15238 "asllib/Parser.ml"
             in
            let s =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 15246 "asllib/Parser.ml"
               _1_1
            in
            
# 464 "asllib/Parser.mly"
                                                                              S_Try  
# 15252 "asllib/Parser.ml"
             (s, c, o)
          in
          
# 196 "<standard.mly>"
    ( x )
# 15258 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15267 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15273 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_298 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _endpos__2_ _startpos__1_ c xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let o =
              let (_1_inlined1, _1) = (_1_inlined3, _1_inlined2) in
              let x =
                let _1 = _1_inlined1 in
                let _1_1 = _1 in
                
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 15290 "asllib/Parser.ml"
                 _1_1
              in
              
# 126 "<standard.mly>"
    ( Some x )
# 15296 "asllib/Parser.ml"
              
            in
            let s =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 15305 "asllib/Parser.ml"
               _1_1
            in
            
# 464 "asllib/Parser.mly"
                                                                              S_Try  
# 15311 "asllib/Parser.ml"
             (s, c, o)
          in
          
# 196 "<standard.mly>"
    ( x )
# 15317 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15326 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15332 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_299 =
    fun _1 _1_inlined2 _3 _5 _endpos__2_ _startpos__1_ cond x xs ->
      let x =
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 15346 "asllib/Parser.ml"
               _1_1
            in
            let looplimit = 
# 205 "<standard.mly>"
    ( x )
# 15352 "asllib/Parser.ml"
             in
            
# 466 "asllib/Parser.mly"
          ( S_While (cond, Some looplimit, body) )
# 15357 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 15363 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15372 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15378 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_300 =
    fun _1 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x = 
# 435 "asllib/Parser.mly"
            ( S_Pass )
# 15388 "asllib/Parser.ml"
           in
          
# 196 "<standard.mly>"
    ( x )
# 15393 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15402 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15408 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_301 =
    fun _1 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let _2 = 
# 123 "<standard.mly>"
    ( None )
# 15419 "asllib/Parser.ml"
             in
            let _2_1 = _2 in
            
# 470 "asllib/Parser.mly"
                                                               S_Return  
# 15425 "asllib/Parser.ml"
             _2_1
          in
          
# 196 "<standard.mly>"
    ( x )
# 15431 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15440 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15446 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_302 =
    fun _1 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let _2 = 
# 126 "<standard.mly>"
    ( Some x )
# 15457 "asllib/Parser.ml"
             in
            let _2_1 = _2 in
            
# 470 "asllib/Parser.mly"
                                                               S_Return  
# 15463 "asllib/Parser.ml"
             _2_1
          in
          
# 196 "<standard.mly>"
    ( x )
# 15469 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15478 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15484 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_303 =
    fun _endpos__2_ _startpos_name_ name xs ->
      let x =
        let desc =
          let x =
            let call =
              let args =
                let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 15497 "asllib/Parser.ml"
                 in
                
# 205 "<standard.mly>"
    ( x )
# 15502 "asllib/Parser.ml"
                
              in
              
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 15508 "asllib/Parser.ml"
              
            in
            
# 471 "asllib/Parser.mly"
                                                               s_call  
# 15514 "asllib/Parser.ml"
             call
          in
          
# 196 "<standard.mly>"
    ( x )
# 15520 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15529 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15535 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_304 =
    fun _1_inlined1 _endpos__2_ _startpos_name_ name xs ->
      let x =
        let desc =
          let x =
            let call =
              let args =
                let x = _1_inlined1 in
                
# 205 "<standard.mly>"
    ( x )
# 15549 "asllib/Parser.ml"
                
              in
              
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 15555 "asllib/Parser.ml"
              
            in
            
# 471 "asllib/Parser.mly"
                                                               s_call  
# 15561 "asllib/Parser.ml"
             call
          in
          
# 196 "<standard.mly>"
    ( x )
# 15567 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15576 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15582 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_305 =
    fun _1_inlined1 _endpos__2_ _startpos_name_ args name xs ->
      let x =
        let desc =
          let x =
            let call =
              let params =
                let x = _1_inlined1 in
                
# 205 "<standard.mly>"
    ( x )
# 15596 "asllib/Parser.ml"
                
              in
              
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 15602 "asllib/Parser.ml"
              
            in
            
# 471 "asllib/Parser.mly"
                                                               s_call  
# 15608 "asllib/Parser.ml"
             call
          in
          
# 196 "<standard.mly>"
    ( x )
# 15614 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15623 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15629 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_306 =
    fun _1 _endpos__2_ _startpos__1_ e xs ->
      let x =
        let desc =
          let x = 
# 472 "asllib/Parser.mly"
                                                               S_Assert  
# 15639 "asllib/Parser.ml"
           e in
          
# 196 "<standard.mly>"
    ( x )
# 15644 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15653 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15659 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_307 =
    fun _1 _3 _endpos__2_ _startpos__1_ decl_item x xs ->
      let x =
        let desc =
          let x =
            let _4 = 
# 133 "asllib/Parser.mly"
                        Some 
# 15670 "asllib/Parser.ml"
             x in
            let local_decl_keyword = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 15675 "asllib/Parser.ml"
             in
            let _4_1 = _4 in
            
# 473 "asllib/Parser.mly"
                                                               S_Decl    
# 15681 "asllib/Parser.ml"
             (local_decl_keyword, decl_item, _4_1)
          in
          
# 196 "<standard.mly>"
    ( x )
# 15687 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15696 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15702 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_308 =
    fun _1 _3 _endpos__2_ _startpos__1_ decl_item x xs ->
      let x =
        let desc =
          let x =
            let _4 = 
# 133 "asllib/Parser.mly"
                        Some 
# 15713 "asllib/Parser.ml"
             x in
            let local_decl_keyword = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 15718 "asllib/Parser.ml"
             in
            let _4_1 = _4 in
            
# 473 "asllib/Parser.mly"
                                                               S_Decl    
# 15724 "asllib/Parser.ml"
             (local_decl_keyword, decl_item, _4_1)
          in
          
# 196 "<standard.mly>"
    ( x )
# 15730 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15739 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15745 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_309 =
    fun _2_inlined1 _endpos__2_ _startpos_le_ e le xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            
# 474 "asllib/Parser.mly"
                                                               S_Assign  
# 15757 "asllib/Parser.ml"
             (le, e)
          in
          
# 196 "<standard.mly>"
    ( x )
# 15763 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_le_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15772 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15778 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_310 =
    fun _2_inlined1 _endpos__2_ _endpos__3_ _startpos_name_ name rhs xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 15793 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 15798 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 15804 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15813 "asllib/Parser.ml"
              
            in
            
# 476 "asllib/Parser.mly"
        ( desugar_setter call [] rhs )
# 15819 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 15825 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15834 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15840 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_311 =
    fun _1_inlined1 _2_inlined1 _endpos__2_ _endpos__3_ _startpos_name_ name rhs xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 15856 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 15862 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15871 "asllib/Parser.ml"
              
            in
            
# 476 "asllib/Parser.mly"
        ( desugar_setter call [] rhs )
# 15877 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 15883 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15892 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15898 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_312 =
    fun _1_inlined1 _2_inlined1 _endpos__2_ _endpos_args_ _startpos_name_ args name rhs xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let params =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 15914 "asllib/Parser.ml"
                  
                in
                
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 15920 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15929 "asllib/Parser.ml"
              
            in
            
# 476 "asllib/Parser.mly"
        ( desugar_setter call [] rhs )
# 15935 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 15941 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15950 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 15956 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_313 =
    fun _2_inlined1 _4 _endpos__2_ _endpos__3_ _startpos_name_ fld name rhs xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 15971 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 15976 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 15982 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 15991 "asllib/Parser.ml"
              
            in
            
# 478 "asllib/Parser.mly"
        ( desugar_setter call [fld] rhs )
# 15997 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16003 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16012 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16018 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_314 =
    fun _1_inlined1 _2_inlined1 _4 _endpos__2_ _endpos__3_ _startpos_name_ fld name rhs xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 16034 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 16040 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16049 "asllib/Parser.ml"
              
            in
            
# 478 "asllib/Parser.mly"
        ( desugar_setter call [fld] rhs )
# 16055 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16061 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16070 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16076 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_315 =
    fun _1_inlined1 _2_inlined1 _4 _endpos__2_ _endpos_args_ _startpos_name_ args fld name rhs xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let params =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 16092 "asllib/Parser.ml"
                  
                in
                
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 16098 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16107 "asllib/Parser.ml"
              
            in
            
# 478 "asllib/Parser.mly"
        ( desugar_setter call [fld] rhs )
# 16113 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16119 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16128 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16134 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_316 =
    fun _1_inlined2 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos__3_ _startpos_name_ name rhs x xs ->
      let x =
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let flds =
              let (_1_inlined1, _2) = (_1_inlined2, _2_inlined1) in
              let x =
                let _1 = _1_inlined1 in
                let li = _1 in
                
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 16151 "asllib/Parser.ml"
                
              in
              
# 205 "<standard.mly>"
    ( x )
# 16157 "asllib/Parser.ml"
              
            in
            let call =
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 16166 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 16171 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 16177 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16186 "asllib/Parser.ml"
              
            in
            
# 480 "asllib/Parser.mly"
        ( desugar_setter call flds rhs )
# 16192 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16198 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16207 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16213 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_317 =
    fun _1_inlined1 _1_inlined3 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos__3_ _startpos_name_ name rhs x xs ->
      let x =
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let flds =
              let (_1_inlined1, _2) = (_1_inlined3, _2_inlined1) in
              let x =
                let _1 = _1_inlined1 in
                let li = _1 in
                
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 16230 "asllib/Parser.ml"
                
              in
              
# 205 "<standard.mly>"
    ( x )
# 16236 "asllib/Parser.ml"
              
            in
            let call =
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 16246 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 16252 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16261 "asllib/Parser.ml"
              
            in
            
# 480 "asllib/Parser.mly"
        ( desugar_setter call flds rhs )
# 16267 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16273 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16282 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16288 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_318 =
    fun _1_inlined1 _1_inlined3 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos_args_ _startpos_name_ args name rhs x xs ->
      let x =
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let flds =
              let (_1_inlined1, _2) = (_1_inlined3, _2_inlined1) in
              let x =
                let _1 = _1_inlined1 in
                let li = _1 in
                
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 16305 "asllib/Parser.ml"
                
              in
              
# 205 "<standard.mly>"
    ( x )
# 16311 "asllib/Parser.ml"
              
            in
            let call =
              let desc =
                let params =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 16321 "asllib/Parser.ml"
                  
                in
                
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 16327 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16336 "asllib/Parser.ml"
              
            in
            
# 480 "asllib/Parser.mly"
        ( desugar_setter call flds rhs )
# 16342 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16348 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16357 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16363 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_319 =
    fun _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _3) = (_endpos__3_inlined2_, _3_inlined1) in
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 16379 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 16384 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 16390 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16399 "asllib/Parser.ml"
              
            in
            let ldk = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 16405 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 16410 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16416 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16425 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16431 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_320 =
    fun _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _1_inlined1, _3) = (_endpos__3_inlined2_, _1_inlined2, _3_inlined1) in
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 16448 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 16454 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16463 "asllib/Parser.ml"
              
            in
            let ldk = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 16469 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 16474 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16480 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16489 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16495 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_321 =
    fun _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_1, _3) = (_1_inlined1, _3_inlined1) in
              let desc =
                let params = _1 in
                
# 531 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 16511 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16520 "asllib/Parser.ml"
              
            in
            let ldk = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 16526 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 16531 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16537 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16546 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16552 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_322 =
    fun _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _3) = (_endpos__3_inlined2_, _3_inlined1) in
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 16568 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 16573 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 16579 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16588 "asllib/Parser.ml"
              
            in
            let ldk = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 16594 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 16599 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16605 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16614 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16620 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_323 =
    fun _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _1_inlined1, _3) = (_endpos__3_inlined2_, _1_inlined2, _3_inlined1) in
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 16637 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 16643 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16652 "asllib/Parser.ml"
              
            in
            let ldk = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 16658 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 16663 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16669 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16678 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16684 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_324 =
    fun _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_1, _3) = (_1_inlined1, _3_inlined1) in
              let desc =
                let params = _1 in
                
# 531 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 16700 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16709 "asllib/Parser.ml"
              
            in
            let ldk = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 16715 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 16720 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16726 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16735 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16741 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_325 =
    fun _1 _endpos__2_ _startpos__1_ ldi xs ->
      let x =
        let desc =
          let x =
            let e = 
# 123 "<standard.mly>"
    ( None )
# 16752 "asllib/Parser.ml"
             in
            
# 483 "asllib/Parser.mly"
                                                             ( S_Decl (LDK_Var, ldi, e) )
# 16757 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16763 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16772 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16778 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_326 =
    fun _1 _1_inlined1 _2_inlined1 _endpos__2_ _startpos__1_ ldi xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let e =
              let _1 = _1_inlined1 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 16793 "asllib/Parser.ml"
              
            in
            
# 483 "asllib/Parser.mly"
                                                             ( S_Decl (LDK_Var, ldi, e) )
# 16799 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16805 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16814 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16820 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_327 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _2_inlined2 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let as_ty =
              let (_2, _1) = (_2_inlined1, _1_inlined2) in
              _2
            in
            let _2 =
              let _1 = _1_inlined1 in
              let li = _1 in
              
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 16839 "asllib/Parser.ml"
              
            in
            let _2_1 = _2 in
            
# 484 "asllib/Parser.mly"
                                                               make_ldi_vars  
# 16846 "asllib/Parser.ml"
             (_2_1, as_ty)
          in
          
# 196 "<standard.mly>"
    ( x )
# 16852 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16861 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16867 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_328 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _2_inlined2 _endpos__2_ _startpos__1_ x xs ->
      let x =
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let as_ty =
              let (_2, _1) = (_2_inlined1, _1_inlined2) in
              _2
            in
            let _2 =
              let _1 = _1_inlined1 in
              let li = _1 in
              
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 16886 "asllib/Parser.ml"
              
            in
            let _2_1 = _2 in
            
# 484 "asllib/Parser.mly"
                                                               make_ldi_vars  
# 16893 "asllib/Parser.ml"
             (_2_1, as_ty)
          in
          
# 196 "<standard.mly>"
    ( x )
# 16899 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16908 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16914 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_329 =
    fun _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _3) = (_endpos__3_inlined2_, _3_inlined1) in
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 16930 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 16935 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 16941 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16950 "asllib/Parser.ml"
              
            in
            
# 486 "asllib/Parser.mly"
        ( desugar_elided_parameter LDK_Var lhs call)
# 16956 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 16962 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 16971 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 16977 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_330 =
    fun _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _1_inlined1, _3) = (_endpos__3_inlined2_, _1_inlined2, _3_inlined1) in
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 16994 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 17000 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17009 "asllib/Parser.ml"
              
            in
            
# 486 "asllib/Parser.mly"
        ( desugar_elided_parameter LDK_Var lhs call)
# 17015 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17021 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17030 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17036 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_331 =
    fun _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_1, _3) = (_1_inlined1, _3_inlined1) in
              let desc =
                let params = _1 in
                
# 531 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 17052 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17061 "asllib/Parser.ml"
              
            in
            
# 486 "asllib/Parser.mly"
        ( desugar_elided_parameter LDK_Var lhs call)
# 17067 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17073 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17082 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17088 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_332 =
    fun _1 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let args =
              let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 17100 "asllib/Parser.ml"
               in
              
# 205 "<standard.mly>"
    ( x )
# 17105 "asllib/Parser.ml"
              
            in
            
# 487 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = false } )
# 17111 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17117 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17126 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17132 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_333 =
    fun _1 _1_inlined2 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let args =
              let _1_inlined1 = _1_inlined2 in
              let x = _1_inlined1 in
              
# 205 "<standard.mly>"
    ( x )
# 17146 "asllib/Parser.ml"
              
            in
            
# 487 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = false } )
# 17152 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17158 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17167 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17173 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_334 =
    fun _1 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let args =
              let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 17185 "asllib/Parser.ml"
               in
              
# 205 "<standard.mly>"
    ( x )
# 17190 "asllib/Parser.ml"
              
            in
            
# 488 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = true } )
# 17196 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17202 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17211 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17217 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_335 =
    fun _1 _1_inlined2 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let args =
              let _1_inlined1 = _1_inlined2 in
              let x = _1_inlined1 in
              
# 205 "<standard.mly>"
    ( x )
# 17231 "asllib/Parser.ml"
              
            in
            
# 488 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = true } )
# 17237 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17243 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17252 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17258 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_336 =
    fun _1 _2_inlined1 _3 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            
# 489 "asllib/Parser.mly"
                                                             ( S_Unreachable )
# 17270 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17276 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17285 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17291 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_337 =
    fun _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ expr xs ->
      let x =
        let desc =
          let x =
            let loop_limit = 
# 123 "<standard.mly>"
    ( None )
# 17302 "asllib/Parser.ml"
             in
            let stmt_list =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 17310 "asllib/Parser.ml"
               _1_1
            in
            
# 490 "asllib/Parser.mly"
                                                               S_Repeat  
# 17316 "asllib/Parser.ml"
             (stmt_list, expr, loop_limit)
          in
          
# 196 "<standard.mly>"
    ( x )
# 17322 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17331 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17337 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_338 =
    fun _1 _1_inlined1 _1_inlined2 _2_inlined1 _3 _endpos__2_ _startpos__1_ expr xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let loop_limit =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 17352 "asllib/Parser.ml"
              
            in
            let stmt_list =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 17361 "asllib/Parser.ml"
               _1_1
            in
            
# 490 "asllib/Parser.mly"
                                                               S_Repeat  
# 17367 "asllib/Parser.ml"
             (stmt_list, expr, loop_limit)
          in
          
# 196 "<standard.mly>"
    ( x )
# 17373 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17382 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17388 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_339 =
    fun _1 _1_inlined2 _3 _5 _endpos__2_ _startpos__1_ cond x xs ->
      let x =
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 17402 "asllib/Parser.ml"
               _1_1
            in
            let looplimit = 
# 205 "<standard.mly>"
    ( x )
# 17408 "asllib/Parser.ml"
             in
            
# 492 "asllib/Parser.mly"
          ( S_Repeat (body, cond, Some looplimit) )
# 17413 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17419 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17428 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17434 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_340 =
    fun _1 _endpos__2_ _startpos__1_ e xs ->
      let x =
        let desc =
          let x = 
# 493 "asllib/Parser.mly"
                                                             ( S_Throw (Some (e, None)) )
# 17444 "asllib/Parser.ml"
           in
          
# 196 "<standard.mly>"
    ( x )
# 17449 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17458 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17464 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_341 =
    fun _1 _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x = 
# 494 "asllib/Parser.mly"
                                                             ( S_Throw None             )
# 17474 "asllib/Parser.ml"
           in
          
# 196 "<standard.mly>"
    ( x )
# 17479 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17488 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17494 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_342 =
    fun _1 _2_inlined1 _endpos__2_ _endpos__2_inlined1_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let (_endpos__2_, _2) = (_endpos__2_inlined1_, _2_inlined1) in
            let loc =
              let desc =
                let _3 = 
# 161 "asllib/Parser.mly"
                ( [] )
# 17508 "asllib/Parser.ml"
                 in
                ()
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17518 "asllib/Parser.ml"
              
            in
            
# 496 "asllib/Parser.mly"
          ( Error.fatal_from loc @@ Error.NotYetImplemented "Pragmas in statements" )
# 17524 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17530 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17539 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17545 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_343 =
    fun _1 _1_inlined1 _2_inlined1 _endpos__1_inlined1_ _endpos__2_ _startpos__1_ xs ->
      let x =
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let loc =
              let desc =
                let _3 = _1_inlined1 in
                ()
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17565 "asllib/Parser.ml"
              
            in
            
# 496 "asllib/Parser.mly"
          ( Error.fatal_from loc @@ Error.NotYetImplemented "Pragmas in statements" )
# 17571 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17577 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17586 "asllib/Parser.ml"
        
      in
      (
# 231 "<standard.mly>"
    ( x :: xs )
# 17592 "asllib/Parser.ml"
       : (AST.stmt list))
  
  let _menhir_action_344 =
    fun _1 _1_inlined1 _2 _3 _endpos__2_inlined1_ _startpos__1_ e s2 ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let s1 =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 17607 "asllib/Parser.ml"
               _1_1
            in
            
# 458 "asllib/Parser.mly"
                                                       S_Cond 
# 17613 "asllib/Parser.ml"
             (e, s1, s2)
          in
          
# 196 "<standard.mly>"
    ( x )
# 17619 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17628 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 17649 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_345 =
    fun _1 _1_inlined1 _2 _3 _endpos__2_inlined1_ _startpos__1_ expr ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let alt = _1_inlined1 in
            
# 459 "asllib/Parser.mly"
                                                       S_Case 
# 17662 "asllib/Parser.ml"
             (expr, alt)
          in
          
# 196 "<standard.mly>"
    ( x )
# 17668 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17677 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 17698 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_346 =
    fun _1 _1_inlined1 _2 _4 _endpos__2_inlined1_ _startpos__1_ expr ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let stmt_list =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 17713 "asllib/Parser.ml"
               _1_1
            in
            let loop_limit = 
# 123 "<standard.mly>"
    ( None )
# 17719 "asllib/Parser.ml"
             in
            
# 460 "asllib/Parser.mly"
                                                       S_While 
# 17724 "asllib/Parser.ml"
             (expr, loop_limit, stmt_list)
          in
          
# 196 "<standard.mly>"
    ( x )
# 17730 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17739 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 17760 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_347 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _4 _endpos__2_inlined2_ _startpos__1_ expr ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let stmt_list =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 17776 "asllib/Parser.ml"
               _1_1
            in
            let loop_limit =
              let _1 = _1_inlined1 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 17785 "asllib/Parser.ml"
              
            in
            
# 460 "asllib/Parser.mly"
                                                       S_While 
# 17791 "asllib/Parser.ml"
             (expr, loop_limit, stmt_list)
          in
          
# 196 "<standard.mly>"
    ( x )
# 17797 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17806 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 17827 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_348 =
    fun _1 _1_inlined1 _1_inlined2 _2 _3 _8 _endpos__2_inlined1_ _startpos__1_ end_e index_name start_e ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 17842 "asllib/Parser.ml"
               _1_1
            in
            let limit = 
# 123 "<standard.mly>"
    ( None )
# 17848 "asllib/Parser.ml"
             in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                       ( AST.Up )
# 17855 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 17861 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17867 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17876 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 17897 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_349 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _8 _endpos__2_inlined2_ _startpos__1_ end_e index_name start_e ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let body =
              let _1 = _1_inlined3 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 17913 "asllib/Parser.ml"
               _1_1
            in
            let limit =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 17922 "asllib/Parser.ml"
              
            in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                       ( AST.Up )
# 17930 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 17936 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 17942 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 17951 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 17972 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_350 =
    fun _1 _1_inlined1 _1_inlined2 _2 _3 _8 _endpos__2_inlined1_ _startpos__1_ end_e index_name start_e ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 17987 "asllib/Parser.ml"
               _1_1
            in
            let limit = 
# 123 "<standard.mly>"
    ( None )
# 17993 "asllib/Parser.ml"
             in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                                            ( AST.Down )
# 18000 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 18006 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 18012 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18021 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18042 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_351 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _8 _endpos__2_inlined2_ _startpos__1_ end_e index_name start_e ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let body =
              let _1 = _1_inlined3 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 18058 "asllib/Parser.ml"
               _1_1
            in
            let limit =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 18067 "asllib/Parser.ml"
              
            in
            let dir =
              let _1 = _1_inlined1 in
              
# 437 "asllib/Parser.mly"
                                            ( AST.Down )
# 18075 "asllib/Parser.ml"
              
            in
            
# 463 "asllib/Parser.mly"
          ( S_For { index_name; start_e; end_e; dir; body; limit } )
# 18081 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 18087 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18096 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18117 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_352 =
    fun _1 _1_inlined1 _2 _3 _endpos__2_inlined1_ _startpos__1_ c ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let o = 
# 123 "<standard.mly>"
    ( None )
# 18129 "asllib/Parser.ml"
             in
            let s =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 18137 "asllib/Parser.ml"
               _1_1
            in
            
# 464 "asllib/Parser.mly"
                                                                              S_Try  
# 18143 "asllib/Parser.ml"
             (s, c, o)
          in
          
# 196 "<standard.mly>"
    ( x )
# 18149 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18158 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18179 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_353 =
    fun _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _endpos__2_inlined2_ _startpos__1_ c ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let o =
              let (_1_inlined1, _1) = (_1_inlined3, _1_inlined2) in
              let x =
                let _1 = _1_inlined1 in
                let _1_1 = _1 in
                
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 18197 "asllib/Parser.ml"
                 _1_1
              in
              
# 126 "<standard.mly>"
    ( Some x )
# 18203 "asllib/Parser.ml"
              
            in
            let s =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 18212 "asllib/Parser.ml"
               _1_1
            in
            
# 464 "asllib/Parser.mly"
                                                                              S_Try  
# 18218 "asllib/Parser.ml"
             (s, c, o)
          in
          
# 196 "<standard.mly>"
    ( x )
# 18224 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18233 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18254 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_354 =
    fun _1 _1_inlined2 _2 _3 _5 _endpos__2_inlined1_ _startpos__1_ cond x ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 18269 "asllib/Parser.ml"
               _1_1
            in
            let looplimit = 
# 205 "<standard.mly>"
    ( x )
# 18275 "asllib/Parser.ml"
             in
            
# 466 "asllib/Parser.mly"
          ( S_While (cond, Some looplimit, body) )
# 18280 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 18286 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18295 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18316 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_355 =
    fun _1 _2 _endpos__2_inlined1_ _startpos__1_ ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x = 
# 435 "asllib/Parser.mly"
            ( S_Pass )
# 18327 "asllib/Parser.ml"
           in
          
# 196 "<standard.mly>"
    ( x )
# 18332 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18341 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18362 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_356 =
    fun _1 _2 _endpos__2_inlined1_ _startpos__1_ ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let _2 = 
# 123 "<standard.mly>"
    ( None )
# 18374 "asllib/Parser.ml"
             in
            let _2_1 = _2 in
            
# 470 "asllib/Parser.mly"
                                                               S_Return  
# 18380 "asllib/Parser.ml"
             _2_1
          in
          
# 196 "<standard.mly>"
    ( x )
# 18386 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18395 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18416 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_357 =
    fun _1 _2 _endpos__2_inlined1_ _startpos__1_ x ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let _2 = 
# 126 "<standard.mly>"
    ( Some x )
# 18428 "asllib/Parser.ml"
             in
            let _2_1 = _2 in
            
# 470 "asllib/Parser.mly"
                                                               S_Return  
# 18434 "asllib/Parser.ml"
             _2_1
          in
          
# 196 "<standard.mly>"
    ( x )
# 18440 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18449 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18470 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_358 =
    fun _2 _endpos__2_inlined1_ _startpos_name_ name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let call =
              let args =
                let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 18484 "asllib/Parser.ml"
                 in
                
# 205 "<standard.mly>"
    ( x )
# 18489 "asllib/Parser.ml"
                
              in
              
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 18495 "asllib/Parser.ml"
              
            in
            
# 471 "asllib/Parser.mly"
                                                               s_call  
# 18501 "asllib/Parser.ml"
             call
          in
          
# 196 "<standard.mly>"
    ( x )
# 18507 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18516 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18537 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_359 =
    fun _1_inlined1 _2 _endpos__2_inlined1_ _startpos_name_ name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let call =
              let args =
                let x = _1_inlined1 in
                
# 205 "<standard.mly>"
    ( x )
# 18552 "asllib/Parser.ml"
                
              in
              
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 18558 "asllib/Parser.ml"
              
            in
            
# 471 "asllib/Parser.mly"
                                                               s_call  
# 18564 "asllib/Parser.ml"
             call
          in
          
# 196 "<standard.mly>"
    ( x )
# 18570 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18579 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18600 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_360 =
    fun _1_inlined1 _2 _endpos__2_inlined1_ _startpos_name_ args name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let call =
              let params =
                let x = _1_inlined1 in
                
# 205 "<standard.mly>"
    ( x )
# 18615 "asllib/Parser.ml"
                
              in
              
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 18621 "asllib/Parser.ml"
              
            in
            
# 471 "asllib/Parser.mly"
                                                               s_call  
# 18627 "asllib/Parser.ml"
             call
          in
          
# 196 "<standard.mly>"
    ( x )
# 18633 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18642 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18663 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_361 =
    fun _1 _2 _endpos__2_inlined1_ _startpos__1_ e ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x = 
# 472 "asllib/Parser.mly"
                                                               S_Assert  
# 18674 "asllib/Parser.ml"
           e in
          
# 196 "<standard.mly>"
    ( x )
# 18679 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18688 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18709 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_362 =
    fun _1 _2 _3 _endpos__2_inlined1_ _startpos__1_ decl_item x ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let _4 = 
# 133 "asllib/Parser.mly"
                        Some 
# 18721 "asllib/Parser.ml"
             x in
            let local_decl_keyword = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 18726 "asllib/Parser.ml"
             in
            let _4_1 = _4 in
            
# 473 "asllib/Parser.mly"
                                                               S_Decl    
# 18732 "asllib/Parser.ml"
             (local_decl_keyword, decl_item, _4_1)
          in
          
# 196 "<standard.mly>"
    ( x )
# 18738 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18747 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18768 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_363 =
    fun _1 _2 _3 _endpos__2_inlined1_ _startpos__1_ decl_item x ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let _4 = 
# 133 "asllib/Parser.mly"
                        Some 
# 18780 "asllib/Parser.ml"
             x in
            let local_decl_keyword = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 18785 "asllib/Parser.ml"
             in
            let _4_1 = _4 in
            
# 473 "asllib/Parser.mly"
                                                               S_Decl    
# 18791 "asllib/Parser.ml"
             (local_decl_keyword, decl_item, _4_1)
          in
          
# 196 "<standard.mly>"
    ( x )
# 18797 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18806 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18827 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_364 =
    fun _2 _2_inlined1 _endpos__2_inlined2_ _startpos_le_ e le ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            
# 474 "asllib/Parser.mly"
                                                               S_Assign  
# 18840 "asllib/Parser.ml"
             (le, e)
          in
          
# 196 "<standard.mly>"
    ( x )
# 18846 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_le_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18855 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18876 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_365 =
    fun _2 _2_inlined1 _endpos__2_inlined2_ _endpos__3_ _startpos_name_ name rhs ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 18892 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 18897 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 18903 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18912 "asllib/Parser.ml"
              
            in
            
# 476 "asllib/Parser.mly"
        ( desugar_setter call [] rhs )
# 18918 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 18924 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18933 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 18954 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_366 =
    fun _1_inlined1 _2 _2_inlined1 _endpos__2_inlined2_ _endpos__3_ _startpos_name_ name rhs ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 18971 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 18977 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 18986 "asllib/Parser.ml"
              
            in
            
# 476 "asllib/Parser.mly"
        ( desugar_setter call [] rhs )
# 18992 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 18998 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19007 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19028 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_367 =
    fun _1_inlined1 _2 _2_inlined1 _endpos__2_inlined2_ _endpos_args_ _startpos_name_ args name rhs ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let params =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 19045 "asllib/Parser.ml"
                  
                in
                
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 19051 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19060 "asllib/Parser.ml"
              
            in
            
# 476 "asllib/Parser.mly"
        ( desugar_setter call [] rhs )
# 19066 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19072 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19081 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19102 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_368 =
    fun _2 _2_inlined1 _4 _endpos__2_inlined2_ _endpos__3_ _startpos_name_ fld name rhs ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 19118 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 19123 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 19129 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19138 "asllib/Parser.ml"
              
            in
            
# 478 "asllib/Parser.mly"
        ( desugar_setter call [fld] rhs )
# 19144 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19150 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19159 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19180 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_369 =
    fun _1_inlined1 _2 _2_inlined1 _4 _endpos__2_inlined2_ _endpos__3_ _startpos_name_ fld name rhs ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 19197 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 19203 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19212 "asllib/Parser.ml"
              
            in
            
# 478 "asllib/Parser.mly"
        ( desugar_setter call [fld] rhs )
# 19218 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19224 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19233 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19254 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_370 =
    fun _1_inlined1 _2 _2_inlined1 _4 _endpos__2_inlined2_ _endpos_args_ _startpos_name_ args fld name rhs ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let desc =
                let params =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 19271 "asllib/Parser.ml"
                  
                in
                
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 19277 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19286 "asllib/Parser.ml"
              
            in
            
# 478 "asllib/Parser.mly"
        ( desugar_setter call [fld] rhs )
# 19292 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19298 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19307 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19328 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_371 =
    fun _1_inlined2 _2 _2_inlined1 _2_inlined2 _4 _endpos__2_inlined3_ _endpos__3_ _startpos_name_ name rhs x ->
      let body =
        let _endpos__2_ = _endpos__2_inlined3_ in
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let flds =
              let (_1_inlined1, _2) = (_1_inlined2, _2_inlined1) in
              let x =
                let _1 = _1_inlined1 in
                let li = _1 in
                
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 19346 "asllib/Parser.ml"
                
              in
              
# 205 "<standard.mly>"
    ( x )
# 19352 "asllib/Parser.ml"
              
            in
            let call =
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 19361 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 19366 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 19372 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19381 "asllib/Parser.ml"
              
            in
            
# 480 "asllib/Parser.mly"
        ( desugar_setter call flds rhs )
# 19387 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19393 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19402 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19423 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_372 =
    fun _1_inlined1 _1_inlined3 _2 _2_inlined1 _2_inlined2 _4 _endpos__2_inlined3_ _endpos__3_ _startpos_name_ name rhs x ->
      let body =
        let _endpos__2_ = _endpos__2_inlined3_ in
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let flds =
              let (_1_inlined1, _2) = (_1_inlined3, _2_inlined1) in
              let x =
                let _1 = _1_inlined1 in
                let li = _1 in
                
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 19441 "asllib/Parser.ml"
                
              in
              
# 205 "<standard.mly>"
    ( x )
# 19447 "asllib/Parser.ml"
              
            in
            let call =
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 19457 "asllib/Parser.ml"
                  
                in
                
# 524 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 19463 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19472 "asllib/Parser.ml"
              
            in
            
# 480 "asllib/Parser.mly"
        ( desugar_setter call flds rhs )
# 19478 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19484 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19493 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19514 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_373 =
    fun _1_inlined1 _1_inlined3 _2 _2_inlined1 _2_inlined2 _4 _endpos__2_inlined3_ _endpos_args_ _startpos_name_ args name rhs x ->
      let body =
        let _endpos__2_ = _endpos__2_inlined3_ in
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let flds =
              let (_1_inlined1, _2) = (_1_inlined3, _2_inlined1) in
              let x =
                let _1 = _1_inlined1 in
                let li = _1 in
                
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 19532 "asllib/Parser.ml"
                
              in
              
# 205 "<standard.mly>"
    ( x )
# 19538 "asllib/Parser.ml"
              
            in
            let call =
              let desc =
                let params =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 19548 "asllib/Parser.ml"
                  
                in
                
# 526 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 19554 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19563 "asllib/Parser.ml"
              
            in
            
# 480 "asllib/Parser.mly"
        ( desugar_setter call flds rhs )
# 19569 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19575 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos_name_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19584 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19605 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_374 =
    fun _1 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _3) = (_endpos__3_inlined2_, _3_inlined1) in
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 19622 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 19627 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 19633 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19642 "asllib/Parser.ml"
              
            in
            let ldk = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 19648 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 19653 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19659 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19668 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19689 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_375 =
    fun _1 _1_inlined2 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _1_inlined1, _3) = (_endpos__3_inlined2_, _1_inlined2, _3_inlined1) in
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 19707 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 19713 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19722 "asllib/Parser.ml"
              
            in
            let ldk = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 19728 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 19733 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19739 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19748 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19769 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_376 =
    fun _1 _1_inlined1 _2 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_inlined2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_1, _3) = (_1_inlined1, _3_inlined1) in
              let desc =
                let params = _1 in
                
# 531 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 19786 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19795 "asllib/Parser.ml"
              
            in
            let ldk = 
# 423 "asllib/Parser.mly"
                ( LDK_Let       )
# 19801 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 19806 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19812 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19821 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19842 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_377 =
    fun _1 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _3) = (_endpos__3_inlined2_, _3_inlined1) in
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 19859 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 19864 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 19870 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19879 "asllib/Parser.ml"
              
            in
            let ldk = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 19885 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 19890 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19896 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19905 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 19926 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_378 =
    fun _1 _1_inlined2 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _1_inlined1, _3) = (_endpos__3_inlined2_, _1_inlined2, _3_inlined1) in
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 19944 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 19950 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19959 "asllib/Parser.ml"
              
            in
            let ldk = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 19965 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 19970 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 19976 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 19985 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20006 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_379 =
    fun _1 _1_inlined1 _2 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_inlined2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_1, _3) = (_1_inlined1, _3_inlined1) in
              let desc =
                let params = _1 in
                
# 531 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 20023 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20032 "asllib/Parser.ml"
              
            in
            let ldk = 
# 424 "asllib/Parser.mly"
                ( LDK_Constant  )
# 20038 "asllib/Parser.ml"
             in
            
# 482 "asllib/Parser.mly"
        ( desugar_elided_parameter ldk lhs call)
# 20043 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20049 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20058 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20079 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_380 =
    fun _1 _2 _endpos__2_inlined1_ _startpos__1_ ldi ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let e = 
# 123 "<standard.mly>"
    ( None )
# 20091 "asllib/Parser.ml"
             in
            
# 483 "asllib/Parser.mly"
                                                             ( S_Decl (LDK_Var, ldi, e) )
# 20096 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20102 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20111 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20132 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_381 =
    fun _1 _1_inlined1 _2 _2_inlined1 _endpos__2_inlined2_ _startpos__1_ ldi ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let e =
              let _1 = _1_inlined1 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 20148 "asllib/Parser.ml"
              
            in
            
# 483 "asllib/Parser.mly"
                                                             ( S_Decl (LDK_Var, ldi, e) )
# 20154 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20160 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20169 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20190 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_382 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _2_inlined2 _endpos__2_inlined3_ _startpos__1_ x ->
      let body =
        let _endpos__2_ = _endpos__2_inlined3_ in
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let as_ty =
              let (_2, _1) = (_2_inlined1, _1_inlined2) in
              _2
            in
            let _2 =
              let _1 = _1_inlined1 in
              let li = _1 in
              
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 20210 "asllib/Parser.ml"
              
            in
            let _2_1 = _2 in
            
# 484 "asllib/Parser.mly"
                                                               make_ldi_vars  
# 20217 "asllib/Parser.ml"
             (_2_1, as_ty)
          in
          
# 196 "<standard.mly>"
    ( x )
# 20223 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20232 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20253 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_383 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _2_inlined2 _endpos__2_inlined3_ _startpos__1_ x ->
      let body =
        let _endpos__2_ = _endpos__2_inlined3_ in
        let desc =
          let x =
            let (_2_inlined1, _2) = (_2_inlined2, _2_inlined1) in
            let as_ty =
              let (_2, _1) = (_2_inlined1, _1_inlined2) in
              _2
            in
            let _2 =
              let _1 = _1_inlined1 in
              let li = _1 in
              
# 164 "asllib/Parser.mly"
                                           ( x :: li )
# 20273 "asllib/Parser.ml"
              
            in
            let _2_1 = _2 in
            
# 484 "asllib/Parser.mly"
                                                               make_ldi_vars  
# 20280 "asllib/Parser.ml"
             (_2_1, as_ty)
          in
          
# 196 "<standard.mly>"
    ( x )
# 20286 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20295 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20316 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_384 =
    fun _1 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _3) = (_endpos__3_inlined2_, _3_inlined1) in
              let desc =
                let args =
                  let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 20333 "asllib/Parser.ml"
                   in
                  
# 205 "<standard.mly>"
    ( x )
# 20338 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 20344 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20353 "asllib/Parser.ml"
              
            in
            
# 486 "asllib/Parser.mly"
        ( desugar_elided_parameter LDK_Var lhs call)
# 20359 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20365 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20374 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20395 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_385 =
    fun _1 _1_inlined2 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_endpos__3_inlined1_, _1_inlined1, _3) = (_endpos__3_inlined2_, _1_inlined2, _3_inlined1) in
              let desc =
                let args =
                  let x = _1_inlined1 in
                  
# 205 "<standard.mly>"
    ( x )
# 20413 "asllib/Parser.ml"
                  
                in
                
# 529 "asllib/Parser.mly"
    ( { name; params=[]; args; call_type = ST_Function } )
# 20419 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__3_inlined1_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20428 "asllib/Parser.ml"
              
            in
            
# 486 "asllib/Parser.mly"
        ( desugar_elided_parameter LDK_Var lhs call)
# 20434 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20440 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20449 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20470 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_386 =
    fun _1 _1_inlined1 _2 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_inlined2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let call =
              let (_1, _3) = (_1_inlined1, _3_inlined1) in
              let desc =
                let params = _1 in
                
# 531 "asllib/Parser.mly"
    ( { name; params; args; call_type = ST_Function } )
# 20487 "asllib/Parser.ml"
                
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos_args_, _startpos_name_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20496 "asllib/Parser.ml"
              
            in
            
# 486 "asllib/Parser.mly"
        ( desugar_elided_parameter LDK_Var lhs call)
# 20502 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20508 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20517 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20538 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_387 =
    fun _1 _2 _endpos__2_inlined1_ _startpos__1_ ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let args =
              let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 20551 "asllib/Parser.ml"
               in
              
# 205 "<standard.mly>"
    ( x )
# 20556 "asllib/Parser.ml"
              
            in
            
# 487 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = false } )
# 20562 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20568 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20577 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20598 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_388 =
    fun _1 _1_inlined2 _2 _endpos__2_inlined1_ _startpos__1_ ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let args =
              let _1_inlined1 = _1_inlined2 in
              let x = _1_inlined1 in
              
# 205 "<standard.mly>"
    ( x )
# 20613 "asllib/Parser.ml"
              
            in
            
# 487 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = false } )
# 20619 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20625 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20634 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20655 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_389 =
    fun _1 _2 _endpos__2_inlined1_ _startpos__1_ ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let args =
              let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 20668 "asllib/Parser.ml"
               in
              
# 205 "<standard.mly>"
    ( x )
# 20673 "asllib/Parser.ml"
              
            in
            
# 488 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = true } )
# 20679 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20685 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20694 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20715 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_390 =
    fun _1 _1_inlined2 _2 _endpos__2_inlined1_ _startpos__1_ ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let args =
              let _1_inlined1 = _1_inlined2 in
              let x = _1_inlined1 in
              
# 205 "<standard.mly>"
    ( x )
# 20730 "asllib/Parser.ml"
              
            in
            
# 488 "asllib/Parser.mly"
                                                             ( S_Print { args; debug = true } )
# 20736 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20742 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20751 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20772 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_391 =
    fun _1 _2 _2_inlined1 _3 _endpos__2_inlined2_ _startpos__1_ ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            
# 489 "asllib/Parser.mly"
                                                             ( S_Unreachable )
# 20785 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20791 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20800 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20821 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_392 =
    fun _1 _1_inlined1 _2 _3 _endpos__2_inlined1_ _startpos__1_ expr ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let loop_limit = 
# 123 "<standard.mly>"
    ( None )
# 20833 "asllib/Parser.ml"
             in
            let stmt_list =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 20841 "asllib/Parser.ml"
               _1_1
            in
            
# 490 "asllib/Parser.mly"
                                                               S_Repeat  
# 20847 "asllib/Parser.ml"
             (stmt_list, expr, loop_limit)
          in
          
# 196 "<standard.mly>"
    ( x )
# 20853 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20862 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20883 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_393 =
    fun _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _3 _endpos__2_inlined2_ _startpos__1_ expr ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let loop_limit =
              let _1 = _1_inlined2 in
              let x = _2 in
              
# 126 "<standard.mly>"
    ( Some x )
# 20899 "asllib/Parser.ml"
              
            in
            let stmt_list =
              let _1 = _1_inlined1 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 20908 "asllib/Parser.ml"
               _1_1
            in
            
# 490 "asllib/Parser.mly"
                                                               S_Repeat  
# 20914 "asllib/Parser.ml"
             (stmt_list, expr, loop_limit)
          in
          
# 196 "<standard.mly>"
    ( x )
# 20920 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20929 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 20950 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_394 =
    fun _1 _1_inlined2 _2 _3 _5 _endpos__2_inlined1_ _startpos__1_ cond x ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x =
            let body =
              let _1 = _1_inlined2 in
              let _1_1 = _1 in
              
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 20965 "asllib/Parser.ml"
               _1_1
            in
            let looplimit = 
# 205 "<standard.mly>"
    ( x )
# 20971 "asllib/Parser.ml"
             in
            
# 492 "asllib/Parser.mly"
          ( S_Repeat (body, cond, Some looplimit) )
# 20976 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 20982 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 20991 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 21012 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_395 =
    fun _1 _2 _endpos__2_inlined1_ _startpos__1_ e ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x = 
# 493 "asllib/Parser.mly"
                                                             ( S_Throw (Some (e, None)) )
# 21023 "asllib/Parser.ml"
           in
          
# 196 "<standard.mly>"
    ( x )
# 21028 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21037 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 21058 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_396 =
    fun _1 _2 _endpos__2_inlined1_ _startpos__1_ ->
      let body =
        let _endpos__2_ = _endpos__2_inlined1_ in
        let desc =
          let x = 
# 494 "asllib/Parser.mly"
                                                             ( S_Throw None             )
# 21069 "asllib/Parser.ml"
           in
          
# 196 "<standard.mly>"
    ( x )
# 21074 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21083 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 21104 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_397 =
    fun _1 _2 _2_inlined1 _endpos__2_inlined1_ _endpos__2_inlined2_ _startpos__1_ ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let (_endpos__2_, _2) = (_endpos__2_inlined1_, _2_inlined1) in
            let loc =
              let desc =
                let _3 = 
# 161 "asllib/Parser.mly"
                ( [] )
# 21119 "asllib/Parser.ml"
                 in
                ()
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21129 "asllib/Parser.ml"
              
            in
            
# 496 "asllib/Parser.mly"
          ( Error.fatal_from loc @@ Error.NotYetImplemented "Pragmas in statements" )
# 21135 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 21141 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21150 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 21171 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_398 =
    fun _1 _1_inlined1 _2 _2_inlined1 _endpos__1_inlined1_ _endpos__2_inlined2_ _startpos__1_ ->
      let body =
        let _endpos__2_ = _endpos__2_inlined2_ in
        let desc =
          let x =
            let _2 = _2_inlined1 in
            let loc =
              let desc =
                let _3 = _1_inlined1 in
                ()
              in
              let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined1_, _startpos__1_) in
              let _endpos = _endpos_desc_ in
              let _symbolstartpos = _startpos_desc_ in
              
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21192 "asllib/Parser.ml"
              
            in
            
# 496 "asllib/Parser.mly"
          ( Error.fatal_from loc @@ Error.NotYetImplemented "Pragmas in statements" )
# 21198 "asllib/Parser.ml"
            
          in
          
# 196 "<standard.mly>"
    ( x )
# 21204 "asllib/Parser.ml"
          
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__2_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21213 "asllib/Parser.ml"
        
      in
      (
# 634 "asllib/Parser.mly"
    (
      [
        D_Func
          {
            name = "main";
            args = [];
            parameters = [];
            body = SB_ASL body;
            return_type = None;
            subprogram_type = ST_Procedure;
            recurse_limit = None;
            builtin = false;
          }
        |> ASTUtils.add_pos_from body
      ]
    )
# 21234 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_399 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 21242 "asllib/Parser.ml"
       : (unit option))
  
  let _menhir_action_400 =
    fun x ->
      (
# 114 "<standard.mly>"
    ( Some x )
# 21250 "asllib/Parser.ml"
       : (unit option))
  
  let _menhir_action_401 =
    fun () ->
      (
# 111 "<standard.mly>"
    ( None )
# 21258 "asllib/Parser.ml"
       : ((string * AST.field list) option))
  
  let _menhir_action_402 =
    fun _1 _2 _3 ->
      let x =
        let _2_1 = _2 in
        let _3_1 = _3 in
        (_2_1, _3_1)
      in
      (
# 114 "<standard.mly>"
    ( Some x )
# 21271 "asllib/Parser.ml"
       : ((string * AST.field list) option))
  
  let _menhir_action_403 =
    fun _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern ->
      let desc = 
# 313 "asllib/Parser.mly"
                        Pattern_Single  
# 21279 "asllib/Parser.ml"
       expr_pattern in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_pattern_, _startpos_expr_pattern_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21287 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_404 =
    fun _2 _endpos_e2_ _startpos_e1_ e1 e2 ->
      let desc = 
# 314 "asllib/Parser.mly"
                                           Pattern_Range  
# 21295 "asllib/Parser.ml"
       (e1, e2) in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_e2_, _startpos_e1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21303 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_405 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 315 "asllib/Parser.mly"
             ( Pattern_All )
# 21311 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21319 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_406 =
    fun _1 _endpos_expr_ _startpos__1_ expr ->
      let desc = 
# 316 "asllib/Parser.mly"
                     Pattern_Leq  
# 21327 "asllib/Parser.ml"
       expr in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21335 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_407 =
    fun _1 _endpos_expr_ _startpos__1_ expr ->
      let desc = 
# 317 "asllib/Parser.mly"
                     Pattern_Geq  
# 21343 "asllib/Parser.ml"
       expr in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_expr_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21351 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_408 =
    fun _2 _endpos__3_ _startpos__1_ li x ->
      let desc =
        let _1 =
          let x = 
# 177 "asllib/Parser.mly"
                                                    ( x :: li )
# 21361 "asllib/Parser.ml"
           in
          
# 205 "<standard.mly>"
    ( x )
# 21366 "asllib/Parser.ml"
          
        in
        let _1_1 = _1 in
        
# 318 "asllib/Parser.mly"
                           Pattern_Tuple  
# 21373 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21382 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_409 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let _1_1 = _1 in
        
# 308 "asllib/Parser.mly"
                                            Pattern_Mask  
# 21392 "asllib/Parser.ml"
         _1_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21401 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_410 =
    fun _1_inlined1 _endpos__1_inlined1_ _startpos__1_inlined1_ ->
      let x =
        let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
        let desc =
          let _1_1 = _1 in
          
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 21413 "asllib/Parser.ml"
           _1_1
        in
        let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
        let _endpos = _endpos_desc_ in
        let _symbolstartpos = _startpos_desc_ in
        
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21422 "asllib/Parser.ml"
        
      in
      (
# 205 "<standard.mly>"
    ( x )
# 21428 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_411 =
    fun _1 _1_inlined2 _endpos__1_inlined2_ _endpos__3_ _startpos__1_ _startpos__1_inlined2_ ->
      let desc =
        let _2 =
          let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) = (_endpos__1_inlined2_, _startpos__1_inlined2_, _1_inlined2) in
          let x =
            let (_endpos__1_, _startpos__1_, _1) = (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1) in
            let desc =
              let _1_1 = _1 in
              
# 309 "asllib/Parser.mly"
                                                   Pattern_Any  
# 21443 "asllib/Parser.ml"
               _1_1
            in
            let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
            let _endpos = _endpos_desc_ in
            let _symbolstartpos = _startpos_desc_ in
            
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21452 "asllib/Parser.ml"
            
          in
          
# 205 "<standard.mly>"
    ( x )
# 21458 "asllib/Parser.ml"
          
        in
        let _2_1 = _2 in
        
# 326 "asllib/Parser.mly"
                                      Pattern_Not  
# 21465 "asllib/Parser.ml"
         _2_1
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21474 "asllib/Parser.ml"
       : (AST.pattern))
  
  let _menhir_action_412 =
    fun _1 _1_inlined1 _3 _endpos_s2_ _startpos__1_ e s2 ->
      let desc =
        let s1 =
          let _1 = _1_inlined1 in
          let _1_1 = _1 in
          
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 21486 "asllib/Parser.ml"
           _1_1
        in
        
# 504 "asllib/Parser.mly"
                                                     S_Cond 
# 21492 "asllib/Parser.ml"
         (e, s1, s2)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_s2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = if _startpos_desc_ != _endpos_desc_ then
        _startpos_desc_
      else
        _endpos in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21504 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_413 =
    fun _endpos__0_ ->
      let desc = 
# 435 "asllib/Parser.mly"
            ( S_Pass )
# 21512 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__0_, _endpos__0_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = if _startpos_desc_ != _endpos_desc_ then
        _startpos_desc_
      else
        _endpos in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 21523 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_414 =
    fun _1 _1_inlined1 ->
      let _1 = _1_inlined1 in
      let _1_1 = _1 in
      (
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 21533 "asllib/Parser.ml"
       _1_1 : (AST.stmt))
  
  let _menhir_action_415 =
    fun x ->
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21541 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_416 =
    fun x xs ->
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21549 "asllib/Parser.ml"
       : (string list))
  
  let _menhir_action_417 =
    fun x ->
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21557 "asllib/Parser.ml"
       : (AST.local_decl_item list))
  
  let _menhir_action_418 =
    fun x xs ->
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21565 "asllib/Parser.ml"
       : (AST.local_decl_item list))
  
  let _menhir_action_419 =
    fun x ->
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21573 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_420 =
    fun x xs ->
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21581 "asllib/Parser.ml"
       : (AST.expr list))
  
  let _menhir_action_421 =
    fun x y ->
      let x = 
# 180 "<standard.mly>"
    ( (x, y) )
# 21589 "asllib/Parser.ml"
       in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21594 "asllib/Parser.ml"
       : ((string * AST.expr) list))
  
  let _menhir_action_422 =
    fun x xs y ->
      let x = 
# 180 "<standard.mly>"
    ( (x, y) )
# 21602 "asllib/Parser.ml"
       in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21607 "asllib/Parser.ml"
       : ((string * AST.expr) list))
  
  let _menhir_action_423 =
    fun expr ->
      let x = 
# 303 "asllib/Parser.mly"
                                  Constraint_Exact  
# 21615 "asllib/Parser.ml"
       expr in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21620 "asllib/Parser.ml"
       : (AST.int_constraint list))
  
  let _menhir_action_424 =
    fun _2 e1 e2 ->
      let x = 
# 304 "asllib/Parser.mly"
                                  Constraint_Range  
# 21628 "asllib/Parser.ml"
       (e1, e2) in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21633 "asllib/Parser.ml"
       : (AST.int_constraint list))
  
  let _menhir_action_425 =
    fun expr xs ->
      let x = 
# 303 "asllib/Parser.mly"
                                  Constraint_Exact  
# 21641 "asllib/Parser.ml"
       expr in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21646 "asllib/Parser.ml"
       : (AST.int_constraint list))
  
  let _menhir_action_426 =
    fun _2_inlined1 e1 e2 xs ->
      let x =
        let _2 = _2_inlined1 in
        
# 304 "asllib/Parser.mly"
                                  Constraint_Range  
# 21656 "asllib/Parser.ml"
         (e1, e2)
      in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21662 "asllib/Parser.ml"
       : (AST.int_constraint list))
  
  let _menhir_action_427 =
    fun x ->
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21670 "asllib/Parser.ml"
       : (AST.lexpr list))
  
  let _menhir_action_428 =
    fun x xs ->
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21678 "asllib/Parser.ml"
       : (AST.lexpr list))
  
  let _menhir_action_429 =
    fun x ->
      let x =
        let y = 
# 123 "<standard.mly>"
    ( None )
# 21687 "asllib/Parser.ml"
         in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 21692 "asllib/Parser.ml"
        
      in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21698 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_430 =
    fun _1 _2 x ->
      let x =
        let y =
          let x = _2 in
          
# 126 "<standard.mly>"
    ( Some x )
# 21709 "asllib/Parser.ml"
          
        in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 21715 "asllib/Parser.ml"
        
      in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21721 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_431 =
    fun _1 _2 x ->
      let x =
        let y =
          let x = _2 in
          
# 126 "<standard.mly>"
    ( Some x )
# 21732 "asllib/Parser.ml"
          
        in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 21738 "asllib/Parser.ml"
        
      in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21744 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_432 =
    fun x xs ->
      let x =
        let y = 
# 123 "<standard.mly>"
    ( None )
# 21753 "asllib/Parser.ml"
         in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 21758 "asllib/Parser.ml"
        
      in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21764 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_433 =
    fun _1 _2_inlined1 x xs ->
      let x =
        let _2 = _2_inlined1 in
        let y =
          let x = _2 in
          
# 126 "<standard.mly>"
    ( Some x )
# 21776 "asllib/Parser.ml"
          
        in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 21782 "asllib/Parser.ml"
        
      in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21788 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_434 =
    fun _1 _2_inlined1 x xs ->
      let x =
        let _2 = _2_inlined1 in
        let y =
          let x = _2 in
          
# 126 "<standard.mly>"
    ( Some x )
# 21800 "asllib/Parser.ml"
          
        in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 21806 "asllib/Parser.ml"
        
      in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21812 "asllib/Parser.ml"
       : ((string * AST.ty option) list))
  
  let _menhir_action_435 =
    fun x ->
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21820 "asllib/Parser.ml"
       : (AST.pattern list))
  
  let _menhir_action_436 =
    fun x xs ->
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21828 "asllib/Parser.ml"
       : (AST.pattern list))
  
  let _menhir_action_437 =
    fun expr ->
      let x = 
# 335 "asllib/Parser.mly"
                                    Slice_Single   
# 21836 "asllib/Parser.ml"
       expr in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21841 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_438 =
    fun _2 e1 e2 ->
      let x = 
# 336 "asllib/Parser.mly"
                                    Slice_Range    
# 21849 "asllib/Parser.ml"
       (e1, e2) in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21854 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_439 =
    fun _2 e1 e2 ->
      let x = 
# 337 "asllib/Parser.mly"
                                    Slice_Length   
# 21862 "asllib/Parser.ml"
       (e1, e2) in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21867 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_440 =
    fun _1 e ->
      let x = 
# 338 "asllib/Parser.mly"
                                  ( Slice_Length(zero, e) )
# 21875 "asllib/Parser.ml"
       in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21880 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_441 =
    fun _2 e1 e2 ->
      let x = 
# 339 "asllib/Parser.mly"
                                    Slice_Star     
# 21888 "asllib/Parser.ml"
       (e1, e2) in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21893 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_442 =
    fun expr xs ->
      let x = 
# 335 "asllib/Parser.mly"
                                    Slice_Single   
# 21901 "asllib/Parser.ml"
       expr in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21906 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_443 =
    fun _2_inlined1 e1 e2 xs ->
      let x =
        let _2 = _2_inlined1 in
        
# 336 "asllib/Parser.mly"
                                    Slice_Range    
# 21916 "asllib/Parser.ml"
         (e1, e2)
      in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21922 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_444 =
    fun _2_inlined1 e1 e2 xs ->
      let x =
        let _2 = _2_inlined1 in
        
# 337 "asllib/Parser.mly"
                                    Slice_Length   
# 21932 "asllib/Parser.ml"
         (e1, e2)
      in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21938 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_445 =
    fun _1 e xs ->
      let x = 
# 338 "asllib/Parser.mly"
                                  ( Slice_Length(zero, e) )
# 21946 "asllib/Parser.ml"
       in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21951 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_446 =
    fun _2_inlined1 e1 e2 xs ->
      let x =
        let _2 = _2_inlined1 in
        
# 339 "asllib/Parser.mly"
                                    Slice_Star     
# 21961 "asllib/Parser.ml"
         (e1, e2)
      in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21967 "asllib/Parser.ml"
       : (AST.slice list))
  
  let _menhir_action_447 =
    fun x ->
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21975 "asllib/Parser.ml"
       : (AST.ty list))
  
  let _menhir_action_448 =
    fun x xs ->
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 21983 "asllib/Parser.ml"
       : (AST.ty list))
  
  let _menhir_action_449 =
    fun _1 _2 x ->
      let x =
        let y = _2 in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 21993 "asllib/Parser.ml"
        
      in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 21999 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_450 =
    fun _1 _2 x ->
      let x =
        let y = _2 in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 22009 "asllib/Parser.ml"
        
      in
      (
# 250 "<standard.mly>"
    ( [ x ] )
# 22015 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_451 =
    fun _1 _2_inlined1 x xs ->
      let x =
        let _2 = _2_inlined1 in
        let y = _2 in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 22026 "asllib/Parser.ml"
        
      in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 22032 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_452 =
    fun _1 _2_inlined1 x xs ->
      let x =
        let _2 = _2_inlined1 in
        let y = _2 in
        
# 172 "<standard.mly>"
    ( (x, y) )
# 22043 "asllib/Parser.ml"
        
      in
      (
# 253 "<standard.mly>"
    ( x :: xs )
# 22049 "asllib/Parser.ml"
       : (AST.typed_identifier list))
  
  let _menhir_action_453 =
    fun x ->
      (
# 196 "<standard.mly>"
    ( x )
# 22057 "asllib/Parser.ml"
       : (AST.t))
  
  let _menhir_action_454 =
    fun _1 ->
      let x =
        let _1_1 = _1 in
        
# 500 "asllib/Parser.mly"
                                            stmt_from_list 
# 22067 "asllib/Parser.ml"
         _1_1
      in
      (
# 196 "<standard.mly>"
    ( x )
# 22073 "asllib/Parser.ml"
       : (AST.stmt))
  
  let _menhir_action_455 =
    fun _1 _endpos__3_ _startpos__1_ ->
      let desc =
        let c =
          let _1 =
            let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 22084 "asllib/Parser.ml"
             in
            
# 205 "<standard.mly>"
    ( x )
# 22089 "asllib/Parser.ml"
            
          in
          let _1_1 = _1 in
          
# 300 "asllib/Parser.mly"
                                                          WellConstrained  
# 22096 "asllib/Parser.ml"
           _1_1
        in
        
# 352 "asllib/Parser.mly"
                                                          T_Int        
# 22102 "asllib/Parser.ml"
         c
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22111 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_456 =
    fun _1 _1_inlined2 _endpos__3_ _startpos__1_ ->
      let desc =
        let c =
          let _1_inlined1 = _1_inlined2 in
          let _1 =
            let x = _1_inlined1 in
            
# 205 "<standard.mly>"
    ( x )
# 22124 "asllib/Parser.ml"
            
          in
          let _1_1 = _1 in
          
# 300 "asllib/Parser.mly"
                                                          WellConstrained  
# 22131 "asllib/Parser.ml"
           _1_1
        in
        
# 352 "asllib/Parser.mly"
                                                          T_Int        
# 22137 "asllib/Parser.ml"
         c
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22146 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_457 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let c = 
# 299 "asllib/Parser.mly"
                                             ( UnConstrained )
# 22155 "asllib/Parser.ml"
         in
        
# 352 "asllib/Parser.mly"
                                                          T_Int        
# 22160 "asllib/Parser.ml"
         c
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22169 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_458 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 353 "asllib/Parser.mly"
                                                        ( T_Real      )
# 22177 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22185 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_459 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 354 "asllib/Parser.mly"
                                                        ( T_Bool      )
# 22193 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22201 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_460 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 355 "asllib/Parser.mly"
                                                        ( T_String    )
# 22209 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22217 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_461 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc = 
# 356 "asllib/Parser.mly"
                                                        ( t_bit       )
# 22225 "asllib/Parser.ml"
       in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22233 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_462 =
    fun _1 _1_inlined2 _endpos__1_inlined2_ _startpos__1_ x ->
      let desc =
        let bitfields_opt = _1_inlined2 in
        let _2 = 
# 205 "<standard.mly>"
    ( x )
# 22243 "asllib/Parser.ml"
         in
        let _2_1 = _2 in
        
# 357 "asllib/Parser.mly"
                                                          T_Bits       
# 22249 "asllib/Parser.ml"
         (_2_1, bitfields_opt)
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_inlined2_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22258 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_463 =
    fun _endpos__3_ _startpos__1_ ->
      let desc =
        let l =
          let x = 
# 161 "asllib/Parser.mly"
                ( [] )
# 22268 "asllib/Parser.ml"
           in
          
# 205 "<standard.mly>"
    ( x )
# 22273 "asllib/Parser.ml"
          
        in
        
# 358 "asllib/Parser.mly"
                                                          T_Tuple      
# 22279 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22288 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_464 =
    fun _1_inlined1 _endpos__3_ _startpos__1_ ->
      let desc =
        let l =
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 22299 "asllib/Parser.ml"
          
        in
        
# 358 "asllib/Parser.mly"
                                                          T_Tuple      
# 22305 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22314 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_465 =
    fun _endpos_name_ _startpos_name_ name ->
      let desc = 
# 359 "asllib/Parser.mly"
                                                          T_Named      
# 22322 "asllib/Parser.ml"
       name in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_name_, _startpos_name_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22330 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_466 =
    fun _1 _3 _endpos_t_ _startpos__1_ t x ->
      let desc =
        let e = 
# 205 "<standard.mly>"
    ( x )
# 22339 "asllib/Parser.ml"
         in
        
# 360 "asllib/Parser.mly"
                                                        ( T_Array (ArrayLength_Expr e, t) )
# 22344 "asllib/Parser.ml"
        
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos_t_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22353 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_467 =
    fun _1 ->
      (_1 : (AST.ty))
  
  let _menhir_action_468 =
    fun _1 _1_inlined2 _endpos__3_ _startpos__1_ ->
      let desc =
        let l =
          let _1_inlined1 = _1_inlined2 in
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 22369 "asllib/Parser.ml"
          
        in
        
# 365 "asllib/Parser.mly"
                                                          T_Enum       
# 22375 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22384 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_469 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let l = 
# 330 "asllib/Parser.mly"
                  ( [] )
# 22393 "asllib/Parser.ml"
         in
        
# 366 "asllib/Parser.mly"
                                                          T_Record     
# 22398 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22407 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_470 =
    fun _1 _1_inlined2 _endpos__3_ _startpos__1_ ->
      let desc =
        let l =
          let _1_inlined1 = _1_inlined2 in
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 22419 "asllib/Parser.ml"
          
        in
        
# 366 "asllib/Parser.mly"
                                                          T_Record     
# 22425 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22434 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_471 =
    fun _1 _endpos__1_ _startpos__1_ ->
      let desc =
        let l = 
# 330 "asllib/Parser.mly"
                  ( [] )
# 22443 "asllib/Parser.ml"
         in
        
# 367 "asllib/Parser.mly"
                                                          T_Exception  
# 22448 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__1_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22457 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_action_472 =
    fun _1 _1_inlined2 _endpos__3_ _startpos__1_ ->
      let desc =
        let l =
          let _1_inlined1 = _1_inlined2 in
          let x = _1_inlined1 in
          
# 205 "<standard.mly>"
    ( x )
# 22469 "asllib/Parser.ml"
          
        in
        
# 367 "asllib/Parser.mly"
                                                          T_Exception  
# 22475 "asllib/Parser.ml"
         l
      in
      let (_endpos_desc_, _startpos_desc_) = (_endpos__3_, _startpos__1_) in
      let _endpos = _endpos_desc_ in
      let _symbolstartpos = _startpos_desc_ in
      (
# 140 "asllib/Parser.mly"
                              ( { desc; pos_start=_symbolstartpos; pos_end=_endpos; version } )
# 22484 "asllib/Parser.ml"
       : (AST.ty))
  
  let _menhir_print_token : token -> string =
    fun _tok ->
      match _tok with
      | Tokens.AND ->
          "AND"
      | Tokens.ARRAY ->
          "ARRAY"
      | Tokens.ARROBASE_LOOPLIMIT ->
          "ARROBASE_LOOPLIMIT"
      | Tokens.ARROW ->
          "ARROW"
      | Tokens.AS ->
          "AS"
      | Tokens.ASSERT ->
          "ASSERT"
      | Tokens.BAND ->
          "BAND"
      | Tokens.BEGIN ->
          "BEGIN"
      | Tokens.BEQ ->
          "BEQ"
      | Tokens.BIT ->
          "BIT"
      | Tokens.BITS ->
          "BITS"
      | Tokens.BITVECTOR_LIT _ ->
          "BITVECTOR_LIT"
      | Tokens.BNOT ->
          "BNOT"
      | Tokens.BOOLEAN ->
          "BOOLEAN"
      | Tokens.BOOL_LIT _ ->
          "BOOL_LIT"
      | Tokens.BOR ->
          "BOR"
      | Tokens.CASE ->
          "CASE"
      | Tokens.CATCH ->
          "CATCH"
      | Tokens.COLON ->
          "COLON"
      | Tokens.COLON_COLON ->
          "COLON_COLON"
      | Tokens.COMMA ->
          "COMMA"
      | Tokens.CONCAT ->
          "CONCAT"
      | Tokens.CONFIG ->
          "CONFIG"
      | Tokens.CONSTANT ->
          "CONSTANT"
      | Tokens.DEBUG ->
          "DEBUG"
      | Tokens.DIV ->
          "DIV"
      | Tokens.DIVRM ->
          "DIVRM"
      | Tokens.DO ->
          "DO"
      | Tokens.DOT ->
          "DOT"
      | Tokens.DOWNTO ->
          "DOWNTO"
      | Tokens.ELSE ->
          "ELSE"
      | Tokens.ELSIF ->
          "ELSIF"
      | Tokens.END ->
          "END"
      | Tokens.ENUMERATION ->
          "ENUMERATION"
      | Tokens.EOF ->
          "EOF"
      | Tokens.EOR ->
          "EOR"
      | Tokens.EQ ->
          "EQ"
      | Tokens.EQ_OP ->
          "EQ_OP"
      | Tokens.EXCEPTION ->
          "EXCEPTION"
      | Tokens.FOR ->
          "FOR"
      | Tokens.FUNC ->
          "FUNC"
      | Tokens.GEQ ->
          "GEQ"
      | Tokens.GETTER ->
          "GETTER"
      | Tokens.GT ->
          "GT"
      | Tokens.IDENTIFIER _ ->
          "IDENTIFIER"
      | Tokens.IF ->
          "IF"
      | Tokens.IMPL ->
          "IMPL"
      | Tokens.IN ->
          "IN"
      | Tokens.INTEGER ->
          "INTEGER"
      | Tokens.INT_LIT _ ->
          "INT_LIT"
      | Tokens.LBRACE ->
          "LBRACE"
      | Tokens.LBRACKET ->
          "LBRACKET"
      | Tokens.LEQ ->
          "LEQ"
      | Tokens.LET ->
          "LET"
      | Tokens.LLBRACKET ->
          "LLBRACKET"
      | Tokens.LOOPLIMIT ->
          "LOOPLIMIT"
      | Tokens.LPAR ->
          "LPAR"
      | Tokens.LT ->
          "LT"
      | Tokens.MASK_LIT _ ->
          "MASK_LIT"
      | Tokens.MINUS ->
          "MINUS"
      | Tokens.MOD ->
          "MOD"
      | Tokens.MUL ->
          "MUL"
      | Tokens.NEQ ->
          "NEQ"
      | Tokens.NOT ->
          "NOT"
      | Tokens.OF ->
          "OF"
      | Tokens.OR ->
          "OR"
      | Tokens.OTHERWISE ->
          "OTHERWISE"
      | Tokens.PASS ->
          "PASS"
      | Tokens.PLUS ->
          "PLUS"
      | Tokens.PLUS_COLON ->
          "PLUS_COLON"
      | Tokens.POW ->
          "POW"
      | Tokens.PRAGMA ->
          "PRAGMA"
      | Tokens.PRINT ->
          "PRINT"
      | Tokens.RBRACE ->
          "RBRACE"
      | Tokens.RBRACKET ->
          "RBRACKET"
      | Tokens.RDIV ->
          "RDIV"
      | Tokens.REAL ->
          "REAL"
      | Tokens.REAL_LIT _ ->
          "REAL_LIT"
      | Tokens.RECORD ->
          "RECORD"
      | Tokens.RECURSELIMIT ->
          "RECURSELIMIT"
      | Tokens.REPEAT ->
          "REPEAT"
      | Tokens.RETURN ->
          "RETURN"
      | Tokens.RPAR ->
          "RPAR"
      | Tokens.RRBRACKET ->
          "RRBRACKET"
      | Tokens.SEMI_COLON ->
          "SEMI_COLON"
      | Tokens.SETTER ->
          "SETTER"
      | Tokens.SHL ->
          "SHL"
      | Tokens.SHR ->
          "SHR"
      | Tokens.SLICING ->
          "SLICING"
      | Tokens.STAR_COLON ->
          "STAR_COLON"
      | Tokens.STRING ->
          "STRING"
      | Tokens.STRING_LIT _ ->
          "STRING_LIT"
      | Tokens.SUBTYPES ->
          "SUBTYPES"
      | Tokens.THEN ->
          "THEN"
      | Tokens.THROW ->
          "THROW"
      | Tokens.TO ->
          "TO"
      | Tokens.TRY ->
          "TRY"
      | Tokens.TYPE ->
          "TYPE"
      | Tokens.UNKNOWN ->
          "UNKNOWN"
      | Tokens.UNREACHABLE ->
          "UNREACHABLE"
      | Tokens.UNTIL ->
          "UNTIL"
      | Tokens.VAR ->
          "VAR"
      | Tokens.WHEN ->
          "WHEN"
      | Tokens.WHERE ->
          "WHERE"
      | Tokens.WHILE ->
          "WHILE"
      | Tokens.WITH ->
          "WITH"
  
  let _menhir_fail : unit -> 'a =
    fun () ->
      Printf.eprintf "Internal failure -- please contact the parser generator's developers.\n%!";
      assert false
  
  include struct
    
    [@@@ocaml.warning "-4-37"]
    
    let _menhir_goto_opn : type  ttv_stack. ttv_stack -> _ -> _menhir_box_opn =
      fun _menhir_stack _v ->
        MenhirBox_opn _v
    
    let _menhir_run_1376 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_stmts =
      fun _menhir_stack _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let _1 = _v in
            let _v = _menhir_action_454 _1 in
            MenhirBox_stmts _v
        | _ ->
            _eRR ()
    
    let _menhir_run_1372 : type  ttv_stack. ttv_stack -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let x = _v in
        let _v = _menhir_action_453 x in
        MenhirBox_spec _v
    
    let rec _menhir_run_1273 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _2_inlined1, _, _endpos__2_inlined1_) = _menhir_stack in
        let MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs) = ((), _v) in
        let _v = _menhir_action_188 _1 _2_inlined1 _endpos__2_ _endpos__2_inlined1_ _startpos__1_ xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_goto_list_decl_ : type  ttv_stack. ttv_stack -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _v _menhir_s ->
        match _menhir_s with
        | MenhirState1030 ->
            _menhir_run_1372 _menhir_stack _v
        | MenhirState1369 ->
            _menhir_run_1370 _menhir_stack _v
        | MenhirState1365 ->
            _menhir_run_1366 _menhir_stack _v
        | MenhirState1361 ->
            _menhir_run_1362 _menhir_stack _v
        | MenhirState1357 ->
            _menhir_run_1358 _menhir_stack _v
        | MenhirState1353 ->
            _menhir_run_1354 _menhir_stack _v
        | MenhirState1348 ->
            _menhir_run_1349 _menhir_stack _v
        | MenhirState1344 ->
            _menhir_run_1345 _menhir_stack _v
        | MenhirState1340 ->
            _menhir_run_1341 _menhir_stack _v
        | MenhirState1336 ->
            _menhir_run_1337 _menhir_stack _v
        | MenhirState1035 ->
            _menhir_run_1333 _menhir_stack _v
        | MenhirState1330 ->
            _menhir_run_1331 _menhir_stack _v
        | MenhirState1055 ->
            _menhir_run_1308 _menhir_stack _v
        | MenhirState1306 ->
            _menhir_run_1307 _menhir_stack _v
        | MenhirState1304 ->
            _menhir_run_1305 _menhir_stack _v
        | MenhirState1298 ->
            _menhir_run_1299 _menhir_stack _v
        | MenhirState1296 ->
            _menhir_run_1297 _menhir_stack _v
        | MenhirState1286 ->
            _menhir_run_1287 _menhir_stack _v
        | MenhirState1284 ->
            _menhir_run_1285 _menhir_stack _v
        | MenhirState1278 ->
            _menhir_run_1279 _menhir_stack _v
        | MenhirState1081 ->
            _menhir_run_1277 _menhir_stack _v
        | MenhirState1275 ->
            _menhir_run_1276 _menhir_stack _v
        | MenhirState1084 ->
            _menhir_run_1273 _menhir_stack _v
        | MenhirState1271 ->
            _menhir_run_1272 _menhir_stack _v
        | MenhirState1265 ->
            _menhir_run_1266 _menhir_stack _v
        | MenhirState1259 ->
            _menhir_run_1260 _menhir_stack _v
        | MenhirState1254 ->
            _menhir_run_1255 _menhir_stack _v
        | MenhirState1248 ->
            _menhir_run_1249 _menhir_stack _v
        | MenhirState1089 ->
            _menhir_run_1243 _menhir_stack _v
        | MenhirState1241 ->
            _menhir_run_1242 _menhir_stack _v
        | MenhirState1239 ->
            _menhir_run_1240 _menhir_stack _v
        | MenhirState1231 ->
            _menhir_run_1232 _menhir_stack _v
        | MenhirState1099 ->
            _menhir_run_1230 _menhir_stack _v
        | MenhirState1228 ->
            _menhir_run_1229 _menhir_stack _v
        | MenhirState1226 ->
            _menhir_run_1227 _menhir_stack _v
        | MenhirState1222 ->
            _menhir_run_1223 _menhir_stack _v
        | MenhirState1220 ->
            _menhir_run_1221 _menhir_stack _v
        | MenhirState1212 ->
            _menhir_run_1213 _menhir_stack _v
        | MenhirState1210 ->
            _menhir_run_1211 _menhir_stack _v
        | MenhirState1195 ->
            _menhir_run_1196 _menhir_stack _v
        | MenhirState1193 ->
            _menhir_run_1194 _menhir_stack _v
        | MenhirState1189 ->
            _menhir_run_1190 _menhir_stack _v
        | MenhirState1187 ->
            _menhir_run_1188 _menhir_stack _v
        | MenhirState1179 ->
            _menhir_run_1180 _menhir_stack _v
        | MenhirState1107 ->
            _menhir_run_1178 _menhir_stack _v
        | MenhirState1176 ->
            _menhir_run_1177 _menhir_stack _v
        | MenhirState1170 ->
            _menhir_run_1171 _menhir_stack _v
        | MenhirState1164 ->
            _menhir_run_1165 _menhir_stack _v
        | MenhirState1159 ->
            _menhir_run_1160 _menhir_stack _v
        | MenhirState1153 ->
            _menhir_run_1154 _menhir_stack _v
        | MenhirState1112 ->
            _menhir_run_1148 _menhir_stack _v
        | MenhirState1146 ->
            _menhir_run_1147 _menhir_stack _v
        | MenhirState1140 ->
            _menhir_run_1141 _menhir_stack _v
        | MenhirState1134 ->
            _menhir_run_1135 _menhir_stack _v
        | MenhirState1129 ->
            _menhir_run_1130 _menhir_stack _v
        | MenhirState1123 ->
            _menhir_run_1124 _menhir_stack _v
        | MenhirState1117 ->
            _menhir_run_1118 _menhir_stack _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1370 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2) = ((), _v, (), ()) in
        let _v = _menhir_action_176 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1366 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined2) = ((), _v, ()) in
        let _v = _menhir_action_186 _1 _1_inlined1 _1_inlined2 _2_inlined1 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1362 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2) = ((), _v, (), ()) in
        let _v = _menhir_action_177 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1358 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined2) = ((), _v, ()) in
        let _v = _menhir_action_187 _1 _1_inlined1 _1_inlined2 _2_inlined1 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1354 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4) = ((), _v, ()) in
        let _v = _menhir_action_175 _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1349 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2, _1_inlined1) = ((), _v, (), (), ()) in
        let _v = _menhir_action_173 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1345 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined2, _1_inlined1) = ((), _v, (), ()) in
        let _v = _menhir_action_184 _1 _1_inlined1 _1_inlined2 _2_inlined1 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1341 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2, _1_inlined1) = ((), _v, (), (), ()) in
        let _v = _menhir_action_174 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1337 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined2, _1_inlined1) = ((), _v, (), ()) in
        let _v = _menhir_action_185 _1 _1_inlined1 _1_inlined2 _2_inlined1 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1333 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined1) = ((), _v, (), ()) in
        let _v = _menhir_action_172 _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1331 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty_decl _menhir_cell0_option_subtype_ _menhir_cell0_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell0_option_subtype_ (_menhir_stack, _1_inlined1) = _menhir_stack in
        let MenhirCell1_ty_decl (_menhir_stack, _, t) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _3) = ((), _v, ()) in
        let _v = _menhir_action_158 _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ t x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1308 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER _menhir_cell0_SUBTYPES _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption___anonymous_22_ _menhir_cell0_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_loption___anonymous_22_ (_menhir_stack, _, _3, _endpos__3_) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell0_SUBTYPES (_menhir_stack, _startpos__1_inlined1_) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined1) = ((), _v, ()) in
        let _v = _menhir_action_159 _1 _1_inlined1 _2_inlined1 _3 _endpos__2_ _endpos__3_ _startpos__1_ _startpos__1_inlined1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1307 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _endpos__1_inlined5_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_SETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined4, _5) = ((), _v, (), ()) in
        let _v = _menhir_action_155 _1 _1_inlined1 _1_inlined3 _1_inlined4 _2 _5 _endpos__1_inlined5_ _endpos__3_inlined1_ _startpos__1_ name x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1305 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined6, _) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_SETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined4, _5) = ((), _v, (), ()) in
        let _v = _menhir_action_154 _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined6 _2 _5 _endpos__3_inlined1_ _startpos__1_ name x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1299 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _endpos__1_inlined5_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_SETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined4, _5) = ((), _v, (), ()) in
        let _v = _menhir_action_157 _1 _1_inlined1 _1_inlined3 _1_inlined4 _2 _5 _endpos__1_inlined5_ _endpos__3_inlined1_ _startpos__1_ name x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1297 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined6, _) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_SETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined4, _5) = ((), _v, (), ()) in
        let _v = _menhir_action_156 _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined6 _2 _5 _endpos__3_inlined1_ _startpos__1_ name x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1287 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _endpos__1_inlined4_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_SETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _5, _1_inlined3) = ((), _v, (), ()) in
        let _v = _menhir_action_151 _1 _1_inlined1 _1_inlined3 _2 _5 _endpos__1_inlined4_ _endpos__3_inlined1_ _startpos__1_ name x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1285 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined5, _) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_SETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _5, _1_inlined3) = ((), _v, (), ()) in
        let _v = _menhir_action_150 _1 _1_inlined1 _1_inlined3 _1_inlined5 _2 _5 _endpos__3_inlined1_ _startpos__1_ name x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1279 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _endpos__1_inlined4_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_SETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _5, _1_inlined3) = ((), _v, (), ()) in
        let _v = _menhir_action_153 _1 _1_inlined1 _1_inlined3 _2 _5 _endpos__1_inlined4_ _endpos__3_inlined1_ _startpos__1_ name x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1277 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined5, _) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_SETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _5, _1_inlined3) = ((), _v, (), ()) in
        let _v = _menhir_action_152 _1 _1_inlined1 _1_inlined3 _1_inlined5 _2 _5 _endpos__3_inlined1_ _startpos__1_ name x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1276 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _endpos__1_inlined1_) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs) = ((), _v) in
        let _v = _menhir_action_189 _1 _1_inlined1 _2_inlined1 _endpos__1_inlined1_ _endpos__2_ _startpos__1_ xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1272 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2) = ((), _v, (), ()) in
        let _v = _menhir_action_164 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1266 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2) = ((), _v, (), ()) in
        let _v = _menhir_action_165 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1260 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4) = ((), _v, ()) in
        let _v = _menhir_action_163 _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1255 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2, _1_inlined1) = ((), _v, (), (), ()) in
        let _v = _menhir_action_161 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1249 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2, _1_inlined1) = ((), _v, (), (), ()) in
        let _v = _menhir_action_162 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1243 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined1) = ((), _v, (), ()) in
        let _v = _menhir_action_160 _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1242 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _endpos__1_inlined5_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_GETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined4) = ((), _v, ()) in
        let _v = _menhir_action_149 _1 _1_inlined1 _1_inlined3 _1_inlined4 _2 _endpos__1_inlined5_ _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1240 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined6, _) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_GETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined4) = ((), _v, ()) in
        let _v = _menhir_action_148 _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined6 _2 _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1232 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _endpos__1_inlined4_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_GETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined3) = ((), _v, ()) in
        let _v = _menhir_action_147 _1 _1_inlined1 _1_inlined3 _2 _endpos__1_inlined4_ _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1230 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined5, _) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_GETTER (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined3) = ((), _v, ()) in
        let _v = _menhir_action_146 _1 _1_inlined1 _1_inlined3 _1_inlined5 _2 _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1229 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _endpos__1_inlined5_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined4) = ((), _v, ()) in
        let _v = _menhir_action_139 _1 _1_inlined1 _1_inlined3 _1_inlined4 _2 _endpos__1_inlined5_ _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1227 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined6, _) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined4) = ((), _v, ()) in
        let _v = _menhir_action_138 _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined6 _2 _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1223 : type  ttv_stack. (((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_BEGIN (_menhir_stack, _, _endpos__1_inlined6_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined5, _1_inlined4) = ((), _v, (), ()) in
        let _v = _menhir_action_141 _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined5 _2 _2_inlined1 _endpos__1_inlined6_ _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1221 : type  ttv_stack. ((((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined7, _) = _menhir_stack in
        let MenhirCell1_BEGIN (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined5, _1_inlined4) = ((), _v, (), ()) in
        let _v = _menhir_action_140 _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined5 _1_inlined7 _2 _2_inlined1 _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1213 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _endpos__1_inlined4_) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs) = ((), _v) in
        let _v = _menhir_action_145 _1 _1_inlined1 _1_inlined3 _endpos__1_inlined4_ _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1211 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined5, _) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs) = ((), _v) in
        let _v = _menhir_action_144 _1 _1_inlined1 _1_inlined3 _1_inlined5 _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1196 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _endpos__1_inlined4_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined3) = ((), _v, ()) in
        let _v = _menhir_action_135 _1 _1_inlined1 _1_inlined3 _2 _endpos__1_inlined4_ _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1194 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined5, _) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined3) = ((), _v, ()) in
        let _v = _menhir_action_134 _1 _1_inlined1 _1_inlined3 _1_inlined5 _2 _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1190 : type  ttv_stack. (((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_BEGIN (_menhir_stack, _, _endpos__1_inlined5_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined4, _1_inlined3) = ((), _v, (), ()) in
        let _v = _menhir_action_137 _1 _1_inlined1 _1_inlined3 _1_inlined4 _2 _2_inlined1 _endpos__1_inlined5_ _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1188 : type  ttv_stack. ((((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined6, _) = _menhir_stack in
        let MenhirCell1_BEGIN (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _1_inlined4, _1_inlined3) = ((), _v, (), ()) in
        let _v = _menhir_action_136 _1 _1_inlined1 _1_inlined3 _1_inlined4 _1_inlined6 _2 _2_inlined1 _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1180 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _endpos__1_inlined3_) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs) = ((), _v) in
        let _v = _menhir_action_143 _1 _1_inlined1 _endpos__1_inlined3_ _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1178 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_, _menhir_box_spec) _menhir_cell1_end_semicolon -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__3_inlined1_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined4, _) = _menhir_stack in
        let MenhirCell0_BEGIN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, name, _, _) = _menhir_stack in
        let MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs) = ((), _v) in
        let _v = _menhir_action_142 _1 _1_inlined1 _1_inlined4 _endpos__3_inlined1_ _startpos__1_ name xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1177 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2) = ((), _v, (), ()) in
        let _v = _menhir_action_170 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1171 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2) = ((), _v, (), ()) in
        let _v = _menhir_action_171 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1165 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4) = ((), _v, ()) in
        let _v = _menhir_action_169 _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1160 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2, _1_inlined1) = ((), _v, (), (), ()) in
        let _v = _menhir_action_167 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1154 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2, _1_inlined1) = ((), _v, (), (), ()) in
        let _v = _menhir_action_168 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1148 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined1) = ((), _v, (), ()) in
        let _v = _menhir_action_166 _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1147 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2) = ((), _v, (), ()) in
        let _v = _menhir_action_182 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1141 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2) = ((), _v, (), ()) in
        let _v = _menhir_action_183 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1135 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _1_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4) = ((), _v, ()) in
        let _v = _menhir_action_181 _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1130 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2, _1_inlined1) = ((), _v, (), (), ()) in
        let _v = _menhir_action_179 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1124 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined2, _1_inlined1) = ((), _v, (), (), ()) in
        let _v = _menhir_action_180 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    and _menhir_run_1118 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_SEMI_COLON -> _ -> _menhir_box_spec =
      fun _menhir_stack _v ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, xs, _4, _1_inlined1) = ((), _v, (), ()) in
        let _v = _menhir_action_178 _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_list_decl_ _menhir_stack _v _menhir_s
    
    let _menhir_run_1016 : type  ttv_stack. ((((((ttv_stack, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _endpos _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, cond, _, _) = _menhir_stack in
            let MenhirCell0_WHILE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_ARROBASE_LOOPLIMIT (_menhir_stack, _, _startpos__1_) = _menhir_stack in
            let (_1, _2, _endpos__2_inlined1_, _3, _5) = ((), (), _endpos, (), ()) in
            let _v = _menhir_action_354 _1 _1_inlined2 _2 _3 _5 _endpos__2_inlined1_ _startpos__1_ cond x in
            _menhir_goto_opn _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_1002 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_CASE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_OF, _menhir_box_opn) _menhir_cell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _endpos _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let MenhirCell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
            let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
            let MenhirCell1_CASE (_menhir_stack, _, _startpos__1_) = _menhir_stack in
            let (_1, _2, _endpos__2_inlined1_, _3) = ((), (), _endpos, ()) in
            let _v = _menhir_action_345 _1 _1_inlined1 _2 _3 _endpos__2_inlined1_ _startpos__1_ expr in
            _menhir_goto_opn _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_0964 : type  ttv_stack. ((((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _endpos _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
            let MenhirCell1_DOWNTO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
            let MenhirCell1_FOR (_menhir_stack, _, _startpos__1_) = _menhir_stack in
            let (_1, _2, _endpos__2_inlined1_, _1_inlined1, _3, _8) = ((), (), _endpos, (), (), ()) in
            let _v = _menhir_action_350 _1 _1_inlined1 _1_inlined2 _2 _3 _8 _endpos__2_inlined1_ _startpos__1_ end_e index_name start_e in
            _menhir_goto_opn _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_0960 : type  ttv_stack. ((((((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _endpos _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined3, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
            let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
            let MenhirCell1_DOWNTO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
            let MenhirCell1_FOR (_menhir_stack, _, _startpos__1_) = _menhir_stack in
            let (_1, _2, _1_inlined2, _1_inlined1, _3, _endpos__2_inlined2_, _8) = ((), (), (), (), (), _endpos, ()) in
            let _v = _menhir_action_351 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _8 _endpos__2_inlined2_ _startpos__1_ end_e index_name start_e in
            _menhir_goto_opn _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_0952 : type  ttv_stack. ((((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _endpos _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
            let MenhirCell1_TO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
            let MenhirCell1_FOR (_menhir_stack, _, _startpos__1_) = _menhir_stack in
            let (_1, _2, _endpos__2_inlined1_, _1_inlined1, _3, _8) = ((), (), _endpos, (), (), ()) in
            let _v = _menhir_action_348 _1 _1_inlined1 _1_inlined2 _2 _3 _8 _endpos__2_inlined1_ _startpos__1_ end_e index_name start_e in
            _menhir_goto_opn _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_0948 : type  ttv_stack. ((((((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _endpos _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined3, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
            let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
            let MenhirCell1_TO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
            let MenhirCell1_FOR (_menhir_stack, _, _startpos__1_) = _menhir_stack in
            let (_1, _2, _1_inlined2, _1_inlined1, _3, _endpos__2_inlined2_, _8) = ((), (), (), (), (), _endpos, ()) in
            let _v = _menhir_action_349 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _8 _endpos__2_inlined2_ _startpos__1_ end_e index_name start_e in
            _menhir_goto_opn _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_0864 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_IF, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_THEN, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_s_else -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _endpos _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let MenhirCell1_s_else (_menhir_stack, _, s2, _) = _menhir_stack in
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
            let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
            let MenhirCell1_IF (_menhir_stack, _, _startpos__1_) = _menhir_stack in
            let (_1, _2, _endpos__2_inlined1_, _3) = ((), (), _endpos, ()) in
            let _v = _menhir_action_344 _1 _1_inlined1 _2 _3 _endpos__2_inlined1_ _startpos__1_ e s2 in
            _menhir_goto_opn _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_0793 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_TRY, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_nonempty_list_catcher_ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _endpos _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let MenhirCell1_nonempty_list_catcher_ (_menhir_stack, _, c) = _menhir_stack in
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
            let MenhirCell1_TRY (_menhir_stack, _, _startpos__1_) = _menhir_stack in
            let (_1, _2, _endpos__2_inlined1_, _3) = ((), (), _endpos, ()) in
            let _v = _menhir_action_352 _1 _1_inlined1 _2 _3 _endpos__2_inlined1_ _startpos__1_ c in
            _menhir_goto_opn _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_0791 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_TRY, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_nonempty_list_catcher_, _menhir_box_opn) _menhir_cell1_OTHERWISE, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _endpos _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined3, _) = _menhir_stack in
            let MenhirCell1_OTHERWISE (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_nonempty_list_catcher_ (_menhir_stack, _, c) = _menhir_stack in
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
            let MenhirCell1_TRY (_menhir_stack, _, _startpos__1_) = _menhir_stack in
            let (_1, _2, _2_inlined1, _1_inlined2, _3, _endpos__2_inlined2_) = ((), (), (), (), (), _endpos) in
            let _v = _menhir_action_353 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _2_inlined1 _3 _endpos__2_inlined2_ _startpos__1_ c in
            _menhir_goto_opn _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_0741 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _endpos _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
            let MenhirCell1_WHILE (_menhir_stack, _, _startpos__1_) = _menhir_stack in
            let (_1, _2, _endpos__2_inlined1_, _4) = ((), (), _endpos, ()) in
            let _v = _menhir_action_346 _1 _1_inlined1 _2 _4 _endpos__2_inlined1_ _startpos__1_ expr in
            _menhir_goto_opn _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_0737 : type  ttv_stack. ((((((ttv_stack, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _endpos _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EOF ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
            let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
            let MenhirCell1_WHILE (_menhir_stack, _, _startpos__1_) = _menhir_stack in
            let (_1, _2, _4, _1_inlined1, _endpos__2_inlined2_) = ((), (), (), (), _endpos) in
            let _v = _menhir_action_347 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _4 _endpos__2_inlined2_ _startpos__1_ expr in
            _menhir_goto_opn _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_0992 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_CONSTANT, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE -> _ -> _ -> _ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                let MenhirCell1_CONSTANT (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _2_inlined1, _3, _3_inlined1, _5, _endpos__2_inlined2_, _endpos_args_, args) = ((), (), (), (), (), (), _endpos_0, _endpos, _v) in
                let _v = _menhir_action_379 _1 _1_inlined1 _2 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_inlined2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let _menhir_run_0853 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_LET, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE -> _ -> _ -> _ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                let MenhirCell1_LET (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _2_inlined1, _3, _3_inlined1, _5, _endpos__2_inlined2_, _endpos_args_, args) = ((), (), (), (), (), (), _endpos_0, _endpos, _v) in
                let _v = _menhir_action_376 _1 _1_inlined1 _2 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_inlined2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let _menhir_run_0773 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE -> _ -> _ -> _ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                let MenhirCell1_VAR (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _2_inlined1, _3, _3_inlined1, _5, _endpos__2_inlined2_, _endpos_args_, args) = ((), (), (), (), (), (), _endpos_0, _endpos, _v) in
                let _v = _menhir_action_386 _1 _1_inlined1 _2 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_inlined2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let _menhir_run_0985 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_CONSTANT, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EOF ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
                    let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                    let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                    let MenhirCell1_CONSTANT (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                    let (_1, _2, _2_inlined1, _1_inlined2, _3, _3_inlined1, _endpos__2_inlined2_, _endpos__3_inlined2_) = ((), (), (), _v, (), (), _endpos_1, _endpos_0) in
                    let _v = _menhir_action_378 _1 _1_inlined2 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                    _menhir_goto_opn _menhir_stack _v
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let _menhir_run_0971 : type  ttv_stack. (ttv_stack, _menhir_box_opn) _menhir_cell1_DEBUG _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EOF ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_DEBUG (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                    let (_1, _2, _endpos__2_inlined1_, _1_inlined2) = ((), (), _endpos_1, _v) in
                    let _v = _menhir_action_390 _1 _1_inlined2 _2 _endpos__2_inlined1_ _startpos__1_ in
                    _menhir_goto_opn _menhir_stack _v
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let _menhir_run_0846 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_LET, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EOF ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
                    let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                    let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                    let MenhirCell1_LET (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                    let (_1, _2, _2_inlined1, _1_inlined2, _3, _3_inlined1, _endpos__2_inlined2_, _endpos__3_inlined2_) = ((), (), (), _v, (), (), _endpos_1, _endpos_0) in
                    let _v = _menhir_action_375 _1 _1_inlined2 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                    _menhir_goto_opn _menhir_stack _v
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let _menhir_run_0830 : type  ttv_stack. (ttv_stack, _menhir_box_opn) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_IDENTIFIER (_menhir_stack, _2_inlined1, _, _) = _menhir_stack in
                let MenhirCell1_PRAGMA (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _endpos__1_inlined1_, _1_inlined1, _endpos__2_inlined2_) = ((), (), _endpos, _v, _endpos_0) in
                let _v = _menhir_action_398 _1 _1_inlined1 _2 _2_inlined1 _endpos__1_inlined1_ _endpos__2_inlined2_ _startpos__1_ in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let _menhir_run_0822 : type  ttv_stack. (ttv_stack, _menhir_box_opn) _menhir_cell1_PRINT _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EOF ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_PRINT (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                    let (_1, _2, _endpos__2_inlined1_, _1_inlined2) = ((), (), _endpos_1, _v) in
                    let _v = _menhir_action_388 _1 _1_inlined2 _2 _endpos__2_inlined1_ _startpos__1_ in
                    _menhir_goto_opn _menhir_stack _v
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let _menhir_run_0766 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_RBRACE _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EOF ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
                    let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                    let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                    let MenhirCell1_VAR (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                    let (_1, _2, _2_inlined1, _1_inlined2, _3, _3_inlined1, _endpos__2_inlined2_, _endpos__3_inlined2_) = ((), (), (), _v, (), (), _endpos_1, _endpos_0) in
                    let _v = _menhir_action_385 _1 _1_inlined2 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                    _menhir_goto_opn _menhir_stack _v
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let _menhir_run_0752 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ -> _ -> _ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, x, _, _) = _menhir_stack in
                let MenhirCell1_VAR (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined2, _2_inlined2, _endpos__2_inlined3_) = ((), (), (), (), _v, _endpos_0) in
                let _v = _menhir_action_382 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _2_inlined2 _endpos__2_inlined3_ _startpos__1_ x in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let _menhir_run_0748 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ -> _ -> _ -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, x, _, _) = _menhir_stack in
                let MenhirCell1_VAR (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined2, _2_inlined2, _endpos__2_inlined3_) = ((), (), (), (), _v, _endpos_0) in
                let _v = _menhir_action_383 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _2_inlined2 _endpos__2_inlined3_ _startpos__1_ x in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let rec _menhir_run_0002 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_UNKNOWN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON_COLON ->
            let _menhir_s = MenhirState0003 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let _menhir_s = MenhirState0350 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0004 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_460 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_ty : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState1363 ->
            _menhir_run_1364 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1355 ->
            _menhir_run_1356 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1342 ->
            _menhir_run_1343 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1334 ->
            _menhir_run_1335 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1309 ->
            _menhir_run_1332 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState1300 ->
            _menhir_run_1301 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1292 ->
            _menhir_run_1293 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1280 ->
            _menhir_run_1281 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1267 ->
            _menhir_run_1268 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1261 ->
            _menhir_run_1262 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1250 ->
            _menhir_run_1251 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1244 ->
            _menhir_run_1245 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1235 ->
            _menhir_run_1236 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1214 ->
            _menhir_run_1215 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1202 ->
            _menhir_run_1203 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1198 ->
            _menhir_run_1199 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1181 ->
            _menhir_run_1182 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1172 ->
            _menhir_run_1173 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1166 ->
            _menhir_run_1167 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1155 ->
            _menhir_run_1156 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1149 ->
            _menhir_run_1150 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1142 ->
            _menhir_run_1143 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1136 ->
            _menhir_run_1137 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1125 ->
            _menhir_run_1126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1119 ->
            _menhir_run_1120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1095 ->
            _menhir_run_1096 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1077 ->
            _menhir_run_1078 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1066 ->
            _menhir_run_1067 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1062 ->
            _menhir_run_1063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1047 ->
            _menhir_run_1048 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1043 ->
            _menhir_run_1044 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0751 ->
            _menhir_run_0752 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0747 ->
            _menhir_run_0748 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0701 ->
            _menhir_run_0702 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0680 ->
            _menhir_run_0687 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0682 ->
            _menhir_run_0683 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0387 ->
            _menhir_run_0388 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0379 ->
            _menhir_run_0380 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0377 ->
            _menhir_run_0378 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0371 ->
            _menhir_run_0372 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0369 ->
            _menhir_run_0370 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0365 ->
            _menhir_run_0366 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0363 ->
            _menhir_run_0364 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0350 ->
            _menhir_run_0351 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0003 ->
            _menhir_run_0349 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0345 ->
            _menhir_run_0344 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0006 ->
            _menhir_run_0344 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0301 ->
            _menhir_run_0306 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0160 ->
            _menhir_run_0161 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0039 ->
            _menhir_run_0159 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0137 ->
            _menhir_run_0138 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0059 ->
            _menhir_run_0134 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0121 ->
            _menhir_run_0133 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0077 ->
            _menhir_run_0078 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1364 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1365
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1365
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1365
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1365
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1365
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1365
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1365
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1365
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1365
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1366 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.EQ ->
            let _menhir_s = MenhirState1367 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1031 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState1033 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON_COLON ->
                let _menhir_s = MenhirState1334 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON ->
                let _menhir_s = MenhirState1342 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState1351 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON_COLON ->
                let _menhir_s = MenhirState1355 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON ->
                let _menhir_s = MenhirState1363 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0010 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_019 _endpos_s_ _startpos_s_ s in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_goto_expr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState1367 ->
            _menhir_run_1368 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1359 ->
            _menhir_run_1360 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1351 ->
            _menhir_run_1352 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1346 ->
            _menhir_run_1347 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1338 ->
            _menhir_run_1339 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1269 ->
            _menhir_run_1270 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1263 ->
            _menhir_run_1264 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1257 ->
            _menhir_run_1258 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1252 ->
            _menhir_run_1253 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1246 ->
            _menhir_run_1247 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1216 ->
            _menhir_run_1217 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1183 ->
            _menhir_run_1184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1174 ->
            _menhir_run_1175 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1168 ->
            _menhir_run_1169 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1162 ->
            _menhir_run_1163 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1157 ->
            _menhir_run_1158 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1151 ->
            _menhir_run_1152 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1144 ->
            _menhir_run_1145 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1138 ->
            _menhir_run_1139 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1132 ->
            _menhir_run_1133 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1127 ->
            _menhir_run_1128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1121 ->
            _menhir_run_1122 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1115 ->
            _menhir_run_1116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1110 ->
            _menhir_run_1111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1087 ->
            _menhir_run_1088 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1033 ->
            _menhir_run_1034 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1026 ->
            _menhir_run_1027 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1020 ->
            _menhir_run_1021 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1012 ->
            _menhir_run_1013 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1009 ->
            _menhir_run_1010 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1004 ->
            _menhir_run_1005 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0998 ->
            _menhir_run_0999 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0977 ->
            _menhir_run_0995 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0956 ->
            _menhir_run_0957 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0954 ->
            _menhir_run_0955 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0944 ->
            _menhir_run_0945 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0942 ->
            _menhir_run_0943 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0940 ->
            _menhir_run_0941 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0934 ->
            _menhir_run_0935 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0929 ->
            _menhir_run_0930 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0919 ->
            _menhir_run_0920 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0909 ->
            _menhir_run_0910 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0904 ->
            _menhir_run_0905 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0894 ->
            _menhir_run_0895 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0886 ->
            _menhir_run_0887 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0881 ->
            _menhir_run_0882 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0871 ->
            _menhir_run_0872 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0859 ->
            _menhir_run_0860 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0838 ->
            _menhir_run_0856 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0813 ->
            _menhir_run_0814 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0809 ->
            _menhir_run_0810 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0801 ->
            _menhir_run_0804 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0795 ->
            _menhir_run_0798 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0758 ->
            _menhir_run_0776 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0708 ->
            _menhir_run_0726 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0395 ->
            _menhir_run_0675 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0397 ->
            _menhir_run_0671 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0666 ->
            _menhir_run_0667 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0662 ->
            _menhir_run_0663 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0434 ->
            _menhir_run_0648 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0627 ->
            _menhir_run_0628 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0622 ->
            _menhir_run_0623 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0617 ->
            _menhir_run_0618 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0607 ->
            _menhir_run_0608 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0597 ->
            _menhir_run_0598 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0592 ->
            _menhir_run_0593 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0582 ->
            _menhir_run_0583 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0574 ->
            _menhir_run_0575 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0569 ->
            _menhir_run_0570 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0559 ->
            _menhir_run_0560 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0548 ->
            _menhir_run_0549 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0546 ->
            _menhir_run_0547 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0463 ->
            _menhir_run_0531 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0501 ->
            _menhir_run_0502 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0495 ->
            _menhir_run_0496 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0485 ->
            _menhir_run_0486 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0482 ->
            _menhir_run_0483 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0478 ->
            _menhir_run_0479 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0475 ->
            _menhir_run_0476 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0470 ->
            _menhir_run_0471 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0454 ->
            _menhir_run_0455 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0452 ->
            _menhir_run_0453 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0450 ->
            _menhir_run_0451 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0441 ->
            _menhir_run_0442 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0413 ->
            _menhir_run_0414 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0358 ->
            _menhir_run_0359 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0356 ->
            _menhir_run_0357 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0353 ->
            _menhir_run_0354 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0001 ->
            _menhir_run_0352 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0013 ->
            _menhir_run_0341 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0014 ->
            _menhir_run_0340 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0015 ->
            _menhir_run_0335 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0332 ->
            _menhir_run_0333 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0017 ->
            _menhir_run_0331 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0221 ->
            _menhir_run_0309 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0307 ->
            _menhir_run_0308 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0299 ->
            _menhir_run_0300 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0297 ->
            _menhir_run_0298 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0295 ->
            _menhir_run_0296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0293 ->
            _menhir_run_0294 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0291 ->
            _menhir_run_0292 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0289 ->
            _menhir_run_0290 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0287 ->
            _menhir_run_0288 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0280 ->
            _menhir_run_0281 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0277 ->
            _menhir_run_0279 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0275 ->
            _menhir_run_0276 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0273 ->
            _menhir_run_0274 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0271 ->
            _menhir_run_0272 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0258 ->
            _menhir_run_0259 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0255 ->
            _menhir_run_0256 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0253 ->
            _menhir_run_0254 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0251 ->
            _menhir_run_0252 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0249 ->
            _menhir_run_0250 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0247 ->
            _menhir_run_0248 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0244 ->
            _menhir_run_0246 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0242 ->
            _menhir_run_0243 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0240 ->
            _menhir_run_0241 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0238 ->
            _menhir_run_0239 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0236 ->
            _menhir_run_0237 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0234 ->
            _menhir_run_0235 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0232 ->
            _menhir_run_0233 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0230 ->
            _menhir_run_0231 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0218 ->
            _menhir_run_0219 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0208 ->
            _menhir_run_0209 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState1083 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0979 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0989 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0981 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0967 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0913 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0867 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0840 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0850 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0842 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0827 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0818 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0760 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0770 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0762 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0710 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0720 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0712 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0401 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0405 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0436 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0642 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0438 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0601 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0445 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0458 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0465 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0525 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0467 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0337 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0019 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0194 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0197 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0203 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0192 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0187 ->
            _menhir_run_0191 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0182 ->
            _menhir_run_0183 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0180 ->
            _menhir_run_0181 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0178 ->
            _menhir_run_0179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0176 ->
            _menhir_run_0177 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0174 ->
            _menhir_run_0175 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0170 ->
            _menhir_run_0171 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0166 ->
            _menhir_run_0167 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0164 ->
            _menhir_run_0165 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0152 ->
            _menhir_run_0153 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0146 ->
            _menhir_run_0147 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0142 ->
            _menhir_run_0143 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0416 ->
            _menhir_run_0141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0031 ->
            _menhir_run_0141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0324 ->
            _menhir_run_0141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0260 ->
            _menhir_run_0141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0154 ->
            _menhir_run_0141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0150 ->
            _menhir_run_0141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0148 ->
            _menhir_run_0141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0144 ->
            _menhir_run_0141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0047 ->
            _menhir_run_0141 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0127 ->
            _menhir_run_0128 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0009 ->
            _menhir_run_0126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0302 ->
            _menhir_run_0126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0131 ->
            _menhir_run_0126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0129 ->
            _menhir_run_0126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0122 ->
            _menhir_run_0126 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0119 ->
            _menhir_run_0120 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0117 ->
            _menhir_run_0118 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0115 ->
            _menhir_run_0116 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0112 ->
            _menhir_run_0114 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0110 ->
            _menhir_run_0111 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0108 ->
            _menhir_run_0109 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0106 ->
            _menhir_run_0107 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0104 ->
            _menhir_run_0105 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0102 ->
            _menhir_run_0103 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0100 ->
            _menhir_run_0101 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0098 ->
            _menhir_run_0099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0096 ->
            _menhir_run_0097 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0094 ->
            _menhir_run_0095 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0091 ->
            _menhir_run_0093 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0089 ->
            _menhir_run_0090 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0087 ->
            _menhir_run_0088 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0085 ->
            _menhir_run_0086 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0083 ->
            _menhir_run_0084 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0081 ->
            _menhir_run_0082 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0079 ->
            _menhir_run_0080 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0074 ->
            _menhir_run_0075 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0064 ->
            _menhir_run_0065 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0062 ->
            _menhir_run_0063 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0043 ->
            _menhir_run_0044 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0034 ->
            _menhir_run_0035 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0032 ->
            _menhir_run_0033 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0029 ->
            _menhir_run_0030 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0027 ->
            _menhir_run_0028 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0025 ->
            _menhir_run_0026 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0022 ->
            _menhir_run_0024 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1368 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1368, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1369
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1369
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1369
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1369
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1369
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1369
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1369
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1369
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1369
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1370 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1368
        | _ ->
            _eRR ()
    
    and _menhir_run_0027 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0027 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0011 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_r_, _startpos_r_, r) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_017 _endpos_r_ _startpos_r_ r in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_r_ _v _menhir_s _tok
    
    and _menhir_run_0013 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0013 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0014 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState0014 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0015 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0015 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0016 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_i_, _startpos_i_, i) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_015 _endpos_i_ _startpos_i_ i in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_i_ _startpos_i_ _v _menhir_s _tok
    
    and _menhir_run_0017 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0017 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0018 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0019 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.LBRACE ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0197 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_020 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0019 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0019
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0019
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let _endpos__3_ = _endpos in
            let _v = _menhir_action_050 _endpos__3_ _startpos_name_ name in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0019
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0019
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0019
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0019
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0019
        | Tokens.IF ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0019
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0019
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0019
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0019
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0019
        | _ ->
            _eRR ()
    
    and _menhir_run_0021 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_b_, _startpos_b_, b) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_016 _endpos_b_ _startpos_b_ b in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_b_ _v _menhir_s _tok
    
    and _menhir_run_0022 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0022 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0023 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_b_, _startpos_b_, b) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_018 _endpos_b_ _startpos_b_ b in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_b_ _v _menhir_s _tok
    
    and _menhir_run_0197 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0197
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0197
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0197
        | Tokens.RBRACE ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let _endpos__3_ = _endpos in
            let _v = _menhir_action_067 _endpos__3_ _endpos_desc_ _startpos_desc_ desc in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0197
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0197
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0197
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0197
        | Tokens.IF ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0197
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0196 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0197
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0197
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0197
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0197
        | _ ->
            _eRR ()
    
    and _menhir_run_0196 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0019 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.LBRACE ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0197 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0208 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.SHL | Tokens.SHR ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_020 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0208 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0208 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0034 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_SHL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0034 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_1036 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_TYPE (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SUBTYPES ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_SUBTYPES (_menhir_stack, _startpos_1) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v_2 ->
                    let _startpos_3 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_4 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_2, _startpos_3, _endpos_4) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.WITH ->
                        _menhir_run_1040 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1039
                    | Tokens.SEMI_COLON ->
                        let _v_5 = _menhir_action_190 () in
                        _menhir_run_1054 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_4 _v_5 MenhirState1039 _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.OF ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1309
                | Tokens.RECORD ->
                    let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        let _menhir_stack = MenhirCell1_RECORD (_menhir_stack, MenhirState1309, _startpos_6, _endpos_7) in
                        let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.IDENTIFIER _v_9 ->
                            _menhir_run_1042 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState1311
                        | Tokens.RBRACE ->
                            let _v_10 = _menhir_action_198 () in
                            _menhir_run_1312 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10
                        | _ ->
                            _eRR ())
                    | Tokens.SEMI_COLON | Tokens.SUBTYPES ->
                        let (_menhir_s, _endpos__1_, _startpos__1_, _1) = (MenhirState1309, _endpos_7, _startpos_6, ()) in
                        let _v = _menhir_action_469 _1 _endpos__1_ _startpos__1_ in
                        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
                    | _ ->
                        _eRR ())
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1309
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1309
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1309
                | Tokens.IDENTIFIER _v_12 ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState1309
                | Tokens.EXCEPTION ->
                    let _startpos_13 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos_14 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        let _menhir_stack = MenhirCell1_EXCEPTION (_menhir_stack, MenhirState1309, _startpos_13, _endpos_14) in
                        let _startpos_15 = _menhir_lexbuf.Lexing.lex_start_p in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_15) in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.IDENTIFIER _v_16 ->
                            _menhir_run_1042 _menhir_stack _menhir_lexbuf _menhir_lexer _v_16 MenhirState1315
                        | Tokens.RBRACE ->
                            let _v_17 = _menhir_action_198 () in
                            _menhir_run_1316 _menhir_stack _menhir_lexbuf _menhir_lexer _v_17
                        | _ ->
                            _eRR ())
                    | Tokens.SEMI_COLON | Tokens.SUBTYPES ->
                        let (_menhir_s, _endpos__1_, _startpos__1_, _1) = (MenhirState1309, _endpos_14, _startpos_13, ()) in
                        let _v = _menhir_action_471 _1 _endpos__1_ _startpos__1_ in
                        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
                    | _ ->
                        _eRR ())
                | Tokens.ENUMERATION ->
                    let _menhir_s = MenhirState1309 in
                    let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                    let _menhir_stack = MenhirCell1_ENUMERATION (_menhir_stack, _menhir_s, _startpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACE ->
                        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
                        let _menhir_s = MenhirState1319 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_1320 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1309
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1309
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1309
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1309
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1040 : type  ttv_stack. (ttv_stack _menhir_cell0_SUBTYPES _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_WITH (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_1042 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState1041
            | Tokens.RBRACE ->
                let _v = _menhir_action_198 () in
                _menhir_run_1052 _menhir_stack _menhir_lexbuf _menhir_lexer _v
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1042 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON_COLON ->
            let _menhir_s = MenhirState1043 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let _menhir_s = MenhirState1047 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0005 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_458 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_run_0006 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0006
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_startpos__1_, _endpos__3_) = (_startpos, _endpos) in
            let _v = _menhir_action_463 _endpos__3_ _startpos__1_ in
            _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
        | Tokens.REAL ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0006
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0006
        | Tokens.INTEGER ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0006
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0006
        | Tokens.BOOLEAN ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0006
        | Tokens.BITS ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0006
        | Tokens.BIT ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0006
        | Tokens.ARRAY ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0006
        | _ ->
            _eRR ()
    
    and _menhir_run_0008 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0009
            | Tokens.STRING_LIT _v ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0009
            | Tokens.REAL_LIT _v ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0009
            | Tokens.RBRACE ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_startpos__1_, _1, _endpos__3_) = (_startpos, (), _endpos_1) in
                let _v = _menhir_action_455 _1 _endpos__3_ _startpos__1_ in
                _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0009
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0009
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0009
            | Tokens.INT_LIT _v ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0009
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0009
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0009
            | Tokens.BOOL_LIT _v ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0009
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0009
            | Tokens.BITVECTOR_LIT _v ->
                let _menhir_stack = MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_0) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0009
            | _ ->
                _eRR ())
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RECURSELIMIT | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.SUBTYPES | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
            let _v = _menhir_action_457 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0040 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_name_, _startpos_name_, name) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_465 _endpos_name_ _startpos_name_ name in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_name_ _v _menhir_s _tok
    
    and _menhir_run_0041 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_459 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_run_0042 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BITS (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState0043 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0060 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_461 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _v _menhir_s _tok
    
    and _menhir_run_0061 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ARRAY (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_s = MenhirState0062 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1052 : type  ttv_stack. (ttv_stack _menhir_cell0_SUBTYPES _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_WITH _menhir_cell0_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_WITH (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, _1_inlined2, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_191 _1 _1_inlined2 in
        _menhir_goto_loption___anonymous_22_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_goto_loption___anonymous_22_ : type  ttv_stack. (ttv_stack _menhir_cell0_SUBTYPES _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState1327 ->
            _menhir_run_1328 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState1039 ->
            _menhir_run_1054 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1328 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty_decl _menhir_cell0_SUBTYPES _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, _2, _, _) = _menhir_stack in
        let MenhirCell0_SUBTYPES (_menhir_stack, _) = _menhir_stack in
        let (_1, _3) = ((), _v) in
        let _v = _menhir_action_402 _1 _2 _3 in
        _menhir_goto_option_subtype_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
    
    and _menhir_goto_option_subtype_ : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty_decl -> _ -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let _menhir_stack = MenhirCell0_option_subtype_ (_menhir_stack, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1330
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1330
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1330
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1330
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1330
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1330
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1330
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1330
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1330
            | Tokens.EOF ->
                let _v_0 = _menhir_action_133 () in
                _menhir_run_1331 _menhir_stack _v_0
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1056 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_SETTER (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_1058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1057
            | Tokens.LPAR ->
                let _v_1 = _menhir_action_194 () in
                _menhir_run_1072 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState1057 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1058 : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState1058 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            _menhir_run_1059 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_1059 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState1060 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_1059 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState1062 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState1066 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_429 x in
            _menhir_goto_separated_nonempty_list_COMMA_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_separated_nonempty_list_COMMA_opt_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState1058 ->
            _menhir_run_1070 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState1068 ->
            _menhir_run_1069 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState1064 ->
            _menhir_run_1065 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState1060 ->
            _menhir_run_1061 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1070 : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let _1_inlined1 = _v in
        let _v = _menhir_action_195 _1_inlined1 in
        _menhir_goto_loption_braced_nclist_opt_typed_identifier___ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_loption_braced_nclist_opt_typed_identifier___ : type  ttv_stack. (ttv_stack _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState1101 ->
            _menhir_run_1102 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState1091 ->
            _menhir_run_1092 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState1057 ->
            _menhir_run_1072 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1102 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState1103 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.RPAR ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, _menhir_s, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.BEGIN ->
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_BEGIN (_menhir_stack, _endpos) in
                    let _menhir_s = MenhirState1105 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.WHILE ->
                        _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.VAR ->
                        _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.UNREACHABLE ->
                        _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.TRY ->
                        _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.THROW ->
                        _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.RETURN ->
                        _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.REPEAT ->
                        _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.PRINT ->
                        _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.PRAGMA ->
                        _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.PASS ->
                        _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.MINUS ->
                        _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.LPAR ->
                        _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.LET ->
                        _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.IF ->
                        _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.IDENTIFIER _v ->
                        _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.FOR ->
                        _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.END ->
                        _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.DEBUG ->
                        _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.CONSTANT ->
                        _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.CASE ->
                        _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.ASSERT ->
                        _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.ARROBASE_LOOPLIMIT ->
                        _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | _ ->
                        _eRR ())
                | Tokens.ARROW ->
                    let _menhir_s = MenhirState1181 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.STRING ->
                        _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.REAL ->
                        _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.LPAR ->
                        _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.INTEGER ->
                        _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.IDENTIFIER _v ->
                        _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BOOLEAN ->
                        _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BITS ->
                        _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BIT ->
                        _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.ARRAY ->
                        _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v ->
                _menhir_run_1197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0356 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0356 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0361 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_0362 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0361
        | Tokens.LPAR ->
            _menhir_run_0367 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0361
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.COMMA ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0361, _v, _startpos_0, _endpos) in
                let _menhir_s = MenhirState0385 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON_COLON ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0361, _v, _startpos_0, _endpos) in
                _menhir_run_0369 _menhir_stack _menhir_lexbuf _menhir_lexer
            | Tokens.COLON ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0361, _v, _startpos_0, _endpos) in
                _menhir_run_0371 _menhir_stack _menhir_lexbuf _menhir_lexer
            | Tokens.EQ | Tokens.SEMI_COLON ->
                let _v =
                  let _1 = _v in
                  _menhir_action_009 _1
                in
                _menhir_run_0705 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0361 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0362 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _menhir_s = MenhirState0363 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _menhir_s = MenhirState0365 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COMMA | Tokens.EQ | Tokens.RPAR | Tokens.SEMI_COLON ->
            let _1 = () in
            let _v = _menhir_action_010 _1 in
            _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_decl_item : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState0975 ->
            _menhir_run_0976 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0836 ->
            _menhir_run_0837 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0743 ->
            _menhir_run_0755 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0361 ->
            _menhir_run_0705 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0461 ->
            _menhir_run_0462 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0432 ->
            _menhir_run_0433 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0382 ->
            _menhir_run_0381 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0374 ->
            _menhir_run_0381 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0367 ->
            _menhir_run_0373 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0976 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_CONSTANT as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0977
            | Tokens.STRING_LIT _v_0 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0977
            | Tokens.REAL_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0977
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0977
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0977
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0977
            | Tokens.INT_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0977
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0977
            | Tokens.IDENTIFIER _v_3 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                    _menhir_run_0019 _menhir_stack _menhir_lexbuf _menhir_lexer
                | Tokens.LBRACE ->
                    let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.UNKNOWN ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0979
                    | Tokens.STRING_LIT _v_5 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState0979
                    | Tokens.REAL_LIT _v_6 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState0979
                    | Tokens.RBRACE ->
                        let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.LPAR ->
                            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.UNKNOWN ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0981
                            | Tokens.STRING_LIT _v_9 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState0981
                            | Tokens.RPAR ->
                                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                                let _tok = _menhir_lexer _menhir_lexbuf in
                                (match (_tok : MenhirBasics.token) with
                                | Tokens.SEMI_COLON ->
                                    let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
                                    let _tok = _menhir_lexer _menhir_lexbuf in
                                    (match (_tok : MenhirBasics.token) with
                                    | Tokens.EOF ->
                                        let MenhirCell1_CONSTANT (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                                        let (_1, _2, _2_inlined1, _3, _3_inlined1, _startpos_name_, name, _endpos__2_inlined2_, lhs, _endpos__3_inlined2_) = ((), (), (), (), (), _startpos, _v_3, _endpos_11, _v, _endpos_10) in
                                        let _v = _menhir_action_377 _1 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                                        _menhir_goto_opn _menhir_stack _v
                                    | _ ->
                                        _eRR ())
                                | _ ->
                                    _eRR ())
                            | Tokens.REAL_LIT _v_12 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState0981
                            | Tokens.NOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0981
                            | Tokens.MINUS ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0981
                            | Tokens.LPAR ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0981
                            | Tokens.INT_LIT _v_13 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState0981
                            | Tokens.IF ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0981
                            | Tokens.IDENTIFIER _v_14 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14 MenhirState0981
                            | Tokens.BOOL_LIT _v_15 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15 MenhirState0981
                            | Tokens.BNOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0981
                            | Tokens.BITVECTOR_LIT _v_16 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0979, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_16 MenhirState0981
                            | _ ->
                                _eRR ())
                        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                            let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                            let _v_17 =
                              let (_endpos__3_, _endpos_desc_, _startpos_desc_, desc) = (_endpos_7, _endpos, _startpos, _v_3) in
                              _menhir_action_067 _endpos__3_ _endpos_desc_ _startpos_desc_ desc
                            in
                            _menhir_run_0995 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_7 _startpos_4 _v_17 MenhirState0977 _tok
                        | _ ->
                            _eRR ())
                    | Tokens.NOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0979
                    | Tokens.MINUS ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0979
                    | Tokens.LPAR ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0979
                    | Tokens.INT_LIT _v_18 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_18 MenhirState0979
                    | Tokens.IF ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0979
                    | Tokens.IDENTIFIER _v_19 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0196 _menhir_stack _menhir_lexbuf _menhir_lexer _v_19 MenhirState0979
                    | Tokens.COMMA ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0979) in
                        let _menhir_s = MenhirState0989 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.UNKNOWN ->
                            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.STRING_LIT _v ->
                            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.REAL_LIT _v ->
                            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.NOT ->
                            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.MINUS ->
                            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.LPAR ->
                            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.INT_LIT _v ->
                            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.IF ->
                            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BOOL_LIT _v ->
                            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BNOT ->
                            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.BITVECTOR_LIT _v ->
                            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | Tokens.BOOL_LIT _v_26 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_26 MenhirState0979
                    | Tokens.BNOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0979
                    | Tokens.BITVECTOR_LIT _v_27 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0977, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_27 MenhirState0979
                    | _ ->
                        _eRR ())
                | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _v_28 =
                      let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v_3) in
                      _menhir_action_020 _1 _endpos__1_ _startpos__1_
                    in
                    _menhir_run_0995 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v_28 MenhirState0977 _tok
                | _ ->
                    _eRR ())
            | Tokens.BOOL_LIT _v_29 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_29 MenhirState0977
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0977
            | Tokens.BITVECTOR_LIT _v_30 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_30 MenhirState0977
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0995 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_CONSTANT, _menhir_box_opn) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
                let MenhirCell1_CONSTANT (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _endpos__2_inlined1_, x, _3) = ((), (), _endpos_0, _v, ()) in
                let _v = _menhir_action_363 _1 _2 _3 _endpos__2_inlined1_ _startpos__1_ decl_item x in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0995
        | _ ->
            _eRR ()
    
    and _menhir_run_0064 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_RDIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0064 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0029 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_POW (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0029 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0079 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_PLUS (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0079 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0089 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_OR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0089 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0091 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0091
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0091
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0091
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0091
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0091
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_063 _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_e_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0091
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0091
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0091
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0091
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0091
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0091
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_NEQ (_menhir_stack, _menhir_s) in
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0091
        | _ ->
            _eRR ()
    
    and _menhir_run_0081 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MUL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0081 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0083 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_MOD (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0083 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0094 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
        let _menhir_s = MenhirState0094 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0096 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0096 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0025 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LLBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0025 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0104 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0104 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0031 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0031 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.COLON ->
            _menhir_run_0032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0032 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_COLON (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0032 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0036 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IN (_menhir_stack, _menhir_s) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState0037 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0038 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0164 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0166 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MASK_LIT _v ->
                _menhir_run_0168 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0169 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LEQ ->
                _menhir_run_0170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LBRACE ->
                _menhir_run_0172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0173 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0186 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.GEQ ->
                _menhir_run_0218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0220 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0221 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.BNOT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_BNOT (_menhir_stack, _startpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState0321 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0038 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0164 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0166 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MASK_LIT _v ->
                    _menhir_run_0168 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0169 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LEQ ->
                    _menhir_run_0170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LBRACE ->
                    _menhir_run_0172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0173 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0186 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.GEQ ->
                    _menhir_run_0218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0220 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0221 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0038 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_UNKNOWN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON_COLON ->
            let _menhir_s = MenhirState0039 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let _menhir_s = MenhirState0160 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0162 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_s_, _startpos_s_, s) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_074 _endpos_s_ _startpos_s_ s in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s_ _startpos_s_ _v _menhir_s _tok
    
    and _menhir_goto_expr_pattern : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState0169 ->
            _menhir_run_0316 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0473 ->
            _menhir_run_0229 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0321 ->
            _menhir_run_0229 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0037 ->
            _menhir_run_0229 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0313 ->
            _menhir_run_0229 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0172 ->
            _menhir_run_0229 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0222 ->
            _menhir_run_0229 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0268 ->
            _menhir_run_0229 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0264 ->
            _menhir_run_0229 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0227 ->
            _menhir_run_0229 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0316 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0230 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0232 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0234 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_121 _endpos__3_ _startpos__1_ x in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0236 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0238 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0240 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0242 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0244 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0247 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0249 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0251 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0253 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0255 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0258 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0260 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0263 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0271 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0273 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0275 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0280 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0282 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0287 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0289 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0291 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0293 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0295 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0297 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0299 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0301 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0307 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.COMMA ->
            let (_endpos_expr_pattern_, _startpos_expr_pattern_, expr_pattern) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_403 _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_pattern_ _startpos_expr_pattern_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0230 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0230 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0232 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0232 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0234 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0234 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0236 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0236 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0238 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0238 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0240 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0240 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0242 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0242 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0244 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0244
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0244
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0244
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0244
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0244
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_118 _1 _2 _endpos__1_ _startpos__1_ _startpos_e_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_e_ _v _menhir_s _tok
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0244
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0244
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0244
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0244
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0244
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0244
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0244
        | _ ->
            _eRR ()
    
    and _menhir_run_0247 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0247 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0249 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0249 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0251 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
        let _menhir_s = MenhirState0251 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0253 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0253 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0255 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0255 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0258 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell0_LEQ (_menhir_stack, _startpos) in
        let _menhir_s = MenhirState0258 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0260 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0260 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.COLON ->
            _menhir_run_0032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0263 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState0264 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0038 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0164 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0166 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MASK_LIT _v ->
                _menhir_run_0168 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0169 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LEQ ->
                _menhir_run_0170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LBRACE ->
                _menhir_run_0172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0173 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0186 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.GEQ ->
                _menhir_run_0218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0220 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0221 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.BNOT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_BNOT (_menhir_stack, _startpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState0268 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0038 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0164 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0166 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MASK_LIT _v ->
                    _menhir_run_0168 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0169 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LEQ ->
                    _menhir_run_0170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LBRACE ->
                    _menhir_run_0172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0173 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0186 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.GEQ ->
                    _menhir_run_0218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0220 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0221 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0163 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_r_, _startpos_r_, r) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_072 _endpos_r_ _startpos_r_ r in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_r_ _startpos_r_ _v _menhir_s _tok
    
    and _menhir_run_0164 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0164 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0166 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0166
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0166
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0166
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0166
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0166
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0166
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0166
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0166
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0166
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0166
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0166
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos, _endpos) in
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0166
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
            let _v = _menhir_action_405 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_pattern : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState0169 ->
            _menhir_run_0312 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0473 ->
            _menhir_run_0226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0321 ->
            _menhir_run_0226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0037 ->
            _menhir_run_0226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0313 ->
            _menhir_run_0226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0172 ->
            _menhir_run_0226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0268 ->
            _menhir_run_0226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0264 ->
            _menhir_run_0226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0227 ->
            _menhir_run_0226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0222 ->
            _menhir_run_0226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0312 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState0313 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0038 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0164 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0166 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MASK_LIT _v ->
                _menhir_run_0168 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0169 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LEQ ->
                _menhir_run_0170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LBRACE ->
                _menhir_run_0172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0173 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0186 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.GEQ ->
                _menhir_run_0218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0220 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0221 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0168 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_409 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_0169 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0169 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0038 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0164 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0166 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_0168 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0169 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_0170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_0172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0173 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0186 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_0218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0220 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0221 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0170 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0170 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0172 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0172 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0038 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0164 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0166 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_0168 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0169 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_0170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_0172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0173 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0186 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_0218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0220 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0221 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0173 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_i_, _startpos_i_, i) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_070 _endpos_i_ _startpos_i_ i in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_i_ _startpos_i_ _v _menhir_s _tok
    
    and _menhir_run_0174 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0174 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0186 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0187
            | Tokens.STRING_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0187
            | Tokens.RPAR ->
                let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__3_, _startpos_name_, name) = (_endpos_2, _startpos, _v) in
                let _v = _menhir_action_105 _endpos__3_ _startpos_name_ name in
                _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
            | Tokens.REAL_LIT _v_3 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState0187
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0187
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0187
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0187
            | Tokens.INT_LIT _v_4 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState0187
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0187
            | Tokens.IDENTIFIER _v_5 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState0187
            | Tokens.BOOL_LIT _v_6 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState0187
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0187
            | Tokens.BITVECTOR_LIT _v_7 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState0187
            | _ ->
                _eRR ())
        | Tokens.LBRACE ->
            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0194
            | Tokens.STRING_LIT _v_9 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState0194
            | Tokens.REAL_LIT _v_10 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState0194
            | Tokens.RBRACE ->
                let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_endpos__3_, _endpos_desc_, _startpos_desc_, desc) = (_endpos_11, _endpos, _startpos, _v) in
                let _v = _menhir_action_122 _endpos__3_ _endpos_desc_ _startpos_desc_ desc in
                _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0194
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0194
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0194
            | Tokens.INT_LIT _v_12 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState0194
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0194
            | Tokens.IDENTIFIER _v_13 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0196 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState0194
            | Tokens.BOOL_LIT _v_14 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14 MenhirState0194
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0194
            | Tokens.BITVECTOR_LIT _v_15 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_8) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15 MenhirState0194
            | _ ->
                _eRR ())
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_075 _1 _endpos__1_ _startpos__1_ in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0218 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0218 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0220 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_b_, _startpos_b_, b) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_071 _endpos_b_ _startpos_b_ b in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_b_ _v _menhir_s _tok
    
    and _menhir_run_0221 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0221 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState0222 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0038 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0164 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0166 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MASK_LIT _v ->
                _menhir_run_0168 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0169 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LEQ ->
                _menhir_run_0170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LBRACE ->
                _menhir_run_0172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0173 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0186 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.GEQ ->
                _menhir_run_0218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0220 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0221 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0223 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos_b_, _startpos_b_, b) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_073 _endpos_b_ _startpos_b_ b in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_b_ _startpos_b_ _v _menhir_s _tok
    
    and _menhir_run_0226 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState0227 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0038 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0164 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0166 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MASK_LIT _v ->
                _menhir_run_0168 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0169 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LEQ ->
                _menhir_run_0170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LBRACE ->
                _menhir_run_0172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0173 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0186 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.GEQ ->
                _menhir_run_0218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0220 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0221 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.ARROW | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos_x_, _startpos_x_, x) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_435 x in
            _menhir_goto_separated_nonempty_list_COMMA_pattern_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_separated_nonempty_list_COMMA_pattern_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState0473 ->
            _menhir_run_0474 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok
        | MenhirState0321 ->
            _menhir_run_0322 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState0037 ->
            _menhir_run_0318 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState0313 ->
            _menhir_run_0314 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0172 ->
            _menhir_run_0310 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState0268 ->
            _menhir_run_0269 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState0264 ->
            _menhir_run_0265 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | MenhirState0227 ->
            _menhir_run_0228 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0222 ->
            _menhir_run_0224 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0474 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_pattern_ (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHERE ->
            let _menhir_s = MenhirState0475 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            let _menhir_s = MenhirState0511 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0390 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.RPAR ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.SEMI_COLON ->
                    let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.WHILE ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.VAR ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.UNREACHABLE ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.TRY ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.THROW ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.RETURN ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.REPEAT ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.PRINT ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.PRAGMA ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.PASS ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.MINUS ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.LPAR ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.LET ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.IF ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.IDENTIFIER _v ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0393
                    | Tokens.FOR ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.DEBUG ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.CONSTANT ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.CASE ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.ASSERT ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.ARROBASE_LOOPLIMIT ->
                        let _menhir_stack = MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0393
                    | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                        let (_startpos__1_, _1, _endpos__2_, _2_inlined1, _3) = (_startpos, (), _endpos_1, (), ()) in
                        let _v = _menhir_action_281 _1 _2_inlined1 _3 _endpos__2_ _startpos__1_ in
                        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0394 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0394 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARROBASE_LOOPLIMIT ->
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0395 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0395
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0395
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0396
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0395, _endpos) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0396
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let (_startpos__1_, _1, _endpos__2_) = (_startpos, (), _endpos) in
                let _v = _menhir_action_286 _1 _endpos__2_ _startpos__1_ in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0395
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0395
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0395
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0395
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0395
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0395
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0395
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0395
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0395
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0395
        | _ ->
            _eRR ()
    
    and _menhir_run_0397 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0397
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0397
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0398
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0397, _endpos) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0398
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let (_startpos__1_, _1, _endpos__2_) = (_startpos, (), _endpos) in
                let _v = _menhir_action_246 _1 _endpos__2_ _startpos__1_ in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0397
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0397
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0397
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0397
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0397
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0397
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0397
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0397
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0397
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0397
        | _ ->
            _eRR ()
    
    and _menhir_run_0399 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0399 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARROBASE_LOOPLIMIT ->
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0400 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0401
            | Tokens.STRING_LIT _v ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0401
            | Tokens.RPAR ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.SEMI_COLON ->
                    let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.WHILE ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.VAR ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.UNREACHABLE ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.TRY ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.THROW ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.RETURN ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.REPEAT ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.PRINT ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.PRAGMA ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.PASS ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.MINUS ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.LPAR ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.LET ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.IF ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.IDENTIFIER _v ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0403
                    | Tokens.FOR ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.DEBUG ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.CONSTANT ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.CASE ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.ASSERT ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.ARROBASE_LOOPLIMIT ->
                        let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0401, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0403
                    | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                        let (_startpos__1_, _1, _endpos__2_) = (_startpos, (), _endpos_1) in
                        let _v = _menhir_action_277 _1 _endpos__2_ _startpos__1_ in
                        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.REAL_LIT _v ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0401
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0401
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0401
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0401
            | Tokens.INT_LIT _v ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0401
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0401
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0401
            | Tokens.BOOL_LIT _v ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0401
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0401
            | Tokens.BITVECTOR_LIT _v ->
                let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0401
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0404 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0405
            | Tokens.STRING_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0405
            | Tokens.SEMI_COLON ->
                let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.VAR ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.UNREACHABLE ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.TRY ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.THROW ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.RETURN ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.REPEAT ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.PRINT ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.PRAGMA ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.PASS ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.LET ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.IDENTIFIER _v_3 ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState0406
                | Tokens.FOR ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.DEBUG ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.CONSTANT ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.CASE ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.ASSERT ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.ARROBASE_LOOPLIMIT ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                    let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0405, _endpos_2) in
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0406
                | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                    let (_startpos__1_, _1, _endpos__2_, _endpos__2_inlined1_, _2_inlined1) = (_startpos, (), _endpos_2, _endpos, _v) in
                    let _v = _menhir_action_287 _1 _2_inlined1 _endpos__2_ _endpos__2_inlined1_ _startpos__1_ in
                    _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | Tokens.REAL_LIT _v_4 ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState0405
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0405
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0405
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0405
            | Tokens.INT_LIT _v_5 ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState0405
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0405
            | Tokens.IDENTIFIER _v_6 ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState0405
            | Tokens.BOOL_LIT _v_7 ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState0405
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0405
            | Tokens.BITVECTOR_LIT _v_8 ->
                let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8 MenhirState0405
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0407 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0408
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0408
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let (_startpos__1_, _1, _endpos__2_) = (_startpos, (), _endpos) in
                let _v = _menhir_action_245 _1 _endpos__2_ _startpos__1_ in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0409 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, ()) in
        let _v = _menhir_action_125 _1 _endpos__1_ _startpos__1_ in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_lexpr : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState0000 ->
            _menhir_run_1025 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1374 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1302 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1294 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1282 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1079 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1237 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1097 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1224 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1218 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1208 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1191 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1185 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1105 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1018 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState1014 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0962 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0958 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0950 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0946 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0861 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0807 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0784 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0789 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0739 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0355 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0732 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0734 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0360 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0730 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0727 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0724 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0718 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0714 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0706 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0703 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0389 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0393 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0394 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0697 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0693 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0695 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0688 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0684 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0676 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0396 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0672 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0398 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0399 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0668 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0664 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0659 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0403 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0654 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0406 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0408 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0649 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0646 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0640 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0440 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0443 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0635 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0629 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0631 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0624 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0619 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0609 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0605 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0599 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0594 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0584 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0580 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0576 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0571 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0561 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0447 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0554 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0556 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0550 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0552 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0542 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0544 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0456 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0540 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0537 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0460 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0532 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0529 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0523 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0469 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0518 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0511 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0514 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0477 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0508 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0480 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0499 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0503 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0487 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0497 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0492 ->
            _menhir_run_0494 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0430 ->
            _menhir_run_0429 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0426 ->
            _menhir_run_0429 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | MenhirState0410 ->
            _menhir_run_0425 _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1025 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_lexpr (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1026 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0494 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_lexpr (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState0495 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0429 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_lexpr as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_lexpr (_menhir_stack, _menhir_s, _v, _startpos) in
            let _menhir_s = MenhirState0430 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0411 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_427 x in
            _menhir_goto_separated_nonempty_list_COMMA_lexpr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0410 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0410 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0411 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0411 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
        let _v = _menhir_action_127 _1 in
        _menhir_goto_lexpr_atom_desc _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_goto_lexpr_atom_desc : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_lexpr_atom_desc (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState0413 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_lexpr_atom_desc (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState0416 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.COLON ->
                _menhir_run_0032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DOT ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.RBRACKET ->
                    let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    let (_2, _endpos__3_, _endpos_desc_, _startpos_desc_, desc) = ((), _endpos_12, _endpos, _startpos, _v) in
                    let _v = _menhir_action_131 _2 _endpos_desc_ _startpos_desc_ desc in
                    _menhir_goto_lexpr_atom_desc _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
                | Tokens.IDENTIFIER _v_13 ->
                    let _menhir_stack = MenhirCell1_lexpr_atom_desc (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState0420
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v_14 ->
                let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let (_2, _endpos_desc_, _startpos_desc_, desc, _endpos_field_, field) = ((), _endpos, _startpos, _v, _endpos_16, _v_14) in
                let _v = _menhir_action_130 _2 _endpos_desc_ _startpos_desc_ desc field in
                _menhir_goto_lexpr_atom_desc _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_field_ _startpos_desc_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.COMMA | Tokens.EQ | Tokens.RPAR ->
            let (_endpos_desc_, _startpos_desc_, desc) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_124 _endpos_desc_ _startpos_desc_ desc in
            _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos_desc_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0068 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_s = MenhirState0069 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON | Tokens.COLON_COLON | Tokens.RBRACKET ->
            let x = _v in
            let _v = _menhir_action_415 x in
            _menhir_goto_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_separated_nonempty_list_COMMA_IDENTIFIER_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState0926 ->
            _menhir_run_0927 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0901 ->
            _menhir_run_0902 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0878 ->
            _menhir_run_0879 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0745 ->
            _menhir_run_0746 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0614 ->
            _menhir_run_0615 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0589 ->
            _menhir_run_0590 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0566 ->
            _menhir_run_0567 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0420 ->
            _menhir_run_0422 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0385 ->
            _menhir_run_0386 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0283 ->
            _menhir_run_0284 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0067 ->
            _menhir_run_0071 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0069 ->
            _menhir_run_0070 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0927 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState0929 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0902 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState0904 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0879 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState0881 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0746 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON_COLON ->
            let _menhir_s = MenhirState0747 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let _menhir_s = MenhirState0751 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0615 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState0617 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0590 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState0592 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0567 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState0569 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0422 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_lexpr_atom_desc -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_lexpr_atom_desc (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_2, _1_inlined1, _endpos__3_) = ((), _v, _endpos) in
            let _v = _menhir_action_132 _1_inlined1 _2 _endpos_desc_ _startpos_desc_ desc in
            _menhir_goto_lexpr_atom_desc _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0386 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON_COLON ->
            let _menhir_s = MenhirState0387 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let _menhir_s = MenhirState0701 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0284 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, _1_inlined1, _endpos__3_) = ((), _v, _endpos) in
            let _v = _menhir_action_111 _1_inlined1 _2 _endpos__3_ _startpos_e_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0071 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOT -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACKET ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_DOT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, _1_inlined1, _endpos__3_) = ((), _v, _endpos) in
            let _v = _menhir_action_056 _1_inlined1 _2 _endpos__3_ _startpos_e_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0070 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_416 x xs in
        _menhir_goto_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_separated_nonempty_list_COMMA_lexpr_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_lexpr as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState0430 ->
            _menhir_run_0431 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0426 ->
            _menhir_run_0427 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0431 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_lexpr, ttv_result) _menhir_cell1_lexpr -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_lexpr (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_428 x xs in
        _menhir_goto_separated_nonempty_list_COMMA_lexpr_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0427 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_lexpr -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_lexpr (_menhir_stack, _, x, _) = _menhir_stack in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_2, _1_inlined1, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_126 _1_inlined1 _2 _endpos__3_ _startpos__1_ x in
        _menhir_goto_lexpr _menhir_stack _menhir_lexbuf _menhir_lexer _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_0425 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_lexpr (_menhir_stack, _menhir_s, _v, _startpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState0426 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0411 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0432 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0432 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_0362 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0367 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0368 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0367 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0367 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_0362 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0367 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0368 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0368 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0369 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.COLON ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0371 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.COMMA | Tokens.EQ | Tokens.RPAR ->
            let _1 = _v in
            let _v = _menhir_action_009 _1 in
            _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0369 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0369 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0371 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0371 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REAL ->
            _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INTEGER ->
            _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOLEAN ->
            _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITS ->
            _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BIT ->
            _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARRAY ->
            _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0441 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0441 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0444 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0445
            | Tokens.STRING_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0445
            | Tokens.RPAR ->
                let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.SEMI_COLON ->
                    let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.WHILE ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.VAR ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.UNREACHABLE ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.TRY ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.THROW ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.RETURN ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.REPEAT ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.PRINT ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.PRAGMA ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.PASS ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.MINUS ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.LPAR ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.LET ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.IF ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.IDENTIFIER _v_4 ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState0447
                    | Tokens.FOR ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.DEBUG ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.CONSTANT ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.CASE ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.ASSERT ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.ARROBASE_LOOPLIMIT ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_3) in
                        _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0447
                    | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                        let (_endpos__2_, _startpos_name_, name) = (_endpos_3, _startpos, _v) in
                        let _v = _menhir_action_248 _endpos__2_ _startpos_name_ name in
                        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                    | _ ->
                        _eRR ())
                | Tokens.EQ ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                    let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                    let _menhir_s = MenhirState0559 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.UNKNOWN ->
                        _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.STRING_LIT _v ->
                        _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.REAL_LIT _v ->
                        _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.NOT ->
                        _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.MINUS ->
                        _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.LPAR ->
                        _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.INT_LIT _v ->
                        _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.IF ->
                        _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.IDENTIFIER _v ->
                        _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BOOL_LIT _v ->
                        _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BNOT ->
                        _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BITVECTOR_LIT _v ->
                        _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | _ ->
                        _eRR ())
                | Tokens.DOT ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                    let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0445, _endpos_2) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.LBRACKET ->
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.IDENTIFIER _v ->
                            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.COMMA ->
                                let _menhir_s = MenhirState0566 in
                                let _tok = _menhir_lexer _menhir_lexbuf in
                                (match (_tok : MenhirBasics.token) with
                                | Tokens.IDENTIFIER _v ->
                                    _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                                | _ ->
                                    _eRR ())
                            | _ ->
                                _eRR ())
                        | _ ->
                            _eRR ())
                    | Tokens.IDENTIFIER _v ->
                        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.EQ ->
                            let _menhir_s = MenhirState0574 in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.UNKNOWN ->
                                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.STRING_LIT _v ->
                                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                            | Tokens.REAL_LIT _v ->
                                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                            | Tokens.NOT ->
                                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.MINUS ->
                                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.LPAR ->
                                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.INT_LIT _v ->
                                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                            | Tokens.IF ->
                                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.IDENTIFIER _v ->
                                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                            | Tokens.BOOL_LIT _v ->
                                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                            | Tokens.BNOT ->
                                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.BITVECTOR_LIT _v ->
                                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                            | _ ->
                                _eRR ())
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.REAL_LIT _v_24 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_24 MenhirState0445
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0445
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0445
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0445
            | Tokens.INT_LIT _v_25 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_25 MenhirState0445
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0445
            | Tokens.IDENTIFIER _v_26 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_26 MenhirState0445
            | Tokens.BOOL_LIT _v_27 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_27 MenhirState0445
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0445
            | Tokens.BITVECTOR_LIT _v_28 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_28 MenhirState0445
            | _ ->
                _eRR ())
        | Tokens.LBRACE ->
            let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState0601 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DOT | Tokens.EQ | Tokens.LBRACKET | Tokens.LLBRACKET ->
            let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_127 _1 in
            _menhir_goto_lexpr_atom_desc _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0448 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState0450 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0457 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0458
            | Tokens.STRING_LIT _v ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0458
            | Tokens.RPAR ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.SEMI_COLON ->
                    let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.WHILE ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.VAR ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.UNREACHABLE ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.TRY ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.THROW ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.RETURN ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.REPEAT ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.PRINT ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.PRAGMA ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.PASS ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.MINUS ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.LPAR ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.LET ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.IF ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.IDENTIFIER _v ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0460
                    | Tokens.FOR ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.DEBUG ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.CONSTANT ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.CASE ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.ASSERT ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.ARROBASE_LOOPLIMIT ->
                        let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0458, _endpos) in
                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                        _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0460
                    | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                        let (_startpos__1_, _1, _endpos__2_) = (_startpos, (), _endpos_1) in
                        let _v = _menhir_action_279 _1 _endpos__2_ _startpos__1_ in
                        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.REAL_LIT _v ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0458
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0458
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0458
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0458
            | Tokens.INT_LIT _v ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0458
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0458
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0458
            | Tokens.BOOL_LIT _v ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0458
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0458
            | Tokens.BITVECTOR_LIT _v ->
                let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos) in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_0) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0458
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0461 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0461 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            _menhir_run_0362 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0367 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0368 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0470 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0470 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0478 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ASSERT (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0478 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0481 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ARROBASE_LOOPLIMIT (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState0482 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_goto_nonempty_list_stmt_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState1374 ->
            _menhir_run_1376 _menhir_stack _v _tok
        | MenhirState1302 ->
            _menhir_run_1303 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1294 ->
            _menhir_run_1295 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1282 ->
            _menhir_run_1283 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1237 ->
            _menhir_run_1238 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1224 ->
            _menhir_run_1225 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1218 ->
            _menhir_run_1219 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1208 ->
            _menhir_run_1209 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1191 ->
            _menhir_run_1192 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1185 ->
            _menhir_run_1186 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1105 ->
            _menhir_run_1106 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1097 ->
            _menhir_run_1098 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1079 ->
            _menhir_run_1080 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1018 ->
            _menhir_run_1019 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1014 ->
            _menhir_run_1015 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0962 ->
            _menhir_run_0963 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0958 ->
            _menhir_run_0959 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0950 ->
            _menhir_run_0951 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0946 ->
            _menhir_run_0947 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0861 ->
            _menhir_run_0862 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0807 ->
            _menhir_run_0808 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0789 ->
            _menhir_run_0790 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0784 ->
            _menhir_run_0785 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0739 ->
            _menhir_run_0740 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0355 ->
            _menhir_run_0736 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0734 ->
            _menhir_run_0735 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0732 ->
            _menhir_run_0733 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0730 ->
            _menhir_run_0731 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0360 ->
            _menhir_run_0729 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0727 ->
            _menhir_run_0728 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0724 ->
            _menhir_run_0725 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0718 ->
            _menhir_run_0719 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0714 ->
            _menhir_run_0715 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0706 ->
            _menhir_run_0707 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0703 ->
            _menhir_run_0704 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0389 ->
            _menhir_run_0700 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0393 ->
            _menhir_run_0699 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0697 ->
            _menhir_run_0698 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0695 ->
            _menhir_run_0696 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0693 ->
            _menhir_run_0694 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0688 ->
            _menhir_run_0689 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0684 ->
            _menhir_run_0685 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0394 ->
            _menhir_run_0678 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0676 ->
            _menhir_run_0677 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0396 ->
            _menhir_run_0674 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0672 ->
            _menhir_run_0673 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0398 ->
            _menhir_run_0670 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0668 ->
            _menhir_run_0669 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0664 ->
            _menhir_run_0665 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0399 ->
            _menhir_run_0661 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0659 ->
            _menhir_run_0660 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0403 ->
            _menhir_run_0656 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0654 ->
            _menhir_run_0655 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0406 ->
            _menhir_run_0652 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0408 ->
            _menhir_run_0651 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0649 ->
            _menhir_run_0650 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0646 ->
            _menhir_run_0647 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0640 ->
            _menhir_run_0641 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0440 ->
            _menhir_run_0637 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0635 ->
            _menhir_run_0636 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0631 ->
            _menhir_run_0632 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0629 ->
            _menhir_run_0630 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0443 ->
            _menhir_run_0626 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0624 ->
            _menhir_run_0625 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0619 ->
            _menhir_run_0620 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0609 ->
            _menhir_run_0610 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0605 ->
            _menhir_run_0606 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0599 ->
            _menhir_run_0600 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0594 ->
            _menhir_run_0595 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0584 ->
            _menhir_run_0585 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0580 ->
            _menhir_run_0581 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0576 ->
            _menhir_run_0577 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0571 ->
            _menhir_run_0572 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0561 ->
            _menhir_run_0562 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0447 ->
            _menhir_run_0558 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0556 ->
            _menhir_run_0557 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0554 ->
            _menhir_run_0555 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0552 ->
            _menhir_run_0553 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0550 ->
            _menhir_run_0551 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0544 ->
            _menhir_run_0545 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0542 ->
            _menhir_run_0543 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0540 ->
            _menhir_run_0541 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0456 ->
            _menhir_run_0539 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0537 ->
            _menhir_run_0538 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0460 ->
            _menhir_run_0534 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0532 ->
            _menhir_run_0533 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0529 ->
            _menhir_run_0530 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0523 ->
            _menhir_run_0524 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0469 ->
            _menhir_run_0520 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0518 ->
            _menhir_run_0519 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0514 ->
            _menhir_run_0515 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0511 ->
            _menhir_run_0512 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0508 ->
            _menhir_run_0509 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0477 ->
            _menhir_run_0506 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0480 ->
            _menhir_run_0505 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0503 ->
            _menhir_run_0504 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0499 ->
            _menhir_run_0500 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0497 ->
            _menhir_run_0498 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0492 ->
            _menhir_run_0493 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0487 ->
            _menhir_run_0488 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1303 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1303
        | _ ->
            _eRR ()
    
    and _menhir_run_0489 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_END (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let (_endpos_x_, x) = (_endpos, ()) in
            let _v = _menhir_action_400 x in
            _menhir_goto_option_SEMI_COLON_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _tok
        | Tokens.ARROBASE_LOOPLIMIT | Tokens.ASSERT | Tokens.CASE | Tokens.CATCH | Tokens.CONFIG | Tokens.CONSTANT | Tokens.DEBUG | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.FOR | Tokens.FUNC | Tokens.GETTER | Tokens.IDENTIFIER _ | Tokens.IF | Tokens.LET | Tokens.LPAR | Tokens.MINUS | Tokens.OTHERWISE | Tokens.PASS | Tokens.PRAGMA | Tokens.PRINT | Tokens.REPEAT | Tokens.RETURN | Tokens.SETTER | Tokens.THROW | Tokens.TRY | Tokens.TYPE | Tokens.UNREACHABLE | Tokens.UNTIL | Tokens.VAR | Tokens.WHEN | Tokens.WHILE ->
            let _v = _menhir_action_399 () in
            _menhir_goto_option_SEMI_COLON_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_option_SEMI_COLON_ : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_END -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_END (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_opt_, opt) = ((), _endpos, _v) in
        let _v = _menhir_action_014 _1 _endpos_opt_ _startpos__1_ opt in
        _menhir_goto_end_semicolon _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_opt_ _v _menhir_s _tok
    
    and _menhir_goto_end_semicolon : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState1302 ->
            _menhir_run_1306 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1303 ->
            _menhir_run_1304 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1294 ->
            _menhir_run_1298 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1295 ->
            _menhir_run_1296 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1282 ->
            _menhir_run_1286 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1283 ->
            _menhir_run_1284 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1079 ->
            _menhir_run_1278 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1237 ->
            _menhir_run_1241 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1238 ->
            _menhir_run_1239 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1097 ->
            _menhir_run_1231 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1224 ->
            _menhir_run_1228 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1225 ->
            _menhir_run_1226 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1218 ->
            _menhir_run_1222 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1219 ->
            _menhir_run_1220 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1208 ->
            _menhir_run_1212 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1209 ->
            _menhir_run_1210 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1191 ->
            _menhir_run_1195 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1192 ->
            _menhir_run_1193 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1185 ->
            _menhir_run_1189 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1186 ->
            _menhir_run_1187 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1105 ->
            _menhir_run_1179 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1106 ->
            _menhir_run_1107 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1098 ->
            _menhir_run_1099 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1080 ->
            _menhir_run_1081 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState1015 ->
            _menhir_run_1016 _menhir_stack _endpos _tok
        | MenhirState1001 ->
            _menhir_run_1002 _menhir_stack _endpos _tok
        | MenhirState0963 ->
            _menhir_run_0964 _menhir_stack _endpos _tok
        | MenhirState0959 ->
            _menhir_run_0960 _menhir_stack _endpos _tok
        | MenhirState0951 ->
            _menhir_run_0952 _menhir_stack _endpos _tok
        | MenhirState0947 ->
            _menhir_run_0948 _menhir_stack _endpos _tok
        | MenhirState0863 ->
            _menhir_run_0864 _menhir_stack _endpos _tok
        | MenhirState0787 ->
            _menhir_run_0793 _menhir_stack _endpos _tok
        | MenhirState0790 ->
            _menhir_run_0791 _menhir_stack _endpos _tok
        | MenhirState0740 ->
            _menhir_run_0741 _menhir_stack _endpos _tok
        | MenhirState0736 ->
            _menhir_run_0737 _menhir_stack _endpos _tok
        | MenhirState0733 ->
            _menhir_run_0734 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0729 ->
            _menhir_run_0730 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0691 ->
            _menhir_run_0697 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0694 ->
            _menhir_run_0695 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0634 ->
            _menhir_run_0635 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0555 ->
            _menhir_run_0556 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0551 ->
            _menhir_run_0552 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0543 ->
            _menhir_run_0544 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0539 ->
            _menhir_run_0540 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0517 ->
            _menhir_run_0518 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0488 ->
            _menhir_run_0492 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1306 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1306
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1306
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1306
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1306
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1306
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1306
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1306
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1306
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1306
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1307 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1082 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1083
            | Tokens.STRING_LIT _v_1 ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState1083
            | Tokens.SEMI_COLON ->
                let _endpos_2 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1083, _endpos_2) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.VAR ->
                    _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1084
                | Tokens.TYPE ->
                    _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1084
                | Tokens.SETTER ->
                    _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1084
                | Tokens.PRAGMA ->
                    _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1084
                | Tokens.LET ->
                    _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1084
                | Tokens.GETTER ->
                    _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1084
                | Tokens.FUNC ->
                    _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1084
                | Tokens.CONSTANT ->
                    _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1084
                | Tokens.CONFIG ->
                    _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1084
                | Tokens.EOF ->
                    let _v_3 = _menhir_action_133 () in
                    _menhir_run_1273 _menhir_stack _v_3
                | _ ->
                    _eRR ())
            | Tokens.REAL_LIT _v_4 ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_4 MenhirState1083
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1083
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1083
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1083
            | Tokens.INT_LIT _v_5 ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState1083
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1083
            | Tokens.IDENTIFIER _v_6 ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState1083
            | Tokens.BOOL_LIT _v_7 ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState1083
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1083
            | Tokens.BITVECTOR_LIT _v_8 ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_8 MenhirState1083
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1085 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState1087 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON_COLON ->
                let _menhir_s = MenhirState1244 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON ->
                let _menhir_s = MenhirState1250 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState1257 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON_COLON ->
                let _menhir_s = MenhirState1261 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON ->
                let _menhir_s = MenhirState1267 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1090 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GETTER (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_1058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1091
            | Tokens.LPAR ->
                let _v_1 = _menhir_action_194 () in
                _menhir_run_1092 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState1091 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1092 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState1093 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.RPAR ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, _menhir_s, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.ARROW ->
                    let _menhir_s = MenhirState1095 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.STRING ->
                        _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.REAL ->
                        _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.LPAR ->
                        _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.INTEGER ->
                        _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.IDENTIFIER _v ->
                        _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BOOLEAN ->
                        _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BITS ->
                        _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BIT ->
                        _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.ARRAY ->
                        _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v ->
                _menhir_run_1197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1197 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON_COLON ->
            let _menhir_s = MenhirState1198 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let _menhir_s = MenhirState1202 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1100 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_FUNC (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_0, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                _menhir_run_1058 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1101
            | Tokens.LPAR ->
                let _v_1 = _menhir_action_194 () in
                _menhir_run_1102 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState1101 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1108 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState1110 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON_COLON ->
                let _menhir_s = MenhirState1149 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON ->
                let _menhir_s = MenhirState1155 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState1162 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON_COLON ->
                let _menhir_s = MenhirState1166 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON ->
                let _menhir_s = MenhirState1172 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1113 : type  ttv_stack. ttv_stack -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_CONFIG (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.MINUS ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_MINUS (_menhir_stack, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState1115 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON_COLON ->
                let _menhir_s = MenhirState1119 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON ->
                let _menhir_s = MenhirState1125 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EQ ->
                let _menhir_s = MenhirState1132 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON_COLON ->
                let _menhir_s = MenhirState1136 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON ->
                let _menhir_s = MenhirState1142 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1304 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1304
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1304
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1304
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1304
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1304
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1304
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1304
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1304
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1304
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1305 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1298 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1298
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1298
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1298
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1298
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1298
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1298
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1298
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1298
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1298
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1299 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1296 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1296
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1296
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1296
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1296
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1296
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1296
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1296
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1296
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1296
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1297 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1286 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1286
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1286
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1286
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1286
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1286
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1286
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1286
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1286
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1286
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1287 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1284 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1284
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1284
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1284
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1284
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1284
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1284
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1284
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1284
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1284
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1285 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1278 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1278
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1278
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1278
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1278
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1278
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1278
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1278
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1278
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1278
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1279 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1241 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1241
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1241
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1241
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1241
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1241
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1241
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1241
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1241
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1241
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1242 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1239 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1239
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1239
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1239
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1239
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1239
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1239
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1239
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1239
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1239
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1240 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1231 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1231
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1231
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1231
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1231
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1231
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1231
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1231
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1231
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1231
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1232 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1228 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1228
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1228
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1228
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1228
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1228
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1228
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1228
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1228
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1228
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1229 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1226 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1226
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1226
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1226
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1226
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1226
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1226
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1226
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1226
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1226
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1227 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1222 : type  ttv_stack. (((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1222
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1222
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1222
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1222
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1222
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1222
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1222
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1222
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1222
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1223 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1220 : type  ttv_stack. ((((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1220
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1220
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1220
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1220
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1220
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1220
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1220
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1220
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1220
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1221 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1212 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1212
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1212
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1212
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1212
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1212
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1212
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1212
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1212
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1212
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1213 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1210 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1210
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1210
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1210
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1210
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1210
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1210
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1210
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1210
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1210
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1211 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1195 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1195
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1195
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1195
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1195
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1195
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1195
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1195
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1195
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1195
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1196 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1193 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1193
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1193
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1193
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1193
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1193
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1193
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1193
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1193
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1193
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1194 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1189 : type  ttv_stack. (((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1189
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1189
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1189
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1189
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1189
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1189
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1189
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1189
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1189
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1190 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1187 : type  ttv_stack. ((((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1187
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1187
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1187
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1187
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1187
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1187
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1187
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1187
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1187
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1188 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1179 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1179
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1179
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1179
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1179
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1179
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1179
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1179
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1179
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1179
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1180 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1107 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1107
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1107
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1107
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1107
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1107
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1107
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1107
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1107
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1107
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1178 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1099 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1099
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1099
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1099
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1099
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1099
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1099
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1099
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1099
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1099
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1230 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_1081 : type  ttv_stack. ((((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN, _menhir_box_spec) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1081
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1081
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1081
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1081
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1081
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1081
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1081
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1081
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1081
        | Tokens.EOF ->
            let _v_0 = _menhir_action_133 () in
            _menhir_run_1277 _menhir_stack _v_0
        | _ ->
            _eRR ()
    
    and _menhir_run_0734 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0734
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0734
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
            let MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _4) = ((), _endpos, ()) in
            let _v = _menhir_action_236 _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ expr in
            _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0730 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0730
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0730
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
            let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
            let MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _4, _1_inlined1) = ((), _endpos, (), ()) in
            let _v = _menhir_action_237 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ expr in
            _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0697 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_nonempty_list_catcher_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0697
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0697
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let MenhirCell1_nonempty_list_catcher_ (_menhir_stack, _, c) = _menhir_stack in
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
            let MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _3) = ((), _endpos, ()) in
            let _v = _menhir_action_242 _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ c in
            _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0695 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_nonempty_list_catcher_, ttv_result) _menhir_cell1_OTHERWISE, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0695
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0695
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined3, _) = _menhir_stack in
            let MenhirCell1_OTHERWISE (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_nonempty_list_catcher_ (_menhir_stack, _, c) = _menhir_stack in
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
            let MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _2_inlined1, _1_inlined2, _3) = ((), _endpos, (), (), ()) in
            let _v = _menhir_action_243 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _endpos__2_ _startpos__1_ c in
            _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0635 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_s_else as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0635
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0635
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let MenhirCell1_s_else (_menhir_stack, _, s2, _) = _menhir_stack in
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
            let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
            let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _3) = ((), _endpos, ()) in
            let _v = _menhir_action_234 _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ e s2 in
            _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0556 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOWNTO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0556
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0556
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
            let MenhirCell1_DOWNTO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
            let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _1_inlined1, _3, _8) = ((), _endpos, (), (), ()) in
            let _v = _menhir_action_240 _1 _1_inlined1 _1_inlined2 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e in
            _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0552 : type  ttv_stack ttv_result. (((((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOWNTO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0552
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0552
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined3, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
            let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
            let MenhirCell1_DOWNTO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
            let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _1_inlined2, _1_inlined1, _3, _8) = ((), _endpos, (), (), (), ()) in
            let _v = _menhir_action_241 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e in
            _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0544 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_TO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0544
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0544
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
            let MenhirCell1_TO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
            let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _1_inlined1, _3, _8) = ((), _endpos, (), (), ()) in
            let _v = _menhir_action_238 _1 _1_inlined1 _1_inlined2 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e in
            _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0540 : type  ttv_stack ttv_result. (((((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_TO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0540
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0540
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined3, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
            let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
            let MenhirCell1_TO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
            let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _1_inlined2, _1_inlined1, _3, _8) = ((), _endpos, (), (), (), ()) in
            let _v = _menhir_action_239 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e in
            _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0518 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_CASE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OF, ttv_result) _menhir_cell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0518
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0518
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let MenhirCell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
            let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
            let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _3) = ((), _endpos, ()) in
            let _v = _menhir_action_235 _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ expr in
            _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0492 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR _menhir_cell0_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.VAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.UNREACHABLE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.TRY ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.THROW ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.RETURN ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.REPEAT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.PRINT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.PRAGMA ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.PASS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.LET ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.IDENTIFIER _v_0 ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0492
        | Tokens.FOR ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.DEBUG ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.CONSTANT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.CASE ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.ASSERT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_end_semicolon (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0492
        | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
            let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
            let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, cond, _, _) = _menhir_stack in
            let MenhirCell0_WHILE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_ARROBASE_LOOPLIMIT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos__2_, _3, _5) = ((), _endpos, (), ()) in
            let _v = _menhir_action_244 _1 _1_inlined2 _3 _5 _endpos__2_ _startpos__1_ cond x in
            _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_1295 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1295
        | _ ->
            _eRR ()
    
    and _menhir_run_1283 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1283
        | _ ->
            _eRR ()
    
    and _menhir_run_1238 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1238
        | _ ->
            _eRR ()
    
    and _menhir_run_1225 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1225
        | _ ->
            _eRR ()
    
    and _menhir_run_1219 : type  ttv_stack. (((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1219
        | _ ->
            _eRR ()
    
    and _menhir_run_1209 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1209
        | _ ->
            _eRR ()
    
    and _menhir_run_1192 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1192
        | _ ->
            _eRR ()
    
    and _menhir_run_1186 : type  ttv_stack. (((((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty, _menhir_box_spec) _menhir_cell1_expr, _menhir_box_spec) _menhir_cell1_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1186
        | _ ->
            _eRR ()
    
    and _menhir_run_1106 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1106
        | _ ->
            _eRR ()
    
    and _menhir_run_1098 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1098
        | _ ->
            _eRR ()
    
    and _menhir_run_1080 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty _menhir_cell0_BEGIN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1080
        | _ ->
            _eRR ()
    
    and _menhir_run_1019 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_REPEAT as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNTIL ->
            let _menhir_s = MenhirState1020 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1015 : type  ttv_stack. ((((((ttv_stack, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1015
        | _ ->
            _eRR ()
    
    and _menhir_run_0963 : type  ttv_stack. ((((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0963
        | _ ->
            _eRR ()
    
    and _menhir_run_0959 : type  ttv_stack. ((((((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0959
        | _ ->
            _eRR ()
    
    and _menhir_run_0951 : type  ttv_stack. ((((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0951
        | _ ->
            _eRR ()
    
    and _menhir_run_0947 : type  ttv_stack. ((((((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0947
        | _ ->
            _eRR ()
    
    and _menhir_run_0862 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_IF, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ELSIF ->
            _menhir_run_0627 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0862
        | Tokens.ELSE ->
            _menhir_run_0631 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0862
        | Tokens.END ->
            let _v_0 =
              let _endpos__0_ = _endpos in
              _menhir_action_413 _endpos__0_
            in
            _menhir_run_0863 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v_0 MenhirState0862 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0627 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0627 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0631 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ELSE (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0631 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARROBASE_LOOPLIMIT ->
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0863 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_IF, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_THEN, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_s_else (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0863
        | _ ->
            _eRR ()
    
    and _menhir_run_0808 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_REPEAT as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNTIL ->
            let _menhir_s = MenhirState0809 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0790 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_TRY, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_nonempty_list_catcher_, _menhir_box_opn) _menhir_cell1_OTHERWISE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0790
        | _ ->
            _eRR ()
    
    and _menhir_run_0785 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_TRY as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.CATCH ->
            let _menhir_s = MenhirState0786 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHEN ->
                _menhir_run_0680 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0680 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0680
        | Tokens.REAL ->
            _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0680
        | Tokens.LPAR ->
            _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0680
        | Tokens.INTEGER ->
            _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0680
        | Tokens.IDENTIFIER _v ->
            let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.COLON ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0680, _v, _startpos_0, _endpos) in
                let _menhir_s = MenhirState0682 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.ARROW ->
                let _v =
                  let (_endpos_name_, _startpos_name_, name) = (_endpos, _startpos_0, _v) in
                  _menhir_action_465 _endpos_name_ _startpos_name_ name
                in
                _menhir_run_0687 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v MenhirState0680 _tok
            | _ ->
                _eRR ())
        | Tokens.BOOLEAN ->
            _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0680
        | Tokens.BITS ->
            _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0680
        | Tokens.BIT ->
            _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0680
        | Tokens.ARRAY ->
            _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0680
        | _ ->
            _eRR ()
    
    and _menhir_run_0687 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ARROW ->
            let _menhir_s = MenhirState0688 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0740 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0740
        | _ ->
            _eRR ()
    
    and _menhir_run_0736 : type  ttv_stack. ((((((ttv_stack, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0736
        | _ ->
            _eRR ()
    
    and _menhir_run_0735 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_end_semicolon -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
        let MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _4) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_291 _1 _1_inlined1 _4 _endpos__2_ _startpos__1_ expr xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0733 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0733
        | _ ->
            _eRR ()
    
    and _menhir_run_0731 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_end_semicolon -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
        let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
        let MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _4, _1_inlined1) = ((), _endpos, _v, (), ()) in
        let _v = _menhir_action_292 _1 _1_inlined1 _1_inlined2 _2_inlined1 _4 _endpos__2_ _startpos__1_ expr xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0729 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0729
        | _ ->
            _eRR ()
    
    and _menhir_run_0728 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, ldi) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _1_inlined1) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_326 _1 _1_inlined1 _2_inlined1 _endpos__2_ _startpos__1_ ldi xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0725 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_COMMA, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_loption_plist_expr__ _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
        let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _3, _3_inlined1, _5) = ((), (), _endpos, _v, (), (), ()) in
        let _v = _menhir_action_331 _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0719 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _endpos__3_inlined2_) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _3, _3_inlined1) = ((), (), _endpos, _v, (), ()) in
        let _v = _menhir_action_330 _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0715 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_inlined2_) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _3, _3_inlined1) = ((), (), _endpos, _v, (), ()) in
        let _v = _menhir_action_329 _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0707 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, ldi) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_325 _1 _endpos__2_ _startpos__1_ ldi xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0704 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_, ttv_result) _menhir_cell1_ty _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined2, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _1_inlined2) = ((), (), _endpos, _v, ()) in
        let _v = _menhir_action_327 _1 _1_inlined1 _1_inlined2 _2_inlined1 _2_inlined2 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0700 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_, ttv_result) _menhir_cell1_ty _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined2, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _1_inlined2) = ((), (), _endpos, _v, ()) in
        let _v = _menhir_action_328 _1 _1_inlined1 _1_inlined2 _2_inlined1 _2_inlined2 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0699 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_UNREACHABLE _menhir_cell0_LPAR _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_UNREACHABLE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _3) = ((), (), _endpos, _v, ()) in
        let _v = _menhir_action_336 _1 _2_inlined1 _3 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0698 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_nonempty_list_catcher_, ttv_result) _menhir_cell1_end_semicolon -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_nonempty_list_catcher_ (_menhir_stack, _, c) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _3) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_297 _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ c xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0696 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_nonempty_list_catcher_, ttv_result) _menhir_cell1_OTHERWISE, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_end_semicolon -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined3, _) = _menhir_stack in
        let MenhirCell1_OTHERWISE (_menhir_stack, _, _, _) = _menhir_stack in
        let MenhirCell1_nonempty_list_catcher_ (_menhir_stack, _, c) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _1_inlined2, _3) = ((), (), _endpos, _v, (), ()) in
        let _v = _menhir_action_298 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _endpos__2_ _startpos__1_ c xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0694 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_nonempty_list_catcher_, ttv_result) _menhir_cell1_OTHERWISE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0694
        | _ ->
            _eRR ()
    
    and _menhir_run_0689 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHEN ->
            let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0680 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0689
        | Tokens.END | Tokens.OTHERWISE ->
            let MenhirCell1_ty (_menhir_stack, _, ty, _) = _menhir_stack in
            let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _) = _menhir_stack in
            let (_1, _4, _1_inlined1) = ((), (), _v) in
            let _v = _menhir_action_230 _1 _1_inlined1 _4 ty in
            _menhir_goto_nonempty_list_catcher_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_nonempty_list_catcher_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState0786 ->
            _menhir_run_0787 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0679 ->
            _menhir_run_0691 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0689 ->
            _menhir_run_0690 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0685 ->
            _menhir_run_0686 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0787 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_TRY, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_catcher_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.OTHERWISE ->
            let _menhir_s = MenhirState0787 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_OTHERWISE (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.ARROW ->
                let _menhir_s = MenhirState0789 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARROBASE_LOOPLIMIT ->
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0787
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0691 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_TRY, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_catcher_ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.OTHERWISE ->
            let _menhir_s = MenhirState0691 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_OTHERWISE (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.ARROW ->
                let _menhir_s = MenhirState0693 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARROBASE_LOOPLIMIT ->
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0691
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0690 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_ty, ttv_result) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, ty, _) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (_1, xs, _4) = ((), _v, ()) in
        let _v = _menhir_action_232 _1 _1_inlined1 _4 ty xs in
        _menhir_goto_nonempty_list_catcher_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_0686 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_ty, ttv_result) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_ty (_menhir_stack, _, ty, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (_1, xs, _4) = ((), _v, ()) in
        let _v = _menhir_action_233 _1 _1_inlined1 _4 ty x xs in
        _menhir_goto_nonempty_list_catcher_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_0685 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHEN ->
            let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0680 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0685
        | Tokens.END | Tokens.OTHERWISE ->
            let MenhirCell1_ty (_menhir_stack, _, ty, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _, x, _, _) = _menhir_stack in
            let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _) = _menhir_stack in
            let (_1, _4, _1_inlined1) = ((), (), _v) in
            let _v = _menhir_action_231 _1 _1_inlined1 _4 ty x in
            _menhir_goto_nonempty_list_catcher_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0678 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_TRY as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.CATCH ->
            let _menhir_s = MenhirState0679 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHEN ->
                _menhir_run_0680 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0677 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_THROW, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_340 _1 _endpos__2_ _startpos__1_ e xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0674 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_THROW, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_341 _1 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0673 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_RETURN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_302 _1 _endpos__2_ _startpos__1_ x xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0670 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_RETURN, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_301 _1 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0669 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_REPEAT, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _1_inlined2, _3) = ((), _endpos, _v, (), ()) in
        let _v = _menhir_action_338 _1 _1_inlined1 _1_inlined2 _2_inlined1 _3 _endpos__2_ _startpos__1_ expr xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0665 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_REPEAT, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _3) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_337 _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ expr xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0661 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_REPEAT as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNTIL ->
            let _menhir_s = MenhirState0662 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0660 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_PRINT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_333 _1 _1_inlined2 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0656 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_PRINT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_332 _1 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0655 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _endpos__1_inlined1_) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_343 _1 _1_inlined1 _2_inlined1 _endpos__1_inlined1_ _endpos__2_ _startpos__1_ xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0652 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, _2_inlined1, _, _endpos__2_inlined1_) = _menhir_stack in
        let MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_342 _1 _2_inlined1 _endpos__2_ _endpos__2_inlined1_ _startpos__1_ xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0651 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_PASS _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_PASS (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_300 _1 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0650 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
        let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _3) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_307 _1 _3 _endpos__2_ _startpos__1_ decl_item x xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0647 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_COMMA, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_loption_plist_expr__ _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
        let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
        let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _3, _3_inlined1, _5) = ((), (), _endpos, _v, (), (), ()) in
        let _v = _menhir_action_321 _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0641 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _endpos__3_inlined2_) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
        let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _3, _3_inlined1) = ((), (), _endpos, _v, (), ()) in
        let _v = _menhir_action_320 _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0637 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_inlined2_) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
        let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _3, _3_inlined1) = ((), (), _endpos, _v, (), ()) in
        let _v = _menhir_action_319 _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0636 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_s_else, ttv_result) _menhir_cell1_end_semicolon -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_s_else (_menhir_stack, _, s2, _) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _3) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_289 _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ e s2 xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0632 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_ELSE -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_ELSE (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, _endpos__1_inlined1_, _1_inlined1) = ((), _endpos, _v) in
        let _v = _menhir_action_414 _1 _1_inlined1 in
        _menhir_goto_s_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined1_ _v _menhir_s _tok
    
    and _menhir_goto_s_else : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState0862 ->
            _menhir_run_0863 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0626 ->
            _menhir_run_0634 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0630 ->
            _menhir_run_0633 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0634 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_s_else (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0634
        | _ ->
            _eRR ()
    
    and _menhir_run_0633 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_s2_, s2) = ((), (), _endpos, _v) in
        let _v = _menhir_action_412 _1 _1_inlined1 _3 _endpos_s2_ _startpos__1_ e s2 in
        _menhir_goto_s_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_s2_ _v _menhir_s _tok
    
    and _menhir_run_0630 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ELSIF ->
            _menhir_run_0627 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0630
        | Tokens.ELSE ->
            _menhir_run_0631 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0630
        | Tokens.END ->
            let _v_0 =
              let _endpos__0_ = _endpos in
              _menhir_action_413 _endpos__0_
            in
            _menhir_run_0633 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v_0 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0626 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ELSIF ->
            _menhir_run_0627 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0626
        | Tokens.ELSE ->
            _menhir_run_0631 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0626
        | Tokens.END ->
            let _v_0 =
              let _endpos__0_ = _endpos in
              _menhir_action_413 _endpos__0_
            in
            _menhir_run_0634 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v_0 MenhirState0626 _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0625 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, rhs, _, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, fld, _, _) = _menhir_stack in
        let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
        let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_2_inlined1, _endpos_xs_, xs, _4) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_315 _1_inlined1 _2_inlined1 _4 _endpos__2_ _endpos_args_ _startpos_name_ args fld name rhs xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0620 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, rhs, _, _) = _menhir_stack in
        let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
        let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_2_inlined1, _endpos_xs_, xs, _4, _2_inlined2) = ((), _endpos, _v, (), ()) in
        let _v = _menhir_action_318 _1_inlined1 _1_inlined3 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos_args_ _startpos_name_ args name rhs x xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0610 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_loption_plist_expr__, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, rhs, _, _) = _menhir_stack in
        let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
        let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_2_inlined1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_312 _1_inlined1 _2_inlined1 _endpos__2_ _endpos_args_ _startpos_name_ args name rhs xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0606 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_loption_plist_expr__ _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _) = _menhir_stack in
        let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_305 _1_inlined1 _endpos__2_ _startpos_name_ args name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0600 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, rhs, _, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, fld, _, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _endpos__3_) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_2_inlined1, _endpos_xs_, xs, _4) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_314 _1_inlined1 _2_inlined1 _4 _endpos__2_ _endpos__3_ _startpos_name_ fld name rhs xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0595 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, rhs, _, _) = _menhir_stack in
        let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _endpos__3_) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_2_inlined1, _endpos_xs_, xs, _4, _2_inlined2) = ((), _endpos, _v, (), ()) in
        let _v = _menhir_action_317 _1_inlined1 _1_inlined3 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos__3_ _startpos_name_ name rhs x xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0585 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, rhs, _, _) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _endpos__3_) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_2_inlined1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_311 _1_inlined1 _2_inlined1 _endpos__2_ _endpos__3_ _startpos_name_ name rhs xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0581 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_304 _1_inlined1 _endpos__2_ _startpos_name_ name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0577 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, rhs, _, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, fld, _, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_2_inlined1, _endpos_xs_, xs, _4) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_313 _2_inlined1 _4 _endpos__2_ _endpos__3_ _startpos_name_ fld name rhs xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0572 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, rhs, _, _) = _menhir_stack in
        let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined2) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_2_inlined1, _endpos_xs_, xs, _4, _2_inlined2) = ((), _endpos, _v, (), ()) in
        let _v = _menhir_action_316 _1_inlined2 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos__3_ _startpos_name_ name rhs x xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0562 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, rhs, _, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_2_inlined1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_310 _2_inlined1 _endpos__2_ _endpos__3_ _startpos_name_ name rhs xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0558 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_303 _endpos__2_ _startpos_name_ name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0557 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOWNTO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_end_semicolon -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
        let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
        let MenhirCell1_DOWNTO (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
        let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _1_inlined1, _3, _8) = ((), _endpos, _v, (), (), ()) in
        let _v = _menhir_action_295 _1 _1_inlined1 _1_inlined2 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0555 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOWNTO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0555
        | _ ->
            _eRR ()
    
    and _menhir_run_0553 : type  ttv_stack ttv_result. (((((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOWNTO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_end_semicolon -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined3, _) = _menhir_stack in
        let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
        let MenhirCell1_DOWNTO (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
        let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _1_inlined2, _1_inlined1, _3, _8) = ((), _endpos, _v, (), (), (), ()) in
        let _v = _menhir_action_296 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0551 : type  ttv_stack ttv_result. ((((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOWNTO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0551
        | _ ->
            _eRR ()
    
    and _menhir_run_0545 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_TO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_end_semicolon -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
        let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
        let MenhirCell1_TO (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
        let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _1_inlined1, _3, _8) = ((), _endpos, _v, (), (), ()) in
        let _v = _menhir_action_293 _1 _1_inlined1 _1_inlined2 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0543 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_TO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0543
        | _ ->
            _eRR ()
    
    and _menhir_run_0541 : type  ttv_stack ttv_result. (((((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_TO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_end_semicolon -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined3, _) = _menhir_stack in
        let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2_inlined1, _, _) = _menhir_stack in
        let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, end_e, _, _) = _menhir_stack in
        let MenhirCell1_TO (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, start_e, _, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, index_name, _, _) = _menhir_stack in
        let MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _1_inlined2, _1_inlined1, _3, _8) = ((), _endpos, _v, (), (), (), ()) in
        let _v = _menhir_action_294 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2_inlined1 _3 _8 _endpos__2_ _startpos__1_ end_e index_name start_e xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0539 : type  ttv_stack ttv_result. ((((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_TO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0539
        | _ ->
            _eRR ()
    
    and _menhir_run_0538 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_DEBUG _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_335 _1 _1_inlined2 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0534 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_DEBUG _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_334 _1 _endpos__2_ _startpos__1_ xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0533 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
        let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _3) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_308 _1 _3 _endpos__2_ _startpos__1_ decl_item x xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0530 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_COMMA, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_loption_plist_expr__ _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
        let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
        let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _3, _3_inlined1, _5) = ((), (), _endpos, _v, (), (), ()) in
        let _v = _menhir_action_324 _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0524 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell0_RPAR (_menhir_stack, _endpos__3_inlined2_) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
        let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _3, _3_inlined1) = ((), (), _endpos, _v, (), ()) in
        let _v = _menhir_action_323 _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0520 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR _menhir_cell0_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_SEMI_COLON (_menhir_stack, _endpos__2_) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_inlined2_) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
        let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _endpos_xs_, xs, _3, _3_inlined1) = ((), (), _endpos, _v, (), ()) in
        let _v = _menhir_action_322 _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0519 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_CASE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OF, ttv_result) _menhir_cell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__, ttv_result) _menhir_cell1_end_semicolon -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell1_OF (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
        let MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _3) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_290 _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ expr xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0515 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_OTHERWISE -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_OTHERWISE (_menhir_stack, _, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _endpos__1_inlined2_) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_pattern_ (_menhir_stack, _, _1_inlined1, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2, _4, _endpos__1_inlined3_, _1_inlined3, desc) = ((), (), (), _endpos, _v, ()) in
        let _v = _menhir_action_205 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _endpos__1_inlined3_ _endpos_desc_ _startpos__1_ _startpos__1_inlined1_ _startpos_desc_ desc in
        _menhir_goto_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState1000 ->
            _menhir_run_1001 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0472 ->
            _menhir_run_0517 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | MenhirState0512 ->
            _menhir_run_0516 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0506 ->
            _menhir_run_0510 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1001 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_CASE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_OF as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1001
        | _ ->
            _eRR ()
    
    and _menhir_run_0517 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_CASE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OF as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0517
        | _ ->
            _eRR ()
    
    and _menhir_run_0516 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, ttv_result) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _endpos__1_inlined2_) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_pattern_ (_menhir_stack, _, _1_inlined1, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _4, l) = ((), (), _v) in
        let _v = _menhir_action_207 _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined1_ l in
        _menhir_goto_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_0510 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ARROW, ttv_result) _menhir_cell1_nonempty_list_stmt_ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined3, _endpos__1_inlined3_) = _menhir_stack in
        let MenhirCell1_ARROW (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2, _, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_pattern_ (_menhir_stack, _, _1_inlined1, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _4, _1_inlined2, l) = ((), (), (), _v) in
        let _v = _menhir_action_208 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _4 _endpos__1_inlined1_ _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined1_ l in
        _menhir_goto_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_0512 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_pattern_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHEN ->
            let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0512
        | Tokens.OTHERWISE ->
            let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState0512 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_OTHERWISE (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.ARROW ->
                let _menhir_s = MenhirState0514 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARROBASE_LOOPLIMIT ->
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.END ->
            let MenhirCell1_separated_nonempty_list_COMMA_pattern_ (_menhir_stack, _, _1_inlined1, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
            let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _4, _1_inlined2, _endpos__1_inlined2_) = ((), (), _v, _endpos) in
            let _v = _menhir_action_203 _1 _1_inlined1 _1_inlined2 _4 _endpos__1_inlined1_ _endpos__1_inlined2_ _startpos__1_ _startpos__1_inlined1_ in
            _menhir_goto_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0473 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0473 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0038 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0162 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0163 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0164 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0166 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MASK_LIT _v ->
            _menhir_run_0168 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0169 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LEQ ->
            _menhir_run_0170 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LBRACE ->
            _menhir_run_0172 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0173 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0174 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0186 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.GEQ ->
            _menhir_run_0218 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0220 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0221 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0223 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0509 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ARROW, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_OTHERWISE -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_OTHERWISE (_menhir_stack, _, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined3, _endpos__1_inlined3_) = _menhir_stack in
        let MenhirCell1_ARROW (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, _2, _, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_pattern_ (_menhir_stack, _, _1_inlined1, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
        let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _2_inlined1, _4, _1_inlined2, _1_inlined4, _endpos__1_inlined4_, desc) = ((), (), (), (), _v, _endpos, ()) in
        let _v = _menhir_action_206 _1 _1_inlined1 _1_inlined2 _1_inlined3 _1_inlined4 _2 _2_inlined1 _4 _endpos__1_inlined1_ _endpos__1_inlined3_ _endpos__1_inlined4_ _endpos_desc_ _startpos__1_ _startpos__1_inlined1_ _startpos_desc_ desc in
        _menhir_goto_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_0506 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_pattern_, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ARROW as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.WHEN ->
            let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
            _menhir_run_0473 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0506
        | Tokens.OTHERWISE ->
            let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState0506 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_OTHERWISE (_menhir_stack, _menhir_s, _startpos, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.ARROW ->
                let _menhir_s = MenhirState0508 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARROBASE_LOOPLIMIT ->
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.END ->
            let MenhirCell1_ARROW (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, _2, _, _) = _menhir_stack in
            let MenhirCell1_separated_nonempty_list_COMMA_pattern_ (_menhir_stack, _, _1_inlined1, _startpos__1_inlined1_, _endpos__1_inlined1_) = _menhir_stack in
            let MenhirCell1_WHEN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _4, _1_inlined2, _endpos__1_inlined3_, _1_inlined3) = ((), (), (), _endpos, _v) in
            let _v = _menhir_action_204 _1 _1_inlined1 _1_inlined2 _1_inlined3 _2 _4 _endpos__1_inlined1_ _endpos__1_inlined3_ _startpos__1_ _startpos__1_inlined1_ in
            _menhir_goto_nlist_opt_terminated_annotated_case_alt__annotated_case_otherwise__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0505 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_ASSERT, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_ASSERT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_306 _1 _endpos__2_ _startpos__1_ e xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0504 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR _menhir_cell0_REPEAT, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, cond, _, _) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
        let MenhirCell0_REPEAT (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ARROBASE_LOOPLIMIT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _3, _5) = ((), _endpos, _v, (), ()) in
        let _v = _menhir_action_339 _1 _1_inlined2 _3 _5 _endpos__2_ _startpos__1_ cond x xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0500 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR _menhir_cell0_REPEAT as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNTIL ->
            let _menhir_s = MenhirState0501 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0498 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_lexpr, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SEMI_COLON -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_SEMI_COLON (_menhir_stack, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_lexpr (_menhir_stack, _menhir_s, le, _startpos_le_) = _menhir_stack in
        let (_2_inlined1, _endpos_xs_, xs) = ((), _endpos, _v) in
        let _v = _menhir_action_309 _2_inlined1 _endpos__2_ _startpos_le_ e le xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0493 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR _menhir_cell0_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_end_semicolon -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_end_semicolon (_menhir_stack, _, _, _endpos__2_) = _menhir_stack in
        let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
        let MenhirCell1_DO (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, cond, _, _) = _menhir_stack in
        let MenhirCell0_WHILE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ARROBASE_LOOPLIMIT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_xs_, xs, _3, _5) = ((), _endpos, _v, (), ()) in
        let _v = _menhir_action_299 _1 _1_inlined2 _3 _5 _endpos__2_ _startpos__1_ cond x xs in
        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0488 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR _menhir_cell0_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DO as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.END ->
            _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0488
        | _ ->
            _eRR ()
    
    and _menhir_run_0322 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_IN _menhir_cell0_BNOT _menhir_cell0_LBRACE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_BNOT (_menhir_stack, _startpos__1_) = _menhir_stack in
            let MenhirCell1_IN (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
            let (_1, _2, _1_inlined2, _endpos__3_, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, _endpos_0, _endpos, _startpos) in
            let _v = _menhir_action_061 _1 _1_inlined2 _2 _endpos__1_inlined2_ _endpos__3_ _startpos__1_ _startpos__1_inlined2_ _startpos_sub_expr_ sub_expr in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_sub_expr_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0318 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_IN _menhir_cell0_LBRACE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_IN (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
            let (_2, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _endpos__3_) = ((), _endpos, _startpos, _v, _endpos_0) in
            let _v = _menhir_action_060 _1_inlined1 _2 _endpos__1_inlined1_ _endpos__3_ _startpos__1_inlined1_ _startpos_sub_expr_ sub_expr in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_sub_expr_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0314 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_pattern -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_pattern (_menhir_stack, _, x, _, _) = _menhir_stack in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_2, _endpos__3_, li) = ((), _endpos_0, _v) in
            let _v = _menhir_action_408 _2 _endpos__3_ _startpos__1_ li x in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0310 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LBRACE (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _endpos__3_) = (_endpos, _startpos, _v, _endpos_0) in
            let _v = _menhir_action_410 _1_inlined1 _endpos__1_inlined1_ _startpos__1_inlined1_ in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0269 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern _menhir_cell0_BNOT _menhir_cell0_LBRACE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_BNOT (_menhir_stack, _startpos__1_) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
            let (_1, _2, _1_inlined2, _endpos__3_, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), (), _v, _endpos_0, _endpos, _startpos) in
            let _v = _menhir_action_116 _1 _1_inlined2 _2 _endpos__1_inlined2_ _endpos__3_ _startpos__1_ _startpos__1_inlined2_ _startpos_sub_expr_ sub_expr in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_sub_expr_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0265 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern _menhir_cell0_LBRACE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
            let (_2, _endpos__1_inlined1_, _startpos__1_inlined1_, _1_inlined1, _endpos__3_) = ((), _endpos, _startpos, _v, _endpos_0) in
            let _v = _menhir_action_115 _1_inlined1 _2 _endpos__1_inlined1_ _endpos__3_ _startpos__1_inlined1_ _startpos_sub_expr_ sub_expr in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_sub_expr_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0228 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_pattern -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_pattern (_menhir_stack, _menhir_s, x, _startpos_x_, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_436 x xs in
        _menhir_goto_separated_nonempty_list_COMMA_pattern_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _startpos_x_ _v _menhir_s _tok
    
    and _menhir_run_0224 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LBRACE (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _1_inlined2, _endpos__3_, _endpos__1_inlined2_, _startpos__1_inlined2_) = ((), _v, _endpos_0, _endpos, _startpos) in
            let _v = _menhir_action_411 _1 _1_inlined2 _endpos__1_inlined2_ _endpos__3_ _startpos__1_ _startpos__1_inlined2_ in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0271 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0271 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0273 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0273 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0275 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell0_GEQ (_menhir_stack, _startpos) in
        let _menhir_s = MenhirState0275 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0277 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0277
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0277
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0277
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0277
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0277
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_117 _1 _2 _endpos__1_ _startpos__1_ _startpos_sub_expr_ sub_expr in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_sub_expr_ _v _menhir_s _tok
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0277
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0277
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0277
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0277
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0277
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0277
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0277
        | _ ->
            _eRR ()
    
    and _menhir_run_0280 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0280 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0282 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_s = MenhirState0283 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, _endpos_x_, x) = ((), _endpos, _v) in
            let _v = _menhir_action_110 _2 _endpos_x_ _startpos_e_ e x in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0287 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0287 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0289 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0289 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0291 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0291 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0293 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0293 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0295 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0295 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0297 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0297 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0299 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0299 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0301 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0301
        | Tokens.REAL ->
            _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0301
        | Tokens.LPAR ->
            _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0301
        | Tokens.LBRACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0302
            | Tokens.STRING_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0302
            | Tokens.REAL_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0302
            | Tokens.RBRACE ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
                let (_startpos__1_, _2, _endpos__3_) = (_startpos, (), _endpos) in
                let _v = _menhir_action_113 _2 _endpos__3_ _startpos__1_ _startpos_sub_expr_ sub_expr in
                _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_sub_expr_ _v _menhir_s _tok
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0302
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0302
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0302
            | Tokens.INT_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0302
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0302
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0302
            | Tokens.BOOL_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0302
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0302
            | Tokens.BITVECTOR_LIT _v ->
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0301, _startpos) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0302
            | _ ->
                _eRR ())
        | Tokens.INTEGER ->
            _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0301
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0301
        | Tokens.BOOLEAN ->
            _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0301
        | Tokens.BITS ->
            _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0301
        | Tokens.BIT ->
            _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0301
        | Tokens.ARRAY ->
            _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0301
        | _ ->
            _eRR ()
    
    and _menhir_run_0307 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState0307 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0229 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0230 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0232 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0234 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0236 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0238 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0240 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0242 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0244 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0247 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0249 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0251 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0253 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0255 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0258 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0260 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0263 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0271 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0273 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0275 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0277 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0280 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0282 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0287 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0289 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0291 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0293 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0295 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0297 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0299 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0301 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0307 _menhir_stack _menhir_lexbuf _menhir_lexer
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let (_endpos_expr_pattern_, _startpos_expr_pattern_, expr_pattern) = (_endpos, _startpos, _v) in
            let _v = _menhir_action_403 _endpos_expr_pattern_ _startpos_expr_pattern_ expr_pattern in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_pattern_ _startpos_expr_pattern_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0110 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_IMPL (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0110 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0106 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_GT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0106 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0108 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0108 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0112 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0112
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0112
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0112
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0112
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0112
        | Tokens.MASK_LIT _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
            let (_endpos__1_, _startpos__1_, _1, _2) = (_endpos, _startpos, _v, ()) in
            let _v = _menhir_action_062 _1 _2 _endpos__1_ _startpos__1_ _startpos_sub_expr_ sub_expr in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos_sub_expr_ _v _menhir_s _tok
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0112
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0112
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0112
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0112
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0112
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0112
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_EQ_OP (_menhir_stack, _menhir_s) in
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0112
        | _ ->
            _eRR ()
    
    and _menhir_run_0098 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_EOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0098 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0066 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_DOT (_menhir_stack, _menhir_s) in
            let _menhir_s = MenhirState0067 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
            let (_2, _endpos_x_, x) = ((), _endpos, _v) in
            let _v = _menhir_action_055 _2 _endpos_x_ _startpos_e_ e x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _startpos_e_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0085 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIVRM (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0085 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0087 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_DIV (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0087 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0074 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_CONCAT (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0074 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0100 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_COLON_COLON (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0100 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0115 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BOR (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0115 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0117 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BEQ (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0117 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0119 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_BAND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0119 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0121 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.STRING ->
            let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
            _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0121
        | Tokens.REAL ->
            let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
            _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0121
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
            _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0121
        | Tokens.LBRACE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0122
            | Tokens.STRING_LIT _v ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0122
            | Tokens.REAL_LIT _v ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0122
            | Tokens.RBRACE ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                let MenhirCell1_expr (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
                let (_startpos__1_, _2, _endpos__3_) = (_startpos, (), _endpos) in
                let _v = _menhir_action_058 _2 _endpos__3_ _startpos__1_ _startpos_sub_expr_ sub_expr in
                _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_sub_expr_ _v _menhir_s _tok
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0122
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0122
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0122
            | Tokens.INT_LIT _v ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0122
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0122
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0122
            | Tokens.BOOL_LIT _v ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0122
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0122
            | Tokens.BITVECTOR_LIT _v ->
                let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
                let _menhir_stack = MenhirCell1_LBRACE (_menhir_stack, MenhirState0121, _startpos) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0122
            | _ ->
                _eRR ())
        | Tokens.INTEGER ->
            let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
            _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0121
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
            _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0121
        | Tokens.BOOLEAN ->
            let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
            _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0121
        | Tokens.BITS ->
            let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
            _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0121
        | Tokens.BIT ->
            let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
            _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0121
        | Tokens.ARRAY ->
            let _menhir_stack = MenhirCell1_AS (_menhir_stack, _menhir_s) in
            _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0121
        | _ ->
            _eRR ()
    
    and _menhir_run_0102 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_AND (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0102 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0837 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_LET as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0838
            | Tokens.STRING_LIT _v_0 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0838
            | Tokens.REAL_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0838
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0838
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0838
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0838
            | Tokens.INT_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0838
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0838
            | Tokens.IDENTIFIER _v_3 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                    _menhir_run_0019 _menhir_stack _menhir_lexbuf _menhir_lexer
                | Tokens.LBRACE ->
                    let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.UNKNOWN ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0840
                    | Tokens.STRING_LIT _v_5 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState0840
                    | Tokens.REAL_LIT _v_6 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState0840
                    | Tokens.RBRACE ->
                        let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.LPAR ->
                            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.UNKNOWN ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0842
                            | Tokens.STRING_LIT _v_9 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState0842
                            | Tokens.RPAR ->
                                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                                let _tok = _menhir_lexer _menhir_lexbuf in
                                (match (_tok : MenhirBasics.token) with
                                | Tokens.SEMI_COLON ->
                                    let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
                                    let _tok = _menhir_lexer _menhir_lexbuf in
                                    (match (_tok : MenhirBasics.token) with
                                    | Tokens.EOF ->
                                        let MenhirCell1_LET (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                                        let (_1, _2, _2_inlined1, _3, _3_inlined1, _startpos_name_, name, _endpos__2_inlined2_, lhs, _endpos__3_inlined2_) = ((), (), (), (), (), _startpos, _v_3, _endpos_11, _v, _endpos_10) in
                                        let _v = _menhir_action_374 _1 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                                        _menhir_goto_opn _menhir_stack _v
                                    | _ ->
                                        _eRR ())
                                | _ ->
                                    _eRR ())
                            | Tokens.REAL_LIT _v_12 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState0842
                            | Tokens.NOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0842
                            | Tokens.MINUS ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0842
                            | Tokens.LPAR ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0842
                            | Tokens.INT_LIT _v_13 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState0842
                            | Tokens.IF ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0842
                            | Tokens.IDENTIFIER _v_14 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14 MenhirState0842
                            | Tokens.BOOL_LIT _v_15 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15 MenhirState0842
                            | Tokens.BNOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0842
                            | Tokens.BITVECTOR_LIT _v_16 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0840, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_16 MenhirState0842
                            | _ ->
                                _eRR ())
                        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                            let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                            let _v_17 =
                              let (_endpos__3_, _endpos_desc_, _startpos_desc_, desc) = (_endpos_7, _endpos, _startpos, _v_3) in
                              _menhir_action_067 _endpos__3_ _endpos_desc_ _startpos_desc_ desc
                            in
                            _menhir_run_0856 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_7 _startpos_4 _v_17 MenhirState0838 _tok
                        | _ ->
                            _eRR ())
                    | Tokens.NOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0840
                    | Tokens.MINUS ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0840
                    | Tokens.LPAR ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0840
                    | Tokens.INT_LIT _v_18 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_18 MenhirState0840
                    | Tokens.IF ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0840
                    | Tokens.IDENTIFIER _v_19 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0196 _menhir_stack _menhir_lexbuf _menhir_lexer _v_19 MenhirState0840
                    | Tokens.COMMA ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0840) in
                        let _menhir_s = MenhirState0850 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.UNKNOWN ->
                            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.STRING_LIT _v ->
                            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.REAL_LIT _v ->
                            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.NOT ->
                            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.MINUS ->
                            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.LPAR ->
                            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.INT_LIT _v ->
                            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.IF ->
                            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BOOL_LIT _v ->
                            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BNOT ->
                            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.BITVECTOR_LIT _v ->
                            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | Tokens.BOOL_LIT _v_26 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_26 MenhirState0840
                    | Tokens.BNOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0840
                    | Tokens.BITVECTOR_LIT _v_27 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0838, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_27 MenhirState0840
                    | _ ->
                        _eRR ())
                | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _v_28 =
                      let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v_3) in
                      _menhir_action_020 _1 _endpos__1_ _startpos__1_
                    in
                    _menhir_run_0856 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v_28 MenhirState0838 _tok
                | _ ->
                    _eRR ())
            | Tokens.BOOL_LIT _v_29 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_29 MenhirState0838
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0838
            | Tokens.BITVECTOR_LIT _v_30 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_30 MenhirState0838
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0856 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_LET, _menhir_box_opn) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
                let MenhirCell1_LET (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _endpos__2_inlined1_, x, _3) = ((), (), _endpos_0, _v, ()) in
                let _v = _menhir_action_362 _1 _2 _3 _endpos__2_inlined1_ _startpos__1_ decl_item x in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0856
        | _ ->
            _eRR ()
    
    and _menhir_run_0755 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_VAR as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_VAR (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _endpos__2_inlined1_, ldi) = ((), (), _endpos, _v) in
                let _v = _menhir_action_380 _1 _2 _endpos__2_inlined1_ _startpos__1_ ldi in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0758
            | Tokens.STRING_LIT _v_0 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0758
            | Tokens.REAL_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0758
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0758
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0758
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0758
            | Tokens.INT_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0758
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0758
            | Tokens.IDENTIFIER _v_3 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                    _menhir_run_0019 _menhir_stack _menhir_lexbuf _menhir_lexer
                | Tokens.LBRACE ->
                    let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.UNKNOWN ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0760
                    | Tokens.STRING_LIT _v_5 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState0760
                    | Tokens.REAL_LIT _v_6 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState0760
                    | Tokens.RBRACE ->
                        let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.LPAR ->
                            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.UNKNOWN ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0762
                            | Tokens.STRING_LIT _v_9 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState0762
                            | Tokens.RPAR ->
                                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                                let _tok = _menhir_lexer _menhir_lexbuf in
                                (match (_tok : MenhirBasics.token) with
                                | Tokens.SEMI_COLON ->
                                    let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
                                    let _tok = _menhir_lexer _menhir_lexbuf in
                                    (match (_tok : MenhirBasics.token) with
                                    | Tokens.EOF ->
                                        let MenhirCell1_VAR (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                                        let (_1, _2, _2_inlined1, _3, _3_inlined1, _startpos_name_, name, _endpos__2_inlined2_, lhs, _endpos__3_inlined2_) = ((), (), (), (), (), _startpos, _v_3, _endpos_11, _v, _endpos_10) in
                                        let _v = _menhir_action_384 _1 _2 _2_inlined1 _3 _3_inlined1 _endpos__2_inlined2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                                        _menhir_goto_opn _menhir_stack _v
                                    | _ ->
                                        _eRR ())
                                | _ ->
                                    _eRR ())
                            | Tokens.REAL_LIT _v_12 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState0762
                            | Tokens.NOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0762
                            | Tokens.MINUS ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0762
                            | Tokens.LPAR ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0762
                            | Tokens.INT_LIT _v_13 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState0762
                            | Tokens.IF ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0762
                            | Tokens.IDENTIFIER _v_14 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14 MenhirState0762
                            | Tokens.BOOL_LIT _v_15 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15 MenhirState0762
                            | Tokens.BNOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0762
                            | Tokens.BITVECTOR_LIT _v_16 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0760, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_16 MenhirState0762
                            | _ ->
                                _eRR ())
                        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                            let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                            let _v_17 =
                              let (_endpos__3_, _endpos_desc_, _startpos_desc_, desc) = (_endpos_7, _endpos, _startpos, _v_3) in
                              _menhir_action_067 _endpos__3_ _endpos_desc_ _startpos_desc_ desc
                            in
                            _menhir_run_0776 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_7 _startpos_4 _v_17 MenhirState0758 _tok
                        | _ ->
                            _eRR ())
                    | Tokens.NOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0760
                    | Tokens.MINUS ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0760
                    | Tokens.LPAR ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0760
                    | Tokens.INT_LIT _v_18 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_18 MenhirState0760
                    | Tokens.IF ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0760
                    | Tokens.IDENTIFIER _v_19 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0196 _menhir_stack _menhir_lexbuf _menhir_lexer _v_19 MenhirState0760
                    | Tokens.COMMA ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0760) in
                        let _menhir_s = MenhirState0770 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.UNKNOWN ->
                            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.STRING_LIT _v ->
                            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.REAL_LIT _v ->
                            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.NOT ->
                            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.MINUS ->
                            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.LPAR ->
                            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.INT_LIT _v ->
                            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.IF ->
                            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BOOL_LIT _v ->
                            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BNOT ->
                            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.BITVECTOR_LIT _v ->
                            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | Tokens.BOOL_LIT _v_26 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_26 MenhirState0760
                    | Tokens.BNOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0760
                    | Tokens.BITVECTOR_LIT _v_27 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0758, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_27 MenhirState0760
                    | _ ->
                        _eRR ())
                | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _v_28 =
                      let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v_3) in
                      _menhir_action_020 _1 _endpos__1_ _startpos__1_
                    in
                    _menhir_run_0776 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v_28 MenhirState0758 _tok
                | _ ->
                    _eRR ())
            | Tokens.BOOL_LIT _v_29 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_29 MenhirState0758
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0758
            | Tokens.BITVECTOR_LIT _v_30 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_30 MenhirState0758
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0776 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_decl_item (_menhir_stack, _, ldi) = _menhir_stack in
                let MenhirCell1_VAR (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined1, _endpos__2_inlined2_) = ((), (), _v, (), _endpos_0) in
                let _v = _menhir_action_381 _1 _1_inlined1 _2 _2_inlined1 _endpos__2_inlined2_ _startpos__1_ ldi in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0776
        | _ ->
            _eRR ()
    
    and _menhir_run_0705 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_VAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.IDENTIFIER _v_0 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0706
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0706
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, ldi) = ((), _endpos, _v) in
                let _v = _menhir_action_270 _1 _endpos__2_ _startpos__1_ ldi in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0708
            | Tokens.STRING_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0708
            | Tokens.REAL_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0708
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0708
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0708
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0708
            | Tokens.INT_LIT _v_3 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState0708
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0708
            | Tokens.IDENTIFIER _v_4 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                    _menhir_run_0019 _menhir_stack _menhir_lexbuf _menhir_lexer
                | Tokens.LBRACE ->
                    let _startpos_5 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.UNKNOWN ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0710
                    | Tokens.STRING_LIT _v_6 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState0710
                    | Tokens.REAL_LIT _v_7 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState0710
                    | Tokens.RBRACE ->
                        let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.LPAR ->
                            let _startpos_9 = _menhir_lexbuf.Lexing.lex_start_p in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.UNKNOWN ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0712
                            | Tokens.STRING_LIT _v_10 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState0712
                            | Tokens.RPAR ->
                                let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
                                let _tok = _menhir_lexer _menhir_lexbuf in
                                (match (_tok : MenhirBasics.token) with
                                | Tokens.SEMI_COLON ->
                                    let _endpos_12 = _menhir_lexbuf.Lexing.lex_curr_p in
                                    let _tok = _menhir_lexer _menhir_lexbuf in
                                    (match (_tok : MenhirBasics.token) with
                                    | Tokens.WHILE ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.VAR ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.UNREACHABLE ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.TRY ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.THROW ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.RETURN ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.REPEAT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.PRINT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.PRAGMA ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.PASS ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.MINUS ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.LPAR ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.LET ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.IF ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.IDENTIFIER _v_13 ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState0714
                                    | Tokens.FOR ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.DEBUG ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.CONSTANT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.CASE ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.ASSERT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.ARROBASE_LOOPLIMIT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0712, _endpos_11) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_12) in
                                        _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0714
                                    | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                                        let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                                        let (_1, _endpos__2_, _2_inlined1, _3, _3_inlined1, _startpos_name_, name, lhs, _endpos__3_inlined2_) = ((), _endpos_12, (), (), (), _startpos, _v_4, _v, _endpos_11) in
                                        let _v = _menhir_action_274 _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                                        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                                    | _ ->
                                        _eRR ())
                                | _ ->
                                    _eRR ())
                            | Tokens.REAL_LIT _v_14 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14 MenhirState0712
                            | Tokens.NOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0712
                            | Tokens.MINUS ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0712
                            | Tokens.LPAR ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0712
                            | Tokens.INT_LIT _v_15 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15 MenhirState0712
                            | Tokens.IF ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0712
                            | Tokens.IDENTIFIER _v_16 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_16 MenhirState0712
                            | Tokens.BOOL_LIT _v_17 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_17 MenhirState0712
                            | Tokens.BNOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0712
                            | Tokens.BITVECTOR_LIT _v_18 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0710, _endpos_8) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_9) in
                                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_18 MenhirState0712
                            | _ ->
                                _eRR ())
                        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                            let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                            let _v_19 =
                              let (_endpos__3_, _endpos_desc_, _startpos_desc_, desc) = (_endpos_8, _endpos, _startpos, _v_4) in
                              _menhir_action_067 _endpos__3_ _endpos_desc_ _startpos_desc_ desc
                            in
                            _menhir_run_0726 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_8 _startpos_5 _v_19 MenhirState0708 _tok
                        | _ ->
                            _eRR ())
                    | Tokens.NOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0710
                    | Tokens.MINUS ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0710
                    | Tokens.LPAR ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0710
                    | Tokens.INT_LIT _v_20 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_20 MenhirState0710
                    | Tokens.IF ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0710
                    | Tokens.IDENTIFIER _v_21 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0196 _menhir_stack _menhir_lexbuf _menhir_lexer _v_21 MenhirState0710
                    | Tokens.COMMA ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0710) in
                        let _menhir_s = MenhirState0720 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.UNKNOWN ->
                            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.STRING_LIT _v ->
                            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.REAL_LIT _v ->
                            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.NOT ->
                            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.MINUS ->
                            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.LPAR ->
                            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.INT_LIT _v ->
                            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.IF ->
                            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BOOL_LIT _v ->
                            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BNOT ->
                            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.BITVECTOR_LIT _v ->
                            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | Tokens.BOOL_LIT _v_28 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_28 MenhirState0710
                    | Tokens.BNOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0710
                    | Tokens.BITVECTOR_LIT _v_29 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0708, _v_4, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_5) in
                        _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_29 MenhirState0710
                    | _ ->
                        _eRR ())
                | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _v_30 =
                      let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v_4) in
                      _menhir_action_020 _1 _endpos__1_ _startpos__1_
                    in
                    _menhir_run_0726 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v_30 MenhirState0708 _tok
                | _ ->
                    _eRR ())
            | Tokens.BOOL_LIT _v_31 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_31 MenhirState0708
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0708
            | Tokens.BITVECTOR_LIT _v_32 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_32 MenhirState0708
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0726 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0727
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0726, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0727
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_decl_item (_menhir_stack, _, ldi) = _menhir_stack in
                let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2_inlined1, _1_inlined1) = ((), _endpos_0, _v, ()) in
                let _v = _menhir_action_271 _1 _1_inlined1 _2_inlined1 _endpos__2_ _startpos__1_ ldi in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0726
        | _ ->
            _eRR ()
    
    and _menhir_run_0462 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_CONSTANT as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0463
            | Tokens.STRING_LIT _v_0 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0463
            | Tokens.REAL_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0463
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0463
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0463
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0463
            | Tokens.INT_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0463
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0463
            | Tokens.IDENTIFIER _v_3 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                    _menhir_run_0019 _menhir_stack _menhir_lexbuf _menhir_lexer
                | Tokens.LBRACE ->
                    let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.UNKNOWN ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0465
                    | Tokens.STRING_LIT _v_5 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState0465
                    | Tokens.REAL_LIT _v_6 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState0465
                    | Tokens.RBRACE ->
                        let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.LPAR ->
                            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.UNKNOWN ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0467
                            | Tokens.STRING_LIT _v_9 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState0467
                            | Tokens.RPAR ->
                                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                                let _tok = _menhir_lexer _menhir_lexbuf in
                                (match (_tok : MenhirBasics.token) with
                                | Tokens.SEMI_COLON ->
                                    let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
                                    let _tok = _menhir_lexer _menhir_lexbuf in
                                    (match (_tok : MenhirBasics.token) with
                                    | Tokens.WHILE ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.VAR ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.UNREACHABLE ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.TRY ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.THROW ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.RETURN ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.REPEAT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.PRINT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.PRAGMA ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.PASS ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.MINUS ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.LPAR ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.LET ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.IF ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.IDENTIFIER _v_12 ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState0469
                                    | Tokens.FOR ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.DEBUG ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.CONSTANT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.CASE ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.ASSERT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.ARROBASE_LOOPLIMIT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0467, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0469
                                    | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                                        let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                                        let (_1, _endpos__2_, _2_inlined1, _3, _3_inlined1, _startpos_name_, name, lhs, _endpos__3_inlined2_) = ((), _endpos_11, (), (), (), _startpos, _v_3, _v, _endpos_10) in
                                        let _v = _menhir_action_267 _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                                        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                                    | _ ->
                                        _eRR ())
                                | _ ->
                                    _eRR ())
                            | Tokens.REAL_LIT _v_13 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState0467
                            | Tokens.NOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0467
                            | Tokens.MINUS ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0467
                            | Tokens.LPAR ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0467
                            | Tokens.INT_LIT _v_14 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14 MenhirState0467
                            | Tokens.IF ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0467
                            | Tokens.IDENTIFIER _v_15 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15 MenhirState0467
                            | Tokens.BOOL_LIT _v_16 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_16 MenhirState0467
                            | Tokens.BNOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0467
                            | Tokens.BITVECTOR_LIT _v_17 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0465, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_17 MenhirState0467
                            | _ ->
                                _eRR ())
                        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                            let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                            let _v_18 =
                              let (_endpos__3_, _endpos_desc_, _startpos_desc_, desc) = (_endpos_7, _endpos, _startpos, _v_3) in
                              _menhir_action_067 _endpos__3_ _endpos_desc_ _startpos_desc_ desc
                            in
                            _menhir_run_0531 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_7 _startpos_4 _v_18 MenhirState0463 _tok
                        | _ ->
                            _eRR ())
                    | Tokens.NOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0465
                    | Tokens.MINUS ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0465
                    | Tokens.LPAR ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0465
                    | Tokens.INT_LIT _v_19 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_19 MenhirState0465
                    | Tokens.IF ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0465
                    | Tokens.IDENTIFIER _v_20 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0196 _menhir_stack _menhir_lexbuf _menhir_lexer _v_20 MenhirState0465
                    | Tokens.COMMA ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0465) in
                        let _menhir_s = MenhirState0525 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.UNKNOWN ->
                            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.STRING_LIT _v ->
                            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.REAL_LIT _v ->
                            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.NOT ->
                            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.MINUS ->
                            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.LPAR ->
                            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.INT_LIT _v ->
                            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.IF ->
                            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BOOL_LIT _v ->
                            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BNOT ->
                            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.BITVECTOR_LIT _v ->
                            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | Tokens.BOOL_LIT _v_27 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_27 MenhirState0465
                    | Tokens.BNOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0465
                    | Tokens.BITVECTOR_LIT _v_28 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0463, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_28 MenhirState0465
                    | _ ->
                        _eRR ())
                | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _v_29 =
                      let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v_3) in
                      _menhir_action_020 _1 _endpos__1_ _startpos__1_
                    in
                    _menhir_run_0531 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v_29 MenhirState0463 _tok
                | _ ->
                    _eRR ())
            | Tokens.BOOL_LIT _v_30 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_30 MenhirState0463
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0463
            | Tokens.BITVECTOR_LIT _v_31 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_31 MenhirState0463
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0531 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0532
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0531, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0532
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
                let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x, _3) = ((), _endpos_0, _v, ()) in
                let _v = _menhir_action_253 _1 _3 _endpos__2_ _startpos__1_ decl_item x in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0531
        | _ ->
            _eRR ()
    
    and _menhir_run_0433 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LET as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0434
            | Tokens.STRING_LIT _v_0 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState0434
            | Tokens.REAL_LIT _v_1 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0434
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0434
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0434
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0434
            | Tokens.INT_LIT _v_2 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0434
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0434
            | Tokens.IDENTIFIER _v_3 ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                    _menhir_run_0019 _menhir_stack _menhir_lexbuf _menhir_lexer
                | Tokens.LBRACE ->
                    let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.UNKNOWN ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0436
                    | Tokens.STRING_LIT _v_5 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_5 MenhirState0436
                    | Tokens.REAL_LIT _v_6 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_6 MenhirState0436
                    | Tokens.RBRACE ->
                        let _endpos_7 = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.LPAR ->
                            let _startpos_8 = _menhir_lexbuf.Lexing.lex_start_p in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.UNKNOWN ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0438
                            | Tokens.STRING_LIT _v_9 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState0438
                            | Tokens.RPAR ->
                                let _endpos_10 = _menhir_lexbuf.Lexing.lex_curr_p in
                                let _tok = _menhir_lexer _menhir_lexbuf in
                                (match (_tok : MenhirBasics.token) with
                                | Tokens.SEMI_COLON ->
                                    let _endpos_11 = _menhir_lexbuf.Lexing.lex_curr_p in
                                    let _tok = _menhir_lexer _menhir_lexbuf in
                                    (match (_tok : MenhirBasics.token) with
                                    | Tokens.WHILE ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.VAR ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.UNREACHABLE ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.TRY ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.THROW ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.RETURN ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.REPEAT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.PRINT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.PRAGMA ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.PASS ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.MINUS ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.LPAR ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.LET ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.IF ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.IDENTIFIER _v_12 ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState0440
                                    | Tokens.FOR ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.DEBUG ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.CONSTANT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.CASE ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.ASSERT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.ARROBASE_LOOPLIMIT ->
                                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                        let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0438, _endpos_10) in
                                        let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_11) in
                                        _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0440
                                    | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                                        let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                                        let (_1, _endpos__2_, _2_inlined1, _3, _3_inlined1, _startpos_name_, name, lhs, _endpos__3_inlined2_) = ((), _endpos_11, (), (), (), _startpos, _v_3, _v, _endpos_10) in
                                        let _v = _menhir_action_264 _1 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                                        _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                                    | _ ->
                                        _eRR ())
                                | _ ->
                                    _eRR ())
                            | Tokens.REAL_LIT _v_13 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState0438
                            | Tokens.NOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0438
                            | Tokens.MINUS ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0438
                            | Tokens.LPAR ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0438
                            | Tokens.INT_LIT _v_14 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_14 MenhirState0438
                            | Tokens.IF ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0438
                            | Tokens.IDENTIFIER _v_15 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15 MenhirState0438
                            | Tokens.BOOL_LIT _v_16 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_16 MenhirState0438
                            | Tokens.BNOT ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0438
                            | Tokens.BITVECTOR_LIT _v_17 ->
                                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                                let _menhir_stack = MenhirCell1_RBRACE (_menhir_stack, MenhirState0436, _endpos_7) in
                                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_8) in
                                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_17 MenhirState0438
                            | _ ->
                                _eRR ())
                        | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                            let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                            let _v_18 =
                              let (_endpos__3_, _endpos_desc_, _startpos_desc_, desc) = (_endpos_7, _endpos, _startpos, _v_3) in
                              _menhir_action_067 _endpos__3_ _endpos_desc_ _startpos_desc_ desc
                            in
                            _menhir_run_0648 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_7 _startpos_4 _v_18 MenhirState0434 _tok
                        | _ ->
                            _eRR ())
                    | Tokens.NOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0436
                    | Tokens.MINUS ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0436
                    | Tokens.LPAR ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0436
                    | Tokens.INT_LIT _v_19 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_19 MenhirState0436
                    | Tokens.IF ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0436
                    | Tokens.IDENTIFIER _v_20 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0196 _menhir_stack _menhir_lexbuf _menhir_lexer _v_20 MenhirState0436
                    | Tokens.COMMA ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0436) in
                        let _menhir_s = MenhirState0642 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.UNKNOWN ->
                            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.STRING_LIT _v ->
                            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.REAL_LIT _v ->
                            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.NOT ->
                            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.MINUS ->
                            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.LPAR ->
                            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.INT_LIT _v ->
                            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.IF ->
                            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BOOL_LIT _v ->
                            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BNOT ->
                            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.BITVECTOR_LIT _v ->
                            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | Tokens.BOOL_LIT _v_27 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_27 MenhirState0436
                    | Tokens.BNOT ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0436
                    | Tokens.BITVECTOR_LIT _v_28 ->
                        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0434, _v_3, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_4) in
                        _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_28 MenhirState0436
                    | _ ->
                        _eRR ())
                | Tokens.AND | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RDIV | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR ->
                    let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                    let _v_29 =
                      let (_endpos__1_, _startpos__1_, _1) = (_endpos, _startpos, _v_3) in
                      _menhir_action_020 _1 _endpos__1_ _startpos__1_
                    in
                    _menhir_run_0648 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v_29 MenhirState0434 _tok
                | _ ->
                    _eRR ())
            | Tokens.BOOL_LIT _v_30 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_30 MenhirState0434
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0434
            | Tokens.BITVECTOR_LIT _v_31 ->
                let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_31 MenhirState0434
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0648 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0649
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0648, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0649
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_decl_item (_menhir_stack, _, decl_item) = _menhir_stack in
                let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x, _3) = ((), _endpos_0, _v, ()) in
                let _v = _menhir_action_252 _1 _3 _endpos__2_ _startpos__1_ decl_item x in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0648
        | _ ->
            _eRR ()
    
    and _menhir_run_0381 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
            let _menhir_s = MenhirState0382 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_0362 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0367 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0368 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_417 x in
            _menhir_goto_separated_nonempty_list_COMMA_decl_item_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_separated_nonempty_list_COMMA_decl_item_ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState0382 ->
            _menhir_run_0383 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0374 ->
            _menhir_run_0375 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0383 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_decl_item -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_decl_item (_menhir_stack, _menhir_s, x) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_418 x xs in
        _menhir_goto_separated_nonempty_list_COMMA_decl_item_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0375 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_decl_item as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_decl_item_ (_menhir_stack, _menhir_s, _v) in
            let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
            let _menhir_s = MenhirState0377 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON ->
            let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_decl_item_ (_menhir_stack, _menhir_s, _v) in
            let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
            let _menhir_s = MenhirState0379 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COMMA | Tokens.EQ | Tokens.RPAR | Tokens.SEMI_COLON ->
            let MenhirCell1_decl_item (_menhir_stack, _, x) = _menhir_stack in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _) = _menhir_stack in
            let (_2, li) = ((), _v) in
            let _v = _menhir_action_011 _2 li x in
            _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0373 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_decl_item (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_s = MenhirState0374 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_0362 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0367 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0368 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1072 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_loption_braced_nclist_opt_typed_identifier___ (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.LPAR ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
            let _menhir_s = MenhirState1073 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.RPAR ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, _menhir_s, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EQ ->
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.IDENTIFIER _v ->
                        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.COLON_COLON ->
                            let _menhir_s = MenhirState1077 in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.STRING ->
                                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.REAL ->
                                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.LPAR ->
                                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.INTEGER ->
                                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.IDENTIFIER _v ->
                                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                            | Tokens.BOOLEAN ->
                                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.BITS ->
                                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.BIT ->
                                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.ARRAY ->
                                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | _ ->
                                _eRR ())
                        | Tokens.COLON ->
                            let _menhir_s = MenhirState1280 in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.STRING ->
                                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.REAL ->
                                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.LPAR ->
                                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.INTEGER ->
                                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.IDENTIFIER _v ->
                                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                            | Tokens.BOOLEAN ->
                                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.BITS ->
                                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.BIT ->
                                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | Tokens.ARRAY ->
                                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                            | _ ->
                                _eRR ())
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v ->
                _menhir_run_1197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1069 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_1, xs) = ((), _v) in
        let _v = _menhir_action_433 _1 _2_inlined1 x xs in
        _menhir_goto_separated_nonempty_list_COMMA_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_1065 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_1, xs) = ((), _v) in
        let _v = _menhir_action_434 _1 _2_inlined1 x xs in
        _menhir_goto_separated_nonempty_list_COMMA_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_1061 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_432 x xs in
        _menhir_goto_separated_nonempty_list_COMMA_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_1054 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER _menhir_cell0_SUBTYPES _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_loption___anonymous_22_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1055
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1055
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1055
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1055
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1055
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1055
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1055
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1055
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1055
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1308 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1312 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_RECORD _menhir_cell0_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_RECORD (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
        let (_1, _1_inlined2, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_470 _1 _1_inlined2 _endpos__3_ _startpos__1_ in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_goto_ty_decl : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty_decl (_menhir_stack, _menhir_s, _v) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SUBTYPES ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell0_SUBTYPES (_menhir_stack, _startpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v_0 ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_0, _startpos_1, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WITH ->
                    _menhir_run_1040 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1327
                | Tokens.SEMI_COLON ->
                    let _v_2 = _menhir_action_190 () in
                    _menhir_run_1328 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.SEMI_COLON ->
            let _v = _menhir_action_401 () in
            _menhir_goto_option_subtype_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_1316 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_EXCEPTION _menhir_cell0_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_EXCEPTION (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
        let (_1, _1_inlined2, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_472 _1 _1_inlined2 _endpos__3_ _startpos__1_ in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_1320 : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v_0 ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                _menhir_run_1320 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState1321
            | Tokens.RBRACE ->
                let (x, x_inlined1) = (_v, ()) in
                let _v = _menhir_action_210 x x_inlined1 in
                _menhir_goto_non_empty_trailing_list_COMMA_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let x = _v in
            let _v = _menhir_action_209 x in
            _menhir_goto_non_empty_trailing_list_COMMA_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_non_empty_trailing_list_COMMA_IDENTIFIER_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState1319 ->
            _menhir_run_1323 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState1321 ->
            _menhir_run_1322 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1323 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ENUMERATION _menhir_cell0_LBRACE -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_ENUMERATION (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _1_inlined2, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_468 _1 _1_inlined2 _endpos__3_ _startpos__1_ in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_1322 : type  ttv_stack. (ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, h, _, _) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_211 _2 h t in
        _menhir_goto_non_empty_trailing_list_COMMA_IDENTIFIER_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_1360 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1360, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1361
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1361
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1361
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1361
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1361
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1361
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1361
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1361
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1361
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1362 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1360
        | _ ->
            _eRR ()
    
    and _menhir_run_1352 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1352, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1353
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1353
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1353
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1353
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1353
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1353
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1353
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1353
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1353
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1354 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1352
        | _ ->
            _eRR ()
    
    and _menhir_run_1347 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1347, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1348
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1348
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1348
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1348
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1348
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1348
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1348
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1348
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1348
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1349 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1347
        | _ ->
            _eRR ()
    
    and _menhir_run_1339 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1339, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1340
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1340
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1340
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1340
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1340
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1340
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1340
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1340
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1340
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1341 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1339
        | _ ->
            _eRR ()
    
    and _menhir_run_1270 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1270, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1271
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1271
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1271
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1271
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1271
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1271
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1271
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1271
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1271
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1272 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1270
        | _ ->
            _eRR ()
    
    and _menhir_run_1264 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1264, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1265
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1265
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1265
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1265
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1265
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1265
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1265
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1265
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1265
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1266 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1264
        | _ ->
            _eRR ()
    
    and _menhir_run_1258 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1258, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1259
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1259
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1259
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1259
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1259
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1259
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1259
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1259
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1259
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1260 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1258
        | _ ->
            _eRR ()
    
    and _menhir_run_1253 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1253, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1254
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1254
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1254
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1254
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1254
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1254
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1254
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1254
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1254
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1255 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1253
        | _ ->
            _eRR ()
    
    and _menhir_run_1247 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1247, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1248
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1248
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1248
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1248
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1248
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1248
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1248
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1248
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1248
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1249 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1247
        | _ ->
            _eRR ()
    
    and _menhir_run_1217 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.BEGIN ->
            let _menhir_s = MenhirState1217 in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, _menhir_s, _endpos) in
            let _menhir_s = MenhirState1218 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.END ->
                _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1217
        | _ ->
            _eRR ()
    
    and _menhir_run_1184 : type  ttv_stack. (((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.BEGIN ->
            let _menhir_s = MenhirState1184 in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_BEGIN (_menhir_stack, _menhir_s, _endpos) in
            let _menhir_s = MenhirState1185 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.END ->
                _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1184
        | _ ->
            _eRR ()
    
    and _menhir_run_1175 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1175, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1176
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1176
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1176
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1176
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1176
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1176
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1176
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1176
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1176
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1177 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1175
        | _ ->
            _eRR ()
    
    and _menhir_run_1169 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1169, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1170
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1170
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1170
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1170
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1170
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1170
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1170
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1170
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1170
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1171 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1169
        | _ ->
            _eRR ()
    
    and _menhir_run_1163 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1163, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1164
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1164
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1164
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1164
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1164
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1164
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1164
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1164
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1164
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1165 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1163
        | _ ->
            _eRR ()
    
    and _menhir_run_1158 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1158, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1159
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1159
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1159
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1159
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1159
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1159
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1159
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1159
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1159
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1160 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1158
        | _ ->
            _eRR ()
    
    and _menhir_run_1152 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1152, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1153
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1153
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1153
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1153
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1153
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1153
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1153
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1153
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1153
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1154 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1152
        | _ ->
            _eRR ()
    
    and _menhir_run_1145 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1145, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1146
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1146
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1146
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1146
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1146
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1146
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1146
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1146
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1146
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1147 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1145
        | _ ->
            _eRR ()
    
    and _menhir_run_1139 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1139, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1140
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1140
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1140
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1140
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1140
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1140
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1140
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1140
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1140
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1141 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1139
        | _ ->
            _eRR ()
    
    and _menhir_run_1133 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1133, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1134
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1134
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1134
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1134
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1134
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1134
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1134
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1134
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1134
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1135 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1133
        | _ ->
            _eRR ()
    
    and _menhir_run_1128 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1128, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1129
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1129
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1129
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1129
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1129
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1129
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1129
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1129
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1129
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1130 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1128
        | _ ->
            _eRR ()
    
    and _menhir_run_1122 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS, _menhir_box_spec) _menhir_cell1_ty as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1122, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1123
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1123
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1123
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1123
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1123
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1123
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1123
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1123
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1123
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1124 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1122
        | _ ->
            _eRR ()
    
    and _menhir_run_1116 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1116, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1117
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1117
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1117
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1117
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1117
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1117
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1117
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1117
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1117
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1118 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1116
        | _ ->
            _eRR ()
    
    and _menhir_run_1111 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1111, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1112
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1112
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1112
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1112
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1112
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1112
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1112
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1112
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1112
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1148 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1111
        | _ ->
            _eRR ()
    
    and _menhir_run_1088 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1088, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1089
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1089
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1089
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1089
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1089
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1089
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1089
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1089
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1089
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1243 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1088
        | _ ->
            _eRR ()
    
    and _menhir_run_1034 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState1034, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1035
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1035
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1035
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1035
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1035
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1035
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1035
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1035
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1035
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1333 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1034
        | _ ->
            _eRR ()
    
    and _menhir_run_1027 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_lexpr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_lexpr (_menhir_stack, _, le, _startpos_le_) = _menhir_stack in
                let (_2, _2_inlined1, _endpos__2_inlined2_, e) = ((), (), _endpos_0, _v) in
                let _v = _menhir_action_364 _2 _2_inlined1 _endpos__2_inlined2_ _startpos_le_ e le in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1027
        | _ ->
            _eRR ()
    
    and _menhir_run_1021 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_REPEAT, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
                let MenhirCell0_REPEAT (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_ARROBASE_LOOPLIMIT (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _endpos__2_inlined1_, _3, _5, cond) = ((), (), _endpos_0, (), (), _v) in
                let _v = _menhir_action_394 _1 _1_inlined2 _2 _3 _5 _endpos__2_inlined1_ _startpos__1_ cond x in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1021
        | _ ->
            _eRR ()
    
    and _menhir_run_1013 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_WHILE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState1013) in
            let _menhir_s = MenhirState1014 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1013
        | _ ->
            _eRR ()
    
    and _menhir_run_1010 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.RPAR ->
            let _menhir_s = MenhirState1010 in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, _menhir_s, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_WHILE (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState1012 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.REPEAT ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_REPEAT (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState1018 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARROBASE_LOOPLIMIT ->
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1010
        | _ ->
            _eRR ()
    
    and _menhir_run_1005 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_ASSERT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_ASSERT (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _endpos__2_inlined1_, e) = ((), (), _endpos_0, _v) in
                let _v = _menhir_action_361 _1 _2 _endpos__2_inlined1_ _startpos__1_ e in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1005
        | _ ->
            _eRR ()
    
    and _menhir_run_0999 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_CASE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.OF ->
            let _menhir_stack = MenhirCell1_OF (_menhir_stack, MenhirState0999) in
            let _menhir_s = MenhirState1000 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHEN ->
                _menhir_run_0473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0999
        | _ ->
            _eRR ()
    
    and _menhir_run_0957 : type  ttv_stack. ((((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0957) in
            let _menhir_s = MenhirState0958 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0957
        | _ ->
            _eRR ()
    
    and _menhir_run_0955 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_DOWNTO as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_LOOPLIMIT (_menhir_stack, MenhirState0955) in
            let _menhir_s = MenhirState0956 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0955) in
            let _menhir_s = MenhirState0962 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0955
        | _ ->
            _eRR ()
    
    and _menhir_run_0945 : type  ttv_stack. ((((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0945) in
            let _menhir_s = MenhirState0946 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0945
        | _ ->
            _eRR ()
    
    and _menhir_run_0943 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_TO as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_LOOPLIMIT (_menhir_stack, MenhirState0943) in
            let _menhir_s = MenhirState0944 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0943) in
            let _menhir_s = MenhirState0950 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0943
        | _ ->
            _eRR ()
    
    and _menhir_run_0941 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.TO ->
            let _menhir_stack = MenhirCell1_TO (_menhir_stack, MenhirState0941) in
            let _menhir_s = MenhirState0942 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.DOWNTO ->
            let _menhir_stack = MenhirCell1_DOWNTO (_menhir_stack, MenhirState0941) in
            let _menhir_s = MenhirState0954 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0941
        | _ ->
            _eRR ()
    
    and _menhir_run_0935 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_IDENTIFIER (_menhir_stack, fld, _, _) = _menhir_stack in
                let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _2_inlined1, _4, _endpos__2_inlined2_, rhs) = ((), (), (), _endpos_0, _v) in
                let _v = _menhir_action_370 _1_inlined1 _2 _2_inlined1 _4 _endpos__2_inlined2_ _endpos_args_ _startpos_name_ args fld name rhs in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0935
        | _ ->
            _eRR ()
    
    and _menhir_run_0930 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
                let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _2_inlined1, _4, _2_inlined2, rhs, _endpos__2_inlined3_) = ((), (), (), (), _v, _endpos_0) in
                let _v = _menhir_action_373 _1_inlined1 _1_inlined3 _2 _2_inlined1 _2_inlined2 _4 _endpos__2_inlined3_ _endpos_args_ _startpos_name_ args name rhs x in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0930
        | _ ->
            _eRR ()
    
    and _menhir_run_0920 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, _menhir_box_opn) _menhir_cell1_loption_plist_expr__ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _2_inlined1, _endpos__2_inlined2_, rhs) = ((), (), _endpos_0, _v) in
                let _v = _menhir_action_367 _1_inlined1 _2 _2_inlined1 _endpos__2_inlined2_ _endpos_args_ _startpos_name_ args name rhs in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0920
        | _ ->
            _eRR ()
    
    and _menhir_run_0910 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_IDENTIFIER (_menhir_stack, fld, _, _) = _menhir_stack in
                let MenhirCell0_RPAR (_menhir_stack, _endpos__3_) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _2_inlined1, _4, _endpos__2_inlined2_, rhs) = ((), (), (), _endpos_0, _v) in
                let _v = _menhir_action_369 _1_inlined1 _2 _2_inlined1 _4 _endpos__2_inlined2_ _endpos__3_ _startpos_name_ fld name rhs in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0910
        | _ ->
            _eRR ()
    
    and _menhir_run_0905 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
                let MenhirCell0_RPAR (_menhir_stack, _endpos__3_) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _2_inlined1, _4, _2_inlined2, rhs, _endpos__2_inlined3_) = ((), (), (), (), _v, _endpos_0) in
                let _v = _menhir_action_372 _1_inlined1 _1_inlined3 _2 _2_inlined1 _2_inlined2 _4 _endpos__2_inlined3_ _endpos__3_ _startpos_name_ name rhs x in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0905
        | _ ->
            _eRR ()
    
    and _menhir_run_0895 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_RPAR (_menhir_stack, _endpos__3_) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _2_inlined1, _endpos__2_inlined2_, rhs) = ((), (), _endpos_0, _v) in
                let _v = _menhir_action_366 _1_inlined1 _2 _2_inlined1 _endpos__2_inlined2_ _endpos__3_ _startpos_name_ name rhs in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0895
        | _ ->
            _eRR ()
    
    and _menhir_run_0887 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_IDENTIFIER (_menhir_stack, fld, _, _) = _menhir_stack in
                let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _2_inlined1, _4, _endpos__2_inlined2_, rhs) = ((), (), (), _endpos_0, _v) in
                let _v = _menhir_action_368 _2 _2_inlined1 _4 _endpos__2_inlined2_ _endpos__3_ _startpos_name_ fld name rhs in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0887
        | _ ->
            _eRR ()
    
    and _menhir_run_0882 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined2) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
                let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _2_inlined1, _4, _2_inlined2, rhs, _endpos__2_inlined3_) = ((), (), (), (), _v, _endpos_0) in
                let _v = _menhir_action_371 _1_inlined2 _2 _2_inlined1 _2_inlined2 _4 _endpos__2_inlined3_ _endpos__3_ _startpos_name_ name rhs x in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0882
        | _ ->
            _eRR ()
    
    and _menhir_run_0872 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, _menhir_box_opn) _menhir_cell1_RPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _2_inlined1, _endpos__2_inlined2_, rhs) = ((), (), _endpos_0, _v) in
                let _v = _menhir_action_365 _2 _2_inlined1 _endpos__2_inlined2_ _endpos__3_ _startpos_name_ name rhs in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0872
        | _ ->
            _eRR ()
    
    and _menhir_run_0860 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState0860) in
            let _menhir_s = MenhirState0861 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0860
        | _ ->
            _eRR ()
    
    and _menhir_run_0814 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_REPEAT, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell1_REPEAT (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _2_inlined1, _1_inlined2, _3, _endpos__2_inlined2_) = ((), (), _v, (), (), _endpos_0) in
                let _v = _menhir_action_393 _1 _1_inlined1 _1_inlined2 _2 _2_inlined1 _3 _endpos__2_inlined2_ _startpos__1_ expr in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0814
        | _ ->
            _eRR ()
    
    and _menhir_run_0810 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_REPEAT, _menhir_box_opn) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell1_REPEAT (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _endpos__2_inlined1_, _3, expr) = ((), (), _endpos_0, (), _v) in
                let _v = _menhir_action_392 _1 _1_inlined1 _2 _3 _endpos__2_inlined1_ _startpos__1_ expr in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_LOOPLIMIT (_menhir_stack, MenhirState0810) in
            let _menhir_s = MenhirState0813 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0810
        | _ ->
            _eRR ()
    
    and _menhir_run_0804 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_RETURN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_RETURN (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _endpos__2_inlined1_, x) = ((), (), _endpos_0, _v) in
                let _v = _menhir_action_357 _1 _2 _endpos__2_inlined1_ _startpos__1_ x in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0804
        | _ ->
            _eRR ()
    
    and _menhir_run_0798 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_THROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell1_THROW (_menhir_stack, _, _startpos__1_) = _menhir_stack in
                let (_1, _2, _endpos__2_inlined1_, e) = ((), (), _endpos_0, _v) in
                let _v = _menhir_action_395 _1 _2 _endpos__2_inlined1_ _startpos__1_ e in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0798
        | _ ->
            _eRR ()
    
    and _menhir_run_0675 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_THROW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0676
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0675, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0676
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_THROW (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, e) = ((), _endpos_0, _v) in
                let _v = _menhir_action_285 _1 _endpos__2_ _startpos__1_ e in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0675
        | _ ->
            _eRR ()
    
    and _menhir_run_0671 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_RETURN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0672
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0671, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0672
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_RETURN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, x) = ((), _endpos_0, _v) in
                let _v = _menhir_action_247 _1 _endpos__2_ _startpos__1_ x in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0671
        | _ ->
            _eRR ()
    
    and _menhir_run_0667 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_REPEAT, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0668
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0667, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0668
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_LOOPLIMIT (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, expr, _, _) = _menhir_stack in
                let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2_inlined1, _1_inlined2, _3) = ((), _endpos_0, _v, (), ()) in
                let _v = _menhir_action_283 _1 _1_inlined1 _1_inlined2 _2_inlined1 _3 _endpos__2_ _startpos__1_ expr in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0667
        | _ ->
            _eRR ()
    
    and _menhir_run_0663 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_REPEAT, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0664
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0663, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0664
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _3, expr) = ((), _endpos_0, (), _v) in
                let _v = _menhir_action_282 _1 _1_inlined1 _3 _endpos__2_ _startpos__1_ expr in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_LOOPLIMIT (_menhir_stack, MenhirState0663) in
            let _menhir_s = MenhirState0666 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0663
        | _ ->
            _eRR ()
    
    and _menhir_run_0628 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_nonempty_list_stmt_, ttv_result) _menhir_cell1_ELSIF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState0628) in
            let _menhir_s = MenhirState0629 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0628
        | _ ->
            _eRR ()
    
    and _menhir_run_0623 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0624
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0623, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0624
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_IDENTIFIER (_menhir_stack, fld, _, _) = _menhir_stack in
                let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_endpos__2_, _2_inlined1, _4, rhs) = (_endpos_0, (), (), _v) in
                let _v = _menhir_action_260 _1_inlined1 _2_inlined1 _4 _endpos__2_ _endpos_args_ _startpos_name_ args fld name rhs in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0623
        | _ ->
            _eRR ()
    
    and _menhir_run_0618 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_loption_plist_expr__ _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0619
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0618, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0619
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
                let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_endpos__2_, _2_inlined1, _4, _2_inlined2, rhs) = (_endpos_0, (), (), (), _v) in
                let _v = _menhir_action_263 _1_inlined1 _1_inlined3 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos_args_ _startpos_name_ args name rhs x in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0618
        | _ ->
            _eRR ()
    
    and _menhir_run_0608 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_loption_plist_expr__ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0609
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0608, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0609
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_loption_plist_expr__ (_menhir_stack, _, args, _endpos_args_) = _menhir_stack in
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_endpos__2_, _2_inlined1, rhs) = (_endpos_0, (), _v) in
                let _v = _menhir_action_257 _1_inlined1 _2_inlined1 _endpos__2_ _endpos_args_ _startpos_name_ args name rhs in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0608
        | _ ->
            _eRR ()
    
    and _menhir_run_0598 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0599
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0598, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0599
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_IDENTIFIER (_menhir_stack, fld, _, _) = _menhir_stack in
                let MenhirCell0_RPAR (_menhir_stack, _endpos__3_) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_endpos__2_, _2_inlined1, _4, rhs) = (_endpos_0, (), (), _v) in
                let _v = _menhir_action_259 _1_inlined1 _2_inlined1 _4 _endpos__2_ _endpos__3_ _startpos_name_ fld name rhs in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0598
        | _ ->
            _eRR ()
    
    and _menhir_run_0593 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0594
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0593, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0594
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
                let MenhirCell0_RPAR (_menhir_stack, _endpos__3_) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_endpos__2_, _2_inlined1, _4, _2_inlined2, rhs) = (_endpos_0, (), (), (), _v) in
                let _v = _menhir_action_262 _1_inlined1 _1_inlined3 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos__3_ _startpos_name_ name rhs x in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0593
        | _ ->
            _eRR ()
    
    and _menhir_run_0583 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0584
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0583, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0584
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_RPAR (_menhir_stack, _endpos__3_) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_endpos__2_, _2_inlined1, rhs) = (_endpos_0, (), _v) in
                let _v = _menhir_action_256 _1_inlined1 _2_inlined1 _endpos__2_ _endpos__3_ _startpos_name_ name rhs in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0583
        | _ ->
            _eRR ()
    
    and _menhir_run_0575 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0576
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0575, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0576
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_IDENTIFIER (_menhir_stack, fld, _, _) = _menhir_stack in
                let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_endpos__2_, _2_inlined1, _4, rhs) = (_endpos_0, (), (), _v) in
                let _v = _menhir_action_258 _2_inlined1 _4 _endpos__2_ _endpos__3_ _startpos_name_ fld name rhs in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0575
        | _ ->
            _eRR ()
    
    and _menhir_run_0570 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ _menhir_cell0_RBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0571
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0570, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0571
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined2) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
                let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_endpos__2_, _2_inlined1, _4, _2_inlined2, rhs) = (_endpos_0, (), (), (), _v) in
                let _v = _menhir_action_261 _1_inlined2 _2_inlined1 _2_inlined2 _4 _endpos__2_ _endpos__3_ _startpos_name_ name rhs x in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0570
        | _ ->
            _eRR ()
    
    and _menhir_run_0560 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR, ttv_result) _menhir_cell1_RPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0561
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0560, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0561
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_RPAR (_menhir_stack, _, _endpos__3_) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_endpos__2_, _2_inlined1, rhs) = (_endpos_0, (), _v) in
                let _v = _menhir_action_255 _2_inlined1 _endpos__2_ _endpos__3_ _startpos_name_ name rhs in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0560
        | _ ->
            _eRR ()
    
    and _menhir_run_0549 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOWNTO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0549) in
            let _menhir_s = MenhirState0550 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0549
        | _ ->
            _eRR ()
    
    and _menhir_run_0547 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DOWNTO as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_LOOPLIMIT (_menhir_stack, MenhirState0547) in
            let _menhir_s = MenhirState0548 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0547) in
            let _menhir_s = MenhirState0554 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0547
        | _ ->
            _eRR ()
    
    and _menhir_run_0502 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR _menhir_cell0_REPEAT, ttv_result) _menhir_cell1_nonempty_list_stmt_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0503
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0502, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0503
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_nonempty_list_stmt_ (_menhir_stack, _, _1_inlined2, _) = _menhir_stack in
                let MenhirCell0_REPEAT (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
                let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
                let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_ARROBASE_LOOPLIMIT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _3, _5, cond) = ((), _endpos_0, (), (), _v) in
                let _v = _menhir_action_284 _1 _1_inlined2 _3 _5 _endpos__2_ _startpos__1_ cond x in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0502
        | _ ->
            _eRR ()
    
    and _menhir_run_0496 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_lexpr as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0497
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0496, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0497
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_lexpr (_menhir_stack, _menhir_s, le, _startpos_le_) = _menhir_stack in
                let (_endpos__2_, _2_inlined1, e) = (_endpos_0, (), _v) in
                let _v = _menhir_action_254 _2_inlined1 _endpos__2_ _startpos_le_ e le in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0496
        | _ ->
            _eRR ()
    
    and _menhir_run_0486 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR _menhir_cell0_WHILE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0486) in
            let _menhir_s = MenhirState0487 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0486
        | _ ->
            _eRR ()
    
    and _menhir_run_0483 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_ARROBASE_LOOPLIMIT _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.RPAR ->
            let _menhir_s = MenhirState0483 in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, _menhir_s, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_WHILE (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState0485 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.REPEAT ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_REPEAT (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState0499 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.VAR ->
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.UNREACHABLE ->
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.TRY ->
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.THROW ->
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.RETURN ->
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REPEAT ->
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRINT ->
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PRAGMA ->
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.PASS ->
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LET ->
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IF ->
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.FOR ->
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.DEBUG ->
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CONSTANT ->
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.CASE ->
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ASSERT ->
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARROBASE_LOOPLIMIT ->
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0483
        | _ ->
            _eRR ()
    
    and _menhir_run_0479 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_ASSERT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0480
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _menhir_stack = MenhirCell1_SEMI_COLON (_menhir_stack, MenhirState0479, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0480
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_ASSERT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, e) = ((), _endpos_0, _v) in
                let _v = _menhir_action_251 _1 _endpos__2_ _startpos__1_ e in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0479
        | _ ->
            _eRR ()
    
    and _menhir_run_0476 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_pattern_ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | Tokens.ARROW ->
            let _menhir_stack = MenhirCell1_ARROW (_menhir_stack, MenhirState0476) in
            let _menhir_s = MenhirState0477 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0476
        | _ ->
            _eRR ()
    
    and _menhir_run_0471 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_CASE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.OF ->
            let _menhir_stack = MenhirCell1_OF (_menhir_stack, MenhirState0471) in
            let _menhir_s = MenhirState0472 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHEN ->
                _menhir_run_0473 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0471
        | _ ->
            _eRR ()
    
    and _menhir_run_0455 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_TO, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0455) in
            let _menhir_s = MenhirState0456 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0455
        | _ ->
            _eRR ()
    
    and _menhir_run_0453 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_TO as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_LOOPLIMIT (_menhir_stack, MenhirState0453) in
            let _menhir_s = MenhirState0454 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0453) in
            let _menhir_s = MenhirState0542 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0453
        | _ ->
            _eRR ()
    
    and _menhir_run_0451 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_FOR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.TO ->
            let _menhir_stack = MenhirCell1_TO (_menhir_stack, MenhirState0451) in
            let _menhir_s = MenhirState0452 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.DOWNTO ->
            let _menhir_stack = MenhirCell1_DOWNTO (_menhir_stack, MenhirState0451) in
            let _menhir_s = MenhirState0546 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0451
        | _ ->
            _eRR ()
    
    and _menhir_run_0442 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState0442) in
            let _menhir_s = MenhirState0443 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0442
        | _ ->
            _eRR ()
    
    and _menhir_run_0414 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_lexpr_atom_desc as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_lexpr_atom_desc (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
            let (_2, _4, expr, _endpos__4_) = ((), (), _v, _endpos_0) in
            let _v = _menhir_action_129 _2 _4 _endpos_desc_ _startpos_desc_ desc expr in
            _menhir_goto_lexpr_atom_desc _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_desc_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0414
        | _ ->
            _eRR ()
    
    and _menhir_run_0359 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_WHILE, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LOOPLIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0359) in
            let _menhir_s = MenhirState0360 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0359
        | _ ->
            _eRR ()
    
    and _menhir_run_0357 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_WHILE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_LOOPLIMIT (_menhir_stack, MenhirState0357) in
            let _menhir_s = MenhirState0358 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0357) in
            let _menhir_s = MenhirState0732 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0357
        | _ ->
            _eRR ()
    
    and _menhir_run_0354 : type  ttv_stack. ((((ttv_stack, _menhir_box_opn) _menhir_cell1_WHILE, _menhir_box_opn) _menhir_cell1_expr, _menhir_box_opn) _menhir_cell1_LOOPLIMIT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0354) in
            let _menhir_s = MenhirState0355 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0354
        | _ ->
            _eRR ()
    
    and _menhir_run_0352 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_WHILE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.LOOPLIMIT ->
            let _menhir_stack = MenhirCell1_LOOPLIMIT (_menhir_stack, MenhirState0352) in
            let _menhir_s = MenhirState0353 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.DO ->
            let _menhir_stack = MenhirCell1_DO (_menhir_stack, MenhirState0352) in
            let _menhir_s = MenhirState0739 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0352
        | _ ->
            _eRR ()
    
    and _menhir_run_0341 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_NOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0341
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0341
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0341
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0341
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_048 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0340 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0340
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0340
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0340
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0340
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_047 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0335 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (x, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_066 _endpos__3_ _startpos__1_ x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0335) in
            let _menhir_s = MenhirState0337 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0335
        | _ ->
            _eRR ()
    
    and _menhir_run_0333 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.ELSIF ->
            _menhir_run_0178 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.ELSE ->
            _menhir_run_0182 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0333
        | _ ->
            _eRR ()
    
    and _menhir_run_0178 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _menhir_stack = MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos) in
        let _menhir_s = MenhirState0178 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0182 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_ELSE (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0182 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0331 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState0331) in
            let _menhir_s = MenhirState0332 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0331
        | _ ->
            _eRR ()
    
    and _menhir_run_0309 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0309
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0309
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0309
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0309
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_101 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0308 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0308
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_076 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0300 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0300
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_077 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0298 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0298
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_079 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0296 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0296
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_078 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0294 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0294
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_099 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0292 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0292
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0292
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0292
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0292
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_100 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0290 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0290
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0290
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0290
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0290
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0290
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0290
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_080 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0288 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0288
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0288
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0288
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0288
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0288
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0288
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_081 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0281 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0281
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_082 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0279 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0279
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_083 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0276 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern _menhir_cell0_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0276
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell0_GEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_086 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0274 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0274
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_085 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0272 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0272
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.IMPL | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_087 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0259 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern _menhir_cell0_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0259
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell0_LEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_089 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0256 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _4, e2, _endpos__4_) = ((), (), _v, _endpos_0) in
            let _v = _menhir_action_109 _2 _4 _endpos__4_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_e1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0256
        | _ ->
            _eRR ()
    
    and _menhir_run_0254 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0254
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_088 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0252 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0252
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell0_MINUS (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_091 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0250 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0250
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0250
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0250
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0250
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0250
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0250
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_092 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0248 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0248
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0248
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0248
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0248
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0248
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0248
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_093 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0246 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0246
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COMMA | Tokens.EQ_OP | Tokens.IMPL | Tokens.NEQ | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_084 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0243 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0243
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_094 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0241 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0241
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RPAR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_090 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0239 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0239
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0239
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0239
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0239
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_098 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0237 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0237
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0237
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0237
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0237
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0237
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0237
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_095 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0235 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0235
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0235
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0235
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0235
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0235
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0235
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_096 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0233 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0233
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0233
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0233
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0233
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0233
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0233
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_097 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0231 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0231
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_404 _2 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0219 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0219
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_GEQ (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_expr_, expr) = ((), _endpos, _v) in
            let _v = _menhir_action_407 _1 _endpos_expr_ _startpos__1_ expr in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0209 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0209) in
            let _menhir_s = MenhirState0210 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EQ ->
                    _menhir_run_0208 _menhir_stack _menhir_lexbuf _menhir_lexer
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0209
        | Tokens.RBRACE ->
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let y = _v in
            let _v = _menhir_action_421 x y in
            _menhir_goto_separated_nonempty_list_COMMA_field_assign_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_separated_nonempty_list_COMMA_field_assign_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState0194 ->
            _menhir_run_0213 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0210 ->
            _menhir_run_0212 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0979 ->
            _menhir_run_0199 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0840 ->
            _menhir_run_0199 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0760 ->
            _menhir_run_0199 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0710 ->
            _menhir_run_0199 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0436 ->
            _menhir_run_0199 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0465 ->
            _menhir_run_0199 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0197 ->
            _menhir_run_0199 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0213 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_1_inlined1, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_123 _1_inlined1 _endpos__3_ _endpos_desc_ _startpos_desc_ desc in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_0212 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, y, _, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_422 x xs y in
        _menhir_goto_separated_nonempty_list_COMMA_field_assign_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0199 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_1_inlined1, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_068 _1_inlined1 _endpos__3_ _endpos_desc_ _startpos_desc_ desc in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_0191 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0191) in
            let _menhir_s = MenhirState0192 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0191
        | Tokens.RBRACE | Tokens.RPAR | Tokens.SEMI_COLON ->
            let (_endpos_x_, x) = (_endpos, _v) in
            let _v = _menhir_action_419 x in
            _menhir_goto_separated_nonempty_list_COMMA_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_x_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_separated_nonempty_list_COMMA_expr_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState1083 ->
            _menhir_run_1274 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0989 ->
            _menhir_run_0990 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0981 ->
            _menhir_run_0985 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0967 ->
            _menhir_run_0971 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0913 ->
            _menhir_run_0914 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0867 ->
            _menhir_run_0890 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0850 ->
            _menhir_run_0851 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0842 ->
            _menhir_run_0846 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0827 ->
            _menhir_run_0830 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0818 ->
            _menhir_run_0822 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0770 ->
            _menhir_run_0771 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0762 ->
            _menhir_run_0766 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0720 ->
            _menhir_run_0721 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0712 ->
            _menhir_run_0716 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0401 ->
            _menhir_run_0657 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0405 ->
            _menhir_run_0653 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0642 ->
            _menhir_run_0643 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0438 ->
            _menhir_run_0638 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0601 ->
            _menhir_run_0602 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0445 ->
            _menhir_run_0578 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0458 ->
            _menhir_run_0535 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0525 ->
            _menhir_run_0526 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0467 ->
            _menhir_run_0521 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0337 ->
            _menhir_run_0338 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0019 ->
            _menhir_run_0329 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0194 ->
            _menhir_run_0215 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0203 ->
            _menhir_run_0205 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | MenhirState0979 ->
            _menhir_run_0201 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0840 ->
            _menhir_run_0201 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0760 ->
            _menhir_run_0201 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0710 ->
            _menhir_run_0201 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0436 ->
            _menhir_run_0201 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0465 ->
            _menhir_run_0201 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0197 ->
            _menhir_run_0201 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0192 ->
            _menhir_run_0193 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0187 ->
            _menhir_run_0189 _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1274 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1275
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1275
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1275
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1275
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1275
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1275
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1275
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1275
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1275
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1276 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0990 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_CONSTANT, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                _menhir_run_0203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0991
            | Tokens.SEMI_COLON ->
                let _v_1 = _menhir_action_200 () in
                _menhir_run_0992 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_0 _v_1 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0203 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE as 'stack) -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0203
        | Tokens.STRING_LIT _v ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0203
        | Tokens.RPAR ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let _endpos__3_ = _endpos in
            let _v = _menhir_action_201 () in
            _menhir_goto_loption_plist_expr__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
        | Tokens.REAL_LIT _v ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0203
        | Tokens.NOT ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0203
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0203
        | Tokens.LPAR ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0203
        | Tokens.INT_LIT _v ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0203
        | Tokens.IF ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0203
        | Tokens.IDENTIFIER _v ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0203
        | Tokens.BOOL_LIT _v ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0203
        | Tokens.BNOT ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0203
        | Tokens.BITVECTOR_LIT _v ->
            let _menhir_stack = MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos) in
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0203
        | _ ->
            _eRR ()
    
    and _menhir_goto_loption_plist_expr__ : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState0991 ->
            _menhir_run_0992 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0915 ->
            _menhir_run_0916 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0852 ->
            _menhir_run_0853 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0772 ->
            _menhir_run_0773 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0722 ->
            _menhir_run_0723 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0644 ->
            _menhir_run_0645 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0603 ->
            _menhir_run_0604 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0527 ->
            _menhir_run_0528 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok
        | MenhirState0216 ->
            _menhir_run_0217 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0202 ->
            _menhir_run_0207 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0916 : type  ttv_stack. (((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.EOF ->
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let (_2, _endpos__2_inlined1_, args) = ((), _endpos_0, _v) in
                let _v = _menhir_action_360 _1_inlined1 _2 _endpos__2_inlined1_ _startpos_name_ args name in
                _menhir_goto_opn _menhir_stack _v
            | _ ->
                _eRR ())
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState0919 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.COMMA ->
                        let _menhir_s = MenhirState0926 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EQ ->
                    let _menhir_s = MenhirState0934 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.UNKNOWN ->
                        _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.STRING_LIT _v ->
                        _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.REAL_LIT _v ->
                        _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.NOT ->
                        _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.MINUS ->
                        _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.LPAR ->
                        _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.INT_LIT _v ->
                        _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.IF ->
                        _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.IDENTIFIER _v ->
                        _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BOOL_LIT _v ->
                        _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BNOT ->
                        _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BITVECTOR_LIT _v ->
                        _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0723 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_COMMA, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0724
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0724
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2_inlined1, _3, _3_inlined1, _5, _endpos_args_, args) = ((), _endpos_0, (), (), (), (), _endpos, _v) in
                let _v = _menhir_action_276 _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0645 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_COMMA, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0646
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0646
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2_inlined1, _3, _3_inlined1, _5, _endpos_args_, args) = ((), _endpos_0, (), (), (), (), _endpos, _v) in
                let _v = _menhir_action_266 _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0604 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0605
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0605
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                let (_endpos__2_, args) = (_endpos_0, _v) in
                let _v = _menhir_action_250 _1_inlined1 _endpos__2_ _startpos_name_ args name in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.EQ ->
            let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState0607 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.IDENTIFIER _v ->
                    let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.COMMA ->
                        let _menhir_s = MenhirState0614 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EQ ->
                    let _menhir_s = MenhirState0622 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.UNKNOWN ->
                        _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.STRING_LIT _v ->
                        _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.REAL_LIT _v ->
                        _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.NOT ->
                        _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.MINUS ->
                        _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.LPAR ->
                        _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.INT_LIT _v ->
                        _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.IF ->
                        _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.IDENTIFIER _v ->
                        _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BOOL_LIT _v ->
                        _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BNOT ->
                        _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BITVECTOR_LIT _v ->
                        _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0528 : type  ttv_stack ttv_result. ((((((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_COMMA, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0529
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_loption_plist_expr__ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0529
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
                let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2_inlined1, _3, _3_inlined1, _5, _endpos_args_, args) = ((), _endpos_0, (), (), (), (), _endpos, _v) in
                let _v = _menhir_action_269 _1 _1_inlined1 _2_inlined1 _3 _3_inlined1 _5 _endpos__2_ _endpos_args_ _startpos__1_ _startpos_name_ args lhs name in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0217 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_endpos_args_, args) = (_endpos, _v) in
        let _v = _menhir_action_107 _1_inlined1 _endpos_args_ _startpos_name_ args name in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_args_ _startpos_name_ _v _menhir_s _tok
    
    and _menhir_run_0207 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _, _1_inlined1, _) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
        let (_endpos_args_, args) = (_endpos, _v) in
        let _v = _menhir_action_052 _1_inlined1 _endpos_args_ _startpos_name_ args name in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_args_ _startpos_name_ _v _menhir_s _tok
    
    and _menhir_run_0914 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                _menhir_run_0203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0915
            | Tokens.DOT | Tokens.EQ | Tokens.SEMI_COLON ->
                let _v_1 = _menhir_action_200 () in
                _menhir_run_0916 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_0 _v_1 MenhirState0915 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0890 : type  ttv_stack. ((ttv_stack, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EOF ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                    let (_2, _endpos__2_inlined1_, _1_inlined1) = ((), _endpos_1, _v) in
                    let _v = _menhir_action_359 _1_inlined1 _2 _endpos__2_inlined1_ _startpos_name_ name in
                    _menhir_goto_opn _menhir_stack _v
                | _ ->
                    _eRR ())
            | Tokens.EQ ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                let _menhir_s = MenhirState0894 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.DOT ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACKET ->
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.IDENTIFIER _v ->
                        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.COMMA ->
                            let _menhir_s = MenhirState0901 in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.IDENTIFIER _v ->
                                _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                            | _ ->
                                _eRR ())
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | Tokens.IDENTIFIER _v ->
                    let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.EQ ->
                        let _menhir_s = MenhirState0909 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.UNKNOWN ->
                            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.STRING_LIT _v ->
                            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.REAL_LIT _v ->
                            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.NOT ->
                            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.MINUS ->
                            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.LPAR ->
                            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.INT_LIT _v ->
                            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.IF ->
                            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BOOL_LIT _v ->
                            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BNOT ->
                            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.BITVECTOR_LIT _v ->
                            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0851 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_LET, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                _menhir_run_0203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0852
            | Tokens.SEMI_COLON ->
                let _v_1 = _menhir_action_200 () in
                _menhir_run_0853 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_0 _v_1 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0771 : type  ttv_stack. (((((ttv_stack, _menhir_box_opn) _menhir_cell1_VAR, _menhir_box_opn) _menhir_cell1_decl_item, _menhir_box_opn) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, _menhir_box_opn) _menhir_cell1_COMMA as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_opn) _menhir_state -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                _menhir_run_0203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0772
            | Tokens.SEMI_COLON ->
                let _v_1 = _menhir_action_200 () in
                _menhir_run_0773 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_0 _v_1 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0721 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_COMMA as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                _menhir_run_0203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0722
            | Tokens.SEMI_COLON ->
                let _v_1 = _menhir_action_200 () in
                _menhir_run_0723 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_0 _v_1 MenhirState0722 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0716 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.VAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.UNREACHABLE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.TRY ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.THROW ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.RETURN ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.REPEAT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.PRINT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.PRAGMA ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.PASS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.LET ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.IDENTIFIER _v_2 ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0718
                | Tokens.FOR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.DEBUG ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.CONSTANT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.CASE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.ASSERT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.ARROBASE_LOOPLIMIT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0718
                | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
                    let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                    let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                    let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                    let (_1, _endpos__2_, _2_inlined1, _1_inlined2, _3, _3_inlined1, _endpos__3_inlined2_) = ((), _endpos_1, (), _v, (), (), _endpos_0) in
                    let _v = _menhir_action_275 _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                    _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0657 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_PRINT _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.VAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.UNREACHABLE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.TRY ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.THROW ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.RETURN ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.REPEAT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.PRINT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.PRAGMA ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.PASS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.LET ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.IDENTIFIER _v_2 ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0659
                | Tokens.FOR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.DEBUG ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.CONSTANT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.CASE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.ASSERT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.ARROBASE_LOOPLIMIT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0659
                | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_PRINT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                    let (_1, _endpos__2_, _1_inlined2) = ((), _endpos_1, _v) in
                    let _v = _menhir_action_278 _1 _1_inlined2 _endpos__2_ _startpos__1_ in
                    _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0653 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_PRAGMA _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0654
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0654
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell0_IDENTIFIER (_menhir_stack, _2_inlined1, _, _) = _menhir_stack in
                let MenhirCell1_PRAGMA (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _endpos__1_inlined1_, _1_inlined1) = ((), _endpos_0, _endpos, _v) in
                let _v = _menhir_action_288 _1 _1_inlined1 _2_inlined1 _endpos__1_inlined1_ _endpos__2_ _startpos__1_ in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0643 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_COMMA as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                _menhir_run_0203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0644
            | Tokens.SEMI_COLON ->
                let _v_1 = _menhir_action_200 () in
                _menhir_run_0645 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_0 _v_1 MenhirState0644 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0638 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_LET, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.VAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.UNREACHABLE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.TRY ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.THROW ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.RETURN ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.REPEAT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.PRINT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.PRAGMA ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.PASS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.LET ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.IDENTIFIER _v_2 ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0640
                | Tokens.FOR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.DEBUG ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.CONSTANT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.CASE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.ASSERT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.ARROBASE_LOOPLIMIT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0640
                | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
                    let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                    let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                    let MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                    let (_1, _endpos__2_, _2_inlined1, _1_inlined2, _3, _3_inlined1, _endpos__3_inlined2_) = ((), _endpos_1, (), _v, (), (), _endpos_0) in
                    let _v = _menhir_action_265 _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                    _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0602 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                _menhir_run_0203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0603
            | Tokens.DOT | Tokens.EQ | Tokens.SEMI_COLON ->
                let _v_1 = _menhir_action_200 () in
                _menhir_run_0604 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_0 _v_1 MenhirState0603 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0578 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.VAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.UNREACHABLE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.TRY ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.THROW ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.RETURN ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.REPEAT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.PRINT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.PRAGMA ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.PASS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.LET ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.IDENTIFIER _v_2 ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0580
                | Tokens.FOR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.DEBUG ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.CONSTANT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.CASE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.ASSERT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.ARROBASE_LOOPLIMIT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0580
                | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
                    let (_endpos__2_, _1_inlined1) = (_endpos_1, _v) in
                    let _v = _menhir_action_249 _1_inlined1 _endpos__2_ _startpos_name_ name in
                    _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | Tokens.EQ ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                let _menhir_s = MenhirState0582 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.DOT ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACKET ->
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.IDENTIFIER _v ->
                        let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.COMMA ->
                            let _menhir_s = MenhirState0589 in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.IDENTIFIER _v ->
                                _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                            | _ ->
                                _eRR ())
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | Tokens.IDENTIFIER _v ->
                    let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                    let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.EQ ->
                        let _menhir_s = MenhirState0597 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.UNKNOWN ->
                            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.STRING_LIT _v ->
                            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.REAL_LIT _v ->
                            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.NOT ->
                            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.MINUS ->
                            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.LPAR ->
                            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.INT_LIT _v ->
                            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.IF ->
                            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BOOL_LIT _v ->
                            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BNOT ->
                            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.BITVECTOR_LIT _v ->
                            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0535 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_DEBUG _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.VAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.UNREACHABLE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.TRY ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.THROW ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.RETURN ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.REPEAT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.PRINT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.PRAGMA ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.PASS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.LET ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.IDENTIFIER _v_2 ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0537
                | Tokens.FOR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.DEBUG ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.CONSTANT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.CASE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.ASSERT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.ARROBASE_LOOPLIMIT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0537
                | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_DEBUG (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                    let (_1, _endpos__2_, _1_inlined2) = ((), _endpos_1, _v) in
                    let _v = _menhir_action_280 _1 _1_inlined2 _endpos__2_ _startpos__1_ in
                    _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0526 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_COMMA as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                _menhir_run_0203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0527
            | Tokens.SEMI_COLON ->
                let _v_1 = _menhir_action_200 () in
                _menhir_run_0528 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_0 _v_1 MenhirState0527 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0521 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_CONSTANT, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_RBRACE _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.WHILE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.VAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.UNREACHABLE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.TRY ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.THROW ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.RETURN ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.REPEAT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.PRINT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.PRAGMA ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.PASS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.LET ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.IDENTIFIER _v_2 ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2 MenhirState0523
                | Tokens.FOR ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.DEBUG ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.CONSTANT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.CASE ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.ASSERT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.ARROBASE_LOOPLIMIT ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
                    let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos_0) in
                    let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_1) in
                    _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0523
                | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                    let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_RBRACE (_menhir_stack, _, _) = _menhir_stack in
                    let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                    let MenhirCell1_IDENTIFIER (_menhir_stack, _, name, _startpos_name_, _) = _menhir_stack in
                    let MenhirCell1_decl_item (_menhir_stack, _, lhs) = _menhir_stack in
                    let MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                    let (_1, _endpos__2_, _2_inlined1, _1_inlined2, _3, _3_inlined1, _endpos__3_inlined2_) = ((), _endpos_1, (), _v, (), (), _endpos_0) in
                    let _v = _menhir_action_268 _1 _1_inlined2 _2_inlined1 _3 _3_inlined1 _endpos__2_ _endpos__3_inlined2_ _startpos__1_ _startpos_name_ lhs name in
                    _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0338 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_2, _endpos__3_, li) = ((), _endpos_0, _v) in
            let _v = _menhir_action_069 _2 _endpos__3_ _startpos__1_ li x in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0329 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (_1_inlined1, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_051 _1_inlined1 _endpos__3_ _startpos_name_ name in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0215 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                _menhir_run_0203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0216
            | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DOT | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
                let _v_1 = _menhir_action_200 () in
                _menhir_run_0217 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_0 _v_1 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0205 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_expr_ _menhir_cell0_RBRACE, ttv_result) _menhir_cell1_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _) = _menhir_stack in
            let (_1_inlined1, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_202 _1_inlined1 in
            _menhir_goto_loption_plist_expr__ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0201 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LBRACE as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_expr_ (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RBRACE ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                _menhir_run_0203 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0202
            | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
                let _v_1 = _menhir_action_200 () in
                _menhir_run_0207 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_0 _v_1 _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0193 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_endpos_xs_, xs) = (_endpos, _v) in
        let _v = _menhir_action_420 x xs in
        _menhir_goto_separated_nonempty_list_COMMA_expr_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_xs_ _v _menhir_s _tok
    
    and _menhir_run_0189 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER _menhir_cell0_LPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, name, _startpos_name_, _) = _menhir_stack in
            let (_1_inlined1, _endpos__3_) = (_v, _endpos_0) in
            let _v = _menhir_action_106 _1_inlined1 _endpos__3_ _startpos_name_ name in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_name_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0183 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSE as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0183
        | Tokens.ARROW | Tokens.BEGIN | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_ELSE (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, _endpos__2_, _2) = ((), _endpos, _v) in
            let _v = _menhir_action_012 _1 _2 in
            _menhir_goto_e_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_goto_e_else : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match _menhir_s with
        | MenhirState0333 ->
            _menhir_run_0334 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0177 ->
            _menhir_run_0185 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | MenhirState0181 ->
            _menhir_run_0184 _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0334 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e1, _, _) = _menhir_stack in
        let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e_else_, e_else) = ((), (), _endpos, _v) in
        let _v = _menhir_action_049 _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_else_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_0185 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e1, _, _) = _menhir_stack in
        let MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e_else_, e_else) = ((), (), _endpos, _v) in
        let _v = _menhir_action_104 _1 _3 _endpos_e_else_ _startpos__1_ e1 e2 e_else in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_else_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_0184 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_THEN (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, c, _, _) = _menhir_stack in
        let MenhirCell1_ELSIF (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _3, _endpos_e_else_, e_else) = ((), (), _endpos, _v) in
        let _v = _menhir_action_013 _1 _3 _endpos_e_else_ _startpos__1_ c e e_else in
        _menhir_goto_e_else _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_else_ _v _menhir_s _tok
    
    and _menhir_run_0181 : type  ttv_stack ttv_result. (((((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.ELSIF ->
            _menhir_run_0178 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.ELSE ->
            _menhir_run_0182 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0181
        | _ ->
            _eRR ()
    
    and _menhir_run_0179 : type  ttv_stack ttv_result. (((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_ELSIF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState0179) in
            let _menhir_s = MenhirState0180 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0179
        | _ ->
            _eRR ()
    
    and _menhir_run_0177 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_IF, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_THEN as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.ELSIF ->
            _menhir_run_0178 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.ELSE ->
            _menhir_run_0182 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0177
        | _ ->
            _eRR ()
    
    and _menhir_run_0175 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_IF as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.THEN ->
            let _menhir_stack = MenhirCell1_THEN (_menhir_stack, MenhirState0175) in
            let _menhir_s = MenhirState0176 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0175
        | _ ->
            _eRR ()
    
    and _menhir_run_0171 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0171
        | Tokens.ARROW | Tokens.COMMA | Tokens.RBRACE | Tokens.RPAR | Tokens.WHERE ->
            let MenhirCell1_LEQ (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_expr_, expr) = ((), _endpos, _v) in
            let _v = _menhir_action_406 _1 _endpos_expr_ _startpos__1_ expr in
            _menhir_goto_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_expr_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0167 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0167
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0167
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0167
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0167
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_MINUS (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_102 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0165 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_NOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0165
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0165
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0165
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0165
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEQ | Tokens.BOR | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OR | Tokens.PLUS | Tokens.POW | Tokens.RBRACE | Tokens.RDIV | Tokens.RPAR | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.WHERE ->
            let MenhirCell1_NOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_103 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0153 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0153) in
            let _menhir_s = MenhirState0154 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.COLON ->
                _menhir_run_0032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0153
        | Tokens.RBRACKET ->
            let MenhirCell1_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_438 _2 e1 e2 in
            _menhir_goto_separated_nonempty_list_COMMA_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_separated_nonempty_list_COMMA_slice_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState0416 ->
            _menhir_run_0417 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0031 ->
            _menhir_run_0326 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0324 ->
            _menhir_run_0325 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0260 ->
            _menhir_run_0261 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0154 ->
            _menhir_run_0155 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0150 ->
            _menhir_run_0151 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0148 ->
            _menhir_run_0149 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0144 ->
            _menhir_run_0145 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0047 ->
            _menhir_run_0048 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0417 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_lexpr_atom_desc -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_lexpr_atom_desc (_menhir_stack, _menhir_s, desc, _startpos_desc_, _endpos_desc_) = _menhir_stack in
        let (_1_inlined1, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_128 _1_inlined1 _endpos_desc_ _startpos_desc_ desc in
        _menhir_goto_lexpr_atom_desc _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_desc_ _v _menhir_s _tok
    
    and _menhir_run_0326 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LBRACKET -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_1_inlined1, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_053 _1_inlined1 _endpos__3_ _startpos_e_ e in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_0325 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_COLON, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e, _, _) = _menhir_stack in
        let MenhirCell1_COLON (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_1, xs) = ((), _v) in
        let _v = _menhir_action_445 _1 e xs in
        _menhir_goto_separated_nonempty_list_COMMA_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0261 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, e, _startpos_e_, _) = _menhir_stack in
        let (_1_inlined1, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_108 _1_inlined1 _endpos__3_ _startpos_e_ e in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_e_ _v _menhir_s _tok
    
    and _menhir_run_0155 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COLON, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_COLON (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
        let (_2_inlined1, xs) = ((), _v) in
        let _v = _menhir_action_443 _2_inlined1 e1 e2 xs in
        _menhir_goto_separated_nonempty_list_COMMA_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0151 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_442 expr xs in
        _menhir_goto_separated_nonempty_list_COMMA_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0149 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_PLUS_COLON, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_PLUS_COLON (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
        let (_2_inlined1, xs) = ((), _v) in
        let _v = _menhir_action_444 _2_inlined1 e1 e2 xs in
        _menhir_goto_separated_nonempty_list_COMMA_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0145 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_STAR_COLON, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_STAR_COLON (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
        let (_2_inlined1, xs) = ((), _v) in
        let _v = _menhir_action_446 _2_inlined1 e1 e2 xs in
        _menhir_goto_separated_nonempty_list_COMMA_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0048 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LBRACKET as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.IDENTIFIER _v_0 ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos_1 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_0, _startpos, _endpos_1) in
                let _startpos_2 = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_2) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACKET ->
                    _menhir_run_0047 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0051
                | Tokens.RBRACE ->
                    let _v_3 = _menhir_action_196 () in
                    _menhir_run_0053 _menhir_stack _menhir_lexbuf _menhir_lexer _v_3 MenhirState0051
                | _ ->
                    _eRR ())
            | Tokens.COMMA ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACKET ->
                    let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _menhir_s, _v) in
                    let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_0, _startpos, _endpos_1) in
                    _menhir_run_0047 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0057
                | Tokens.RBRACE ->
                    let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
                    let (x, _1_inlined1, x_inlined1) = (_v_0, _v, ()) in
                    let _v = _menhir_action_213 _1_inlined1 x x_inlined1 in
                    _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON_COLON ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_0, _startpos, _endpos_1) in
                let _menhir_s = MenhirState0059 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.COLON ->
                let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_RBRACKET (_menhir_stack, _endpos) in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v_0, _startpos, _endpos_1) in
                let _menhir_s = MenhirState0137 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.RBRACE ->
                let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
                let (x, _1_inlined1) = (_v_0, _v) in
                let _v = _menhir_action_212 _1_inlined1 x in
                _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0047 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s ->
        let _menhir_stack = MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) in
        let _menhir_s = MenhirState0047 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.UNKNOWN ->
            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.STRING_LIT _v ->
            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.REAL_LIT _v ->
            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.NOT ->
            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.INT_LIT _v ->
            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.IF ->
            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.COLON ->
            _menhir_run_0032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BOOL_LIT _v ->
            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.BNOT ->
            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.BITVECTOR_LIT _v ->
            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0053 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LBRACKET, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER _menhir_cell0_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _menhir_stack = MenhirCell1_loption_non_empty_trailing_list_COMMA_bitfield__ (_menhir_stack, _menhir_s, _v) in
                let _menhir_stack = MenhirCell0_RBRACE (_menhir_stack, _endpos) in
                _menhir_run_0047 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0055
            | Tokens.RBRACE ->
                let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
                let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
                let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_1_inlined3, x_inlined1) = (_v, ()) in
                let _v = _menhir_action_215 _1_inlined1 _1_inlined3 x x_inlined1 in
                _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
            let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
            let _1_inlined3 = _v in
            let _v = _menhir_action_214 _1_inlined1 _1_inlined3 x in
            _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState0139 ->
            _menhir_run_0140 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0135 ->
            _menhir_run_0136 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0057 ->
            _menhir_run_0058 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0055 ->
            _menhir_run_0056 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0046 ->
            _menhir_run_0052 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState0051 ->
            _menhir_run_0052 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0140 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LBRACKET, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_2, _1_inlined2, t) = ((), (), _v) in
        let _v = _menhir_action_222 _1_inlined1 _1_inlined2 _2 _2_inlined1 t x in
        _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0136 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LBRACKET, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_2, _1_inlined2, t) = ((), (), _v) in
        let _v = _menhir_action_223 _1_inlined1 _1_inlined2 _2 _2_inlined1 t x in
        _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0058 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_LBRACKET, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_220 _1_inlined1 _2 t x in
        _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0056 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LBRACKET, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER _menhir_cell0_LBRACE, ttv_result) _menhir_cell1_loption_non_empty_trailing_list_COMMA_bitfield__ _menhir_cell0_RBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell0_RBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_loption_non_empty_trailing_list_COMMA_bitfield__ (_menhir_stack, _, _1_inlined3) = _menhir_stack in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
        let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
        let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
        let (_2, t) = ((), _v) in
        let _v = _menhir_action_221 _1_inlined1 _1_inlined3 _2 t x in
        _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0052 : type  ttv_stack ttv_result. (ttv_stack _menhir_cell0_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let x = _v in
        let _v = _menhir_action_197 x in
        _menhir_goto_loption_non_empty_trailing_list_COMMA_bitfield__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_goto_loption_non_empty_trailing_list_COMMA_bitfield__ : type  ttv_stack ttv_result. (ttv_stack _menhir_cell0_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState0046 ->
            _menhir_run_0156 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0051 ->
            _menhir_run_0053 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0156 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR _menhir_cell0_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let (_1_inlined1, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_193 _1_inlined1 in
        _menhir_goto_loption_bitfields_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _tok
    
    and _menhir_goto_loption_bitfields_ : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RPAR -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_RPAR (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell0_LPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_BITS (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _1_inlined2, _endpos__1_inlined2_) = ((), _v, _endpos) in
        let _v = _menhir_action_462 _1 _1_inlined2 _endpos__1_inlined2_ _startpos__1_ x in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_inlined2_ _v _menhir_s _tok
    
    and _menhir_run_0147 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_PLUS_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0147) in
            let _menhir_s = MenhirState0148 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.COLON ->
                _menhir_run_0032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0147
        | Tokens.RBRACKET ->
            let MenhirCell1_PLUS_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_439 _2 e1 e2 in
            _menhir_goto_separated_nonempty_list_COMMA_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0143 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_STAR_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0143) in
            let _menhir_s = MenhirState0144 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.COLON ->
                _menhir_run_0032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0143
        | Tokens.RBRACKET ->
            let MenhirCell1_STAR_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_441 _2 e1 e2 in
            _menhir_goto_separated_nonempty_list_COMMA_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0141 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.STAR_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_STAR_COLON (_menhir_stack, MenhirState0141) in
            let _menhir_s = MenhirState0142 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.PLUS_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_PLUS_COLON (_menhir_stack, MenhirState0141) in
            let _menhir_s = MenhirState0146 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0141) in
            let _menhir_s = MenhirState0150 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.COLON ->
                _menhir_run_0032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COLON (_menhir_stack, MenhirState0141) in
            let _menhir_s = MenhirState0152 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0141
        | Tokens.RBRACKET ->
            let expr = _v in
            let _v = _menhir_action_437 expr in
            _menhir_goto_separated_nonempty_list_COMMA_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0128 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SLICING as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0128) in
            let _menhir_s = MenhirState0129 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0128
        | Tokens.RBRACE ->
            let MenhirCell1_SLICING (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
            let (_2, e2) = ((), _v) in
            let _v = _menhir_action_424 _2 e1 e2 in
            _menhir_goto_separated_nonempty_list_COMMA_int_constraint_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_separated_nonempty_list_COMMA_int_constraint_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState0009 ->
            _menhir_run_0342 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0302 ->
            _menhir_run_0304 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0131 ->
            _menhir_run_0132 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0129 ->
            _menhir_run_0130 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0122 ->
            _menhir_run_0124 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0342 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_INTEGER _menhir_cell0_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell0_LBRACE (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_INTEGER (_menhir_stack, _menhir_s, _startpos__1_, _) = _menhir_stack in
        let (_1, _1_inlined2, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_456 _1 _1_inlined2 _endpos__3_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_run_0304 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr_pattern, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _, _startpos__1_) = _menhir_stack in
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
        let (_2, _1_inlined1, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_114 _1_inlined1 _2 _endpos__3_ _startpos__1_ _startpos_sub_expr_ sub_expr in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_sub_expr_ _v _menhir_s _tok
    
    and _menhir_run_0132 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, expr, _, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_425 expr xs in
        _menhir_goto_separated_nonempty_list_COMMA_int_constraint_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0130 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SLICING, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COMMA -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_COMMA (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, e2, _, _) = _menhir_stack in
        let MenhirCell1_SLICING (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _, _) = _menhir_stack in
        let (_2_inlined1, xs) = ((), _v) in
        let _v = _menhir_action_426 _2_inlined1 e1 e2 xs in
        _menhir_goto_separated_nonempty_list_COMMA_int_constraint_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0124 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AS, ttv_result) _menhir_cell1_LBRACE -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LBRACE (_menhir_stack, _, _startpos__1_) = _menhir_stack in
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
        let (_2, _1_inlined1, _endpos__3_) = ((), _v, _endpos) in
        let _v = _menhir_action_059 _1_inlined1 _2 _endpos__3_ _startpos__1_ _startpos_sub_expr_ sub_expr in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _startpos_sub_expr_ _v _menhir_s _tok
    
    and _menhir_run_0126 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SLICING ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_SLICING (_menhir_stack, MenhirState0126) in
            let _menhir_s = MenhirState0127 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0126) in
            let _menhir_s = MenhirState0131 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0126
        | Tokens.RBRACE ->
            let expr = _v in
            let _v = _menhir_action_423 expr in
            _menhir_goto_separated_nonempty_list_COMMA_int_constraint_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0120 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BAND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0120
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BAND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_022 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0118 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0118
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_024 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0116 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_BOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0116
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_023 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0114 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_EQ_OP as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0114
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_EQ_OP (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_028 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0111 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_IMPL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0111
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_IMPL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_032 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0109 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_GEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0109
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_GEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_031 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0107 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_GT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0107
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_GT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_030 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0105 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0105
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_LEQ (_menhir_stack, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_034 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0103 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AND as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0103
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_AND (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_021 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0101 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_COLON_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0101
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_COLON_COLON (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_044 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0099 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_EOR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0099
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_EOR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_027 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0097 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0097
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_LT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_033 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0095 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MINUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0095
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_MINUS (_menhir_stack, _, _, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_036 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0093 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_NEQ as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0093
        | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EQ_OP | Tokens.IMPL | Tokens.LOOPLIMIT | Tokens.NEQ | Tokens.OF | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_NEQ (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_029 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0090 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_OR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0090
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_OR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_039 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0088 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0088
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0088
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0088
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0088
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0088
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0088
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_DIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_025 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0086 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_DIVRM as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0086
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0086
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0086
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0086
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0086
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0086
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_DIVRM (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_026 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0084 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MOD as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0084
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0084
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0084
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0084
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0084
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0084
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_MOD (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_037 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0082 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_MUL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0082
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0082
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0082
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0082
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0082
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0082
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_MUL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_038 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0080 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_PLUS as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0080
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_PLUS (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_035 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0075 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_CONCAT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0075
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0075
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0075
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0075
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_CONCAT (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_045 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0065 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RDIV as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0065
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0065
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0065
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0065
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0065
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0065
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_RDIV (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_040 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0063 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_ARRAY as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.RBRACKET ->
            let _menhir_s = MenhirState0063 in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RBRACKET (_menhir_stack, _menhir_s, _endpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.OF ->
                let _menhir_s = MenhirState0077 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.STRING ->
                    _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.REAL ->
                    _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INTEGER ->
                    _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOLEAN ->
                    _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITS ->
                    _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BIT ->
                    _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.ARRAY ->
                    _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0063
        | _ ->
            _eRR ()
    
    and _menhir_run_0044 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BITS _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.SHL ->
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.RPAR ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0044, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACE ->
                let _startpos_1 = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos_1) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.LBRACKET ->
                    _menhir_run_0047 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0046
                | Tokens.RBRACE ->
                    let _v_2 = _menhir_action_196 () in
                    _menhir_run_0156 _menhir_stack _menhir_lexbuf _menhir_lexer _v_2
                | _ ->
                    _eRR ())
            | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOT | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.IN | Tokens.LBRACKET | Tokens.LEQ | Tokens.LLBRACKET | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RECURSELIMIT | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.SUBTYPES | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
                let _endpos = _endpos_0 in
                let _v = _menhir_action_192 () in
                _menhir_goto_loption_bitfields_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok
            | _ ->
                _eRR ())
        | Tokens.RDIV ->
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.POW ->
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.PLUS ->
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.OR ->
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.NEQ ->
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.MUL ->
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.MOD ->
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.MINUS ->
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.LT ->
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.LLBRACKET ->
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.LEQ ->
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.LBRACKET ->
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.IN ->
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.IMPL ->
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.GT ->
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.GEQ ->
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.EQ_OP ->
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.EOR ->
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.DOT ->
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.DIVRM ->
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.DIV ->
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.CONCAT ->
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.COLON_COLON ->
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.BOR ->
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.BEQ ->
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.BAND ->
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.AS ->
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | Tokens.AND ->
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0044
        | _ ->
            _eRR ()
    
    and _menhir_run_0035 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SHL as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0035
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0035
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0035
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0035
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0035
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0035
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_SHL (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_041 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0033 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_COLON as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            let _menhir_stack = MenhirCell1_COMMA (_menhir_stack, MenhirState0033) in
            let _menhir_s = MenhirState0324 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.COLON ->
                _menhir_run_0032 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0033
        | Tokens.RBRACKET ->
            let MenhirCell1_COLON (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_1, e) = ((), _v) in
            let _v = _menhir_action_440 _1 e in
            _menhir_goto_separated_nonempty_list_COMMA_slice_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0030 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_POW as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0030
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0030
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0030
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0030
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_POW (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_043 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0028 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_SHR as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0028
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0028
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0028
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0028
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0028
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0028
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_SHR (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_1, _endpos_e2_, e2) = ((), _endpos, _v) in
            let _v = _menhir_action_042 _1 _endpos_e2_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e2_ _startpos_e1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_0026 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_LLBRACKET as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SHR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0027 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.SHL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0034 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.RRBRACKET ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            let MenhirCell1_LLBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_expr (_menhir_stack, _menhir_s, e1, _startpos_e1_, _) = _menhir_stack in
            let (_2, _4, e2, _endpos__4_) = ((), (), _v, _endpos_0) in
            let _v = _menhir_action_054 _2 _4 _endpos__4_ _startpos_e1_ e1 e2 in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__4_ _startpos_e1_ _v _menhir_s _tok
        | Tokens.RDIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0064 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.POW ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0029 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.PLUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0079 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.OR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0089 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.NEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0091 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.MUL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0081 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.MOD ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0083 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.MINUS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0094 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.LT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0096 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.LEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0104 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.IMPL ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0110 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.GT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0106 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.GEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.EQ_OP ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0112 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.EOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0098 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.DIVRM ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.DIV ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0087 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.CONCAT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0074 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.COLON_COLON ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.BOR ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0115 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.BEQ ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0117 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.BAND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0119 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.AS ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0121 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | Tokens.AND ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0102 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0026
        | _ ->
            _eRR ()
    
    and _menhir_run_0024 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_BNOT as 'stack) -> _ -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _startpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.LLBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0025 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0024
        | Tokens.LBRACKET ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0024
        | Tokens.IN ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0024
        | Tokens.DOT ->
            let _menhir_stack = MenhirCell1_expr (_menhir_stack, _menhir_s, _v, _startpos, _endpos) in
            _menhir_run_0066 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0024
        | Tokens.AND | Tokens.ARROW | Tokens.AS | Tokens.BAND | Tokens.BEGIN | Tokens.BEQ | Tokens.BOR | Tokens.COLON | Tokens.COLON_COLON | Tokens.COMMA | Tokens.CONCAT | Tokens.DIV | Tokens.DIVRM | Tokens.DO | Tokens.DOWNTO | Tokens.ELSE | Tokens.ELSIF | Tokens.EOR | Tokens.EQ_OP | Tokens.GEQ | Tokens.GT | Tokens.IMPL | Tokens.LEQ | Tokens.LOOPLIMIT | Tokens.LT | Tokens.MINUS | Tokens.MOD | Tokens.MUL | Tokens.NEQ | Tokens.OF | Tokens.OR | Tokens.PLUS | Tokens.PLUS_COLON | Tokens.POW | Tokens.RBRACE | Tokens.RBRACKET | Tokens.RDIV | Tokens.RPAR | Tokens.RRBRACKET | Tokens.SEMI_COLON | Tokens.SHL | Tokens.SHR | Tokens.SLICING | Tokens.STAR_COLON | Tokens.THEN | Tokens.TO | Tokens.WHERE ->
            let MenhirCell1_BNOT (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
            let (_1, _endpos_e_, e) = ((), _endpos, _v) in
            let _v = _menhir_action_046 _1 _endpos_e_ _startpos__1_ e in
            _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_e_ _startpos__1_ _v _menhir_s _tok
        | _ ->
            _eRR ()
    
    and _menhir_run_1356 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1357
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1357
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1357
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1357
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1357
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1357
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1357
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1357
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1357
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1358 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.EQ ->
            let _menhir_s = MenhirState1359 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1343 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1344
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1344
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1344
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1344
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1344
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1344
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1344
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1344
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1344
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1345 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.EQ ->
            let _menhir_s = MenhirState1346 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1335 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_VAR _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.VAR ->
                _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1336
            | Tokens.TYPE ->
                _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1336
            | Tokens.SETTER ->
                _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1336
            | Tokens.PRAGMA ->
                _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1336
            | Tokens.LET ->
                _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1336
            | Tokens.GETTER ->
                _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1336
            | Tokens.FUNC ->
                _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1336
            | Tokens.CONSTANT ->
                _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1336
            | Tokens.CONFIG ->
                _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1336
            | Tokens.EOF ->
                let _v_1 = _menhir_action_133 () in
                _menhir_run_1337 _menhir_stack _v_1
            | _ ->
                _eRR ())
        | Tokens.EQ ->
            let _menhir_s = MenhirState1338 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1332 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_TYPE _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok ->
        let _1 = _v in
        let _v = _menhir_action_467 _1 in
        _menhir_goto_ty_decl _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_1301 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BEGIN (_menhir_stack, _endpos) in
            let _menhir_s = MenhirState1302 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.END ->
                _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1293 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BEGIN (_menhir_stack, _endpos) in
            let _menhir_s = MenhirState1294 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.END ->
                _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1281 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BEGIN (_menhir_stack, _endpos) in
            let _menhir_s = MenhirState1282 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.END ->
                _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1268 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1269 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1262 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1263 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1251 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1252 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1245 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_LET _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1246 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1236 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BEGIN (_menhir_stack, _endpos) in
            let _menhir_s = MenhirState1237 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.END ->
                _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1215 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_separated_nonempty_list_COMMA_typed_identifier_ _menhir_cell0_RPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            let _menhir_s = MenhirState1216 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BEGIN (_menhir_stack, _endpos) in
            let _menhir_s = MenhirState1224 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.END ->
                _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1203 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState1204 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_1197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_449 _1 _2 x in
            _menhir_goto_separated_nonempty_list_COMMA_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_separated_nonempty_list_COMMA_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState1073 ->
            _menhir_run_1288 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState1093 ->
            _menhir_run_1233 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState1103 ->
            _menhir_run_1206 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState1204 ->
            _menhir_run_1205 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState1200 ->
            _menhir_run_1201 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1288 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.COLON_COLON ->
                    let _menhir_s = MenhirState1292 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.STRING ->
                        _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.REAL ->
                        _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.LPAR ->
                        _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.INTEGER ->
                        _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.IDENTIFIER _v ->
                        _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BOOLEAN ->
                        _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BITS ->
                        _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BIT ->
                        _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.ARRAY ->
                        _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | _ ->
                        _eRR ())
                | Tokens.COLON ->
                    let _menhir_s = MenhirState1300 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.STRING ->
                        _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.REAL ->
                        _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.LPAR ->
                        _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.INTEGER ->
                        _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.IDENTIFIER _v ->
                        _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BOOLEAN ->
                        _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BITS ->
                        _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BIT ->
                        _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.ARRAY ->
                        _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1233 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.ARROW ->
            let _menhir_s = MenhirState1235 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1206 : type  ttv_stack. (((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let _menhir_stack = MenhirCell1_separated_nonempty_list_COMMA_typed_identifier_ (_menhir_stack, _menhir_s, _v) in
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _menhir_stack = MenhirCell0_RPAR (_menhir_stack, _endpos) in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BEGIN (_menhir_stack, _endpos) in
            let _menhir_s = MenhirState1208 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.END ->
                _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.ARROW ->
            let _menhir_s = MenhirState1214 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1205 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_1, xs) = ((), _v) in
        let _v = _menhir_action_451 _1 _2_inlined1 x xs in
        _menhir_goto_separated_nonempty_list_COMMA_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_1201 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_1, xs) = ((), _v) in
        let _v = _menhir_action_452 _1 _2_inlined1 x xs in
        _menhir_goto_separated_nonempty_list_COMMA_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_1199 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState1200 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_1197 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_450 _1 _2 x in
            _menhir_goto_separated_nonempty_list_COMMA_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_1182 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_FUNC _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.RECURSELIMIT ->
            let _menhir_s = MenhirState1183 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BEGIN (_menhir_stack, _endpos) in
            let _menhir_s = MenhirState1191 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.END ->
                _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1173 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1174 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1167 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1168 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1156 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1157 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1150 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONSTANT _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1151 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1143 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1144 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1137 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1138 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1126 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1127 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1120 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_CONFIG _menhir_cell0_MINUS as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.EQ ->
            let _menhir_s = MenhirState1121 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1096 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_GETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BEGIN (_menhir_stack, _endpos) in
            let _menhir_s = MenhirState1097 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.END ->
                _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1078 : type  ttv_stack. ((((ttv_stack, _menhir_box_spec) _menhir_cell1_SETTER _menhir_cell0_IDENTIFIER, _menhir_box_spec) _menhir_cell1_loption_braced_nclist_opt_typed_identifier___ _menhir_cell0_LPAR, _menhir_box_spec) _menhir_cell1_RPAR _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.BEGIN ->
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _menhir_stack = MenhirCell0_BEGIN (_menhir_stack, _endpos) in
            let _menhir_s = MenhirState1079 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.END ->
                _menhir_run_0489 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_1067 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState1068 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_1059 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_430 _1 _2 x in
            _menhir_goto_separated_nonempty_list_COMMA_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_1063 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState1064 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                _menhir_run_1059 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let (_1, _2) = ((), _v) in
            let _v = _menhir_action_431 _1 _2 x in
            _menhir_goto_separated_nonempty_list_COMMA_opt_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_1048 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v_0 ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                _menhir_run_1042 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState1049
            | Tokens.RBRACE ->
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
                let (_1, _2_inlined1, x_inlined1) = ((), _v, ()) in
                let _v = _menhir_action_225 _1 _2_inlined1 x x_inlined1 in
                _menhir_goto_non_empty_trailing_list_COMMA_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let (_1, _2_inlined1) = ((), _v) in
            let _v = _menhir_action_224 _1 _2_inlined1 x in
            _menhir_goto_non_empty_trailing_list_COMMA_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_non_empty_trailing_list_COMMA_typed_identifier_ : type  ttv_stack. ttv_stack -> _ -> _ -> _ -> (ttv_stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState1315 ->
            _menhir_run_1051 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState1311 ->
            _menhir_run_1051 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState1041 ->
            _menhir_run_1051 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | MenhirState1049 ->
            _menhir_run_1050 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState1045 ->
            _menhir_run_1046 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1051 : type  ttv_stack. (ttv_stack _menhir_cell0_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        let x = _v in
        let _v = _menhir_action_199 x in
        _menhir_goto_loption_non_empty_trailing_list_COMMA_typed_identifier__ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_goto_loption_non_empty_trailing_list_COMMA_typed_identifier__ : type  ttv_stack. (ttv_stack _menhir_cell0_LBRACE as 'stack) -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState1315 ->
            _menhir_run_1316 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState1311 ->
            _menhir_run_1312 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState1041 ->
            _menhir_run_1052 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_1050 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_1, _2, t) = ((), (), _v) in
        let _v = _menhir_action_228 _1 _2 _2_inlined1 t x in
        _menhir_goto_non_empty_trailing_list_COMMA_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_1046 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER, _menhir_box_spec) _menhir_cell1_ty -> _ -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _, _2_inlined1, _) = _menhir_stack in
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
        let (_1, _2, t) = ((), (), _v) in
        let _v = _menhir_action_229 _1 _2 _2_inlined1 t x in
        _menhir_goto_non_empty_trailing_list_COMMA_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_1044 : type  ttv_stack. ((ttv_stack, _menhir_box_spec) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, _menhir_box_spec) _menhir_state -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v_0 ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                _menhir_run_1042 _menhir_stack _menhir_lexbuf _menhir_lexer _v_0 MenhirState1045
            | Tokens.RBRACE ->
                let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
                let (_1, _2_inlined1, x_inlined1) = ((), _v, ()) in
                let _v = _menhir_action_227 _1 _2_inlined1 x x_inlined1 in
                _menhir_goto_non_empty_trailing_list_COMMA_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, x, _, _) = _menhir_stack in
            let (_1, _2_inlined1) = ((), _v) in
            let _v = _menhir_action_226 _1 _2_inlined1 x in
            _menhir_goto_non_empty_trailing_list_COMMA_typed_identifier_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0702 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0703
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0703
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, x, _, _) = _menhir_stack in
                let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2_inlined1, _1_inlined2, _2_inlined2) = ((), _endpos_0, (), (), _v) in
                let _v = _menhir_action_272 _1 _1_inlined1 _1_inlined2 _2_inlined1 _2_inlined2 _endpos__2_ _startpos__1_ x in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0683 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_WHEN, ttv_result) _menhir_cell1_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
        match (_tok : MenhirBasics.token) with
        | Tokens.ARROW ->
            let _menhir_s = MenhirState0684 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0388 : type  ttv_stack ttv_result. ((((ttv_stack, ttv_result) _menhir_cell1_VAR, ttv_result) _menhir_cell1_IDENTIFIER, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_IDENTIFIER_ as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.SEMI_COLON ->
            let _endpos_0 = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.VAR ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.UNREACHABLE ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.TRY ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.THROW ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.RETURN ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.REPEAT ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.PRINT ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.PRAGMA ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.PASS ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.LET ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.IDENTIFIER _v_1 ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v_1 MenhirState0389
            | Tokens.FOR ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.DEBUG ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.CONSTANT ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.CASE ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.ASSERT ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.ARROBASE_LOOPLIMIT ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                let _menhir_stack = MenhirCell0_SEMI_COLON (_menhir_stack, _endpos_0) in
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0389
            | Tokens.CATCH | Tokens.ELSE | Tokens.ELSIF | Tokens.END | Tokens.EOF | Tokens.OTHERWISE | Tokens.UNTIL | Tokens.WHEN ->
                let MenhirCell1_separated_nonempty_list_COMMA_IDENTIFIER_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_IDENTIFIER (_menhir_stack, _, x, _, _) = _menhir_stack in
                let MenhirCell1_VAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
                let (_1, _endpos__2_, _2_inlined1, _1_inlined2, _2_inlined2) = ((), _endpos_0, (), (), _v) in
                let _v = _menhir_action_273 _1 _1_inlined1 _1_inlined2 _2_inlined1 _2_inlined2 _endpos__2_ _startpos__1_ x in
                _menhir_goto_nonempty_list_stmt_ _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__2_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    and _menhir_run_0380 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_decl_item_ _menhir_cell0_RPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_decl_item_ (_menhir_stack, _, li) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, x) = _menhir_stack in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (_2, _2_inlined1, _1_inlined1) = ((), _v, ()) in
        let _v = _menhir_action_007 _1_inlined1 _2 _2_inlined1 li x in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_0378 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LPAR, ttv_result) _menhir_cell1_decl_item, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_decl_item_ _menhir_cell0_RPAR -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell0_RPAR (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_separated_nonempty_list_COMMA_decl_item_ (_menhir_stack, _, li) = _menhir_stack in
        let MenhirCell1_decl_item (_menhir_stack, _, x) = _menhir_stack in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _) = _menhir_stack in
        let (_2, _2_inlined1, _1_inlined1) = ((), _v, ()) in
        let _v = _menhir_action_008 _1_inlined1 _2 _2_inlined1 li x in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_0372 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _1, _, _) = _menhir_stack in
        let (_2, _1_inlined1) = (_v, ()) in
        let _v = _menhir_action_003 _1 _1_inlined1 _2 in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_0370 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_IDENTIFIER -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_IDENTIFIER (_menhir_stack, _menhir_s, _1, _, _) = _menhir_stack in
        let (_2, _1_inlined1) = (_v, ()) in
        let _v = _menhir_action_004 _1 _1_inlined1 _2 in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_0366 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_MINUS -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_MINUS (_menhir_stack, _menhir_s, _, _) = _menhir_stack in
        let (_1, _2, _1_inlined1) = ((), _v, ()) in
        let _v = _menhir_action_005 _1 _1_inlined1 _2 in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_0364 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_MINUS -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _tok ->
        let MenhirCell1_MINUS (_menhir_stack, _menhir_s, _, _) = _menhir_stack in
        let (_1, _2, _1_inlined1) = ((), _v, ()) in
        let _v = _menhir_action_006 _1 _1_inlined1 _2 in
        _menhir_goto_decl_item _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s _tok
    
    and _menhir_run_0351 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_UNKNOWN -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_UNKNOWN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _1_inlined1, _endpos_ty_, ty) = ((), (), _endpos, _v) in
        let _v = _menhir_action_064 _1 _1_inlined1 _endpos_ty_ _startpos__1_ ty in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_0349 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_UNKNOWN -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_UNKNOWN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _1_inlined1, _endpos_ty_, ty) = ((), (), _endpos, _v) in
        let _v = _menhir_action_065 _1 _1_inlined1 _endpos_ty_ _startpos__1_ ty in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_0344 : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
            let _menhir_s = MenhirState0345 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.STRING ->
                _menhir_run_0004 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REAL ->
                _menhir_run_0005 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0006 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INTEGER ->
                _menhir_run_0008 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0040 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOLEAN ->
                _menhir_run_0041 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITS ->
                _menhir_run_0042 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BIT ->
                _menhir_run_0060 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARRAY ->
                _menhir_run_0061 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RPAR ->
            let x = _v in
            let _v = _menhir_action_447 x in
            _menhir_goto_separated_nonempty_list_COMMA_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_goto_separated_nonempty_list_COMMA_ty_ : type  ttv_stack ttv_result. ttv_stack -> _ -> _ -> _ -> (ttv_stack, ttv_result) _menhir_state -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s ->
        match _menhir_s with
        | MenhirState0006 ->
            _menhir_run_0347 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | MenhirState0345 ->
            _menhir_run_0346 _menhir_stack _menhir_lexbuf _menhir_lexer _v
        | _ ->
            _menhir_fail ()
    
    and _menhir_run_0347 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_LPAR -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
        let _tok = _menhir_lexer _menhir_lexbuf in
        let MenhirCell1_LPAR (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1_inlined1, _endpos__3_) = (_v, _endpos) in
        let _v = _menhir_action_464 _1_inlined1 _endpos__3_ _startpos__1_ in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__3_ _v _menhir_s _tok
    
    and _menhir_run_0346 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_ty -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _v ->
        let MenhirCell1_ty (_menhir_stack, _menhir_s, x, _) = _menhir_stack in
        let xs = _v in
        let _v = _menhir_action_448 x xs in
        _menhir_goto_separated_nonempty_list_COMMA_ty_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
    
    and _menhir_run_0306 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_expr_pattern -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_expr_pattern (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
        let (_2, _endpos_ty_, ty) = ((), _endpos, _v) in
        let _v = _menhir_action_112 _2 _endpos_ty_ _startpos_sub_expr_ sub_expr ty in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos_sub_expr_ _v _menhir_s _tok
    
    and _menhir_run_0161 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_UNKNOWN -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_UNKNOWN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _1_inlined1, _endpos_ty_, ty) = ((), (), _endpos, _v) in
        let _v = _menhir_action_119 _1 _1_inlined1 _endpos_ty_ _startpos__1_ ty in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_0159 : type  ttv_stack ttv_result. (ttv_stack, ttv_result) _menhir_cell1_UNKNOWN -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_UNKNOWN (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _1_inlined1, _endpos_ty_, ty) = ((), (), _endpos, _v) in
        let _v = _menhir_action_120 _1 _1_inlined1 _endpos_ty_ _startpos__1_ ty in
        _menhir_goto_expr_pattern _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos__1_ _v _menhir_s _tok
    
    and _menhir_run_0138 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LBRACKET, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                _menhir_run_0047 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0139
            | Tokens.RBRACE ->
                let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
                let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_2_inlined1, _1_inlined2, x_inlined1) = (_v, (), ()) in
                let _v = _menhir_action_217 _1_inlined1 _1_inlined2 _2_inlined1 x x_inlined1 in
                _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
            let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_2_inlined1, _1_inlined2) = (_v, ()) in
            let _v = _menhir_action_216 _1_inlined1 _1_inlined2 _2_inlined1 x in
            _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0134 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_LBRACKET, ttv_result) _menhir_cell1_separated_nonempty_list_COMMA_slice_ _menhir_cell0_RBRACKET _menhir_cell0_IDENTIFIER as 'stack) -> _ -> _ -> _ -> _ -> ('stack, ttv_result) _menhir_state -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _menhir_s _tok ->
        match (_tok : MenhirBasics.token) with
        | Tokens.COMMA ->
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LBRACKET ->
                let _menhir_stack = MenhirCell1_ty (_menhir_stack, _menhir_s, _v, _endpos) in
                _menhir_run_0047 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0135
            | Tokens.RBRACE ->
                let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
                let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
                let MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
                let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
                let (_2_inlined1, _1_inlined2, x_inlined1) = (_v, (), ()) in
                let _v = _menhir_action_219 _1_inlined1 _1_inlined2 _2_inlined1 x x_inlined1 in
                _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.RBRACE ->
            let MenhirCell0_IDENTIFIER (_menhir_stack, x, _, _) = _menhir_stack in
            let MenhirCell0_RBRACKET (_menhir_stack, _) = _menhir_stack in
            let MenhirCell1_separated_nonempty_list_COMMA_slice_ (_menhir_stack, _, _1_inlined1) = _menhir_stack in
            let MenhirCell1_LBRACKET (_menhir_stack, _menhir_s) = _menhir_stack in
            let (_2_inlined1, _1_inlined2) = (_v, ()) in
            let _v = _menhir_action_218 _1_inlined1 _1_inlined2 _2_inlined1 x in
            _menhir_goto_non_empty_trailing_list_COMMA_bitfield_ _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | _ ->
            _eRR ()
    
    and _menhir_run_0133 : type  ttv_stack ttv_result. ((ttv_stack, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_AS -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_AS (_menhir_stack, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _menhir_s, sub_expr, _startpos_sub_expr_, _) = _menhir_stack in
        let (_2, _endpos_ty_, ty) = ((), _endpos, _v) in
        let _v = _menhir_action_057 _2 _endpos_ty_ _startpos_sub_expr_ sub_expr ty in
        _menhir_goto_expr _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_ty_ _startpos_sub_expr_ _v _menhir_s _tok
    
    and _menhir_run_0078 : type  ttv_stack ttv_result. (((ttv_stack, ttv_result) _menhir_cell1_ARRAY, ttv_result) _menhir_cell1_expr, ttv_result) _menhir_cell1_RBRACKET -> _ -> _ -> _ -> _ -> _ -> ttv_result =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer _endpos _v _tok ->
        let MenhirCell1_RBRACKET (_menhir_stack, _, _) = _menhir_stack in
        let MenhirCell1_expr (_menhir_stack, _, x, _, _) = _menhir_stack in
        let MenhirCell1_ARRAY (_menhir_stack, _menhir_s, _startpos__1_) = _menhir_stack in
        let (_1, _endpos_t_, t, _3) = ((), _endpos, _v, ()) in
        let _v = _menhir_action_466 _1 _3 _endpos_t_ _startpos__1_ t x in
        _menhir_goto_ty _menhir_stack _menhir_lexbuf _menhir_lexer _endpos_t_ _v _menhir_s _tok
    
    let _menhir_run_0000 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_opn =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            let _menhir_s = MenhirState0000 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_WHILE (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState0001 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.VAR ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_VAR (_menhir_stack, MenhirState0000, _startpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_0362 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0743
            | Tokens.LPAR ->
                _menhir_run_0367 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0743
            | Tokens.IDENTIFIER _v ->
                let _startpos_0 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.COMMA ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0743, _v, _startpos_0, _endpos) in
                    let _menhir_s = MenhirState0745 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.IDENTIFIER _v ->
                        _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | _ ->
                        _eRR ())
                | Tokens.COLON_COLON ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0743, _v, _startpos_0, _endpos) in
                    _menhir_run_0369 _menhir_stack _menhir_lexbuf _menhir_lexer
                | Tokens.COLON ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0743, _v, _startpos_0, _endpos) in
                    _menhir_run_0371 _menhir_stack _menhir_lexbuf _menhir_lexer
                | Tokens.EQ | Tokens.SEMI_COLON ->
                    let _v =
                      let _1 = _v in
                      _menhir_action_009 _1
                    in
                    _menhir_run_0755 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0743 _tok
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.UNREACHABLE ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.RPAR ->
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.SEMI_COLON ->
                        let _endpos_3 = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.EOF ->
                            let (_startpos__1_, _1, _2, _2_inlined1, _3, _endpos__2_inlined2_) = (_startpos, (), (), (), (), _endpos_3) in
                            let _v = _menhir_action_391 _1 _2 _2_inlined1 _3 _endpos__2_inlined2_ _startpos__1_ in
                            _menhir_goto_opn _menhir_stack _v
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.TRY ->
            let _menhir_s = MenhirState0000 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_TRY (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState0784 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.THROW ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0795
            | Tokens.STRING_LIT _v ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0795
            | Tokens.SEMI_COLON ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EOF ->
                    let (_startpos__1_, _1, _2, _endpos__2_inlined1_) = (_startpos, (), (), _endpos) in
                    let _v = _menhir_action_396 _1 _2 _endpos__2_inlined1_ _startpos__1_ in
                    _menhir_goto_opn _menhir_stack _v
                | _ ->
                    _eRR ())
            | Tokens.REAL_LIT _v ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0795
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0795
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0795
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0795
            | Tokens.INT_LIT _v ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0795
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0795
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0795
            | Tokens.BOOL_LIT _v ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0795
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0795
            | Tokens.BITVECTOR_LIT _v ->
                let _menhir_stack = MenhirCell1_THROW (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0795
            | _ ->
                _eRR ())
        | Tokens.RETURN ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0801
            | Tokens.STRING_LIT _v ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0801
            | Tokens.SEMI_COLON ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EOF ->
                    let (_startpos__1_, _1, _2, _endpos__2_inlined1_) = (_startpos, (), (), _endpos) in
                    let _v = _menhir_action_356 _1 _2 _endpos__2_inlined1_ _startpos__1_ in
                    _menhir_goto_opn _menhir_stack _v
                | _ ->
                    _eRR ())
            | Tokens.REAL_LIT _v ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0801
            | Tokens.NOT ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0801
            | Tokens.MINUS ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0801
            | Tokens.LPAR ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0801
            | Tokens.INT_LIT _v ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0801
            | Tokens.IF ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0801
            | Tokens.IDENTIFIER _v ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0801
            | Tokens.BOOL_LIT _v ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0801
            | Tokens.BNOT ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0801
            | Tokens.BITVECTOR_LIT _v ->
                let _menhir_stack = MenhirCell1_RETURN (_menhir_stack, MenhirState0000, _startpos) in
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0801
            | _ ->
                _eRR ())
        | Tokens.REPEAT ->
            let _menhir_s = MenhirState0000 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_REPEAT (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState0807 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.WHILE ->
                _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.VAR ->
                _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.UNREACHABLE ->
                _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.TRY ->
                _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.THROW ->
                _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.RETURN ->
                _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.REPEAT ->
                _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRINT ->
                _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PRAGMA ->
                _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.PASS ->
                _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LET ->
                _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IF ->
                _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.FOR ->
                _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.DEBUG ->
                _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CONSTANT ->
                _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.CASE ->
                _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ASSERT ->
                _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.ARROBASE_LOOPLIMIT ->
                _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | _ ->
                _eRR ())
        | Tokens.PRINT ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _startpos_4 = _menhir_lexbuf.Lexing.lex_start_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0818
                | Tokens.STRING_LIT _v ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0818
                | Tokens.RPAR ->
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.SEMI_COLON ->
                        let _endpos_5 = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.EOF ->
                            let (_startpos__1_, _1, _2, _endpos__2_inlined1_) = (_startpos, (), (), _endpos_5) in
                            let _v = _menhir_action_387 _1 _2 _endpos__2_inlined1_ _startpos__1_ in
                            _menhir_goto_opn _menhir_stack _v
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | Tokens.REAL_LIT _v ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0818
                | Tokens.NOT ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0818
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0818
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0818
                | Tokens.INT_LIT _v ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0818
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0818
                | Tokens.IDENTIFIER _v ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0818
                | Tokens.BOOL_LIT _v ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0818
                | Tokens.BNOT ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0818
                | Tokens.BITVECTOR_LIT _v ->
                    let _menhir_stack = MenhirCell1_PRINT (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_4) in
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0818
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.PRAGMA ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos_6 = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0827
                | Tokens.STRING_LIT _v_7 ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_7 MenhirState0827
                | Tokens.SEMI_COLON ->
                    let _endpos_8 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.EOF ->
                        let (_startpos__1_, _1, _2, _endpos__2_inlined1_, _2_inlined1, _endpos__2_inlined2_) = (_startpos, (), (), _endpos, _v, _endpos_8) in
                        let _v = _menhir_action_397 _1 _2 _2_inlined1 _endpos__2_inlined1_ _endpos__2_inlined2_ _startpos__1_ in
                        _menhir_goto_opn _menhir_stack _v
                    | _ ->
                        _eRR ())
                | Tokens.REAL_LIT _v_9 ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_9 MenhirState0827
                | Tokens.NOT ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0827
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0827
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0827
                | Tokens.INT_LIT _v_10 ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_10 MenhirState0827
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0827
                | Tokens.IDENTIFIER _v_11 ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_11 MenhirState0827
                | Tokens.BOOL_LIT _v_12 ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_12 MenhirState0827
                | Tokens.BNOT ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0827
                | Tokens.BITVECTOR_LIT _v_13 ->
                    let _menhir_stack = MenhirCell1_PRAGMA (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos_6, _endpos) in
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_13 MenhirState0827
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.PASS ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.SEMI_COLON ->
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EOF ->
                    let (_startpos__1_, _1, _2, _endpos__2_inlined1_) = (_startpos, (), (), _endpos) in
                    let _v = _menhir_action_355 _1 _2 _endpos__2_inlined1_ _startpos__1_ in
                    _menhir_goto_opn _menhir_stack _v
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.MINUS ->
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0000
        | Tokens.LPAR ->
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0000
        | Tokens.LET ->
            let _menhir_s = MenhirState0000 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_LET (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState0836 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_0362 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0367 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0368 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.IF ->
            let _menhir_s = MenhirState0000 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_IF (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState0859 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.IDENTIFIER _v ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _startpos_14 = _menhir_lexbuf.Lexing.lex_start_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0867
                | Tokens.STRING_LIT _v_15 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v_15 MenhirState0867
                | Tokens.RPAR ->
                    let _endpos_16 = _menhir_lexbuf.Lexing.lex_curr_p in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.SEMI_COLON ->
                        let _endpos_17 = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.EOF ->
                            let (_2, _endpos__2_inlined1_, _startpos_name_, name) = ((), _endpos_17, _startpos, _v) in
                            let _v = _menhir_action_358 _2 _endpos__2_inlined1_ _startpos_name_ name in
                            _menhir_goto_opn _menhir_stack _v
                        | _ ->
                            _eRR ())
                    | Tokens.EQ ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0867, _endpos_16) in
                        let _menhir_s = MenhirState0871 in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.UNKNOWN ->
                            _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.STRING_LIT _v ->
                            _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.REAL_LIT _v ->
                            _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.NOT ->
                            _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.MINUS ->
                            _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.LPAR ->
                            _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.INT_LIT _v ->
                            _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.IF ->
                            _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.IDENTIFIER _v ->
                            _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BOOL_LIT _v ->
                            _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | Tokens.BNOT ->
                            _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                        | Tokens.BITVECTOR_LIT _v ->
                            _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                        | _ ->
                            _eRR ())
                    | Tokens.DOT ->
                        let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                        let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                        let _menhir_stack = MenhirCell1_RPAR (_menhir_stack, MenhirState0867, _endpos_16) in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.LBRACKET ->
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.IDENTIFIER _v ->
                                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                                let _tok = _menhir_lexer _menhir_lexbuf in
                                (match (_tok : MenhirBasics.token) with
                                | Tokens.COMMA ->
                                    let _menhir_s = MenhirState0878 in
                                    let _tok = _menhir_lexer _menhir_lexbuf in
                                    (match (_tok : MenhirBasics.token) with
                                    | Tokens.IDENTIFIER _v ->
                                        _menhir_run_0068 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                                    | _ ->
                                        _eRR ())
                                | _ ->
                                    _eRR ())
                            | _ ->
                                _eRR ())
                        | Tokens.IDENTIFIER _v ->
                            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                            let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                            let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                            let _tok = _menhir_lexer _menhir_lexbuf in
                            (match (_tok : MenhirBasics.token) with
                            | Tokens.EQ ->
                                let _menhir_s = MenhirState0886 in
                                let _tok = _menhir_lexer _menhir_lexbuf in
                                (match (_tok : MenhirBasics.token) with
                                | Tokens.UNKNOWN ->
                                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                                | Tokens.STRING_LIT _v ->
                                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                                | Tokens.REAL_LIT _v ->
                                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                                | Tokens.NOT ->
                                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                                | Tokens.MINUS ->
                                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                                | Tokens.LPAR ->
                                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                                | Tokens.INT_LIT _v ->
                                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                                | Tokens.IF ->
                                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                                | Tokens.IDENTIFIER _v ->
                                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                                | Tokens.BOOL_LIT _v ->
                                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                                | Tokens.BNOT ->
                                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                                | Tokens.BITVECTOR_LIT _v ->
                                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                                | _ ->
                                    _eRR ())
                            | _ ->
                                _eRR ())
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | Tokens.REAL_LIT _v_37 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v_37 MenhirState0867
                | Tokens.NOT ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0867
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0867
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0867
                | Tokens.INT_LIT _v_38 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v_38 MenhirState0867
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0867
                | Tokens.IDENTIFIER _v_39 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v_39 MenhirState0867
                | Tokens.BOOL_LIT _v_40 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v_40 MenhirState0867
                | Tokens.BNOT ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0867
                | Tokens.BITVECTOR_LIT _v_41 ->
                    let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_14) in
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v_41 MenhirState0867
                | _ ->
                    _eRR ())
            | Tokens.LBRACE ->
                let _menhir_stack = MenhirCell1_IDENTIFIER (_menhir_stack, MenhirState0000, _v, _startpos, _endpos) in
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LBRACE (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState0913 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | Tokens.DOT | Tokens.EQ | Tokens.LBRACKET | Tokens.LLBRACKET ->
                let (_menhir_s, _endpos__1_, _startpos__1_, _1) = (MenhirState0000, _endpos, _startpos, _v) in
                let _v = _menhir_action_127 _1 in
                _menhir_goto_lexpr_atom_desc _menhir_stack _menhir_lexbuf _menhir_lexer _endpos__1_ _startpos__1_ _v _menhir_s _tok
            | _ ->
                _eRR ())
        | Tokens.FOR ->
            let _menhir_s = MenhirState0000 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_FOR (_menhir_stack, _menhir_s, _startpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.IDENTIFIER _v ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _endpos = _menhir_lexbuf.Lexing.lex_curr_p in
                let _menhir_stack = MenhirCell0_IDENTIFIER (_menhir_stack, _v, _startpos, _endpos) in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.EQ ->
                    let _menhir_s = MenhirState0940 in
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.UNKNOWN ->
                        _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.STRING_LIT _v ->
                        _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.REAL_LIT _v ->
                        _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.NOT ->
                        _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.MINUS ->
                        _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.LPAR ->
                        _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.INT_LIT _v ->
                        _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.IF ->
                        _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.IDENTIFIER _v ->
                        _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BOOL_LIT _v ->
                        _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | Tokens.BNOT ->
                        _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                    | Tokens.BITVECTOR_LIT _v ->
                        _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                    | _ ->
                        _eRR ())
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.DEBUG ->
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _startpos_56 = _menhir_lexbuf.Lexing.lex_start_p in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0967
                | Tokens.STRING_LIT _v ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0967
                | Tokens.RPAR ->
                    let _tok = _menhir_lexer _menhir_lexbuf in
                    (match (_tok : MenhirBasics.token) with
                    | Tokens.SEMI_COLON ->
                        let _endpos_57 = _menhir_lexbuf.Lexing.lex_curr_p in
                        let _tok = _menhir_lexer _menhir_lexbuf in
                        (match (_tok : MenhirBasics.token) with
                        | Tokens.EOF ->
                            let (_startpos__1_, _1, _2, _endpos__2_inlined1_) = (_startpos, (), (), _endpos_57) in
                            let _v = _menhir_action_389 _1 _2 _endpos__2_inlined1_ _startpos__1_ in
                            _menhir_goto_opn _menhir_stack _v
                        | _ ->
                            _eRR ())
                    | _ ->
                        _eRR ())
                | Tokens.REAL_LIT _v ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0967
                | Tokens.NOT ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0967
                | Tokens.MINUS ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0967
                | Tokens.LPAR ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0967
                | Tokens.INT_LIT _v ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0967
                | Tokens.IF ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0967
                | Tokens.IDENTIFIER _v ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0967
                | Tokens.BOOL_LIT _v ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0967
                | Tokens.BNOT ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState0967
                | Tokens.BITVECTOR_LIT _v ->
                    let _menhir_stack = MenhirCell1_DEBUG (_menhir_stack, MenhirState0000, _startpos) in
                    let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos_56) in
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v MenhirState0967
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | Tokens.CONSTANT ->
            let _menhir_s = MenhirState0000 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_CONSTANT (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState0975 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.MINUS ->
                _menhir_run_0362 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0367 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0368 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.CASE ->
            let _menhir_s = MenhirState0000 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_CASE (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState0998 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.ASSERT ->
            let _menhir_s = MenhirState0000 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_ASSERT (_menhir_stack, _menhir_s, _startpos) in
            let _menhir_s = MenhirState1004 in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.UNKNOWN ->
                _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.STRING_LIT _v ->
                _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.REAL_LIT _v ->
                _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.NOT ->
                _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.MINUS ->
                _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.LPAR ->
                _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.INT_LIT _v ->
                _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.IF ->
                _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.IDENTIFIER _v ->
                _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BOOL_LIT _v ->
                _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | Tokens.BNOT ->
                _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
            | Tokens.BITVECTOR_LIT _v ->
                _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
            | _ ->
                _eRR ())
        | Tokens.ARROBASE_LOOPLIMIT ->
            let _menhir_s = MenhirState0000 in
            let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
            let _menhir_stack = MenhirCell1_ARROBASE_LOOPLIMIT (_menhir_stack, _menhir_s, _startpos) in
            let _tok = _menhir_lexer _menhir_lexbuf in
            (match (_tok : MenhirBasics.token) with
            | Tokens.LPAR ->
                let _startpos = _menhir_lexbuf.Lexing.lex_start_p in
                let _menhir_stack = MenhirCell0_LPAR (_menhir_stack, _startpos) in
                let _menhir_s = MenhirState1009 in
                let _tok = _menhir_lexer _menhir_lexbuf in
                (match (_tok : MenhirBasics.token) with
                | Tokens.UNKNOWN ->
                    _menhir_run_0002 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.STRING_LIT _v ->
                    _menhir_run_0010 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.REAL_LIT _v ->
                    _menhir_run_0011 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.NOT ->
                    _menhir_run_0013 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.MINUS ->
                    _menhir_run_0014 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.LPAR ->
                    _menhir_run_0015 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.INT_LIT _v ->
                    _menhir_run_0016 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.IF ->
                    _menhir_run_0017 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.IDENTIFIER _v ->
                    _menhir_run_0018 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BOOL_LIT _v ->
                    _menhir_run_0021 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | Tokens.BNOT ->
                    _menhir_run_0022 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
                | Tokens.BITVECTOR_LIT _v ->
                    _menhir_run_0023 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
                | _ ->
                    _eRR ())
            | _ ->
                _eRR ())
        | _ ->
            _eRR ()
    
    let _menhir_run_1030 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_spec =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.VAR ->
            _menhir_run_1031 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1030
        | Tokens.TYPE ->
            _menhir_run_1036 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1030
        | Tokens.SETTER ->
            _menhir_run_1056 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1030
        | Tokens.PRAGMA ->
            _menhir_run_1082 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1030
        | Tokens.LET ->
            _menhir_run_1085 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1030
        | Tokens.GETTER ->
            _menhir_run_1090 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1030
        | Tokens.FUNC ->
            _menhir_run_1100 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1030
        | Tokens.CONSTANT ->
            _menhir_run_1108 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1030
        | Tokens.CONFIG ->
            _menhir_run_1113 _menhir_stack _menhir_lexbuf _menhir_lexer MenhirState1030
        | Tokens.EOF ->
            let _v = _menhir_action_133 () in
            _menhir_run_1372 _menhir_stack _v
        | _ ->
            _eRR ()
    
    let _menhir_run_1374 : type  ttv_stack. ttv_stack -> _ -> _ -> _menhir_box_stmts =
      fun _menhir_stack _menhir_lexbuf _menhir_lexer ->
        let _menhir_s = MenhirState1374 in
        let _tok = _menhir_lexer _menhir_lexbuf in
        match (_tok : MenhirBasics.token) with
        | Tokens.WHILE ->
            _menhir_run_0356 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.VAR ->
            _menhir_run_0361 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.UNREACHABLE ->
            _menhir_run_0390 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.TRY ->
            _menhir_run_0394 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.THROW ->
            _menhir_run_0395 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.RETURN ->
            _menhir_run_0397 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.REPEAT ->
            _menhir_run_0399 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRINT ->
            _menhir_run_0400 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PRAGMA ->
            _menhir_run_0404 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.PASS ->
            _menhir_run_0407 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.MINUS ->
            _menhir_run_0409 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LPAR ->
            _menhir_run_0410 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.LET ->
            _menhir_run_0432 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IF ->
            _menhir_run_0441 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.IDENTIFIER _v ->
            _menhir_run_0444 _menhir_stack _menhir_lexbuf _menhir_lexer _v _menhir_s
        | Tokens.FOR ->
            _menhir_run_0448 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.DEBUG ->
            _menhir_run_0457 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CONSTANT ->
            _menhir_run_0461 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.CASE ->
            _menhir_run_0470 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ASSERT ->
            _menhir_run_0478 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | Tokens.ARROBASE_LOOPLIMIT ->
            _menhir_run_0481 _menhir_stack _menhir_lexbuf _menhir_lexer _menhir_s
        | _ ->
            _eRR ()
    
  end
  
  let stmts =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_stmts v = _menhir_run_1374 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let spec =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_spec v = _menhir_run_1030 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
  let opn =
    fun _menhir_lexer _menhir_lexbuf ->
      let _menhir_stack = () in
      let MenhirBox_opn v = _menhir_run_0000 _menhir_stack _menhir_lexbuf _menhir_lexer in
      v
  
end
